;;; GNU Guix --- Functional package management for GNU
;;; Copyright © 2013, 2014, 2015, 2016, 2022 Andreas Enge <andreas@enge.fr>
;;; Copyright © 2014 Eric Bavier <bavier@member.fsf.org>
;;; Copyright © 2015 Mark H Weaver <mhw@netris.org>
;;; Copyright © 2016 Roel Janssen <roel@gnu.org>
;;; Copyright © 2016, 2018, 2019, 2020, 2021 Efraim Flashner <efraim@flashner.co.il>
;;; Copyright © 2016 Federico Beffa <beffa@fbengineering.ch>
;;; Copyright © 2016 Thomas Danckaert <post@thomasdanckaert.be>
;;; Copyright © 2016-2023 Ricardo Wurmus <rekado@elephly.net>
;;; Copyright © 2017 Leo Famulari <leo@famulari.name>
;;; Copyright © 2017, 2020-2022 Marius Bakke <marius@gnu.org>
;;; Copyright © 2017, 2018, 2019, 2020 Tobias Geerinckx-Rice <me@tobias.gr>
;;; Copyright © 2018 Danny Milosavljevic <dannym+a@scratchpost.org>
;;; Copyright © 2018, 2020 Arun Isaac <arunisaac@systemreboot.net>
;;; Copyright © 2020 Vincent Legoll <vincent.legoll@gmail.com>
;;; Copyright © 2020, 2021 Paul Garlick <pgarlick@tourbillion-technology.com>
;;; Copyright © 2021, 2022 Maxim Cournoyer <maxim.cournoyer@gmail.com>
;;; Copyright © 2021-2024 Nicolas Goaziou <mail@nicolasgoaziou.fr>
;;; Copyright © 2021 Leo Le Bouter <lle-bout@zaclys.net>
;;; Copyright © 2021 Xinglu Chen <public@yoctocell.xyz>
;;; Copyright © 2021 Ivan Gankevich <i.gankevich@spbu.ru>
;;; Copyright © 2021 Julien Lepiller <julien@lepiller.eu>
;;; Copyright © 2021 Thiago Jung Bauermann <bauermann@kolabnow.com>
;;; Copyright © 2022 Simon South <simon@simonsouth.net>
;;; Copyright © 2022 Jack Hill <jackhill@jackhill.us>
;;; Copyright © 2022 Fabio Natali <me@fabionatali.com>
;;; Copyright © 2022 Philip McGrath <philip@philipmcgrath.com>
;;; Copyright © 2023 Thomas Albers Raviola <thomas@thomaslabs.org>
;;; Copyright © 2023 John Kehayias <john.kehayias@protonmail.com>
;;; Copyright © 2023 Dominik Delgado Steuter <d@delgado.nrw>
;;; Copyright © 2023 Timothy Sample <samplet@ngyro.com>
;;;
;;; This file is part of GNU Guix.
;;;
;;; GNU Guix is free software; you can redistribute it and/or modify it
;;; under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 3 of the License, or (at
;;; your option) any later version.
;;;
;;; GNU Guix is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.

(define-module (gnu packages tex)
  #:use-module ((guix licenses) #:prefix license:)
  #:use-module (guix gexp)
  #:use-module (guix packages)
  #:use-module (guix download)
  #:use-module (guix build-system copy)
  #:use-module (guix build-system gnu)
  #:use-module (guix build-system perl)
  #:use-module (guix build-system pyproject)
  #:use-module (guix build-system python)
  #:use-module (guix build-system qt)
  #:use-module (guix build-system trivial)
  #:use-module (guix build-system texlive)
  #:use-module (guix utils)
  #:use-module (guix deprecation)
  #:use-module (guix gexp)
  #:use-module (guix git-download)
  #:use-module (guix svn-download)
  #:use-module (gnu packages)
  #:use-module (gnu packages algebra)
  #:use-module (gnu packages aspell)
  #:use-module (gnu packages autotools)
  #:use-module (gnu packages bash)
  #:use-module (gnu packages boost)
  #:use-module (gnu packages compression)
  #:use-module (gnu packages cpp)
  #:use-module (gnu packages digest)
  #:use-module (gnu packages lisp)
  #:use-module (gnu packages fonts)
  #:use-module (gnu packages fontutils)
  #:use-module (gnu packages gd)
  #:use-module (gnu packages ghostscript)
  #:use-module (gnu packages graphviz)
  #:use-module (gnu packages groff)
  #:use-module (gnu packages gtk)
  #:use-module (gnu packages icu4c)
  #:use-module (gnu packages image)
  #:use-module (gnu packages java)
  #:use-module (gnu packages libreoffice)
  #:use-module (gnu packages lua)
  #:use-module (gnu packages maths)
  #:use-module (gnu packages multiprecision)
  #:use-module (gnu packages pdf)
  #:use-module (gnu packages perl)
  #:use-module (gnu packages perl-check)
  #:use-module (gnu packages pkg-config)
  #:use-module (gnu packages plotutils)
  #:use-module (gnu packages python)
  #:use-module (gnu packages python-xyz)
  #:use-module (gnu packages qt)
  #:use-module (gnu packages readline)
  #:use-module (gnu packages ruby)
  #:use-module (gnu packages shells)
  #:use-module (gnu packages tcl)
  #:use-module (gnu packages tls)
  #:use-module (gnu packages base)
  #:use-module (gnu packages gawk)
  #:use-module (gnu packages web)
  #:use-module (gnu packages xml)
  #:use-module (gnu packages xorg)
  #:use-module (gnu packages xdisorg)
  #:use-module (gnu packages texinfo)
  #:use-module (ice-9 ftw)
  #:use-module (ice-9 match)
  #:use-module ((srfi srfi-1) #:hide (zip)))

;;; Commentary:
;;;
;;; Guix provides two different TeX Live systems: one monolithic, the TEXLIVE
;;; package, and the other modular.  This module is about the latter.  It aims
;;; at being as faithful as possible to TeX Live distribution.  Yet, some of
;;; the packages defined here are Guix specific.  The following paragraphs
;;; describe them.
;;;
;;; Source for all TeX Live binaries is located in TEXLIVE-SOURCE, which is
;;; therefore the starting point of any TeX Live update.  This is first used
;;; to build TEXLIVE-LIBKPATHSEA and TEXLIVE-LIBPTEXENC.
;;;
;;; Both TEXLIVE-SOURCE and TEXLIVE-LIBKPATHSEA---which takes care of creating
;;; a search path for GUIX_TEXMF environment variable---are used to compile
;;; TEXLIVE-BIN.  In turn, TEXLIVE-BIN propagates TEXLIVE-SCRIPTS, which
;;; contains core scripts and related files, including "texlive.tldb"
;;; database.  TEXLIVE-BIN is a mandatory native input in the `texlive' build
;;; system.
;;;
;;; Then, the system builds its way towards regular TEXLIVE-LATEX-BIN package,
;;; which is a convenient native input---that can be ignored using
;;; `texlive-latex-bin?' keyword argument---for most TeX Live packages.  For
;;; obvious reasons, packages used to build TEXLIVE-LATEX-BIN must be set it
;;; to `#f'.
;;;
;;; The TEXLIVE-BIN package provides a few Web2C tools, Metafont and some TeX
;;; engines---i.e, TeX, pdfLaTeX, LuaTeX and LuaHBTeX.  The rest of the
;;; binaries are built in separate packages, from TEXLIVE-SOURCE, and possibly
;;; with the help of TEXLIVE-LIBKPATHSEA and TEXLIVE-LIBPTEXENC.  Those
;;; packages inherit their phases from TEXLIVE-BIN.  As a convention, the
;;; package named "texlive-NAME-bin" provides binaries for "texlive-NAME",
;;; TEXLIVE-LATEX-BIN being the obvious exception to this scheme.
;;;
;;; Unlike font map files, TeX formats are not built from a profile hook, as
;;; the process would be too time-consuming, e.g., when invoking "guix shell".
;;; Instead, those are generated when the corresponding package is built.  It
;;; is therefore not possible for the build system to take into consideration
;;; hyphenation rules installed after a given format has been built.  To work
;;; around this, all hyphenations rules are packed into
;;; TEXLIVE-HYPHEN-COMPLETE, and all formats, being built with it, include all
;;; rules right from the start.
;;;
;;; Any other "texlive-NAME" package matches "NAME" TeX Live package, as
;;; defined in the "texlive.tlpdb" database.
;;;
;;; The following piece of art illustrates the bootstrap process of the
;;; modular Guix TeX Live distribution.  All "texlive-" prefixes have been
;;; dropped for brevity.
;;;
;;;
;;;           ,-- libptexenc-----------------------.
;;;           |                                    |
;;;           |                                    |
;;;  source --|                    ,-- all "*-bin" minus latex-bin
;;;    |      |                    |   ___________________________
;;;    |      |                    |               |
;;;    |      `-- libkpathsea --.  |               |
;;;    |                        |--|    (inherit phases from bin)
;;;    `------------------------’  |
;;;                                |
;;;                                |
;;;                                `-- bin -- hyphen-complete, etc. -- latex-bin
;;;                                     |     _____________________
;;;  scripts --------(propagated)-------’               |
;;;                                                     |
;;;                                          (#:texlive-latex-bin? #f)
;;;
;;;
;;; Default font map files are updated in a profile hook (see
;;; `texlive-font-maps' in "profiles.scm").  However, this option is not
;;; available when building documentation for a package.  Consequently, this
;;; module also provides TEXLIVE-UPDMAP.CFG function, which creates a TeX Live
;;; tree with font map files updates.  It should be used exclusively for
;;; package definitions, as a native input.  It is possible to augment that
;;; tree, in particular with additional font packages.
;;;
;;;
;;; Notes about updating TeX Live distribution:
;;; -------------------------------------------
;;;
;;; Thanks to the `texlive' updater, the more tedious part of that task, i.e.,
;;; refreshing version strings, hashes, possibly locations and inputs, is
;;; automated.  Yet, the following additional steps are required, and they can
;;; keep one busy for a while:
;;;
;;; 1. First and foremost, run the updater:
;;;
;;;      ./pre-inst-env guix refresh -t texlive -u
;;;
;;;    This takes care of updating all binaries and all TeX Live packages,
;;;    barring "collections" and "schemes", in a single run.
;;;
;;; 2. Then delete packages absent from the new TeX Live version.  Those are
;;;    usually indicated by a failed update, or, more obviously, by their
;;;    outdated version in the module.
;;;
;;;    Since "collections" and "schemes" are not updated automatically, all
;;;    references to deleted packages must also be cleared from their
;;;    propagated inputs.
;;;
;;; 3. Conversely, import newly integrated packages with, e.g.,
;;;
;;;       ./pre-inst-env guix import texlive -r scheme-full
;;;
;;;    Those must be added to their respective "collections", too.
;;;
;;; 4. Handle inputs issues.  No updater is allowed to create an input field
;;;    in a package if it didn't exist beforehand.  `texlive' updater is no
;;;    exception; it cannot update, e.g., propagated inputs if the relative
;;;    package didn't propagate some inputs already.  Double check updater's
;;;    output, such issues are mentioned, and resolve them manually.
;;;
;;;    Likewise, look for `(list)' artefacts the updater may have scattered
;;;    throughout this module.  They usually appear when all elements have
;;;    been removed from an input field.  In this situation, for aesthetics,
;;;    the whole field can be suppressed.
;;;
;;; 5. Last, but not least, test and fix the new packages, progressively.  For
;;;    example, it is possible to consider the following packages as
;;;    milestones:
;;;
;;;      libkpathsea > bin > latex-bin > scheme-basic > scheme-small
;;;
;;;    Also, for good measure, it is advisable to check some common
;;;    "collections" such as "pictures" and (gulp!) "latexextra".
;;;
;;;    At this point, if all is fine, send the update to the ML and let the CI
;;;    sort the rest out.
;;;
;;;    Don't forget to pat yourself on the back!
;;;
;;;
;;; Code:

(define-syntax-rule (define-deprecated-package old-name name)
  "Define OLD-NAME as a deprecated package alias for NAME."
  (define-deprecated/public old-name name
    (deprecated-package (symbol->string 'old-name) name)))

(define-public texlive-source
  (package
    (name "texlive-source")
    (version "2024.2")
    (source
     (origin
       ;; This could be written as a SVN reference, but with a multi-reference
       ;; the package can benefit from the `texlive' updater.
       (method svn-multi-fetch)
       (uri (svn-multi-reference
             (url (string-append %texlive-repository
                                 "tags/texlive-" version "/Build/source"))
             (revision 70951)
             (locations (list "./"))))
       (file-name (git-file-name name version))
       (sha256
        (base32
         "1qrbdghbi0r43l4yparr3wld98pgb3fmbdwx7yb1hv8cx6wlwl9l"))))
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Source code for all TeX Live programs")
    (description
     "This package fetches the source for all TeX Live programs provided by
the TeX Live repository.  It is meant to be used as a source-only package; it
should not be installed in a profile.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-libkpathsea
  (package
    (name "texlive-libkpathsea")
    (version (package-version texlive-source))
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("kpathsea"))))))
    (build-system gnu-build-system)
    (arguments
     (list
      #:out-of-source? #t
      #:configure-flags
      #~(list "--disable-static"
              "--disable-native-texlive-build"
              "--enable-shared"
              "--with-banner-add=/GNU Guix"
              "--disable-all-pkgs"
              "--enable-kpathsea")
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'customize-texmf.cnf
            ;; The default "texmf.cnf" file is provided by this package.
            ;; Every variable of interest is set relatively to the GUIX_TEXMF
            ;; environment variable defined via a search path below.
            ;;
            ;; This phase must happen before the `configure' phase, because
            ;; the value of the TEXMFCNF variable is used at compile time to
            ;; generate "paths.h" file.
            (lambda _
              (substitute* "texk/kpathsea/texmf.cnf"
                (("^TEXMFROOT = .*") "TEXMFROOT = {$GUIX_TEXMF}/..\n")
                (("^TEXMFDIST = .*") "TEXMFDIST = {$GUIX_TEXMF}\n")
                ;; "ls-R" files are to be expected only in the TEXMFDIST
                ;; directories.  However, those are not always present, e.g.,
                ;; when building a package with `texlive-build-system' or when
                ;; generating a profile.  Since both situations need to be
                ;; handled, drop the "!!" prefixes.
                (("^TEXMF = .*")
                 "TEXMF = {$TEXMFCONFIG,$TEXMFVAR,$TEXMFHOME,$TEXMFSYSCONFIG,$TEXMFSYSVAR,$TEXMFDIST}\n")
                (("^TEXMFDBS = .*") "TEXMFDBS = {$TEXMFDIST}\n")
                ;; Ignore system-wide cache, which is not writable.  Use local
                ;; one instead, i.e. "$HOME/.texliveYYYY/texmf-var/".
                (("^TEXMFCACHE = .*") "TEXMFCACHE = $TEXMFVAR\n")
                ;; Set TEXMFCNF.  Since earlier values of variables have
                ;; precedence over later ones, insert the desired value first.
                (("^TEXMFCNF =")
                 (string-append
                  "TEXMFCNF = " #$output "/share/texmf-dist/web2c\n"
                  "TEXMFCNF ="))
                ;; Help TeX finding fonts installed on the system.
                (("^OSFONTDIR = .*") "OSFONTDIR = {$XDG_DATA_DIRS}\n")
                ;; Don't truncate lines.
                (("^error_line = .*$") "error_line = 254\n")
                (("^half_error_line = .*$") "half_error_line = 238\n")
                (("^max_print_line = .*$") "max_print_line = 1000\n"))))
          (add-after 'unpack 'patch-directory-traversal
            ;; When ST_NLINK_TRICK is set, kpathsea attempts to avoid work
            ;; when searching files by assuming that a directory with exactly
            ;; two links has no sub-directories.  This assumption does not
            ;; hold in our case, so some directories with symlinked
            ;; sub-directories would not be traversed.
            (lambda _
              (substitute* "texk/kpathsea/config.h"
                (("#define ST_NLINK_TRICK") ""))))
          (replace 'install
            (lambda _
              (with-directory-excursion "texk/kpathsea"
                (invoke "make" "install"))))
          (add-after 'install 'remove-documentation
            ;; Documentation is provided by TEXLIVE-KPATHSEA, in a dedicated
            ;; "doc" output.  Remove duplicates.
            (lambda _
              (with-directory-excursion #$output
                (for-each delete-file-recursively
                          '("share/info" "share/man"))))))))
    (native-search-paths
     (list (search-path-specification
            (variable "GUIX_TEXMF")
            (files '("share/texmf-dist")))))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Path searching library")
    (description
     "Kpathsea is a library whose purpose is to return a filename from a list
of user-specified directories similar to how shells look up executables.")
    (license license:lgpl2.1)))

(define-public texlive-libptexenc
  (package
    (name "texlive-libptexenc")
    (version (package-version texlive-source))
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs with-files?)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir
                       "."
                       (lambda (file)
                         (and (not (member file (append '("." "..") dirs)))
                              (or with-files?
                                  (eq? 'directory (stat:type (stat file))))))))))))
            (delete-other-directories "libs" '() #f)
            (delete-other-directories "utils" '() #f)
            ;; Tests require "texmf.cnf" to be present in the tree.  Also test
            ;; data is spread across multiple directories, which need to be
            ;; preserved.
            (delete-other-directories "texk"
                                      '("bibtex-x" "ptexenc" "kpathsea" "tests"
                                        "web2c")
                                      #f)
            (delete-other-directories "texk/web2c" '("tests") #t)
            (delete-other-directories "texk/bibtex-x" '("tests") #t)
            (with-directory-excursion "texk/kpathsea"
              (for-each
               delete-file-recursively
               (scandir "." (lambda (f)
                              (not (member f '("." ".." "texmf.cnf")))))))))))
    (build-system gnu-build-system)
    (arguments
     (list
      #:out-of-source? #t
      #:configure-flags
      #~(list "--disable-static"
              "--disable-native-texlive-build"
              "--enable-shared"
              "--with-banner-add=/GNU Guix"
              "--disable-all-pkgs")
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'install-missing-files
            ;; These two files are not installed (on purpose, see ChangeLog),
            ;; but are required nonetheless if this library is meant to be
            ;; used externally.
            (lambda _
              (with-directory-excursion "texk/ptexenc/ptexenc"
                (let ((inc (string-append #$output "/include/ptexenc")))
                  (for-each (lambda (f) (install-file f inc))
                            '("kanjicnv.h" "unicode-jp.h"))))))
          (replace 'check
            (lambda* (#:key tests? #:allow-other-keys)
              (when tests?
                (with-directory-excursion "texk/ptexenc"
                  (invoke "make" "check")))))
          (replace 'install
            (lambda* (#:key inputs #:allow-other-keys)
              (with-directory-excursion "texk/ptexenc"
                (invoke "make" "install")))))))
    (native-inputs (list pkg-config texlive-libkpathsea))
    (inputs (list libiconv))
    (home-page "http://tutimura.ath.cx/ptexlive/?ptexenc%2FDetails")
    (synopsis "Library for Japanese pTeX")
    (description
     "This package provides a library for Japanese pTeX and its surrounding tools.")
    (license license:gpl2)))

(define-public texlive-scripts
  (package
    (name "texlive-scripts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (string-append %texlive-repository
                                        "tags/texlive-" version "/Master/"))
                    (revision 70951)
                    (locations
                     (list "texmf-dist/doc/man/man1/fmtutil-sys.1"
                           "texmf-dist/doc/man/man1/fmtutil-sys.man1.pdf"
                           "texmf-dist/doc/man/man1/fmtutil-user.1"
                           "texmf-dist/doc/man/man1/fmtutil-user.man1.pdf"
                           "texmf-dist/doc/man/man1/fmtutil.1"
                           "texmf-dist/doc/man/man1/fmtutil.man1.pdf"
                           "texmf-dist/doc/man/man1/install-tl.1"
                           "texmf-dist/doc/man/man1/install-tl.man1.pdf"
                           "texmf-dist/doc/man/man1/mktexfmt.1"
                           "texmf-dist/doc/man/man1/mktexfmt.man1.pdf"
                           "texmf-dist/doc/man/man1/mktexlsr.1"
                           "texmf-dist/doc/man/man1/mktexlsr.man1.pdf"
                           "texmf-dist/doc/man/man1/mktexmf.1"
                           "texmf-dist/doc/man/man1/mktexmf.man1.pdf"
                           "texmf-dist/doc/man/man1/mktexpk.1"
                           "texmf-dist/doc/man/man1/mktexpk.man1.pdf"
                           "texmf-dist/doc/man/man1/mktextfm.1"
                           "texmf-dist/doc/man/man1/mktextfm.man1.pdf"
                           "texmf-dist/doc/man/man1/texhash.1"
                           "texmf-dist/doc/man/man1/texhash.man1.pdf"
                           "texmf-dist/doc/man/man1/tlmgr.1"
                           "texmf-dist/doc/man/man1/tlmgr.man1.pdf"
                           "texmf-dist/doc/man/man1/updmap-sys.1"
                           "texmf-dist/doc/man/man1/updmap-sys.man1.pdf"
                           "texmf-dist/doc/man/man1/updmap-user.1"
                           "texmf-dist/doc/man/man1/updmap-user.man1.pdf"
                           "texmf-dist/doc/man/man1/updmap.1"
                           "texmf-dist/doc/man/man1/updmap.man1.pdf"
                           "texmf-dist/doc/man/man5/fmtutil.cnf.5"
                           "texmf-dist/doc/man/man5/fmtutil.cnf.man5.pdf"
                           "texmf-dist/doc/man/man5/updmap.cfg.5"
                           "texmf-dist/doc/man/man5/updmap.cfg.man5.pdf"
                           "texmf-dist/dvips/tetex/"
                           "texmf-dist/fonts/enc/dvips/tetex/"
                           "texmf-dist/fonts/map/dvips/tetex/"
                           "texmf-dist/scripts/texlive/fmtutil-sys.sh"
                           "texmf-dist/scripts/texlive/fmtutil-user.sh"
                           "texmf-dist/scripts/texlive/fmtutil.pl"
                           "texmf-dist/scripts/texlive/mktexlsr.pl"
                           "texmf-dist/scripts/texlive/mktexmf"
                           "texmf-dist/scripts/texlive/mktexpk"
                           "texmf-dist/scripts/texlive/mktextfm"
                           "texmf-dist/scripts/texlive/tlmgr.pl"
                           "texmf-dist/scripts/texlive/updmap-sys.sh"
                           "texmf-dist/scripts/texlive/updmap-user.sh"
                           "texmf-dist/scripts/texlive/updmap.pl"
                           "texmf-dist/web2c/fmtutil-hdr.cnf"
                           "texmf-dist/web2c/updmap-hdr.cfg"
                           "texmf-dist/web2c/updmap.cfg"
                           "tlpkg/TeXLive/"
                           "tlpkg/gpg/"
                           "tlpkg/installer/config.guess"
                           "tlpkg/installer/curl/curl-ca-bundle.crt"
                           "tlpkg/texlive.tlpdb"))))
              (file-name (git-file-name name version))
              (sha256
               "0ld5nsns6ms639pig2l5989997n1hg0afs1wh8z9yi7mdhn2ak0p")))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system copy-build-system)
    (arguments
     (list
      #:imported-modules `(,@%copy-build-system-modules
                           (guix build texlive-build-system)
                           (guix build union))
      #:modules '((guix build copy-build-system)
                  ((guix build texlive-build-system) #:prefix tex:)
                  (guix build utils))
      #:install-plan
      #~'(("texmf-dist/dvips/"   "share/texmf-dist/dvips")
          ("texmf-dist/fonts/"   "share/texmf-dist/fonts")
          ("texmf-dist/scripts/" "share/texmf-dist/scripts")
          ("texmf-dist/web2c/"   "share/texmf-dist/web2c")
          ("tlpkg/"              "share/tlpkg"))
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'patch-scripts
            (lambda _
              ;; First patch shell scripts with ".sh" extension.
              (with-directory-excursion "texmf-dist"
                ((assoc-ref tex:%standard-phases 'patch-shell-scripts)))
              ;; Then patch scripts without such extension.
              (let ((dirs (map (compose dirname which)
                               (list "awk" "cat" "grep" "sed"))))
                (substitute*
                    (find-files "texmf-dist/scripts/" "^mktex(mf|pk|tfm)$")
                  (("^version=" m)
                   (format #false "PATH=\"~{~a:~}$PATH\"; export PATH~%~a"
                           dirs m))))
              ;; Make sure that fmtutil can find its Perl modules.
              (substitute* "texmf-dist/scripts/texlive/fmtutil.pl"
                (("\\$TEXMFROOT/")
                 (string-append #$output "/share/")))
              ;; Likewise for updmap.pl.
              (substitute* "texmf-dist/scripts/texlive/updmap.pl"
                (("\\$TEXMFROOT/tlpkg")
                 (string-append #$output "/share/tlpkg")))
              ;; Likewise for the tlmgr.
              (substitute* "texmf-dist/scripts/texlive/tlmgr.pl"
                ((".*\\$::installerdir = \\$Master.*" all)
                 (format #f "  $Master = ~s;~%~a"
                         (string-append #$output "/share")
                         all)))))
          (add-after 'install 'install-doc
            (lambda _
              (let ((doc (string-append #$output:doc "/share/texmf-dist/doc")))
                (mkdir-p doc)
                (copy-recursively "texmf-dist/doc/" doc))))
          (add-after 'install-doc 'link-scripts
            (lambda* (#:key outputs #:allow-other-keys)
              (with-directory-excursion "texmf-dist"
                (apply (assoc-ref tex:%standard-phases 'link-scripts)
                       (list #:outputs outputs
                             #:link-scripts
                             (find-files "scripts"))))
              (with-directory-excursion (string-append #$output "/bin")
                (symlink "fmtutil" "mktexfmt")))))))
    (inputs (list perl))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "TeX Live infrastructure programs")
    (description
     "This package provides core TeX Live scripts such as @code{updmap},
@code{fmtutil}, and @code{tlmgr}.  It is automatically installed alongside
@code{texlive-bin}.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-hyphen-complete
  (package
    (name "texlive-hyphen-complete")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/dehyph-exptl/"
                                     "doc/generic/elhyphen/"
                                     "doc/generic/huhyphen/"
                                     "doc/generic/hyph-utf8/"
                                     "doc/generic/ukrhyph/"
                                     "doc/luatex/hyph-utf8/"
                                     "source/generic/hyph-utf8/"
                                     "source/generic/ruhyphen/"
                                     "source/luatex/hyph-utf8/"
                                     "tex/generic/config/"
                                     "tex/generic/dehyph-exptl/"
                                     "tex/generic/dehyph/"
                                     "tex/generic/hyph-utf8/"
                                     "tex/generic/hyphen/"
                                     "tex/generic/ruhyphen/"
                                     "tex/generic/ukrhyph/"
                                     "tex/luatex/hyph-utf8/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18i12gzlss0myj3c0lb5i0xwpmcffanj1lwyq7pk59ss6mcax2y9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:texlive-latex-bin? #f
      #:tex-engine "tex"
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'remove-ruby-byebug-dependency
            ;; Avoid dependency on byebug to reduce package closure
            ;; significantly, see <https://issues.guix.gnu.org/55997>.
            (lambda _
              (substitute* "source/generic/hyph-utf8/lib/tex/hyphen/language.rb"
                (("require 'byebug'") ""))))
          (add-before 'build 'include-docstrip.tex
            (lambda* (#:key inputs native-inputs #:allow-other-keys)
              (let ((docstrip.tex
                     (search-input-file (or native-inputs inputs)
                                        "tex/latex/base/docstrip.tex")))
                (setenv "TEXINPUTS"
                        (string-append (dirname docstrip.tex) ":")))))
          (add-before 'build 'regenerate-converters
            (lambda _
              (let ((root (getcwd)))
                (for-each delete-file
                          (find-files "tex/generic/hyph-utf8/conversions/"))
                (with-directory-excursion "source/generic/hyph-utf8"
                  (substitute* "generate-converters.rb"
                    (("\\$path_root=File.*")
                     (string-append "$path_root=\"" root "\"\n"))
                    ;; Avoid error with newer Ruby.
                    (("#1\\{%") "#1{%%"))
                  (invoke "ruby" "generate-converters.rb")))))
          (add-before 'build 'regenerate-patterns
            (lambda* (#:key inputs #:allow-other-keys)
              (let* ((root (getcwd))
                     (hyph-utf8 (string-append root "/tex/generic/hyph-utf8"))
                     (loaders (string-append hyph-utf8 "/loadhyph"))
                     (patterns (string-append hyph-utf8 "/patterns/txt"))
                     (ptex (string-append hyph-utf8 "/patterns/ptex"))
                     (quote (string-append hyph-utf8 "/patterns/quote")))
                ;; Initial clean-up.  Some files are not generated and need to
                ;; be preserved.
                (for-each delete-file (find-files loaders))
                (let ((preserved (list "hyph-sr-cyrl.hyp.txt"
                                       "hyph-sr-cyrl.pat.txt"
                                       "hyph-de-1901.ec.tex"
                                       "hyph-de-1996.ec.tex"
                                       "hyph-ru.t2a.tex"
                                       "hyph-uk.t2a.tex"
                                       "hyph-zh-latn-pinyin.ec.tex")))
                  (for-each
                   (lambda (directory)
                     (for-each delete-file
                               (find-files directory
                                           (lambda (f _)
                                             (not (member (basename f)
                                                          preserved))))))
                   (list patterns ptex quote)))
                ;; Generate plain patterns.  Write to the local directory.
                ;; Install phase will take care of moving the files to the
                ;; output.
                (with-directory-excursion "source/generic/hyph-utf8/"
                  (substitute* "lib/tex/hyphen/path.rb"
                    (("^([[:blank:]]+)TeXROOT = .*" _ indent)
                     (string-append indent "TeXROOT = \"" root "\"\n")))
                  (substitute* "generate-plain-patterns.rb"
                    ;; Ruby 2 does not need this.
                    (("require 'unicode'") "")
                    (("File\\.join\\(PATH::TXT")
                     (string-append "File.join(\"" patterns "\""))
                    (("File\\.join\\(PATH::QUOTE")
                     (string-append "File.join(\"" quote "\"")))
                  (invoke "ruby" "generate-plain-patterns.rb")
                  ;; Build pattern loaders.
                  (substitute* "generate-pattern-loaders.rb"
                    (("File\\.join\\(PATH::LOADER")
                     (string-append "File.join(\"" loaders "\"")))
                  (invoke "ruby" "generate-pattern-loaders.rb")
                  ;; Build ptex patterns.
                  (substitute* "generate-ptex-patterns.rb"
                    (("File\\.join\\(PATH::PTEX")
                     (string-append "File.join(\"" ptex "\"")))
                  (invoke "ruby" "generate-ptex-patterns.rb"))))))))
    (native-inputs
     ;; TODO: Remove input labels on next rebuild cycle.
     `(("ruby" ,ruby-2.7)
       ("ruby-hydra-minimal" ,ruby-hydra-minimal/pinned)
       ;; Build phase requires "docstrip.tex" from TEXLIVE-LATEX.
       ;; However, adding this package to native inputs would initiate
       ;; a circular dependency.  To work around this, use TEXLIVE-LATEX
       ;; source, then add "docstrip.tex" to TEXINPUTS before build.
       ("_" ,(package-source texlive-latex))
       ("texlive-tex" ,texlive-tex)))
    (home-page "https://ctan.org/pkg/hyph-utf8")
    (synopsis "Hyphenation patterns expressed in UTF-8")
    (description
     "Modern native UTF-8 engines such as XeTeX and LuaTeX need hyphenation
patterns in UTF-8 format, whereas older systems require hyphenation patterns
in the 8-bit encoding of the font in use (such encodings are codified in the
LaTeX scheme with names like OT1, T2A, TS1, OML, LY1, etc).  The present
package offers a collection of conversions of existing patterns to UTF-8
format, together with converters for use with 8-bit fonts in older systems.

This Guix-specific package provides hyphenation patterns for all languages
supported in TeX Live.  It is a strict super-set of code{hyphen-base} package
and should be preferred to it whenever a package would otherwise depend on
@code{hyph-utf8}.")
    ;; Individual files each have their own license.  Most of these files are
    ;; independent hyphenation patterns.
    (license
     (list license:asl2.0
           license:bsd-3
           license:cc0
           license:expat
           license:gpl2
           license:gpl2+
           license:gpl3+
           license:knuth
           license:lgpl2.1
           license:lgpl2.1+
           license:lgpl3+
           license:lppl
           license:lppl1.0+
           license:lppl1.2+
           license:lppl1.3
           license:lppl1.3+
           license:lppl1.3a+
           license:mpl1.1
           license:public-domain
           license:wtfpl2
           (license:fsf-free
            "/tex/generic/hyph-utf8/patterns/tex/hyph-eu.tex")
           (license:non-copyleft
            "file:///tex/generic/hyph-utf8/patterns/tex/hyph-bg.tex"
            "Ancestral BSD variant")
           (license:non-copyleft
            "file:///tex/generic/hyph-utf8/patterns/tex/hyph-en-us.tex"
            "FSF all permissive license")
           (license:non-copyleft
            "/tex/generic/hyph-utf8/patterns/tex/hyph-no.tex"
            "FSF All permissive license")
           (license:non-copyleft
            "file:///tex/generic/hyph-utf8/patterns/tex/hyph-sa.tex")))))

(define-deprecated-package texlive-dehyph texlive-hyphen-complete)
(define-deprecated-package texlive-generic-dehyph-exptl texlive-hyphen-complete)
(define-deprecated-package texlive-generic-hyph-utf8 texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-afrikaans texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-ancientgreek texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-armenian texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-basque texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-belarusian texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-bulgarian texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-catalan texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-chinese texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-churchslavonic texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-coptic texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-croatian texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-czech texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-danish texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-dutch texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-english texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-esperanto texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-estonian texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-ethiopic texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-finnish texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-french texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-friulan texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-galician texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-georgian texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-german texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-greek texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-hungarian texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-icelandic texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-indic texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-indonesian texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-interlingua texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-irish texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-italian texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-kurmanji texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-latin texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-latvian texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-lithuanian texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-macedonian texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-mongolian texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-norwegian texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-occitan texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-pali texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-piedmontese texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-polish texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-portuguese texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-romanian texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-romansh texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-russian texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-sanskrit texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-schoolfinnish texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-serbian texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-slovak texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-slovenian texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-spanish texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-swedish texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-thai texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-turkish texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-turkmen texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-ukrainian texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-uppersorbian texlive-hyphen-complete)
(define-deprecated-package texlive-hyphen-welsh texlive-hyphen-complete)
(define-deprecated-package texlive-ruhyphen texlive-hyphen-complete)
(define-deprecated-package texlive-ukrhyph texlive-hyphen-complete)

(define-public texlive-bin
  (package
    (name "texlive-bin")
    (version (package-version texlive-source))
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file
                                                   (append '("." "..") dirs)))
                                      (eq? 'directory
                                           (stat:type (stat file)))))))))))
            ;; Delete bundled software, except Lua which cannot easily be used
            ;; as an external dependency, pplib and xpdf which aren't
            ;; supported as system libraries (see m4/kpse-xpdf-flags.m4).
            (delete-other-directories "libs" '("lua53" "luajit" "pplib" "xpdf"))
            ;; Remove all packages: they are installed through their
            ;; respective regular TeX Live package.
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("kpathsea" "tests" "web2c"))
            ;; Tests require the "texmf.cnf" file to still be present in the
            ;; tree.
            (with-directory-excursion "texk/kpathsea"
              (for-each
               delete-file-recursively
               (scandir "." (lambda (f)
                              (not (member f '("." ".." "texmf.cnf")))))))))))
    (build-system gnu-build-system)
    (arguments
     (list
      #:out-of-source? #t
      #:configure-flags
      #~(let ((kpathsea #$(this-package-input "texlive-libkpathsea")))
          (list "--with-banner-add=/GNU Guix"
                "--enable-shared"
                "--disable-native-texlive-build"
                "--disable-static"
                "--disable-linked-scripts"
                "--disable-all-pkgs"
                ;; Help locating external kpathsea.  For some reason
                ;; PKG-CONFIG is unable to find it.
                "--with-system-kpathsea"
                (format #f "--with-kpathsea-includes=~a/include" kpathsea)
                (format #f "--with-kpathsea-libdir=~a/lib" kpathsea)
                "--enable-web2c"
                ;; Disable web2c parts provided in their own packages.  See
                ;; "texk/web2c/ac/web2c.ac" in source.
                "--disable-aleph"
                "--disable-eptex"
                "--disable-euptex"
                "--disable-hitex"
                "--disable-luajithbtex"
                "--disable-luajittex"
                "--disable-mflua"
                "--disable-mfluajit"
                "--disable-mp"
                "--disable-pmp"
                "--disable-ptex"
                "--disable-upmp"
                "--disable-uptex"
                "--disable-web-progs"
                "--disable-xetex"))
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'locate-external-kpathsea
            ;; Despite our best efforts, the configure script below is not
            ;; able to find an external Kpathsea library.  Set include
            ;; directory when appropriate.
            (lambda _
              (when (file-exists? "texk/web2c/configure")
                (substitute* "texk/web2c/configure"
                  (("/usr/include /usr/local/include")
                   (string-append #$(this-package-input "texlive-libkpathsea")
                                  "/include"))))))
          ;; XXX: Fix a failing test where "kpsewhich" location is hard-coded
          ;; in the source tree.
          (add-after 'unpack 'fix-failing-test
            (lambda _
              (substitute* (find-files "texk/" "wcfname\\.test$")
                (("_kpsewhich=.*")
                 (format #f "_kpsewhich=~a/bin/kpsewhich\n"
                         #$(this-package-input "texlive-libkpathsea"))))))
          (add-after 'install 'maybe-clear-symlinks
            ;; XXX: No matter the combination of configure flags, process
            ;; insists on creating those dangling links, resulting in an error
            ;; during `validate-runpath' phase.
            ;;
            ;; Make it specific to TEXLIVE-BIN package by verifying the
            ;; existence of "tex" binary so that packages inheriting from this
            ;; one do not need to remove the phase.
            (lambda _
              (let ((bin (string-append #$output "/bin/")))
                (when (file-exists? (string-append bin "tex"))
                  (with-directory-excursion bin
                    (for-each delete-file
                              '("pbibtex" "pdvitype" "ppltotf" "ptftopl")))))))
          (add-after 'install 'remove-documentation
            ;; Documentation is provided by specific TeX Live packages, in
            ;; a dedicated "doc" output.  Ignore documentation generated when
            ;; building TEXLIVE-BIN and its derivatives.
            (lambda _
              (with-directory-excursion #$output
                (for-each (lambda (d)
                            (when (file-exists? d)
                              (delete-file-recursively d)))
                          '("share/info"
                            "share/man"
                            "share/texmf-dist/doc"))))))))
    (native-inputs (list perl pkg-config))
    (inputs
     (list fontconfig
           harfbuzz
           icu4c
           libpng
           libxt
           zlib
           zziplib))
    (propagated-inputs (list texlive-libkpathsea texlive-scripts))
    (synopsis "TeX Live, a package of the TeX typesetting system")
    (description
     "TeX Live provides a comprehensive TeX document production system.
It includes all the major TeX-related programs, macro packages, and fonts that
are free software, including support for many languages around the world.

This package contains some Web2C binaries and Metafont.  TeX engines, in
addition to TeX itself, are limited to LuaHBTeX, LuaTeX and pdfTeX.  For
a self-sufficient TeX installation, users are advised to add at least a TeX
Live collection or scheme package to their profile instead of this package.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))
    (home-page "https://www.tug.org/texlive/")))

;; This package must be located before `texlive-updmap.cfg' in the module.
(define-public texlive-scheme-basic
  (package
    (name "texlive-scheme-basic")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs (list texlive-collection-basic texlive-collection-latex))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Basic scheme (plain and latex)")
    (description
     "This is the basic TeX Live scheme: it is a small set of files sufficient
to typeset plain TeX or LaTeX documents in PostScript or PDF, using the
Computer Modern fonts.  This scheme corresponds to @code{collection-basic} and
@code{collection-latex}.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-deprecated-package texlive-base texlive-scheme-basic)

(define-public texlive-scheme-bookpub
  (package
    (name "texlive-scheme-bookpub")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-barcodes
           texlive-biber
           texlive-biblatex
           texlive-bookcover
           texlive-caption
           texlive-collection-basic
           texlive-collection-latex
           texlive-enumitem
           texlive-fontspec
           texlive-latexmk
           texlive-lipsum
           texlive-listings
           texlive-markdown
           texlive-memoir
           texlive-microtype
           texlive-minted
           texlive-novel
           texlive-octavo
           texlive-pdfpages
           texlive-pgf
           texlive-qrcode
           texlive-shapes
           texlive-titlesec
           texlive-tocloft
           texlive-tufte-latex
           texlive-willowtreebook))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Book publishing scheme (core LaTeX and add-ons)")
    (description
     "This is a book publishing scheme, containing core (Lua)LaTeX and
selected additional packages likely to be useful for non-technical book
publication.  It does not contain additional fonts (different books need
different fonts, and the packages are large), nor does it contain additional
mathematical or other technical packages.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-scheme-context
  (package
    (name "texlive-scheme-context")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-antt
           texlive-asana-math
           texlive-ccicons
           texlive-collection-context
           texlive-collection-metapost
           texlive-dejavu
           texlive-eulervm
           texlive-gentium-tug
           texlive-iwona
           texlive-kurier
           texlive-ly1
           texlive-manfnt-font
           texlive-marvosym
           texlive-mflogo-font
           texlive-poltawski
           texlive-pxfonts
           texlive-tex-gyre
           texlive-tex-gyre-math
           texlive-txfonts
           texlive-wasy
           texlive-xits))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "ConTeXt scheme")
    (description "This is the TeX Live scheme for installing ConTeXt.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-scheme-full
  (package
    (name "texlive-scheme-full")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-collection-basic
           texlive-collection-bibtexextra
           texlive-collection-binextra
           texlive-collection-context
           texlive-collection-fontsextra
           texlive-collection-fontsrecommended
           texlive-collection-fontutils
           texlive-collection-formatsextra
           texlive-collection-games
           texlive-collection-humanities
           texlive-collection-langarabic
           texlive-collection-langchinese
           texlive-collection-langcjk
           texlive-collection-langcyrillic
           texlive-collection-langczechslovak
           texlive-collection-langenglish
           texlive-collection-langeuropean
           texlive-collection-langfrench
           texlive-collection-langgerman
           texlive-collection-langgreek
           texlive-collection-langitalian
           texlive-collection-langjapanese
           texlive-collection-langkorean
           texlive-collection-langother
           texlive-collection-langpolish
           texlive-collection-langportuguese
           texlive-collection-langspanish
           texlive-collection-latex
           texlive-collection-latexextra
           texlive-collection-latexrecommended
           texlive-collection-luatex
           texlive-collection-mathscience
           texlive-collection-metapost
           texlive-collection-music
           texlive-collection-pictures
           texlive-collection-plaingeneric
           texlive-collection-pstricks
           texlive-collection-publishers
           texlive-collection-xetex))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "TeX Live full scheme (everything)")
    (description
     "This is the full TeX Live scheme: it installs everything available.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-scheme-gust
  (package
    (name "texlive-scheme-gust")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-amslatex-primer
           texlive-amstex
           texlive-antt
           texlive-bibtex8
           texlive-collection-basic
           texlive-collection-context
           texlive-collection-fontsrecommended
           texlive-collection-fontutils
           texlive-collection-langpolish
           texlive-collection-latex
           texlive-collection-latexrecommended
           texlive-collection-metapost
           texlive-collection-plaingeneric
           texlive-collection-xetex
           texlive-comment
           texlive-comprehensive
           texlive-concrete
           texlive-cyklop
           texlive-dvidvi
           texlive-dviljk
           texlive-fontinstallationguide
           texlive-gustprog
           texlive-impatient
           texlive-iwona
           texlive-metafont-beginners
           texlive-metapost-examples
           texlive-poltawski
           texlive-seetexk
           texlive-seminar
           texlive-tds
           texlive-tex4ht
           texlive-texdoc))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "GUST TeX Live scheme")
    (description
     "This is the GUST TeX Live scheme: it is a set of files sufficient to
typeset Polish plain TeX, LaTeX and ConTeXt documents in PostScript or PDF.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-scheme-medium
  (package
    (name "texlive-scheme-medium")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-collection-basic
           texlive-collection-binextra
           texlive-collection-context
           texlive-collection-fontsrecommended
           texlive-collection-fontutils
           texlive-collection-langczechslovak
           texlive-collection-langenglish
           texlive-collection-langeuropean
           texlive-collection-langfrench
           texlive-collection-langgerman
           texlive-collection-langitalian
           texlive-collection-langpolish
           texlive-collection-langportuguese
           texlive-collection-langspanish
           texlive-collection-latex
           texlive-collection-latexrecommended
           texlive-collection-luatex
           texlive-collection-mathscience
           texlive-collection-metapost
           texlive-collection-plaingeneric
           texlive-collection-xetex))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Small scheme with additional packages and languages")
    (description
     "This is the medium TeX Live collection: it contains plain TeX,
LaTeX, many recommended packages, and support for most European languages.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-scheme-minimal
  (package
    (name "texlive-scheme-minimal")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs (list texlive-collection-basic))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Minimal scheme (plain only)")
    (description
     "This is the minimal TeX Live scheme, with support for only plain
TeX. (No LaTeX macros.) LuaTeX is included because Lua scripts are used in TeX
Live infrastructure.  This scheme corresponds exactly to
@code{collection-basic}.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-scheme-small
  (package
    (name "texlive-scheme-small")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-babel-basque
           texlive-babel-czech
           texlive-babel-danish
           texlive-babel-dutch
           texlive-babel-english
           texlive-babel-finnish
           texlive-babel-french
           texlive-babel-german
           texlive-babel-hungarian
           texlive-babel-italian
           texlive-babel-norsk
           texlive-babel-polish
           texlive-babel-portuges
           texlive-babel-spanish
           texlive-babel-swedish
           texlive-collection-basic
           texlive-collection-latex
           texlive-collection-latexrecommended
           texlive-collection-metapost
           texlive-collection-xetex
           texlive-ec
           texlive-eurosym
           texlive-hyphen-complete
           texlive-lm
           texlive-lualibs
           texlive-luaotfload
           texlive-luatexbase
           texlive-revtex
           texlive-synctex
           texlive-times
           texlive-tipa
           texlive-ulem
           texlive-upquote
           texlive-zapfding))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Small scheme (basic, XeTeX, Metapost, and a few languages)")
    (description
     "This is a small TeX Live scheme, corresponding to MacTeX's BasicTeX
variant.  It adds XeTeX, MetaPost, and some recommended packages to
@code{scheme-basic}.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-scheme-tetex
  (package
    (name "texlive-scheme-tetex")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-acronym
           texlive-amslatex-primer
           texlive-bbm
           texlive-bbm-macros
           texlive-bbold
           texlive-bibtex8
           texlive-cmbright
           texlive-collection-basic
           texlive-collection-context
           texlive-collection-fontsrecommended
           texlive-collection-fontutils
           texlive-collection-formatsextra
           texlive-collection-langcjk
           texlive-collection-langcyrillic
           texlive-collection-langczechslovak
           texlive-collection-langenglish
           texlive-collection-langeuropean
           texlive-collection-langfrench
           texlive-collection-langgerman
           texlive-collection-langgreek
           texlive-collection-langitalian
           texlive-collection-langother
           texlive-collection-langpolish
           texlive-collection-langportuguese
           texlive-collection-langspanish
           texlive-collection-latex
           texlive-collection-latexrecommended
           texlive-collection-mathscience
           texlive-collection-metapost
           texlive-collection-pictures
           texlive-collection-plaingeneric
           texlive-collection-pstricks
           texlive-ctie
           texlive-cweb
           texlive-detex
           texlive-dtl
           texlive-dvi2tty
           texlive-dvicopy
           texlive-dvidvi
           texlive-dviljk
           texlive-eplain
           texlive-eulervm
           texlive-gentle
           texlive-lshort-english
           texlive-mltex
           texlive-multirow
           texlive-nomencl
           texlive-patgen
           texlive-pst-pdf
           texlive-rsfs
           texlive-seetexk
           texlive-siunits
           texlive-subfigure
           texlive-supertabular
           texlive-tamethebeast
           texlive-tds
           texlive-tex-refs
           texlive-tie
           texlive-web
           texlive-xpdfopen))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "teTeX scheme (more than medium, but nowhere near full)")
    (description
     "Larger than medium, this TeX Live scheme is nearly equivalent to the
teTeX distribution that was maintained by Thomas Esser.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

;; This package must be located before any package adding it to its native
;; inputs.
(define-public texlive-updmap.cfg
  (lambda* (#:optional (packages '()))
    "Return a 'texlive-updmap.cfg' package which contains the fonts map and
mktex scripts configuration, along with a base set of packages plus additional
PACKAGES.

This function is meant to be used in packages as a native input, to build
documentation in the TeX format."
    (let ((default-packages (list texlive-scheme-basic)))
      (package
        (version (package-version texlive-source))
        (source (package-source texlive-scripts))
        (name "texlive-updmap.cfg")
        (build-system copy-build-system)
        (arguments
         (list
          #:modules '((guix build copy-build-system)
                      (guix build utils)
                      (ice-9 popen)
                      (ice-9 textual-ports))
          #:install-plan
          #~'(("texmf-dist/web2c/updmap.cfg" "share/texmf-config/web2c/")
              ("texmf-dist/web2c/mktex.cnf"  "share/texmf-config/web2c/")
              ("texmf-dist/web2c/map"        "share/texmf-dist/fonts/map"))
          #:phases
          #~(modify-phases %standard-phases
              (add-after 'unpack 'generate-mktex.cnf
                ;; When building a package, mktex programs try to create files
                ;; in TEXMFVAR, which is unavailable.  Force creating those
                ;; files in the working directory instead.
                (lambda _
                  (with-directory-excursion "texmf-dist/web2c"
                    (with-output-to-file "mktex.cnf"
                      (lambda _ (display ": ${MT_DESTROOT=''}"))))))
              (add-before 'install 'regenerate-updmap.cfg
                (lambda _
                  (with-directory-excursion "texmf-dist/web2c"
                    (make-file-writable "updmap.cfg")

                    ;; Disable unavailable map files.
                    (let* ((port (open-pipe* OPEN_WRITE "updmap-sys"
                                             "--syncwithtrees"
                                             "--nohash"
                                             "--cnffile" "updmap.cfg")))
                      (display "Y\n" port)
                      (when (not (zero? (status:exit-val (close-pipe port))))
                        (error "failed to filter updmap.cfg")))

                    ;; Set TEXMFSYSVAR to a sane and writable value; updmap
                    ;; fails if it cannot create its log file.
                    (setenv "TEXMFSYSVAR" (getcwd))

                    ;; Generate maps.
                    (invoke "updmap-sys"
                            "--cnffile"           "updmap.cfg"
                            "--dvipdfmxoutputdir" "map/dvipdfmx/updmap/"
                            "--dvipsoutputdir"    "map/dvips/updmap/"
                            "--pdftexoutputdir"   "map/pdftex/updmap/")))))))
        (native-inputs (list texlive-scripts))
        (propagated-inputs (map (lambda (package)
                                  (list (package-name package) package))
                                (append default-packages packages)))
        (home-page (package-home-page texlive-bin))
        (synopsis "TeX Live fonts map configuration")
        (description "This package contains the fonts map configuration file
generated for the base TeX Live packages as well as, optionally, user-provided
ones.")
        (license (delete-duplicates
                  (fold (lambda (package result)
                          (match (package-license package)
                            ((lst ...)
                             (append lst result))
                            ((? license:license? license)
                             (cons license result))))
                        '()
                        (append default-packages packages))))))))

(define-deprecated-package texlive-tiny texlive-scheme-basic)
(define-deprecated/alias texlive-union texlive-updmap.cfg)
(export texlive-union)

(define-public texlive-12many
  (package
    (name "texlive-12many")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/12many/" "source/latex/12many/"
                                     "tex/latex/12many/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "104vqgl5kqdbwfa5wxj7gpxfrqa3k4ky4806mg6zscd6palf2gi5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/one2many")
    (synopsis "Generalising mathematical index sets")
    (description
     "In the discrete branches of mathematics and the computer sciences, it
will only take some seconds before you're faced with a set like
@samp{@{1,...,m@}}.  Some people write @samp{$1\\ldotp\\ldotp m$}, others
@samp{$\\{j:1\\leq j\\leq m\\}$}, and the journal you're submitting to might
want something else entirely.  The @code{12many} package provides an interface
that makes changing from one to another a one-line change.")
    (license license:lppl)))

(define-public texlive-a2ping
  (package
    (name "texlive-a2ping")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/a2ping.1"
                                     "doc/man/man1/a2ping.man1.pdf"
                                     "doc/support/a2ping/" "scripts/a2ping/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lhmh1rnykmi6i5mklj7fwhndw1xxmwy2xsy8j1px8ishf5czhvq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "a2ping.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/a2ping")
    (synopsis "Advanced PS, PDF, EPS converter")
    (description
     "@command{a2ping} is a Perl script command line utility written for Unix
that converts many raster image and vector graphics formats to EPS or PDF and
other page description formats.  Accepted input file formats are:
PS (PostScript), EPS, PDF, PNG, JPEG, TIFF, PNM, BMP, GIF, LBM, XPM, PCX,
TGA. Accepted output formats are: EPS, PCL5, PDF, PDF1, PBM, PGM, PPM, PS,
markedEPS, markedPS, PNG, XWD, BMP, TIFF, JPEG, GIF, XPM.")
    (license license:gpl3+)))

(define-public texlive-aaai-named
  (package
    (name "texlive-aaai-named")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/aaai-named/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xs2iki0v1mh0kbqjxnv9r24bcfmgj6myfw7h368h8g0s1n8d5v6"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/aaai-named")
    (synopsis "BibTeX style for AAAI")
    (description
     "This package provides a BibTeX style derived from the standard master,
presumably for use with the @code{aaai} package.")
    (license license:knuth)))

(define-public texlive-aalok
  (package
    (name "texlive-aalok")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/aalok/" "source/latex/aalok/"
                                     "tex/latex/aalok/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vpvqv60p5v3frdqa5r8k9k4zxk0icma5blw9dr6jhqfzf6lc3jy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/aalok")
    (synopsis "LaTeX class file for the Marathi journal @emph{Aalok}")
    (description
     "This package provides the class file for typesetting @emph{Aalok},
a Marathi journal, with LaTeX.")
    (license (list license:gpl3+
                   ;; Aalok (आलोक) copyleft license v1.0+.
                   (license:fsf-free "file://doc/latex/aalok/README.txt")
                   license:fdl1.3+))))

(define-public texlive-aastex
  (package
    (name "texlive-aastex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/aastex/" "doc/latex/aastex/"
                                     "tex/latex/aastex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07kbrv0vhlpdaxqkiwn2q4psldn5p2x5mmpaw70g6pgcbhk7r74h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/aastex")
    (synopsis "Macros for manuscript preparation for AAS journals")
    (description
     "The bundle provides a document class for preparing papers for
@acronym{AAS, American Astronomical Society} publications.  Authors who wish
to submit papers to AAS journals are strongly urged to use this class in
preference to any of the alternatives available.")
    (license license:lppl1.3+)))

(define-public texlive-abc
  (package
    (name "texlive-abc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/abc/" "source/latex/abc/"
                                     "tex/latex/abc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vywrv35h65gkxipc7d26k32r04fk61kfkkk9bj3zsmxsw1v3r8d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/abc")
    (synopsis "Support ABC music notation in LaTeX")
    (description
     "The abc package lets you include lines of music written in the ABC Plus
language.  The package will then employ the @code{\\write18} facility to
convert your notation to PostScript (using the established utility
@command{abcm2ps}) and hence to the format needed for inclusion in your
document.")
    (license license:lppl1.2+)))

(define-public texlive-abnt
  (package
    (name "texlive-abnt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/abnt/" "tex/latex/abnt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zjsvp6ng6vf87mmnv18q435h6p3ygs512pk0m05yd8gyrmhmrxr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/abnt")
    (synopsis "Typesetting academic works according to ABNT rules")
    (description
     "The ABNT package provides a clean and practical implementation of the
@acronym{ABNT, Associacao Brasileira de Normas Tecnicas} rules for academic
texts.")
    (license license:lppl1.3c)))

(define-public texlive-abntex2
  (package
    (name "texlive-abntex2")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/abntex2/" "bibtex/bst/abntex2/"
                                     "doc/latex/abntex2/" "tex/latex/abntex2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07752n6s2nl4h8j1wg7hjx2wisn505asb1r1i38z7qjbzg7lwqq5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/abntex2")
    (synopsis
     "Typeset technical and scientific Brazilian documents based on ABNT rules")
    (description
     "The bundle provides support for typesetting technical and scientific
Brazilian documents (like academic thesis, articles, reports, research project
and others) based on the @acronym{ABNT, Associacao Brasileira de Normas
Tecnicas} rules.  It replaces the old @code{abntex}.")
    (license license:lppl1.3+)))

(define-public texlive-abntexto
  (package
    (name "texlive-abntexto")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/abntexto/" "tex/latex/abntexto/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0p5fkcgcfxqdznigj947dxgpy6vw52ahpqs5j58li0dlgp01k8l9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/abntexto")
    (synopsis "LaTeX class for formatting academic papers in ABNT standards")
    (description
     "This is a LaTeX class created for Brazilian students to facilitate the
use of standards from the @acronym{ABNT, Associacao Brasileira de Normas
Tecnicas} in academic works like TCCs, dissertations, theses.")
    (license license:public-domain)))

(define-public texlive-aboensis
  (package
    (name "texlive-aboensis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/aboensis/"
                                     "fonts/opentype/public/aboensis/"
                                     "tex/latex/aboensis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14333k6bkfywdka3h2a2yd2nw0521q0lwl3x38612j7cb82izyi3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/aboensis")
    (synopsis "Late medieval OpenType cursive font")
    (description
     "The package contains the OpenType medieval cursive font Aboensis and
a style file to use it in XeLaTeX documents.  The font is based on @emph{Codex
Aboensis}, that is a law book written in Sweden in the 1430s.  Since medieval
cursive is very difficult to read for modern people, the font is not suitable
for use as an ordinary book font, but is intended for emulating late medieval
manuscripts.

The font contains two sets of initials: lombardic and cursive to go with the
basic alphabet, and there is support for writing two-colored initials and
capitals.  There are also a large number of abbreviation sigla that can be
accessed as ligature substitutions.  The style file contains macros that help
to use the extended features of the font such as initials and two-colored
capitals.  There are also macros to help achieve even pages with consistent
line spacing.")
    (license
     (list license:silofl1.1
           license:lppl1.3c
           license:cc-by4.0
           license:public-domain))))

(define-public texlive-academicons
  (package
    (name "texlive-academicons")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/academicons/"
                                     "fonts/truetype/public/academicons/"
                                     "tex/latex/academicons/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gxgj0ppyrf6pj9qvhk02ybwf68yzlh2110r41iwsai5by2iczhm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/academicons")
    (synopsis "Font containing high quality icons of online academic profiles")
    (description
     "The @code{academicons} package provides access in (La)TeX to 124 high
quality icons of online academic profiles included in the free Academicons
font.  This package requires either the Xe(La)TeX or Lua(La)TeX engine to load
the Academicons font from the system.  The @code{academicons} package provides
the generic @code{\\aiicon} command to access icons, which takes as mandatory
argument the name of the desired icon.  It also provides individual direct
commands for each specific icon.")
    (license (list license:lppl1.3c license:silofl1.1))))

(define-public texlive-accanthis
  (package
    (name "texlive-accanthis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/accanthis/"
                                     "fonts/enc/dvips/accanthis/"
                                     "fonts/map/dvips/accanthis/"
                                     "fonts/opentype/arkandis/accanthis/"
                                     "fonts/tfm/arkandis/accanthis/"
                                     "fonts/type1/arkandis/accanthis/"
                                     "fonts/vf/arkandis/accanthis/"
                                     "tex/latex/accanthis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xpy3bs8wwb6ncw4c8kc5vvddl77rmjwfjq66xw12sc8mgg9grmv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/accanthis")
    (synopsis "Accanthis fonts, with LaTeX support")
    (description
     "Accanthis No.@: 3, designed by Hirwin Harendal, is suitable as an
alternative to fonts such as Garamond, Galliard, Horley old style, Sabon, and
Bembo.  The package provides support files for use with all LaTeX engines.")
    (license (list license:gpl2+ license:lppl))))

(define-public texlive-accents
  (package
    (name "texlive-accents")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/accents/" "tex/latex/accents/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0p8g86xbfladz52dwbssmw3w9mbl987d1b740d25miphvj4ia9y9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/accents")
    (synopsis "Multiple mathematical accents")
    (description
     "This package provides a package for multiple accents in mathematics,
with nice features concerning the creation of accents and placement of
scripts.")
    (license license:expat)))

(define-public texlive-accfonts
  (package
    (name "texlive-accfonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/accfonts/" "scripts/accfonts/"
                                     "tex/latex/accfonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kja24rh0ysljwgkyg9mf47h64ayi2kmb1jb3dmvb42ywvg0w9i7"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "mkt1font" "vpl2ovp" "vpl2vpl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/accfonts")
    (synopsis "Utilities to derive new fonts from existing ones")
    (description
     "The @code{accfonts} package contains three utilities to permit easy
manipulation of fonts, in particular the creation of unusual accented
characters. @command{mkt1font} works on Adobe Type 1 fonts, @command{vpl2vpl}
works on TeX virtual fonts and @command{vpl2ovp} transforms a TeX font to an
Omega one.")
    (license license:gpl3+)))

(define-public texlive-accsupp
  (package
    (name "texlive-accsupp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/accsupp/" "source/latex/accsupp/"
                                     "tex/latex/accsupp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10xdg3gk5madpb131lhc9x2sxzby4rvqycbfzb5kl2zkwr1qw5v7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/accsupp")
    (synopsis "Better accessibility support for PDF files")
    (description
     "Since PDF 1.5 portions of a page can be marked for better accessibility
support.  For example, replacement texts or expansions of abbreviations can be
provided.  This package starts with providing a minimal low-level interface
for programmers; its status is experimental.")
    (license license:lppl1.3c)))

(define-public texlive-abbr
  (package
    (name "texlive-abbr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/abbr/" "tex/generic/abbr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zi5qkgr2nnb3jp5adv42d84w7yav1dw0lgg2vdxfsz03j1bmlsb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/abbr")
    (synopsis "Simple macros supporting abbreviations for Plain and LaTeX")
    (description
     "The package provides some simple macros to support abbreviations in
Plain TeX or LaTeX.  It allows writing, e.g., @samp{\\<TEX>} instead of
@samp{\\TeX}, hence frees users from having to escape space after
parameterless macros.")
    (license license:public-domain)))

(define-public texlive-abstyles
  (package
    (name "texlive-abstyles")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/abstyles/"
                                     "bibtex/bst/abstyles/"
                                     "doc/bibtex/abstyles/"
                                     "tex/generic/abstyles/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ij4cp3pydfs4lch0f93gi2q7msafxyqfvv44whw1ppczidicnn2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/abstyles-orig")
    (synopsis "Adaptable BibTeX styles")
    (description
     "This package provides a family of modifications of the standard BibTeX
styles whose behaviour may be changed by changing the user document, without
change to the styles themselves.  The package is largely used nowadays in its
adaptation for working with Babel.")
    (license
     (list license:isc                  ;apreamble
           license:knuth                ;bxabst
           license:public-domain))))    ;docmac

(define-public texlive-acmconf
  (package
    (name "texlive-acmconf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/acmconf/" "source/latex/acmconf/"
                                     "tex/latex/acmconf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0j30krvxzps7ka3xzv0qifrzxhxzkr3b3f9gska6najp1dvygs3a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/acmconf")
    (synopsis "Class for ACM conference proceedings")
    (description
     "This class may be used to typeset articles to be published in the
proceedings of @acronym{ACM, Association for Computing Machinery} conferences
and workshops.  The layout produced by the @code{acmconf} class is based on
the ACM's own specification.")
    (license license:lppl)))

(define-public texlive-active-conf
  (package
    (name "texlive-active-conf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/active-conf/"
                                     "source/latex/active-conf/"
                                     "tex/latex/active-conf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12krmwspwkhcwk5q0qf2hldnsk44vd2jfssfdiwm97alicc3cpj1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/active-conf")
    (synopsis "Class for typesetting ACTIVE conference papers")
    (description
     "Active-conf is a class for typesetting papers for the Active conference
on noise and vibration control.  The class is based on @code{article} with
more flexible front-matter, and can be customised for conferences in future
years with a header file.")
    (license license:lppl)))

(define-public texlive-adfathesis
  (package
    (name "texlive-adfathesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/adfathesis/"
                                     "doc/latex/adfathesis/"
                                     "source/latex/adfathesis/"
                                     "tex/latex/adfathesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zi91xc3sbdjvp87zgrb7g3l5hxqig33fchlhg2i8gjya9ij67p6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/adfathesis")
    (synopsis "Australian Defence Force Academy thesis format")
    (description "The package provides the Australian Defence Force Academy
thesis format.  The bundle also includes a BibTeX style file.")
    (license license:public-domain)))

(define-public texlive-adforn
  (package
    (name "texlive-adforn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/adforn/"
                                     "fonts/afm/arkandis/adforn/"
                                     "fonts/enc/dvips/adforn/"
                                     "fonts/map/dvips/adforn/"
                                     "fonts/tfm/arkandis/adforn/"
                                     "fonts/type1/arkandis/adforn/"
                                     "tex/latex/adforn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dpdbqlc7p3mwm1bj1m5sbkwi5qjsvsfzfb0wnq4flvz1gc09245"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/adforn")
    (synopsis "OrnementsADF font with TeX and LaTeX support")
    (description
     "The bundle provides the Ornements ADF font in PostScript Type 1 format
with TeX and LaTeX support files.")
    (license (list license:lppl license:gpl2+))))

(define-public texlive-adfsymbols
  (package
    (name "texlive-adfsymbols")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/adfsymbols/"
                                     "fonts/afm/arkandis/adfsymbols/"
                                     "fonts/enc/dvips/adfsymbols/"
                                     "fonts/map/dvips/adfsymbols/"
                                     "fonts/tfm/arkandis/adfsymbols/"
                                     "fonts/type1/arkandis/adfsymbols/"
                                     "tex/latex/adfsymbols/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "188is31d2zcd8kk339x4wvhhm98gbfkvq6pi25d9mva4vz3w1vf5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/adfsymbols")
    (synopsis "SymbolsADF with TeX and LaTeX support")
    (description
     "The package provides Arkandis foundry's ArrowsADF and BulletsADF fonts
in Adobe Type 1 format, together with TeX and LaTeX support files.")
    (license (list license:lppl license:gpl2))))

(define-public texlive-adhocfilelist
  (package
    (name "texlive-adhocfilelist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/adhocfilelist/"
                                     "scripts/adhocfilelist/"
                                     "source/support/adhocfilelist/"
                                     "tex/support/adhocfilelist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "097yy38571fa2hzp4s3p125xknqgjmkhv1vgi0q9vz83b6175hc4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "adhocfilelist.sh")))
    (home-page "https://ctan.org/pkg/adhocfilelist")
    (synopsis "@code{\\listfiles} entries from the command line")
    (description
     "The package provides a Unix shell script to display a list of LaTeX
@code{\\Provides}...-command contexts on screen.  Provision is made for
controlling the searches that the package does.")
    (license license:lppl)))

(define-public texlive-adtrees
  (package
    (name "texlive-adtrees")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/adtrees/" "tex/latex/adtrees/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ypb609wvw3mvs7bf2mwa7r7v4frxjhfll8d1sqfry3dv3kr13pq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/adtrees")
    (synopsis "Macros for drawing adpositional trees")
    (description
     "This package provides a means to write adpositional trees, a formalism
devoted to representing natural language expressions.")
    (license license:gpl3+)))

(define-public texlive-adobemapping
  (package
    (name "texlive-adobemapping")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "fonts/cmap/adobemapping/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yvf74mlmxmnq9m0wvda9xcna8xnn382bbrzizzjm5w7bk8c4g98"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/adobemapping")
    (synopsis "Adobe CMap and PDF mapping files")
    (description
     "The package comprises the collection of CMap and PDF mapping files made
available for distribution by Adobe.")
    (license license:bsd-3)))

(define-public texlive-aesupp
  (package
    (name "texlive-aesupp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/aesupp/"
                                     "fonts/enc/dvips/aesupp/"
                                     "fonts/map/dvips/aesupp/"
                                     "fonts/opentype/public/aesupp/"
                                     "fonts/tfm/public/aesupp/"
                                     "fonts/type1/public/aesupp/"
                                     "source/fonts/aesupp/"
                                     "tex/latex/aesupp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sx5802d1ib72i0ssjpr0c54pgq1s980wg3q1685pjniw68ns1vj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/aesupp")
    (synopsis "Special support for the @samp{ae} character")
    (description
     "This package provides special support for the italic @samp{ae} character
in some fonts, due to design flaws (in the author's opinion) regarding this
character.  At the moment only the fonts TeX Gyre Bonum, TeX Gyre Schola, TeX
Gyre Pagella, and the Latin Modern fonts are supported.  The other fonts in
the TeX Gyre bundle do not need this support.")
    (license (list license:gfl1.0 license:gpl3+))))

(define-public texlive-afm2pl
  (package
    (name "texlive-afm2pl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/afm2pl.1"
                                     "doc/man/man1/afm2pl.man1.pdf"
                                     "fonts/enc/dvips/afm2pl/"
                                     "fonts/lig/afm2pl/" "tex/fontinst/afm2pl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19llzzr4kmmyf7l18ngx1rhaqaqvgm3md924m4dxcv7nmrvga2b2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-afm2pl-bin))
    (home-page "https://ctan.org/pkg/afm2pl")
    (synopsis "Convert AFM to TeX property list (@file{.pl}) metrics")
    (description
     "@command{afm2pl} converts a @file{.afm} (Adobe Font Metric) file into
a @file{.pl} (Property List) file, which in its turn can be converted to
a @file{.tfm} (TeX Font Metric) file.  It normally preserves kerns and
ligatures, but also offers additional control over them.")
    (license license:gpl2)))

(define-public texlive-afm2pl-bin
  (package
    (inherit texlive-bin)
    (name "texlive-afm2pl-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("afm2pl"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-afm2pl" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/afm2pl"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/afm2pl"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list texlive-libkpathsea))
    (propagated-inputs '())
    (synopsis "Binary for @code{texlive-afm2pl}")
    (description
     "This package provides the binary for @code{texlive-afm2pl}.")
    (license (package-license texlive-afm2pl))))

(define-public texlive-afparticle
  (package
    (name "texlive-afparticle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/afparticle/"
                                     "source/latex/afparticle/"
                                     "tex/latex/afparticle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g7dk32la2zlspdsw1pz15bf90jjycblgpg91m24bx70svdv67kv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/afparticle")
    (synopsis "Typesetting articles for @emph{Archives of Forensic Psychology}")
    (description
     "This package provides a class for typesetting articles for the open
access journal @emph{Archives of Forensic Psychology}.")
    (license license:lppl1.3+)))

(define-public texlive-afthesis
  (package
    (name "texlive-afthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/afthesis/" "doc/latex/afthesis/"
                                     "tex/latex/afthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1db9fzs4rf1d86n2gcn0zs255nlwc8i1yl5n9qzsn6xf5as7zz1i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/afthesis")
    (synopsis "Air Force Institute of Technology thesis class")
    (description
     "This is a LaTeX thesis and dissertation class for US Air Force Institute
Of Technology.")
    (license license:public-domain)))

(define-public texlive-aguplus
  (package
    (name "texlive-aguplus")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/aguplus/" "doc/latex/aguplus/"
                                     "tex/latex/aguplus/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qpi5r4y70cmxinr9y46rw6dfd337l5xhnqfvbkz27nw98j87fi3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/aguplus")
    (synopsis "Styles for American Geophysical Union")
    (description
     "This bundle started as an extension to the @acronym{AGU, American
Geophysical Union}'s own published styles, providing extra facilities and
improved usability.  The AGU now publishes satisfactory LaTeX materials of its
own; it is recommended to switch to the official distribution.")
    (license license:lppl)))

(define-public texlive-aiaa
  (package
    (name "texlive-aiaa")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/aiaa/" "doc/latex/aiaa/"
                                     "source/latex/aiaa/" "tex/latex/aiaa/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l6sp7q53nr1ppxaynfc0q3kf1hg5v22yxyvzjdg028rf1nvbhww"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/aiaa")
    (synopsis "Typeset AIAA conference papers")
    (description
     "This package provides a bundle of LaTeX and BibTeX files and sample
documents to aid those producing papers and journal articles according to the
guidelines of the @acronym{AIAA, American Institute of Aeronautics and
Astronautics}.")
    (license license:lppl)))

(define-public texlive-aichej
  (package
    (name "texlive-aichej")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/aichej/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pr92pq3yjsrbax6ah01cqg7131fp2rkqqjnxwcrm4119z2ic0gf"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/aichej")
    (synopsis "Bibliography style file for the AIChE Journal")
    (description
     "The style was generated using custom-bib, and implements the style of
the American Institute of Chemical Engineers Journal (or @code{AIChE} Journal
or @code{AIChE} J or @code{AIChEJ).}")
    (license license:lppl)))

(define-public texlive-ajl
  (package
    (name "texlive-ajl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/ajl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xkrvy06lw4ngj94zybs14ysal2pg7g71h864gq9bjw0zwq2yjzs"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ajl")
    (synopsis "BibTeX style for AJL")
    (description
     "This package provides bibliographic style references in style of
Australian Journal of Linguistics.")
    (license license:lppl)))

(define-public texlive-akshar
  (package
    (name "texlive-akshar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/akshar/" "source/latex/akshar/"
                                     "tex/latex/akshar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17xiqalqpw64pgvmpsa41qf6y5fhg720rpbr57kv8ipvvm1fn3n5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/akshar")
    (synopsis "Support for syllables in the Devanagari script")
    (description
     "This LaTeX3 package provides macros and interfaces to work with
Devanagari characters and syllables in a more correct way.")
    (license license:lppl1.3c)))

(define-public texlive-albatross
  (package
    (name "texlive-albatross")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/albatross.1"
                                     "doc/man/man1/albatross.man1.pdf"
                                     "doc/support/albatross/"
                                     "scripts/albatross/"
                                     "source/support/albatross/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gg7abaixfxmwhdj3z84sg1vkglh8a8q2p3ql1hy74f5rpkyf3yg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "albatross.sh")))
    (home-page "https://ctan.org/pkg/albatross")
    (synopsis "Find fonts that contain a given glyph")
    (description
     "This is a command line tool for finding fonts that contain
a given (Unicode) glyph.  It relies on Fontconfig.")
    (license license:bsd-3)))

(define-public texlive-alegreya
  (package
    (name "texlive-alegreya")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/alegreya/"
                                     "fonts/enc/dvips/alegreya/"
                                     "fonts/map/dvips/alegreya/"
                                     "fonts/opentype/huerta/alegreya/"
                                     "fonts/tfm/huerta/alegreya/"
                                     "fonts/type1/huerta/alegreya/"
                                     "fonts/vf/huerta/alegreya/"
                                     "tex/latex/alegreya/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n09fq89nxw3jaglmvjfl7ysflqi0rh6mmp6q0zn57m72sza9rra"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/alegreya")
    (synopsis "Alegreya fonts with LaTeX support")
    (description
     "Alegreya, designed by Juan Pablo del Peral, is a typeface originally
intended for literature.  It conveys a dynamic and varied rhythm which
facilitates the reading of long texts.  Bold, black, small caps and five
number styles are available.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-aleph
  (package
    (name "texlive-aleph")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/aleph/base/" "doc/man/man1/aleph.1"
                                     "doc/man/man1/aleph.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "096p2kcfmdvf09xpijwsrhkhmaggvd04jxrs2abag45wsrj75h0s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:create-formats #~(list "aleph")))
    (propagated-inputs
     (list texlive-aleph-bin
           texlive-cm
           texlive-hyphen-base
           texlive-knuth-lib
           texlive-lambda
           texlive-latex
           texlive-plain))
    (home-page "https://ctan.org/pkg/aleph")
    (synopsis "Extended TeX")
    (description
     "This package provides a development of Omega, using most of the
extensions of TeX, itself developed for e-TeX.")
    (license license:gpl3+)))

(define-public texlive-aleph-bin
  (package
    (inherit texlive-bin)
    (name "texlive-aleph-bin")
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons* "--disable-web2c"
                 "--enable-aleph"
                 (delete "--disable-aleph"
                         (delete "--enable-web2c" #$flags))))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/web2c"
                  (invoke "make" "aleph")
                  (install-file "aleph" (string-append #$output "/bin")))))))))
    (native-inputs (list pkg-config))
    (home-page (package-home-page texlive-aleph))
    (synopsis "Binary for @code{texlive-aleph}")
    (description
     "This package provides the binary for @code{texlive-aleph}.")
    (license (package-license texlive-aleph))))

(define-public texlive-alfaslabone
  (package
    (name "texlive-alfaslabone")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/alfaslabone/"
                                     "fonts/enc/dvips/alfaslabone/"
                                     "fonts/map/dvips/alfaslabone/"
                                     "fonts/opentype/public/alfaslabone/"
                                     "fonts/tfm/public/alfaslabone/"
                                     "fonts/type1/public/alfaslabone/"
                                     "fonts/vf/public/alfaslabone/"
                                     "tex/latex/alfaslabone/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wpn96dd1rca52dqwngvyyvnmvak32sjz2id6lcra2jnz5jhk01g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/alfaslabone")
    (synopsis "Alfa Slab One font face with support for LaTeX and pdfLaTeX")
    (description
     "The @code{alfaslabone} package supports the Alfa Slab One font face for
LaTeX.  There is only a Regular font face.  It's useful for book-chapter
headlines.")
    (license license:silofl1.1)))

(define-public texlive-alg
  (package
    (name "texlive-alg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/alg/" "source/latex/alg/"
                                     "tex/latex/alg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jqk9sgw2m4c6hssfc5c3qfxqvpyppvcmy8i5crm7fsmkv0y6wkg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/alg")
    (synopsis "LaTeX environments for typesetting algorithms")
    (description
     "The package defines two environments for typesetting algorithms in LaTeX2e.
The @code{algtab} environment is used to typeset an algorithm with
automatically numbered lines.  The @code{algorithm} environment can be used to
encapsulate the @code{algtab} environment algorithm in a floating body
together with a header, a caption, etc.  @code{\\listofalgorithms} is
defined.")
    (license license:lppl)))

(define-public texlive-algobox
  (package
    (name "texlive-algobox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/algobox/" "source/latex/algobox/"
                                     "tex/latex/algobox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03z5s4v1asfp6rm51wfkmax69rlggfdyb3p1acdy8cx1gwd10f2w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/algobox")
    (synopsis "Typeset Algobox programs")
    (description
     "This LaTeX package can typeset Algobox programs almost exactly as
displayed when editing with Algobox itself, using an input syntax very similar
to the actual Algobox program text.  It gives better results than Algobox's
own LaTeX export which does not look like the editor rendition, produces
standalone documents cumbersome to customize, and has arbitrary and
inconsistent differences between the input syntax and the program text.")
    (license license:gpl3+)))

(define-public texlive-algolrevived
  (package
    (name "texlive-algolrevived")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/algolrevived/"
                                     "fonts/enc/dvips/algolrevived/"
                                     "fonts/map/dvips/algolrevived/"
                                     "fonts/opentype/public/algolrevived/"
                                     "fonts/tfm/public/algolrevived/"
                                     "fonts/type1/public/algolrevived/"
                                     "fonts/vf/public/algolrevived/"
                                     "tex/latex/algolrevived/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0709ijp5jqajwdc9ryhjp4jky0pqynj9wj3rryxk9z6sm63pbq1k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/algolrevived")
    (synopsis "Revival of Frutiger's Algol alphabet")
    (description
     "The package revives Frutiger's Algol alphabet, designed in 1963 for the
code segments in an ALGOL manual.  It provides OpenType and Type 1, regular
and medium weights, upright and slanted variations.  Albeit not monospaced,
this font is good for listings if you don't need code to be aligned with
specific columns.  It also makes a passable but limited text font.")
    (license (list license:silofl1.1 license:lppl1.3c))))

(define-public texlive-algorithm2e
  (package
    (name "texlive-algorithm2e")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/algorithm2e/"
                                     "tex/latex/algorithm2e/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bf4fc9p84zy2zdl0hiklcbbxn17j3qyl02kyj5ya00lrf6sv93n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/algorithm2e")
    (synopsis "Floating algorithm environment with algorithmic keywords")
    (description
     "Algorithm2e is an environment for writing algorithms.  An algorithm
becomes a floating object (like figure, table, etc.).  The package provides
macros that allow you to create different keywords, and a set of predefined
key words is provided; you can change the typography of the keywords.  The
package allows vertical lines delimiting a block of instructions in an
algorithm, and defines different sorts of algorithms such as @samp{Procedure}
or @samp{Function}; the name of these functions may be reused in the text or
in other algorithms.")
    (license license:lppl)))

(define-public texlive-algorithmicx
  (package
    (name "texlive-algorithmicx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/algorithmicx/"
                                     "tex/latex/algorithmicx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q0qkzc88479y5dqifnpfxhclk48gf1c4shxi1xhgqbvjp2gqgza"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/algorithmicx")
    (synopsis "The algorithmic style you always wanted")
    (description
     "Algorithmicx provides a flexible, yet easy to use, way for inserting
good looking pseudocode or source code in your papers.  It has built in
support for pseudocode, Pascal and C, and offers powerful means to create
definitions for any programming language.  The user can adapt a pseudocode
style to his native language.")
    (license license:lppl)))

(define-public texlive-algorithms
  (package
    (name "texlive-algorithms")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/algorithms/"
                                     "source/latex/algorithms/"
                                     "tex/latex/algorithms/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yw0alkigq77a2ha4hdrvpagqvyy0cv61ddhvf227wlwmvw5ch2w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/algorithms")
    (synopsis "Suite of tools for typesetting algorithms in pseudo-code")
    (description
     "The package consists of two environments: @code{algorithm} and
@code{algorithmic}.  The @code{algorithm} package defines a floating
@code{algorithm} environment designed to work with the @code{algorithmic}
style.  Within an @code{algorithmic} environment a number of commands for
typesetting popular algorithmic constructs are available.")
    (license license:lgpl2.1)))

(define-public texlive-algpseudocodex
  (package
    (name "texlive-algpseudocodex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/algpseudocodex/"
                                     "tex/latex/algpseudocodex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03k0ynz63gqgmm6ylikpaq28cd70qfq3advv8n1nbi8bjgz7xrd4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/algpseudocodex")
    (synopsis "Package for typesetting pseudocode")
    (description
     "This package allows typesetting pseudocode in LaTeX.  It is based on
@code{algpseudocode} from the @code{algorithmicx} package and uses the same
syntax, but adds several new features and improvements.  Notable features
include customizable indent guide lines and the ability to draw boxes around
parts of the code for highlighting differences.  This package also has better
support for long code lines spanning several lines and improved comments.")
    (license license:lppl1.3c)))

(define-public texlive-algxpar
  (package
    (name "texlive-algxpar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/algxpar/"
                                     "tex/latex/algxpar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14hspzx0bd2p2aahfa54jz0f97nz1wbjykjrgb5l8ncmr11hr09h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/algxpar")
    (synopsis "Support multiple lines pseudocode")
    (description
     "This package extends the package @code{algorithmicx} to support long
text which spans over multiple lines.")
    (license license:lppl1.3+)))

(define-public texlive-aligned-overset
  (package
    (name "texlive-aligned-overset")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/aligned-overset/"
                                     "source/latex/aligned-overset/"
                                     "tex/latex/aligned-overset/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1awawz0ypq15r16mx949g7r7pp9a60xhi8hciy1xsa6dvvj47h5x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/aligned-overset")
    (synopsis "Fix alignment at @code{\\overset} or @code{\\underset}")
    (description
     "This package allows the base character of @code{\\underset} or
@code{\\overset} to be used as the alignment position for the @code{aligned}
math environments.")
    (license license:lppl1.3c)))

(define-public texlive-alkalami
  (package
    (name "texlive-alkalami")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/alkalami/"
                                     "fonts/truetype/public/alkalami/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0979xhsjar0gwjp9yqp0kaf4gp4z715gr2kdb8dkqg8zzlkqhgzk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/alkalami")
    (synopsis "Font for Arabic-based writing systems in Nigeria and Niger")
    (description
     "This font is designed for Arabic-based writing systems in the Kano
region of Nigeria and Niger.")
    (license license:silofl1.1)))

(define-public texlive-allrunes
  (package
    (name "texlive-allrunes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/allrunes/"
                                     "fonts/map/dvips/allrunes/"
                                     "fonts/source/public/allrunes/"
                                     "fonts/type1/public/allrunes/"
                                     "source/fonts/allrunes/"
                                     "tex/latex/allrunes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14a1qaa30s4dzmg4dlrjd3faa3bcrl2gdpp700i8pghj3pjk7gp4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/allrunes")
    (synopsis "Fonts and LaTeX package for almost all runes")
    (description
     "This large collection of fonts (in Adobe Type 1 format), with the LaTeX
package gives access to almost all runes ever used in Europe.  The bundle
covers not only the main forms but also a lot of varieties.")
    (license license:lppl)))

(define-public texlive-almendra
  (package
    (name "texlive-almendra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/almendra/"
                                     "fonts/enc/dvips/almendra/"
                                     "fonts/map/dvips/almendra/"
                                     "fonts/tfm/public/almendra/"
                                     "fonts/truetype/public/almendra/"
                                     "fonts/type1/public/almendra/"
                                     "fonts/vf/public/almendra/"
                                     "tex/latex/almendra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mkj0cjpry0hdynlpf719haczm1csv0yvla6nhlgp3dq5k28hvp2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/almendra")
    (synopsis "Almendra fonts with LaTeX support")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX, and LuaLaTeX support for
the Almendra family of fonts, designed by Ana Sanfelippo.  Almendra is
a typeface design based on calligraphy.  Its style is related to the Chancery
and Gothic hands.  There are regular and bold weights with matching italics.
There is also a regular-weight small-caps.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-almfixed
  (package
    (name "texlive-almfixed")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/almfixed/"
                                     "fonts/opentype/public/almfixed/"
                                     "fonts/truetype/public/almfixed/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ihyldbdz89swj8lm75kb3n3nqqgzkydwlppsndfpib74pvp6s97"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/almfixed")
    (synopsis "Extend TeX-Gyre Latin Modern to full Arabic Unicode support")
    (description
     "Arabic-Latin Modern Fixed is an extension of TeX-Gyre Latin Modern Mono
10 Regular.  Every glyph and OpenType feature of the Latin Modern Mono has
been retained, with minor improvements.  On the other hand, we have changed
the vertical metrics of the font.

The unique feature of Arabic-Latin Modern is its treatment of vowels and
diacritics.  Each vowel and diacritic (ALM Fixed contains a total of 68 such
glyphs) may now be edited horizontally within any text editor or processor.
Editing complex Arabic texts will now be much easier to input and to
proofread.")
    (license license:gfl1.0)))

(define-public texlive-alpha-persian
  (package
    (name "texlive-alpha-persian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/alpha-persian/"
                                     "doc/bibtex/alpha-persian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15ynmgh3fp6s40c200kgr6v0q84bkzp9cv45yg90mr9d7mq72djv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/alpha-persian")
    (synopsis "Persian version of @file{alpha.bst}")
    (description
     "The package provides a Persian version of the alpha BibTeX style and
offers several enhancements.  It is compatible with the @code{hyperref},
@code{url}, @code{natbib}, and @code{cite} packages.")
    (license license:lppl1.3c)))

(define-public texlive-amscdx
  (package
    (name "texlive-amscdx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/amscdx/" "source/latex/amscdx/"
                                     "tex/latex/amscdx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13gxllncd46w4kscb7isivw6x82pw9yfamcv3sq6wnx68z03n2q3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/amscdx")
    (synopsis "Enhanced commutative diagrams")
    (description
     "The original @code{amscd} package provides a @code{CD} environment that
emulates the commutative diagram capabilities of AMS-TeX version 2.x.  This
means that only simple rectangular diagrams are supported, with no diagonal
arrows or more exotic features.  This enhancement package implements double,
dashed, and bidirectional arrows (left-right and up-down), and color
attributes for arrows and their annotations.  The restriction to rectangular
geometry remains.  This nevertheless allows the drawing of a much broader
class of commutative diagrams and alike.")
    (license license:lppl1.3c)))

(define-public texlive-amscls-doc
  (package
    (name "texlive-amscls-doc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/amscls-doc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0allim05cp20zhn480df2mivd3p9gnc069d7hbjlzv660bw7mapx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/amscls-doc")
    (synopsis "User documentation for AMS document classes")
    (description
     "This collection comprises a set of four manuals, or Author Handbooks,
each documenting the use of a class of publications based on one of the AMS
document classes @code{amsart}, @code{amsbook}, @code{amsproc} and one hybrid,
as well as a guide to the generation of the four manuals from a coordinated
set of LaTeX source files.  The Handbooks comprise the user documentation for
the pertinent document classes.  As the source for the Handbooks consists of
a large number of files, and the intended output is multiple different
documents, the principles underlying this collection can be used as a model
for similar projects.  The manual @emph{Compiling the AMS Author Handbooks}
provides information about the structure of and interaction between the
various components.")
    (license license:lppl1.3c)))

(define-public texlive-amslatex-primer
  (package
    (name "texlive-amslatex-primer")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/amslatex-primer/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kzayyh1bycmq43s2xn81jf05r18azidbk3gv6igf2vaq37fmxil"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/amslatex-primer")
    (synopsis "Getting up and running with AMS-LaTeX")
    (description
     "The document aims to get you up and running with AMS-LaTeX as quickly as
possible.  These instructions are not a substitute for the full documentation,
but they may get you started quickly enough so that you will only need to
refer to the main documentation occasionally.  In addition to AMS-LaTeX out of
the box, the document contains a section describing how to draw commutative
diagrams using Xy-pic and a section describing how to use @code{amsrefs} to
create a bibliography.")
    (license license:lppl)))

(define-public texlive-amsldoc-it
  (package
    (name "texlive-amsldoc-it")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/amsldoc-it/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d4hwb7hywy56d6934448lcr6fdx7qchkfzs806dr7wfzfy36yix"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/amsldoc-it")
    (synopsis "Italian translation of @code{amsldoc}")
    (description
     "This package provides an Italian translation of @code{amsldoc}.")
    ;; Use same license as `amsmath'.
    (license license:lppl1.3c)))

(define-public texlive-amsldoc-vn
  (package
    (name "texlive-amsldoc-vn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/amsldoc-vn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1iz0zjn1v7izwbsq0zb6cvpnkbvk0nxw1b24j7dzqwk3m9j43i6x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/amslatexdoc-vietnamese")
    (synopsis "Vietnamese translation of AMSLaTeX documentation")
    (description
     "This is a Vietnamese translation of @code{amsldoc}, the users guide to
@code{amsmath}.")
    (license license:lppl1.3+)))

(define-public texlive-amstex
  (package
    (name "texlive-amstex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/amstex/base/" "doc/man/man1/amstex.1"
                                     "doc/man/man1/amstex.man1.pdf"
                                     "tex/amstex/base/" "tex/amstex/config/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19wmfij3g3kaqnhypczpda7i2c3nhin1h6fjwjb5raimr9g5qyql"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:create-formats #~(list "amstex")
           #:phases
           #~(modify-phases %standard-phases
               (add-after 'install 'symlink-binaries
                 (lambda* (#:key inputs #:allow-other-keys)
                   (let ((pdftex (search-input-file inputs "bin/pdftex"))
                         (bin (string-append #$output "/bin")))
                     (mkdir-p bin)
                     (with-directory-excursion bin
                       (symlink pdftex "amstex"))))))))
    (propagated-inputs
     (list texlive-amsfonts
           texlive-cm
           texlive-hyphen-base
           texlive-knuth-lib
           texlive-pdftex
           texlive-plain
           texlive-tex))
    (home-page "https://ctan.org/pkg/amstex")
    (synopsis "American Mathematical Society plain TeX macros")
    (description
     "AMS-TeX is a TeX macro package based on Plain TeX: it provides many
features for producing more professional-looking maths formulas with less
burden on authors.

This is the final archival distribution of AMS-TeX.  AMS-TeX is no longer
supported by the AMS, nor is it used by the AMS publishing program.  The AMS
does not recommend creating any new documents using AMS-TeX; this distribution
will be left on CTAN to facilitate processing of legacy documents and as
a historical record of a pioneering TeX macro collection that played a key
role in popularizing TeX and revolutionizing mathematics publishing.  AMS-TeX
is the historical basis of @code{amslatex}, which should now be used to
prepare submissions for the AMS.")
    (license license:lppl)))

(define-public texlive-amsthdoc-it
  (package
    (name "texlive-amsthdoc-it")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/amsthdoc-it/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ic88gs89m3d9ys40c4k7sgx6wy82c8isg2qkmd4snw5yms6fpaz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/amsthdoc-it")
    (synopsis "Italian translation of @code{amsthdoc}")
    (description
     "This package provides an Italian translation of @code{amsthdoc}.")
    ;; Use same license as `amscls'.
    (license license:lppl1.3c)))

(define-public texlive-andika
  (package
    (name "texlive-andika")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/andika/"
                                     "fonts/enc/dvips/andika/"
                                     "fonts/map/dvips/andika/"
                                     "fonts/tfm/SIL/andika/"
                                     "fonts/truetype/SIL/andika/"
                                     "fonts/type1/SIL/andika/"
                                     "fonts/vf/SIL/andika/"
                                     "tex/latex/andika/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gjahg3xwzwrj9cp6l0zmhfqxwzl4m89vvngmpq4ym0f6rg5pb4i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/andika")
    (synopsis "Andika fonts with support for all LaTeX engines")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the Andika family of fonts designed by SIL International especially for
literacy use, taking into account the needs of beginning readers.  The focus
is on clear, easy-to-perceive letterforms that will not be readily confused
with one another.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-annee-scolaire
  (package
    (name "texlive-annee-scolaire")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/annee-scolaire/"
                                     "source/latex/annee-scolaire/"
                                     "tex/latex/annee-scolaire/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nwm67p4s822d7r4kr3rbvnm9vlkvzjbikqy8hq2fqsc9bdx34ib"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/annee-scolaire")
    (synopsis "Automatically typeset the academic year (French way)")
    (description
     "This package provides a macro @code{\\anneescolaire} to automatically
write the academic year in the French way, according to the date of
compilation, two other macros to obtain the first and the second calendar year
of the academic year, a macro to be redefined to change the presentation of
the years.")
    (license license:lppl1.3c)))

(define-public texlive-annotate
  (package
    (name "texlive-annotate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/annotate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12q3xk08ycz57vsrcr2glk7y48w8sbc4n8lrqaicd46cxfd4jdqm"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/annotate")
    (synopsis "Bibliography style with annotations")
    (description
     "The style is a derivative of the standard @code{alpha} style, which
processes an entry's annotate field as part of the printed output.")
    ;; There is no explicit license in the "annotate.bst" file, but it
    ;; mentions being derived from "alpha.bst", which is released under
    ;; Knuth's terms.  We therefore use the same license.
    (license license:knuth)))

(define-public texlive-annotate-equations
  (package
    (name "texlive-annotate-equations")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/annotate-equations/"
                                     "tex/latex/annotate-equations/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07cdj0sqx796gsjmrpq8bzkmiqbli24593y4axcmrr8kngfki9f2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/annotate-equations")
    (synopsis "Easily annotate math equations using TikZ")
    (description
     "This package provides commands that make it easy to highlight terms in
equations and add annotation labels using TikZ.  It should work with pdfLaTeX
as well as LuaLaTeX.")
    (license license:expat)))

(define-public texlive-anonymous-acm
  (package
    (name "texlive-anonymous-acm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/anonymous-acm/"
                                     "tex/latex/anonymous-acm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05csmx485sjky64d2hwlb5f7mrkixhw1gn3nl7p7lng9sd8qh25k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/anonymous-acm")
    (synopsis "Typeset anonymous versions for ACM articles")
    (description
     "Academics often need to submit anonymous versions of their papers for
peer-review.  This often requires anonymization which at some future date
needs to be reversed.  However de-anonymizing an anonymized paper can be
laborious and error-prone.  This LaTeX package allows anonymization options to
be specified at the time of writing for authors using @code{acmart.cls}, the
official @acronym{ACM, Association of Computing Machinery} master
@code{article} template.  Anonymization or deanonymization is carried out by
simply changing one option and recompiling.")
    (license license:lppl1.3+)))

(define-public texlive-anonymouspro
  (package
    (name "texlive-anonymouspro")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/anonymouspro/"
                                     "fonts/afm/public/anonymouspro/"
                                     "fonts/enc/dvips/anonymouspro/"
                                     "fonts/map/dvips/anonymouspro/"
                                     "fonts/tfm/public/anonymouspro/"
                                     "fonts/truetype/public/anonymouspro/"
                                     "fonts/type1/public/anonymouspro/"
                                     "fonts/vf/public/anonymouspro/"
                                     "source/fonts/anonymouspro/"
                                     "tex/latex/anonymouspro/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qfhsbq3ab72k9d023pa70vs1807djijg84l888nwsf3ylfwg7mf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/anonymouspro")
    (synopsis "Use AnonymousPro fonts with LaTeX")
    (description
     "The fonts are a monowidth set, designed for use by coders.  They appear
as a set of four TrueType, or Adobe Type 1 font files, and LaTeX support is
also provided.")
    (license license:lppl1.3c)))

(define-public texlive-antanilipsum
  (package
    (name "texlive-antanilipsum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/antanilipsum/"
                                     "source/latex/antanilipsum/"
                                     "tex/latex/antanilipsum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yighrv3nxb266949m8sqvvl5yp8bhjq478h2abfrs1z0r65gpjr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/antanilipsum")
    (synopsis "Generate sentences in the style of @emph{Amici miei}")
    (description
     "This package is an italian blind text generator that outputs supercazzole,
mocking nonsense phrases from the movie series @emph{Amici Miei} (``My
friends'', in English), directed by Mario Monicelli.")
    (license license:lppl1.3c)))

(define-public texlive-antiqua
  (package
    (name "texlive-antiqua")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/antiqua/"
                                     "fonts/afm/urw/antiqua/"
                                     "fonts/map/dvips/antiqua/"
                                     "fonts/map/vtex/antiqua/"
                                     "fonts/tfm/urw/antiqua/"
                                     "fonts/type1/urw/antiqua/"
                                     "fonts/vf/urw/antiqua/"
                                     "tex/latex/antiqua/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0agnibj98zx2f2r40gqcfm2f1x06389wd2qrlf6b4pl8pgay42z2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/urw-antiqua")
    (synopsis "URW Antiqua condensed font, for use with TeX")
    (description
     "The package contains a copy of the Type 1 font URW Antiqua 2051 Regular
Condensed, with supporting files for use with (La)TeX.")
    (license license:gpl3+)))

(define-public texlive-antomega
  (package
    (name "texlive-antomega")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/omega/antomega/" "omega/ocp/antomega/"
                                     "omega/otp/antomega/"
                                     "source/lambda/antomega/"
                                     "tex/lambda/antomega/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02pfjm9y33mjggn9w2lrk1fxfz3m72xgbvyvrq2iri9yf0hk33pf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'fix-build
            ;; This phase is necessary because the build phase is reluctant to
            ;; generate "hyphen.cfg" since there is another one among the
            ;; inputs already.
            (lambda _
              (substitute* "source/lambda/antomega/antomega.ins"
                (("\\\\generateFile\\{hyphen\\.cfg\\}\\{t\\}")
                 "\\generateFile{hyphen.cfg}{f}")))))))
    (propagated-inputs (list texlive-omega))
    (home-page "https://ctan.org/pkg/antomega")
    (synopsis "Alternative language support for Omega and Lambda")
    (description
     "This package provides a language support package for Omega and Lambda.
This replaces the original Omega package for use with Lambda, and provides
extra facilities (including Babel-like language switching, which eases porting
of LaTeX documents to Lambda).")
    (license license:lppl)))

(define-public texlive-anufinalexam
  (package
    (name "texlive-anufinalexam")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/anufinalexam/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1v1k74vxidgxn5zzqz6v9zga468kcf7hwdrnvw44cd318221y396"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/anufinalexam")
    (synopsis "LaTeX document shell for ANU final exam")
    (description
     "This LaTeX document shell is created for the standard formatting of
final exams in the @acronym{ANU, Australian National University}.")
    (license license:gpl3+)))

(define-public texlive-anyfontsize
  (package
    (name "texlive-anyfontsize")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/anyfontsize/"
                                     "tex/latex/anyfontsize/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wr4brhggmkb1rwzmcc2r5ygzqp6090z0bp3sfbarwvwz903wpdn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/anyfontsize")
    (synopsis "Select any font size in LaTeX")
    (description
     "The package allows the to user select any font size , even those sizes
that are not listed in the @file{.fd} file.  If such a size is requested,
LaTeX will search for and select the nearest listed size; @code{anyfontsize}
will then scale the font to the size actually requested.  Similar
functionality is available for the CM family, for the EC family, or for either
Computer Modern encoding; the present package generalises the facility.")
    (license license:lppl)))

(define-public texlive-aomart
  (package
    (name "texlive-aomart")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/aomart/" "doc/latex/aomart/"
                                     "source/latex/aomart/" "tex/latex/aomart/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gdi54qi0m96pwwn59r9qjlkw0986z9ra57g1vf11h67zwmrgrv9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/aomart")
    (synopsis "Typeset articles for the @emph{Annals of Mathematics}")
    (description
     "The package provides a class for typesetting articles for the
@emph{Annals of Mathematics}.")
    (license license:lppl1.3+)))

(define-public texlive-apa
  (package
    (name "texlive-apa")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/apa/" "tex/latex/apa/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0slrvw7awva4d2zf7a6qyvh85qhrp8ml4ncdzjfizr5xz4ki6gs2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/apa")
    (synopsis "American Psychological Association format")
    (description
     "This package provides a LaTeX class to format text according to the
@emph{American Psychological Association Publication Manual} (5th ed.)
specifications for manuscripts or to the @acronym{APA, Americal Psychological
Association} journal look found in journals like the @emph{Journal of
Experimental Psychology} etc.  In addition, it provides regular LaTeX-like
output with a few enhancements and APA-motivated changes.  Note that the
@code{apa7} class (covering the 7th edition of the manual) and
@code{apa6} (covering the 6th edition of the manual) are now commonly in use.
Apacite, which used to work with this class, has been updated for use with
@code{apa6}.")
    (license license:lppl)))

(define-public texlive-apa6e
  (package
    (name "texlive-apa6e")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/apa6e/" "source/latex/apa6e/"
                                     "tex/latex/apa6e/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dksjpdywwvyj9mfhaghsrf935p061gsnx4lf5s6pkv5nxn2pbln"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/apa6e")
    (synopsis "Format manuscripts to APA 6th edition guidelines")
    (description
     "This is a minimalist class file for formatting manuscripts in the style
described in the @acronym{APA, American Psychological Association} 6th edition
guidelines.  The @code{apa6} class provides better coverage of the
requirements.")
    (license license:bsd-2)))

(define-public texlive-apa7
  (package
    (name "texlive-apa7")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/apa7/" "source/latex/apa7/"
                                     "tex/latex/apa7/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kifjg61s16cn7zvmix2yqdz26spr7f9gsxkiv822qs3y337l6ry"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:phases
           #~(modify-phases %standard-phases
               ;; ".ins" file writes files to "./config" and "./build".
               ;; Create these directories first to prevent an error.
               (add-before 'build 'prepare-build
                 (lambda _
                   (for-each mkdir-p (list "build/config" "build/samples")))))))
    (home-page "https://ctan.org/pkg/apa7")
    (synopsis "Format documents in APA style (7th edition)")
    (description
     "This class formats documents in @acronym{APA, American Psychological
Association} style (7th Edition).  It provides a full set of facilities in
four different output modes (journal-like appearance, double-spaced
manuscript, double-spaced student manuscript, LaTeX-like document).  The class
can mask author identity for copies for use in masked peer review.  It is
a development of the @code{apa6} class.")
    (license license:lppl1.3c)))

(define-public texlive-apalike-ejor
  (package
    (name "texlive-apalike-ejor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/apalike-ejor/"
                                     "doc/bibtex/apalike-ejor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qq7c81hqi46596zw322w1qd8z341zksi5720f9s75nj1hmjj12g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/apalike-ejor")
    (synopsis
     "BibTeX style file for the European Journal of Operational Research")
    (description
     "This package contains a BibTeX style file, @file{apalike-ejor.bst},
made to follow the European Journal of Operational Research reference style
guidelines.")
    (license license:lppl1.3c)))

(define-public texlive-apalike2
  (package
    (name "texlive-apalike2")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/apalike2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mn84ahwjg8gvw5lifvcrnch11q79d4bgw3nmhrh4v8slwgip5l7"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/apalike2")
    (synopsis "Bibliography style that approaches APA requirements")
    (description
     "This package is an adaptation of @code{apalike}, which is part of the
base BibTeX distribution.")
    (license license:knuth)))

(define-public texlive-apnum
  (package
    (name "texlive-apnum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/apnum/" "tex/generic/apnum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0s6nklimzbqc1z1vhgffzp76d1kl2shz1xkf119bck482rvn3x61"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/apnum")
    (synopsis "Arbitrary precision numbers implemented by TeX macros")
    (description
     "The basic operations (addition, subtraction, multiplication,
division, power to an integer) are implemented by TeX macros in this package.
Operands may be numbers with arbitrary numbers of digits; scientific notation
is allowed.  The expression scanner is also provided.")
    (license license:public-domain)))

(define-public texlive-apprendre-a-programmer-en-tex
  (package
    (name "texlive-apprendre-a-programmer-en-tex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/apprendre-a-programmer-en-tex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05779lk9v849k712wfjv0mhyzahwpl4n892ydamfdc5yg05bsnyv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/apprendre-a-programmer-en-tex")
    (synopsis "@emph{Apprendre à programmer en TeX} book")
    (description
     "This book explains the basic concepts required for programming in TeX
and explains the programming methods, providing many examples.  The package
makes the compilable source code as well as the compiled PDF file accessible
to everyone.")
    (license license:lppl1.2+)))

(define-public texlive-apprends-latex
  (package
    (name "texlive-apprends-latex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/apprends-latex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xzy7svb2xz6bdfg0f1r3whwda118pl7qdwygx1l7h4d1vqm2rcq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/apprends-latex")
    (synopsis "@emph{Apprends LaTeX!} book")
    (description
     "@emph{Apprends LaTeX!} (``Learn LaTeX'', in English) is French
documentation for LaTeX beginners.")
    (license license:lppl)))

(define-public texlive-apxproof
  (package
    (name "texlive-apxproof")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/apxproof/"
                                     "source/latex/apxproof/"
                                     "tex/latex/apxproof/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m4nvqxvnsllh25qmms6szcqqpb8wffk1z0v2p507fkgsdjz9jln"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/apxproof")
    (synopsis "Proofs in appendix")
    (description
     "The package makes it easier to write articles where proofs and other
material are deferred to the appendix.  The appendix material is written in
the LaTeX code along with the main text which it naturally complements, and it
is automatically deferred.  The package can automatically send proofs to the
appendix, can repeat in the appendix the theorem environments stated in the
main text, can section the appendix automatically based on the sectioning of
the main text, and supports a separate bibliography for the appendix
material.")
    (license license:lppl1.3+)))

(define-public texlive-arabi
  (package
    (name "texlive-arabi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/arabi/"
                                     "fonts/afm/arabi/arabeyes/"
                                     "fonts/enc/dvips/arabi/"
                                     "fonts/map/dvips/arabi/"
                                     "fonts/tfm/arabi/arabeyes/"
                                     "fonts/tfm/arabi/farsiweb/"
                                     "fonts/type1/arabi/arabeyes/"
                                     "fonts/type1/arabi/farsiweb/"
                                     "tex/latex/arabi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19js5lw5r51n97gnf7ggvnvdkaamd0aagx73hnpyfzgzj9nb8pjr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/arabi")
    (synopsis "(La)TeX support for Arabic and Farsi, compliant with Babel")
    (description
     "The package provides an Arabic and Farsi script support for TeX without
the need of any external pre-processor, and in a way that is compatible with
Babel.  The bi-directional capability supposes that the user has a TeX engine
that knows the four primitives @code{\\beginR}, @code{\\endR}, @code{\\beginL}
and @code{\\endL}.  That is the case in both the TeX--XeT and e-TeX engines.

Arabi will accept input in several 8-bit encodings, including UTF-8.  Arabi
can make use of a wide variety of Arabic and Farsi fonts, and provides one of
its own.  PDF files generated using Arabi may be searched, and text may be
copied from them and pasted elsewhere.")
    (license license:lppl)))

(define-public texlive-arabi-add
  (package
    (name "texlive-arabi-add")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/arabi-add/"
                                     "tex/latex/arabi-add/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lrr3vr9sv554bvad70rc32x0jgsam2jaflgxw0nid0629rmigdj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/arabi-add")
    (synopsis
     "Using @code{hyperref} and @code{bookmark} packages with Arabic and Farsi languages")
    (description
     "This package takes advantage of some of the possibilities that
@code{hyperref} and @code{bookmark} packages offer when you create a table of
contents for Arabic texts created by the @code{arabi} package.")
    (license license:lppl1.3)))

(define-public texlive-arabic-book
  (package
    (name "texlive-arabic-book")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/arabic-book/"
                                     "tex/xelatex/arabic-book/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "070agzwpgdfvjqn2klxw2m1bavy0l9b9pqqikc7il3wx107m4ni1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/arabic-book")
    (synopsis "Arabic @code{book} class")
    (description
     "This document class provides both Arabic and English support for TeX and
LaTeX.  Input may be in ASCII transliteration or other encodings
(including UTF-8), and output may be Arabic, Hebrew, or any of several
languages that use the Arabic script, as can be specified by the Polyglossia
package.  The Arabic font is presently available in any Arabic fonts style.
In order to use Amiri font style, the user needs to install the amiri package.
This document class runs with the XeTeX engine.  PDF files generated using
this class can be searched, and text can be copied from them and pasted
elsewhere.")
    (license license:lppl1.3+)))

(define-public texlive-arabluatex
  (package
    (name "texlive-arabluatex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/arabluatex/"
                                     "source/lualatex/arabluatex/"
                                     "tex/lualatex/arabluatex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g1ai0inai3jniq49avfswyaysxlk1yp6n97l94pq8v3vszx0k8i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/arabluatex")
    (synopsis "ArabTeX for LuaLaTeX")
    (description
     "This package provides for LuaLaTeX an ArabTeX-like interface to generate
Arabic writing from an ascii transliteration.  It is particularly well-suited
for complex documents such as technical documents or critical editions where
a lot of left-to-right commands intertwine with Arabic writing.
@code{arabluatex} is able to process any ArabTeX input notation.  Its output
can be set in the same modes of vocalization as ArabTeX, or in different roman
transliterations.  It further allows many typographical refinements.  It will
eventually interact with some other packages yet to come to produce from
@file{.tex} source files, in addition to printed books, TEI XML compliant
critical editions and/or lexicons that can be searched, analyzed and
correlated in various ways.")
    (license (list license:gpl3+ license:cc-by-sa4.0))))

(define-public texlive-arabtex
  (package
    (name "texlive-arabtex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/arabtex/"
                                     "fonts/map/dvips/arabtex/"
                                     "fonts/source/public/arabtex/"
                                     "fonts/tfm/public/arabtex/"
                                     "fonts/type1/public/arabtex/"
                                     "tex/latex/arabtex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z1iaj59lawilydp31d3zxbd5jbny4szpdnkbwl6lrnki4c0s51c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/arabtex")
    (synopsis "Macros and fonts for typesetting Arabic")
    (description
     "ArabTeX is a package extending the capabilities of TeX and LaTeX to
generate Arabic and Hebrew text.  Input may be in ASCII transliteration or
other encodings (including UTF-8); output may be Arabic, Hebrew, or any of
several languages that use the Arabic script.  ArabTeX consists of a TeX macro
package and Arabic and Hebrew fonts (provided both in Metafont format and
Adobe Type 1).  The Arabic font is presently only available in the Naskhi
style.  ArabTeX will run with Plain TeX and also with LaTeX.")
    (license license:lppl)))

(define-public texlive-arara
  (package
    (name "texlive-arara")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/arara.1"
                                     "doc/man/man1/arara.man1.pdf"
                                     "doc/support/arara/" "scripts/arara/"
                                     "source/support/arara/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13wqpc586vmk2c3fj2w1ykixrgfkjnwiplb1ra5mia9m53g6s7wz"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "icedtea")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:link-scripts #~(list "arara.sh")
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'locate-java
            (lambda* (#:key inputs #:allow-other-keys)
              (substitute* "scripts/arara/arara.sh"
                (("java") (search-input-file inputs "/bin/java"))))))))
    (inputs (list icedtea))
    (home-page "https://ctan.org/pkg/arara")
    (synopsis "Automation of LaTeX compilation")
    (description
     "Arara is comparable with other well-known compilation tools like
@command{latexmk} and @command{rubber}.  The key difference is that Arara
determines its actions from metadata in the source code, rather than relying
on indirect resources, such as log file analysis.  Arara requires a Java
virtual machine.")
    (license license:bsd-3)))

(define-public texlive-aramaic-serto
  (package
    (name "texlive-aramaic-serto")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/aramaic-serto/"
                                     "fonts/afm/public/aramaic-serto/"
                                     "fonts/map/dvips/aramaic-serto/"
                                     "fonts/source/public/aramaic-serto/"
                                     "fonts/tfm/public/aramaic-serto/"
                                     "fonts/type1/public/aramaic-serto/"
                                     "tex/latex/aramaic-serto/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "154bicknhsj8nypnyzr999wj34xli0kfpic9vym805abxbpwrmsw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/aramaic-serto")
    (synopsis "Fonts and LaTeX for Syriac written in Serto")
    (description
     "This package enables (La)TeX users to typeset words or phrases (e-TeX
extensions are needed) in Syriac (Aramaic) using the Serto-alphabet.  The
package includes a preprocessor written in Python in order to deal with
right-to-left typesetting for those who do not want to use e-LaTeX and to
choose the correct letter depending on word context (initial/medial/final
form).")
    (license license:lppl1.3+)))

(define-public texlive-archaeologie
  (package
    (name "texlive-archaeologie")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/archaeologie/"
                                     "doc/latex/archaeologie/"
                                     "source/latex/archaeologie/"
                                     "tex/latex/archaeologie/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17wffhg034ja4iy6sikyhfh97gvjhk2020bpk3zqmh13wkh2p6cg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/archaeologie")
    (synopsis "Citation-style for the German Archaeological Institute")
    (description
     "This citation-style covers the citation and bibliography rules of the
German Archaeological Institute (DAI).  Various options are available to
change and adjust the outcome according to one's own preferences.")
    (license license:lppl1.3+)))

(define-public texlive-archaic
  (package
    (name "texlive-archaic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/archaic/"
                                     "fonts/afm/public/archaic/"
                                     "fonts/map/dvips/archaic/"
                                     "fonts/source/public/archaic/"
                                     "fonts/tfm/public/archaic/"
                                     "fonts/type1/public/archaic/"
                                     "source/fonts/archaic/"
                                     "tex/latex/archaic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a6lp4w9b76q1w30a58205b1n7jf61n58ps2hdxrhpg9nxqwy1w0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/archaic")
    (synopsis "Collection of archaic fonts")
    (description
     "The collection contains fonts to represent Aramaic, Cypriot,
Etruscan, Greek of the 6th and 4th centuries BCE, Egyptian hieroglyphics,
Linear A, Linear B, Nabatean old Persian, the Phaistos disc, Phoenician,
proto-Semitic, runic, South Arabian Ugaritic and Viking scripts.  The bundle
also includes a small font for use in phonetic transcription of the archaic
writings.")
    (license license:lppl)))

(define-public texlive-archivo
  (package
    (name "texlive-archivo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/archivo/"
                                     "fonts/enc/dvips/archivo/"
                                     "fonts/map/dvips/archivo/"
                                     "fonts/opentype/public/archivo/"
                                     "fonts/tfm/public/archivo/"
                                     "fonts/type1/public/archivo/"
                                     "fonts/vf/public/archivo/"
                                     "tex/latex/archivo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wdvr7ch2ydj41yd0xniwppb5wh1m9w97d839fhmp21lgyhss0jl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/archivo")
    (synopsis "Archivo font face with support for LaTeX and pdfLaTeX")
    (description
     "This package provides the Archivo family of fonts designed by
Omnibus-Type, with support for LaTeX and pdfLaTeX.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-arimo
  (package
    (name "texlive-arimo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/arimo/"
                                     "fonts/enc/dvips/arimo/"
                                     "fonts/map/dvips/arimo/"
                                     "fonts/tfm/google/arimo/"
                                     "fonts/truetype/google/arimo/"
                                     "fonts/type1/google/arimo/"
                                     "fonts/vf/google/arimo/"
                                     "tex/latex/arimo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06m23slsvcp0pm2ds2rxmgj0qrrvy8qknda4yjhvcz9almwb4syx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/arimo")
    (synopsis "Arimo sans serif fonts with LaTeX support")
    (description
     "The Arimo family, designed by Steve Matteson, is a refreshing sans serif
design which is metrically compatible with Arial.")
    (license license:asl2.0)))

(define-public texlive-armtex
  (package
    (name "texlive-armtex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/armenian/"
                                     "fonts/afm/public/armenian/"
                                     "fonts/map/dvips/armenian/"
                                     "fonts/source/public/armenian/"
                                     "fonts/tfm/public/armenian/"
                                     "fonts/type1/public/armenian/"
                                     "tex/latex/armenian/"
                                     "tex/plain/armenian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00y0kb6kmfa8d2sqsya93b312170p3vgcd0q9b9l96vys45npx8n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/armtex")
    (synopsis "System for writing in Armenian with TeX and LaTeX")
    (description
     "ArmTeX is a system for typesetting Armenian text with Plain TeX or LaTeX(2e).
It may be used with input: from a standard Latin keyboard without any special
encoding or support for Armenian letters, from any keyboard which uses an
encoding that has Armenian letters in the second half (characters 128-255) of
the extended ASCII table (for example ArmSCII8 Armenian standard), or from an
Armenian keyboard using UTF-8 encoding.")
    (license license:lppl)))

(define-public texlive-around-the-bend
  (package
    (name "texlive-around-the-bend")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/around-the-bend/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00nc6kx4ylz9g6vmjlgyjvmy1ls86pjblbcpm5z40wh5xl7l184f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/around-the-bend")
    (synopsis "Typeset exercises in TeX, with answers")
    (description
     "This is a typeset version of the files of the @code{aro-bend}, plus
three extra questions (with their answers) that Michael Downes didn't manage
to get onto CTAN.")
    (license license:lppl)))

(define-public texlive-arphic
  (package
    (name "texlive-arphic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/arphic/"
                                     "dvips/arphic/"
                                     "fonts/afm/arphic/bkaiu/"
                                     "fonts/afm/arphic/bsmiu/"
                                     "fonts/afm/arphic/gbsnu/"
                                     "fonts/afm/arphic/gkaiu/"
                                     "fonts/map/dvips/arphic/"
                                     "fonts/tfm/arphic/bkaimp/"
                                     "fonts/tfm/arphic/bkaiu/"
                                     "fonts/tfm/arphic/bsmilp/"
                                     "fonts/tfm/arphic/bsmiu/"
                                     "fonts/tfm/arphic/gbsnlp/"
                                     "fonts/tfm/arphic/gbsnu/"
                                     "fonts/tfm/arphic/gkaimp/"
                                     "fonts/tfm/arphic/gkaiu/"
                                     "fonts/type1/arphic/bkaiu/"
                                     "fonts/type1/arphic/bsmiu/"
                                     "fonts/type1/arphic/gbsnu/"
                                     "fonts/type1/arphic/gkaiu/"
                                     "fonts/vf/arphic/bkaimp/"
                                     "fonts/vf/arphic/bsmilp/"
                                     "fonts/vf/arphic/gbsnlp/"
                                     "fonts/vf/arphic/gkaimp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sqsgw9xjgd3ss2q7hwnb3vv38sg7l9i8bvsy79m5hyg29wn973x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/arphic")
    (synopsis "Arphic (Chinese) font packages")
    (description
     "These are font bundles for the Chinese Arphic fonts which work with the
CJK package.  TrueType versions of these fonts for use with XeLaTeX and
LuaLaTeX are provided by the @code{arphic-ttf} package.")
    ;; The files are generated from `chinese-fonts-truetype', located in
    ;; non-GNU FTP site, using the license below.
    (license license:arphic-1999)))

(define-public texlive-arphic-ttf
  (package
    (name "texlive-arphic-ttf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/arphic-ttf/"
                                     "fonts/truetype/public/arphic-ttf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "141hsz7lhqpbz3k10kl57bg21yslrb562alk1a6q129i56zb7jby"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/arphic-ttf")
    (synopsis "TrueType version of Chinese Arphic fonts")
    (description
     "This package provides TrueType versions of the Chinese Arphic fonts for
use with XeLaTeX and LuaLaTeX.  Type1 versions of these fonts, for use with
pdfLaTeX and the @code{cjk} package, are provided by the @code{arphic}
package.")
    (license license:arphic-1999)))

(define-public texlive-arsclassica
  (package
    (name "texlive-arsclassica")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/arsclassica/"
                                     "tex/latex/arsclassica/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cxmp68na3ww565r7ixqbhsy2mp063wwq5p6gwvq5fdrk34ci2a5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/arsclassica")
    (synopsis "Different view of the ClassicThesis package")
    (description
     "The package changes some typographical points of the ClassicThesis
style.  It enables the user to reproduce the look of the guide @emph{The art
of writing with LaTeX} (the web page is in Italian).")
    (license license:lppl)))

(define-public texlive-articleingud
  (package
    (name "texlive-articleingud")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/articleingud/"
                                     "source/latex/articleingud/"
                                     "tex/latex/articleingud/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1iprjpjr3yav8afmgirrfmdipxb1fmdwa3b0ss5y8l7wspijmmp8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/articleingud")
    (synopsis "LaTeX class for articles published in INGENIERIA review")
    (description
     "The package provides a class for articles published in INGENIERIA
review.  This class is derived from the standard LaTeX class @code{article}.")
    (license license:lppl1.2+)))

(define-public texlive-arvo
  (package
    (name "texlive-arvo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/arvo/"
                                     "fonts/enc/dvips/arvo/"
                                     "fonts/map/dvips/arvo/"
                                     "fonts/tfm/public/arvo/"
                                     "fonts/truetype/public/arvo/"
                                     "fonts/vf/public/arvo/"
                                     "tex/latex/arvo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dc52n81wxz06vfbxzmfdp9j6a217v8yf8bczqlnx5vgzy8wlmi3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/arvo")
    (synopsis "Arvo font face with support for LaTeX and pdfLaTeX")
    (description
     "This package provides the Arvo family of fonts, designed by Anton
Koovit, with support for LaTeX and pdfLaTeX.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-asaetr
  (package
    (name "texlive-asaetr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/asaetr/" "doc/latex/asaetr/"
                                     "tex/latex/asaetr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yms34l9nx151vgjrjsa94801q0bgp2khjgk933iy1bpkmm7jf2d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/asaetr")
    (synopsis "Transactions of the ASAE")
    (description
     "This package provides a class and BibTeX style for submissions to the
@emph{Transactions of the American Society of Agricultural Engineers}.  Also
included is the Metafont source of a slanted Computer Modern Caps and Small
Caps font.")
    (license license:public-domain)))

(define-public texlive-asapsym
  (package
    (name "texlive-asapsym")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/asapsym/"
                                     "fonts/opentype/omnibus-type/asapsym/"
                                     "source/fonts/asapsym/"
                                     "tex/generic/asapsym/"
                                     "tex/latex/asapsym/"
                                     "tex/plain/asapsym/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "038adcagkzy1bj5y9i5a4i5kbyr3wg7w0lfhbbg9z7glqmivilic"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/asapsym")
    (synopsis "Using the ASAP Symbol font with LaTeX and Plain TeX")
    (description
     "The package provides macros (usable with LaTeX or Plain TeX) for using
the ASAP Symbol font, which is also included.  The font is distributed in
OpenType format, and makes extensive use of OpenType features.  Therefore, at
this time, only XeTeX and LuaTeX are supported.")
    (license license:lppl1.3+)))

(define-public texlive-ascelike
  (package
    (name "texlive-ascelike")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/ascelike/" "doc/latex/ascelike/"
                                     "tex/latex/ascelike/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14n4z4agsnnvms51r142q0r5bv9yqp4gchrr7zvakkp2r3232dai"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ascelike")
    (synopsis "Bibliography style for the ASCE")
    (description
     "This package provides a document class and bibliographic style that
prepares documents in the style required by the @acronym{ASCE, American
Society of Civil Engineers}.  These are unofficial files, not sanctioned by
that organization.")
    (license license:lppl)))

(define-public texlive-ascii-chart
  (package
    (name "texlive-ascii-chart")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/ascii-chart/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m2x7iwz80plq6hbhp9xia6bp8wbi03iifs0pkr7ji3gn8hqgh1r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ascii-chart")
    (synopsis "ASCII wall chart")
    (description
     "This package contains an ASCII wall chart.  The document may be
converted between Plain TeX and LaTeX by a simple editing action.")
    (license license:lppl1.3+)))

(define-public texlive-ascii-font
  (package
    (name "texlive-ascii-font")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/ascii-font/"
                                     "fonts/map/dvips/ascii-font/"
                                     "fonts/tfm/public/ascii-font/"
                                     "fonts/type1/public/ascii-font/"
                                     "source/fonts/ascii-font/"
                                     "tex/latex/ascii-font/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cbzvbszxyv552z1274m3bf5k40xr8w12da17db0w2w02y47nyq5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ascii-font")
    (synopsis "Use the ASCII font in LaTeX")
    (description
     "The package provides glyph and font access commands so that LaTeX users
can use the ASCII glyphs in their documents.  The ASCII font is encoded
according to the IBM PC Code Page 437 C0 Graphics.")
    (license license:lppl)))

(define-public texlive-ascmac
  (package
    (name "texlive-ascmac")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ascmac/"
                                     "fonts/map/dvips/ascmac/"
                                     "fonts/source/public/ascmac/"
                                     "fonts/tfm/public/ascmac/"
                                     "fonts/type1/public/ascmac/"
                                     "source/latex/ascmac/"
                                     "tex/latex/ascmac/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1d388nqyjipqsgd0pd4zrskaf3wddacg6rrmy3q1n8pvmna4gmz1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/ascmac")
    (synopsis "Boxes and picture macros with Japanese vertical writing support")
    (description
     "The bundle provides boxes and picture macros with Japanese vertical
writing support.  It uses only native picture macros and fonts for drawing
boxes and is thus driver independent.")
    (license license:bsd-3)))

(define-public texlive-asmeconf
  (package
    (name "texlive-asmeconf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/asmeconf/" "doc/latex/asmeconf/"
                                     "tex/latex/asmeconf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sgpm9avf7s81xzq80ny0d0i2zvhgjz3iqnbx5xpwkrk82gi3qsv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/asmeconf")
    (synopsis "LaTeX template for ASME conference papers")
    (description
     "The @code{asmeconf} class provides a LaTeX template for ASME conference
papers, following ASME's guidelines for margins, fonts, headings, captions,
and reference formats as of 2022.  This LaTeX template is intended to be used
with the @file{asmeconf.bst} BibTeX style, for reference formatting, which is
part of this distribution.  The code is compatible with pdfLaTeX or LuaLaTeX.

This LaTeX template is not a publication of ASME.")
    (license license:expat)))

(define-public texlive-asmejour
  (package
    (name "texlive-asmejour")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/asmejour/" "doc/latex/asmejour/"
                                     "tex/latex/asmejour/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13znp2mmizab1993f00f2pq3wg104z5vndnqgszbnia2yxr9g18f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/asmejour")
    (synopsis "Template for ASME journal papers")
    (description
     "The @code{asmejour} class provides a template to format preprints
submitted to ASME journals.  The layout and reference formats closely follow
the style that is currently being used for published papers.  The class is
intended to be used with the @file{asmejour.bst} BibTeX style, which is part
of this distribution. The class is compatible with pdfLaTeX or LuaLaTeX.

This package is not a publication of ASME.")
    (license license:expat)))

(define-public texlive-aspectratio
  (package
    (name "texlive-aspectratio")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/aspectratio/"
                                     "fonts/map/dvips/aspectratio/"
                                     "fonts/source/public/aspectratio/"
                                     "fonts/tfm/public/aspectratio/"
                                     "fonts/type1/public/aspectratio/"
                                     "tex/latex/aspectratio/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vm1aj4mm2rn2p032nakg16gmyzv43149h2v1l18dw72sayqqg2s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/aspectratio")
    (synopsis "Capital @samp{A} and capital @samp{R} ligature for Aspect Ratio")
    (description
     "The package provides fonts (both as Adobe Type 1 format, and as Metafont
source) for the AR symbol (for Aspect Ratio) used by aeronautical scientists
and engineers.  Note that the package supersedes the package @code{ar}.")
    (license license:lppl)))

(define-public texlive-asternote
  (package
    (name "texlive-asternote")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/asternote/"
                                     "tex/latex/asternote/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a53pmw237lm1yjx55qwq3fq6jq34vlw03w62vrq3ksw9346dg5r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/asternote")
    (synopsis "Annotation symbols enclosed in square brackets with an asterisk")
    (description
     "This LaTeX package can output annotation symbols enclosed in square
brackets and marked with an asterisk.")
    (license license:expat)))

(define-public texlive-astro
  (package
    (name "texlive-astro")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/astro/"
                                     "fonts/source/public/astro/"
                                     "fonts/tfm/public/astro/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pdmn93wiarwplha6r59ap9nvhdm9ir4aa4az93w3b189g316g2c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/astro")
    (synopsis "Astronomical (planetary) symbols")
    (description
     "Astrosym is a font containing astronomical symbols, including those used
for the planets, four planetoids, the phases of the moon, the signs of the
zodiac, and some additional symbols.  The font is distributed as Metafont
source.")
    (license license:lppl)))

(define-public texlive-asymptote-by-example-zh-cn
  (package
    (name "texlive-asymptote-by-example-zh-cn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/asymptote-by-example-zh-cn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0854pbh3rm21rzzbhai7xijzw26qawffj4wd3mrwbva1406106ff"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/asymptote-by-example-zh-cn")
    (synopsis "Asymptote by example")
    (description "This is an Asymptote tutorial written in Simplified
Chinese.")
    (license license:gpl3+)))

(define-public texlive-asymptote-faq-zh-cn
  (package
    (name "texlive-asymptote-faq-zh-cn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/asymptote-faq-zh-cn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0z09f5as68dz66dlj370xfx593bv50ihxx10zxmm9lk27ymr52hb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/asymptote-faq-zh-cn")
    (synopsis "Asymptote FAQ (Chinese translation)")
    (description "This is a Chinese translation of the Asymptote FAQ.")
    (license license:lppl)))

(define-public texlive-asymptote-manual-zh-cn
  (package
    (name "texlive-asymptote-manual-zh-cn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/asymptote-manual-zh-cn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "047l3bh8vvk185wkazyfw4dm6893xpa2ksn5vfc57r5rv4x16wmb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/asymptote-manual-zh-cn")
    (synopsis "Chinese translation of the Asymptote manual")
    (description
     "This is an (incomplete, simplified) Chinese translation of the Asymptote
manual.")
    (license license:lgpl3+)))

(define-public texlive-atkinson
  (package
    (name "texlive-atkinson")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/atkinson/"
                                     "fonts/enc/dvips/atkinson/"
                                     "fonts/map/dvips/atkinson/"
                                     "fonts/opentype/public/atkinson/"
                                     "fonts/tfm/public/atkinson/"
                                     "fonts/type1/public/atkinson/"
                                     "fonts/vf/public/atkinson/"
                                     "tex/latex/atkinson/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00wg21v7jiaw3qajdxp2jih5xjpv7h8d0n1d6zjnzkxzk0p8zcj0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/atkinson")
    (synopsis "Support for the Atkinson Hyperlegible family of fonts")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the Atkinson Hyperlegible family of fonts.  What makes it different from
traditional typography design is that it focuses on letterform distinction to
increase character recognition, ultimately improving readability.")
    (license
     (list license:lppl
           (license:fsdg-compatible
            "file://doc/Atkinson-Hyperlegible-Font-License-2020-1104.pdf")))))

(define-public texlive-aucklandthesis
  (package
    (name "texlive-aucklandthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/aucklandthesis/"
                                     "tex/latex/aucklandthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bdm6crn17a0rrszx28r6bn8v9w6z4rwfz2r8avd5fc3byl5dix8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/aucklandthesis")
    (synopsis "Memoir-based class for formatting University of Auckland theses")
    (description
     "This package provides a @code{memoir}-based class for formatting
University of Auckland masters and doctors thesis dissertations in any
discipline.  The title page does not handle short dissertations for
diplomas.")
    (license license:lppl1.3+)))

(define-public texlive-augie
  (package
    (name "texlive-augie")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/augie/"
                                     "fonts/afm/public/augie/"
                                     "fonts/map/dvips/augie/"
                                     "fonts/tfm/public/augie/"
                                     "fonts/type1/public/augie/"
                                     "fonts/vf/public/augie/"
                                     "tex/latex/augie/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fvl04lcvi4vsx547gx349dbld4hf7k2j08adqlnszs23p95yj3f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/augie")
    (synopsis "Calligraphic font for typesetting handwriting")
    (description
     "This package provides a calligraphic font for simulating American-style
informal handwriting.  The font is distributed in Adobe Type 1 format.")
    (license license:lppl)))

(define-public texlive-auncial-new
  (package
    (name "texlive-auncial-new")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/auncial-new/"
                                     "fonts/afm/public/auncial-new/"
                                     "fonts/map/dvips/auncial-new/"
                                     "fonts/tfm/public/auncial-new/"
                                     "fonts/type1/public/auncial-new/"
                                     "source/fonts/auncial-new/"
                                     "tex/latex/auncial-new/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1644ank81l1qlijmld88k1qq3qk4x6an0qvyqz1da2dgwdhjap00"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/auncial-new")
    (synopsis "Artificial Uncial font and LaTeX support macros")
    (description
     "The @code{auncial-new} bundle provides packages and fonts for a script
based on the Artificial Uncial manuscript book-hand used between the 6th &
10th century AD.  The script consists of minuscules and digits, with some
appropriate period punctuation marks.  Both normal and bold versions are
provided, and the font is distributed in Adobe Type 1 format.")
    (license license:lppl)))

(define-public texlive-aurical
  (package
    (name "texlive-aurical")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/aurical/"
                                     "fonts/afm/public/aurical/"
                                     "fonts/map/dvips/aurical/"
                                     "fonts/source/public/aurical/"
                                     "fonts/tfm/public/aurical/"
                                     "fonts/type1/public/aurical/"
                                     "tex/latex/aurical/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jaqr4gdywnjn7hclinjyydndxsa1f2j7382ygl0jnj35kxz0pkr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/aurical")
    (synopsis "Calligraphic fonts for use with LaTeX in T1 encoding")
    (description
     "The package that implements a set (AuriocusKalligraphicus) of three
calligraphic fonts derived from the author's handwriting in Adobe Type
1 Format, T1 encoding for use with LaTeX: Auriocus Kalligraphicus; Lukas
Svatba; and Jana Skrivana.  Each font features old style digits
and (machine-generated) boldface and slanted versions.  A variant of Lukas
Svatba offers a long @samp{s}.")
    (license license:lppl)))

(define-public texlive-authordate
  (package
    (name "texlive-authordate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/authordate/"
                                     "doc/bibtex/authordate/"
                                     "tex/latex/authordate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d3cd63b80vfd8vzbpn6dnhy47fpq5rxm95i52id2j6606gi1skf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/authordate")
    (synopsis "Author/date style citation styles")
    (description
     "The bundle provides four BibTeX styles (@code{authordate1}, ...,
@code{authordate4}), and a LaTeX package, for citation in author/date style.
The BibTeX styles differ in how they format names and titles; one of them is
necessary for the LaTeX package to work.")
    (license license:knuth)))

(define-public texlive-auto-pst-pdf
  (package
    (name "texlive-auto-pst-pdf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/auto-pst-pdf/"
                                     "source/latex/auto-pst-pdf/"
                                     "tex/latex/auto-pst-pdf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lpjwqd0rhdzz3kywl54pjlpj1qsj7kflj0336vj2zb20rxl0hqp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-ifplatform texlive-iftex texlive-xkeyval))
    (home-page "https://ctan.org/pkg/auto-pst-pdf")
    (synopsis "Wrapper for @code{pst-pdf} (with some PSfrag features)")
    (description
     "The package uses @samp{--shell-escape} to execute @code{pst-pdf} when necessary.
Wrappers are provided for various psfrag-related features so that Matlab
figures via @code{laprint}, Mathematica figures via MathPSfrag, and regular
PSfrag figures can all be input consistently and easily.")
    (license license:lppl1.3c)))

(define-public texlive-autoaligne
  (package
    (name "texlive-autoaligne")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/autoaligne/"
                                     "tex/generic/autoaligne/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "138d030zgzpdwqxx55gjw35y0c3v794fpa3c6znc9kv1vj8cs9d3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/autoaligne")
    (synopsis "Align terms and members in math expressions")
    (description
     "This package aligns terms and members between lines containing
math expressions.")
    (license license:lppl1.3c)))

(define-public texlive-autobreak
  (package
    (name "texlive-autobreak")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/autobreak/"
                                     "source/latex/autobreak/"
                                     "tex/latex/autobreak/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xw4m1wyv17xi6yjfcamb1gjdwzbhrjjdpyc8fydq1qbki1yvv1k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/autobreak")
    (synopsis "Simple line breaking of long formulae")
    (description
     "This package implements a simple mechanism of line or page breaking
within the @code{align} environment of the @code{amsmath} package; new line
characters are considered as possible candidates for the breaks and the
package tries to put breaks at adequate places.  It is suitable for
computer-generated long formulae with many terms.")
    (license license:lppl1.3+)))

(define-public texlive-autosp
  (package
    (name "texlive-autosp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/autosp/"
                                     "doc/man/man1/autosp.1"
                                     "doc/man/man1/autosp.man1.pdf"
                                     "doc/man/man1/tex2aspc.1"
                                     "doc/man/man1/tex2aspc.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n9vpb0cmi0b9gbi3f70zafvhj9znvfhd9614xcn49jwss2bwdk9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-autosp-bin))
    (home-page "https://ctan.org/pkg/autosp")
    (synopsis
     "Preprocessor generating note-spacing commands for MusiXTeX scores")
    (description
     "This program simplifies the creation of MusiXTeX scores by converting
(non-standard) commands of the form @code{\\anotes ... \\en} into one or more
conventional note-spacing commands, as determined by the note values
themselves, with @code{\\sk} spacing commands inserted as necessary.  The
coding for an entire measure can be entered one part at a time, without
concern for note-spacing changes within the part or spacing requirements of
other parts.")
    (license license:gpl2+)))

(define-public texlive-autosp-bin
  (package
    (inherit texlive-bin)
    (name "texlive-autosp-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '("autosp"))
            (delete-other-directories "texk" '())))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-autosp" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "utils/autosp"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda* (#:key inputs native-inputs #:allow-other-keys)
                (with-directory-excursion "utils/autosp"
                  (invoke "make" "install"))))))))
    (native-inputs '())
    (inputs '())
    (propagated-inputs '())
    (home-page (package-home-page texlive-autosp))
    (synopsis "Binaries for @code{texlive-autosp}")
    (description
     "This package provides binaries for @code{texlive-autosp}.")
    (license (package-license texlive-autosp))))

(define-public texlive-axodraw2
  (package
    (name "texlive-axodraw2")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/axodraw2/"
                                     "doc/man/man1/axohelp.1"
                                     "doc/man/man1/axohelp.man1.pdf"
                                     "source/latex/axodraw2/"
                                     "tex/latex/axodraw2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0x1cskdm3kmf08gdrvgasd1b3l0dri9mdmk13880dz4g2rdgbvi2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-axodraw2-bin))
    (home-page "https://ctan.org/pkg/axodraw2")
    (synopsis "Feynman diagrams in a LaTeX document")
    (description
     "This package defines macros for drawing Feynman graphs in LaTeX documents.
It is an important update of the @code{axodraw} package, but since it is not
completely backwards compatible, we have given the style file a changed name.

Many new features have been added, with new types of line, and much more
flexibility in their properties.  In addition, it is now possible to use
@code{axodraw2} with pdfLaTeX, as well as with the LaTeX-dvips method.
However with pdfLaTeX (and also LuaLaTeX and XeLaTeX), an external program,
@command{axohelp}, is used to perform the geometrical calculations needed for
the pdf code inserted in the output file.  The processing involves a run of
@command{pdflatex}, a run of @command{axohelp}, and then another run of
@command{pdflatex}.")
    (license license:gpl3+)))

(define-public texlive-axodraw2-bin
  (package
    (inherit texlive-bin)
    (name "texlive-axodraw2-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root keep)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir
                       "."
                       (lambda (file)
                         (and (not (member file (append keep '("." ".."))))
                              (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '("axodraw2"))
            (delete-other-directories "texk" '())))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-axodraw2" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "utils/axodraw2"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "utils/axodraw2"
                  (invoke "make" "install"))))))))
    (native-inputs '())
    (inputs '())
    (propagated-inputs '())
    (home-page (package-home-page texlive-axodraw2))
    (synopsis "Binary for @code{texlive-axodraw2}")
    (description
     "This package provides the binary for @code{texlive-axodraw2}.")
    (license (package-license texlive-axodraw2))))

(define-public texlive-b1encoding
  (package
    (name "texlive-b1encoding")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/b1encoding/"
                                     "fonts/enc/dvips/b1encoding/"
                                     "source/latex/b1encoding/"
                                     "tex/latex/b1encoding/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lzsa0k5rr0n50d31dh4ghww329qjpg39w843zmh05z0jir6rg79"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/b1encoding")
    (synopsis "LaTeX encoding tools for Bookhands fonts")
    (description
     "The package characterises and defines the author's B1 encoding for use
with LaTeX when typesetting things using his Bookhands fonts.")
    (license license:lppl1.3+)))

(define-public texlive-backnaur
  (package
    (name "texlive-backnaur")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/backnaur/"
                                     "source/latex/backnaur/"
                                     "tex/latex/backnaur/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "168ng265vdl74l9c2jmp34ba6ir5i6c1jb7jpyzc31g9snqmyr09"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/backnaur")
    (synopsis "Typeset Backus Naur Form definitions")
    (description
     "The package typesets Backus-Naur Form (BNF) definitions.  It prints
formatted lists of productions, with numbers if required.  It can also print
in-line BNF expressions using math mode.")
    (license license:lppl1.3c)))

(define-public texlive-baekmuk
  (package
    (name "texlive-baekmuk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/baekmuk/"
                                     "fonts/truetype/public/baekmuk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nc6sfjbimh1g8zhcl58ag6kqskhwd3h0m68y7k2v3v5i9n5g5yr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/baekmuk")
    (synopsis "Baekmuk Korean TrueType fonts")
    (description
     "This bundle consists of four Korean fonts: @file{batang.ttf} (serif),
@file{dotum.ttf} (sans-serif), @file{gulim.ttf} (sans-serif rounded) and
@file{hline.ttf} (headline).")
    (license license:expat)))

(define-public texlive-bagpipe
  (package
    (name "texlive-bagpipe")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/bagpipe/"
                                     "tex/generic/bagpipe/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zybnikkj00hmlzfaaljcq1ml5vi6qfhl1hfrjq9vjc409vzzvka"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bagpipe")
    (synopsis "Support for typesetting bagpipe music")
    (description
     "Typesetting bagpipe music in MusixTeX is needlessly tedious.  This
package provides specialized and re-defined macros to simplify this task.")
    (license license:lppl1.3+)))

(define-public texlive-bangla
  (package
    (name "texlive-bangla")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bangla/"
                                     "fonts/truetype/public/bangla/"
                                     "tex/latex/bangla/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0basibrsbns9s2ny6ny95hl6dj4rjf6q4z9bqn2kc9945akxg8af"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-charissil texlive-doulossil))
    (home-page "https://ctan.org/pkg/bangla")
    (synopsis "Comprehensive Bangla LaTeX package")
    (description
     "This package provides all the necessary LaTeX frontends for the Bangla
language and comes with some fonts of its own.")
    (license (list license:lppl1.3c license:silofl1.1))))

(define-public texlive-bangorcsthesis
  (package
    (name "texlive-bangorcsthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bangorcsthesis/"
                                     "source/latex/bangorcsthesis/"
                                     "tex/latex/bangorcsthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "138h5q8060z7frb6krrzcx49pd0ifqh1lizi465gs6x7q7cdagz8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bangorcsthesis")
    (synopsis "Typeset a thesis at Bangor University")
    (description
     "The class typesets thesis or dissertation documents for all
levels (i.e., both undergraduate and graduate students may use the class).  It
also provides macros designed to optimise the process of producing a thesis.")
    (license license:lppl1.3+)))

(define-public texlive-bangorexam
  (package
    (name "texlive-bangorexam")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bangorexam/"
                                     "source/latex/bangorexam/"
                                     "tex/latex/bangorexam/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09pp88415mba65icf6cx4vqn3an54hrgkd8s677ndlf2ml7n0lhs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bangorexam")
    (synopsis "Typeset an examination at Bangor University")
    (description
     "The package allows typesetting of Bangor Univesity's exam style.  It
currently supports a standard A/B choice, A-only compulsory and n from m exam
styles.  Marks are totalled and checked automatically.")
    (license license:lppl1.3+)))

(define-public texlive-bangtex
  (package
    (name "texlive-bangtex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bangtex/"
                                     "fonts/source/public/bangtex/"
                                     "fonts/tfm/public/bangtex/"
                                     "tex/latex/bangtex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hmv27wpnwv70gipvfvxs1rwfjqbcy0lgn09hs2ah6ayqgr740im"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/bangtex")
    (synopsis "Writing Bangla and Assamese with LaTeX")
    (description
     "The bundle provides class files for writing Bangla and Assamese with LaTeX,
and Metafont sources for fonts.")
    (license license:lppl)))

(define-public texlive-barr
  (package
    (name "texlive-barr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/barr/" "tex/generic/barr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1l532g0nxigbllv2lf74bwx78sf4jsfr1cad0hpq7i7kq820wbii"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/diagxy")
    (synopsis "Diagram macros by Michael Barr")
    (description
     "Diagxy is a general diagramming package, useful for diagrams in a number
of mathematical disciplines.")
    (license license:lppl1.3+)))

(define-public texlive-bartel-chess-fonts
  (package
    (name "texlive-bartel-chess-fonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/bartel-chess-fonts/"
                                     "fonts/source/public/bartel-chess-fonts/"
                                     "fonts/tfm/public/bartel-chess-fonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gg7g2gb5j0g0ig4190260zlpnyfmdzcqn7dsw5kp9p5pbn5hbhf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    ;; FIXME: Font metrics generation fails with "! Strange path (turning
    ;; number is zero)." error.
    (arguments
     (list #:phases
           #~(modify-phases %standard-phases
               (delete 'generate-font-metrics))))
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/bartel-chess-fonts")
    (synopsis "Set of fonts supporting chess diagrams")
    (description "This package provides fonts supporting chess diagrams.")
    (license license:gpl3+)))

(define-public texlive-baskervald
  (package
    (name "texlive-baskervald")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/baskervald/"
                                     "fonts/afm/arkandis/baskervald/"
                                     "fonts/enc/dvips/baskervald/"
                                     "fonts/map/dvips/baskervald/"
                                     "fonts/tfm/arkandis/baskervald/"
                                     "fonts/type1/arkandis/baskervald/"
                                     "fonts/vf/arkandis/baskervald/"
                                     "source/fonts/baskervald/"
                                     "tex/latex/baskervald/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1alny6nsxm43mn84w16vp2whlhnmqkr7pfx8jsmgkz8bkxzh9pg9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/baskervaldadf")
    (synopsis "Baskervald ADF fonts collection with TeX and LaTeX support")
    (description
     "Baskervald ADF is a serif family with lining figures designed as
a substitute for Baskerville.  The family currently includes upright and
italic or oblique shapes in each of regular, bold and heavy weights.  All
fonts include the slashed zero and additional non-standard ligatures.")
    (license license:lppl)))

(define-public texlive-baskervaldx
  (package
    (name "texlive-baskervaldx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/baskervaldx/"
                                     "fonts/afm/public/baskervaldx/"
                                     "fonts/enc/dvips/baskervaldx/"
                                     "fonts/map/dvips/baskervaldx/"
                                     "fonts/opentype/public/baskervaldx/"
                                     "fonts/tfm/public/baskervaldx/"
                                     "fonts/type1/public/baskervaldx/"
                                     "fonts/vf/public/baskervaldx/"
                                     "tex/latex/baskervaldx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1h3959cxlbjxyw4kf4j3rpjar389kfq1kn9wq89xaifhvcmvll1a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/baskervaldx")
    (synopsis "Extension and modification of BaskervaldADF with LaTeX support")
    (description
     "This package extends and modifies the BaskervaldADF font (a Baskerville
substitute) with more accented glyphs, with small caps and oldstyle figures in
all shapes.  It includes OpenType and PostScript fonts, as well as LaTeX
support files.")
    (license (list license:gpl2+ license:lppl1.3+))))

(define-public texlive-baskervillef
  (package
    (name "texlive-baskervillef")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/baskervillef/"
                                     "fonts/enc/dvips/baskervillef/"
                                     "fonts/map/dvips/baskervillef/"
                                     "fonts/opentype/public/baskervillef/"
                                     "fonts/tfm/public/baskervillef/"
                                     "fonts/type1/public/baskervillef/"
                                     "fonts/vf/public/baskervillef/"
                                     "tex/latex/baskervillef/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "107lqn684kgr7fk3zh1lgi6q7hqz9gs18kkg3fbbrg9qjva1j4xv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/baskervillef")
    (synopsis "Fry's Baskerville look-alike, with math support")
    (description
     "BaskervilleF is a fork from the Libre Baskerville fonts (Roman, Italic,
Bold only).  Their fonts are optimized for web usage, while BaskervilleF is
optimized for traditional TeX usage, normally destined for production of PDF
files.  A bold italic style was added and mathematical support is offered as
an option to @code{newtxmath}.")
    (license (list license:silofl1.1 license:lppl1.3+))))

(define-public texlive-basque-book
  (package
    (name "texlive-basque-book")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/basque-book/"
                                     "source/latex/basque-book/"
                                     "tex/latex/basque-book/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16jgn4pxqbmq2dx5gfyy4p04ykaijkjyy9banp3l3a6ykm2xn8w7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/basque-book")
    (synopsis "Class for book-type documents written in Basque")
    (description
     "The class is derived from the LaTeX @code{book} class.  The extensions
solve grammatical and numeration issues that occur when book-type documents
are written in Basque.  The class is useful for writing books, PhD and Master
Theses, etc., in Basque.")
    (license license:lppl1.2+)))

(define-public texlive-basque-date
  (package
    (name "texlive-basque-date")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/basque-date/"
                                     "source/latex/basque-date/"
                                     "tex/latex/basque-date/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0n1nc2nrwl3ajk1n7xbnf49mvg8dlqlyndsyywgs46dnv55b7gs5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/basque-date")
    (synopsis "Print the date in Basque")
    (description
     "The package provides two LaTeX commands to print the current date in
Basque according to the correct forms ruled by The Basque Language Academy
(Euskaltzaindia).  The commands automatically solve the complex declination
issues of numbers in Basque.")
    (license license:lppl1.2+)))

(define-public texlive-bath-bst
  (package
    (name "texlive-bath-bst")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/bath-bst/"
                                     "doc/bibtex/bath-bst/"
                                     "source/bibtex/bath-bst/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06v5icy6537d69g5in7ps322wgnkf0imd93gnmh2y7fladsmvp06"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bath-bst")
    (synopsis
     "Harvard referencing style recommended by the University of Bath Library")
    (description
     "This package provides a BibTeX style to format reference lists in the
Harvard style recommended by the University of Bath Library.  It should be
used in conjunction with @code{natbib} for citations.")
    (license license:lppl1.3c)))

(define-public texlive-bbding
  (package
    (name "texlive-bbding")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bbding/"
                                     "fonts/source/public/bbding/"
                                     "fonts/tfm/public/bbding/"
                                     "source/latex/bbding/" "tex/latex/bbding/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l507nxnnh880h5kg8q0ww6sl93k441l0lsplr5ldrngxvx1vrsc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/bbding")
    (synopsis "Symbol (dingbat) font and LaTeX macros for its use")
    (description
     "This package provides a symbol font (distributed as Metafont source)
that contains many of the symbols of the Zapf dingbats set, together with an
NFSS interface for using the font.  An Adobe Type 1 version of the fonts is
available in the @code{niceframe} fonts bundle.")
    (license license:lppl)))

(define-public texlive-bbold-type1
  (package
    (name "texlive-bbold-type1")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/bbold-type1/"
                                     "fonts/afm/public/bbold-type1/"
                                     "fonts/map/dvips/bbold-type1/"
                                     "fonts/type1/public/bbold-type1/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1flccfh58w977j9w62mcn7xzspmg68gb6h5nwh2mfbz7l0015fsz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bbold-type1")
    (synopsis "Adobe Type 1 format version of the @code{bbold} font")
    (description
     "The files offer an Adobe Type 1 format version of the 5pt, 7pt and 10pt
versions of the @code{bbold} fonts.")
    ;; The README states: "You may freely use, modify and/or
    ;; distribute this file".
    (license (license:fsf-free "file:doc/fonts/bbold-type1/README"))))

(define-public texlive-bboldx
  (package
    (name "texlive-bboldx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/bboldx/"
                                     "fonts/afm/public/bboldx/"
                                     "fonts/enc/dvips/bboldx/"
                                     "fonts/map/dvips/bboldx/"
                                     "fonts/tfm/public/bboldx/"
                                     "fonts/type1/public/bboldx/"
                                     "tex/latex/bboldx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r4s3yyah0iqwhzss52wjv3wml5r4bywp3fbanjzkv16f2pk51yb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bboldx")
    (synopsis "Extend the @code{bbold} package with a Blackboard Bold alphabet")
    (description
     "This is an extension of @code{bbold} to a package with three weights,
of which the original is considered as light and the additions as regular and
bold.")
    ;; The README states: "You may freely use, modify and/or
    ;; distribute this file".
    (license (license:fsf-free "file://doc/fonts/bboldx/README"))))

(define-public texlive-bclogo
  (package
    (name "texlive-bclogo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bclogo/" "metapost/bclogo/"
                                     "tex/latex/bclogo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "087d4cgv42vf8hh1d5n09zjbd0rl7rs961gzqmp1ha8n8fymadi2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bclogo")
    (synopsis "Creating colourful boxes with logos")
    (description
     "The package facilitates the creation of colorful boxes with a title and logo.
It may use either TikZ or PSTricks as graphics engine.")
    (license license:lppl1.3+)))

(define-public texlive-beamer-fuberlin
  (package
    (name "texlive-beamer-fuberlin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamer-fuberlin/"
                                     "tex/latex/beamer-fuberlin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03zp6gpzilcfgrbz1lh8lpldvkf9g98f45fhsb72ikgjnka6211c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamer-fuberlin")
    (synopsis "Beamer, using the style of FU Berlin")
    (description
     "The bundle provides a @code{beamer}-derived class and a theme style file
for the corporate design of the Free University in Berlin.  Users may use the
class itself (FUbeamer) or use the theme in the usual way with
@code{\\usetheme@{BerlinFU@}}.")
    (license license:lppl)))

(define-public texlive-beamer-verona
  (package
    (name "texlive-beamer-verona")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamer-verona/"
                                     "tex/latex/beamer-verona/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q79bdsc98a3y5h0yb3qwpsd0yyfyaxfjfhn4xkxf2qzyfp1mgd5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamer-verona")
    (synopsis "Theme for the @code{beamer} class")
    (description
     "This package provides the Verona theme for the @code{beamer} class.")
    (license license:lppl1.3+)))

(define-public texlive-beebe
  (package
    (name "texlive-beebe")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/beebe/" "tex/generic/beebe/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1w6n6112mq82gz8mmyfjs1wgqfpy1dln2s49r8dmxzqjakws1486"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblio")
    (synopsis "Collection of bibliographies")
    (description
     "This package provides a collection of BibTeX bibliographies on
TeX-related topics (including, for example, spell-checking and SGML).  Each
includes a LaTeX wrapper file to typeset the bibliography.")
    (license license:public-domain)))

(define-public texlive-begingreek
  (package
    (name "texlive-begingreek")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/begingreek/"
                                     "source/latex/begingreek/"
                                     "tex/latex/begingreek/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1amzzc96pqxjicrgl4fnl2j7b65vvpxl32ckl308nbwfhd56fz6l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/begingreek")
    (synopsis "Greek environment to be used with pdfLaTeX only")
    (description
     "This simple package defines a greek environment to be used with pdfLaTeX
only, that accepts an optional Greek font family name to type its contents
with.  A similar @code{\\greektxt} command does a similar action for shorter
texts.")
    (license license:lppl1.3c)))

(define-public texlive-beilstein
  (package
    (name "texlive-beilstein")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/beilstein/"
                                     "doc/latex/beilstein/"
                                     "source/latex/beilstein/"
                                     "tex/latex/beilstein/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gr4fb0g3449jx6mbwfl2g00anss6xbj9xiak83hkc7797jzmg2b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beilstein")
    (synopsis
     "Support for submissions to the @emph{Beilstein Journal of Nanotechnology}")
    (description
     "The package provides a LaTeX class file and a BibTeX style file in
accordance with the requirements of submissions to the @emph{Beilstein Journal
of Nanotechnology}.")
    (license license:lppl1.3c)))

(define-public texlive-belleek
  (package
    (name "texlive-belleek")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/belleek/"
                                     "fonts/map/dvips/belleek/"
                                     "fonts/truetype/public/belleek/"
                                     "fonts/type1/public/belleek/"
                                     "source/latex/belleek/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12jigkk2xlnfllwaj6qsisgvl5b2kcwnv5j921cvm7gjn9x1i941"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/belleek")
    (synopsis "Replacement for basic MathTime fonts")
    (description "This package replaces the original MathTime fonts.")
    (license license:public-domain)))

(define-public texlive-begriff
  (package
    (name "texlive-begriff")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/begriff/" "tex/latex/begriff/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vi7i35fqi32y26crk5aj93mivix61ppgmpz0djshizwrd9pn9xy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/begriff")
    (synopsis "Typeset Begriffschrift")
    (description
     "The package defines maths mode commands for typesetting Frege's
@emph{Begriffschrift}.")
    (license license:gpl3+)))

(define-public texlive-bengali
  (package
    (name "texlive-bengali")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/bengali/"
                                     "fonts/source/public/bengali/"
                                     "fonts/tfm/public/bengali/"
                                     "source/latex/bengali/" "tex/latex/bengali/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "077rs7rcx592g5m53hy73w6jd39qgb83z5sg2jbymjfwkk7y593h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/bengali-pandey")
    (synopsis "Support for the Bengali language")
    (description
     "The package is based on Velthuis transliteration scheme, with extensions
to deal with the Bengali letters that are not in Devanagari.  The package also
supports Assamese.")
    (license license:lppl)))

(define-public texlive-berenisadf
  (package
    (name "texlive-berenisadf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/berenisadf/"
                                     "fonts/afm/arkandis/berenisadf/"
                                     "fonts/enc/dvips/berenisadf/"
                                     "fonts/map/dvips/berenisadf/"
                                     "fonts/opentype/arkandis/berenisadf/"
                                     "fonts/tfm/arkandis/berenisadf/"
                                     "fonts/type1/arkandis/berenisadf/"
                                     "tex/latex/berenisadf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11daizsls1zhwdfy78s2rjk76zwkziv33xrvrqbxybs2hdbg261d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/berenisadf")
    (synopsis "Berenis ADF fonts and TeX/LaTeX support")
    (description
     "The bundle provides the BerenisADF Pro font collection, in OpenType and
PostScript Type 1 formats, together with support files to use the fonts in
TeXnANSI (LY1) and LaTeX standard T1 and TS1 encodings.")
    ;; (La)TeX support is released under LPPL 1.3+ terms.  Fonts themselves
    ;; use GPL 2+ with exceptions.
    (license (list license:lppl1.3+ license:gpl2+))))

(define-public texlive-besjournals
  (package
    (name "texlive-besjournals")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/besjournals/"
                                     "doc/bibtex/besjournals/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mcc5xa56j17h6wv9b111qypw6ff4mg0skapa4wq79lb8p3l1cmv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/besjournals-bst")
    (synopsis
     "Bibliographies suitable for British Ecological Society journals")
    (description
     "The package provides a BibTeX style for use with journals published by
the British Ecological Society.  The style was produced independently of the
Society, and has no formal approval by the BES.")
    (license license:lppl)))

(define-public texlive-bestpapers
  (package
    (name "texlive-bestpapers")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/bestpapers/"
                                     "doc/bibtex/bestpapers/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c0lp51z5z2707r1hig993gbx78v7zb84wmk3z9iyw08m3bbq34s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bestpapers")
    (synopsis "BibTeX package to produce lists of authors' best papers")
    (description
     "Many people preparing their resumes find the requirement ``please list
five (or six, or ten) papers authored by you''.  The same requirement is often
stated for reports prepared by professional teams.  The creation of such lists
may be a cumbersome task.  Even more difficult is it to support such lists
over the time, when new papers are added.  The BibTeX style
@file{bestpapers.bst} is intended to facilitate this task.  It is based on the
idea that it is easier to score than to sort: we can assign a score to a paper
and then let the computer select the papers with highest scores.")
    (license license:public-domain)))

(define-public texlive-betababel
  (package
    (name "texlive-betababel")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/betababel/"
                                     "tex/latex/betababel/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lck0wighndd3qrhcks6amc6gm5y50f6a61nfcz31j087r3a7liv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/betababel")
    (synopsis "Insert ancient greek text coded in Beta Code")
    (description
     "The @code{betababel} package extends the Babel @samp{polutonikogreek}
option to provide a simple way to insert ancient Greek texts with diacritical
characters into your document using the commonly used Beta Code
transliteration.")
    (license license:lppl)))

(define-public texlive-beuron
  (package
    (name "texlive-beuron")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/beuron/"
                                     "fonts/map/dvips/beuron/"
                                     "fonts/opentype/public/beuron/"
                                     "fonts/source/public/beuron/"
                                     "fonts/tfm/public/beuron/"
                                     "fonts/type1/public/beuron/"
                                     "tex/latex/beuron/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06hk60z0s2rdbj1iard10zxw7zvvm2xds755r4mqh0p70qhkpjzx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/beuron")
    (synopsis "Script of the Beuronese art school")
    (description
     "This package provides the script used in the works of the Beuron art
school for use with TeX and LaTeX.  It is a monumental script consisting of
capital letters only.  The fonts are provided as Metafont sources, in the
Type1 and in the OpenType format.  The package includes suitable font
selection commands for use with LaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-bfh-ci
  (package
    (name "texlive-bfh-ci")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bfh-ci/" "tex/latex/bfh-ci/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "175mb10mcj7yq3ncg2bgm1c9i7rgkmrwbfbw3vdm9m7z526k9g34"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-adjustbox
                             texlive-amsfonts
                             texlive-amsmath
                             texlive-anyfontsize
                             texlive-beamer
                             texlive-fontawesome
                             texlive-fontspec
                             texlive-geometry
                             texlive-graphics
                             texlive-handoutwithnotes
                             texlive-hyperref
                             texlive-iftex
                             texlive-koma-script
                             texlive-l3kernel
                             texlive-l3packages
                             texlive-listings
                             texlive-nunito
                             texlive-pgf
                             texlive-qrcode
                             texlive-sourceserifpro
                             texlive-tcolorbox
                             texlive-tools
                             texlive-translations
                             texlive-url
                             texlive-xcolor
                             texlive-zref))
    (home-page "https://ctan.org/pkg/bfh-ci")
    (synopsis "Corporate design for Bern University of Applied Sciences")
    (description
     "This bundle provides possibilities to use the corporate design of Bern
University of Applied Sciences (BFH) with LaTeX.  To this end it contains
classes as well as some helper packages and config files.")
    (license license:lppl1.3c)))

(define-public texlive-bgteubner
  (package
    (name "texlive-bgteubner")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/bgteubner/"
                                     "doc/latex/bgteubner/"
                                     "makeindex/bgteubner/"
                                     "source/latex/bgteubner/"
                                     "tex/latex/bgteubner/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1plc42glcq2pxyns6lm6fygicjm8whrls1qlfw00fccsw9v1hgxv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'fix-build
            ;; This phase is necessary because the build phase is reluctant to
            ;; generate "ltxdoc.cfg" since there is another one among the
            ;; inputs already.
            (lambda _
              (substitute* "source/latex/bgteubner/hhsubfigure.ins"
                (("\\\\generateFile\\{ltxdoc\\.cfg\\}\\{t\\}")
                 "\\generateFile{ltxdoc.cfg}{f}")))))))
    (home-page "https://ctan.org/pkg/bgteubner")
    (synopsis "Class for producing books for the publisher Teubner Verlag")
    (description
     "The @code{bgteubner} document class has been programmed by order of the
Teubner Verlag, Wiesbaden, Germany, to ensure that books of this publisher
have a unique layout.  Unfortunately, most of the documentation is only
available in German.  Since the document class is intended to generate
a unique layout, many things (layout etc.) are fixed and cannot be altered by
the user.")
    (license license:lppl)))

(define-public texlive-bguq
  (package
    (name "texlive-bguq")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/bguq/"
                                     "fonts/map/dvips/bguq/"
                                     "fonts/source/public/bguq/"
                                     "fonts/tfm/public/bguq/"
                                     "fonts/type1/public/bguq/"
                                     "source/fonts/bguq/"
                                     "tex/latex/bguq/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d87ihzwq3lxhr28yaj1wpkvl4jgcfw8859g9mamrprkm7klm2rb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/bguq")
    (synopsis "Improved quantifier stroke for Begriffsschrift packages")
    (description
     "The font contains a single character: the Begriffsschrift quantifier (in
several sizes), as used to set the Begriffsschrift (concept notation) of
Frege.  The font is not intended for end users; instead it is expected that it
will be used by other packages which implement the Begriffsschrift.")
    (license license:lppl)))

(define-public texlive-bib-fr
  (package
    (name "texlive-bib-fr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/bib-fr/" "doc/bibtex/bib-fr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11af1p52vr16l5gf69ql2zz0328yqd75nbcvik7b0g05pbqc12nv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bib-fr")
    (synopsis "French translation of classical BibTeX styles")
    (description
     "These files are French translations of the classical BibTeX style
files.")
    (license license:lppl)))

(define-public texlive-bib2gls
  (package
    (name "texlive-bib2gls")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/bib2gls.1"
                                     "doc/man/man1/bib2gls.man1.pdf"
                                     "doc/man/man1/convertgls2bib.1"
                                     "doc/man/man1/convertgls2bib.man1.pdf"
                                     "doc/support/bib2gls/"
                                     "scripts/bib2gls/"
                                     "source/support/bib2gls/src/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06jylyhgj53dc424j7ahlxng5wwa2ihf4azx9851h68rylv4i6fh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "bib2gls.sh" "convertgls2bib.sh")))
    (propagated-inputs (list texlive-glossaries-extra))
    (home-page "https://ctan.org/pkg/bib2gls")
    (synopsis
     "Convert @file{.bib} files to @file{glossaries-extra.sty} resource files")
    (description
     "This Java command line application may be used to extract glossary
information stored in a @file{.bib} file and convert it into glossary entry
definition commands.  This application should be used with
@file{glossaries-extra.sty}'s record package option.  It performs two
functions in one: it selects entries according to records found in the
@file{.aux} file (similar to BibTeX), and hierarchically sorts entries and
collates location lists (similar to MakeIndex or Xindy).  The glossary entries
can then be managed in a system such as JabRef, and only the entries that are
actually required will be defined, reducing the resources required by TeX.

The supplementary application @command{convertgls2bib} can be used to convert
existing @file{.tex} files containing definitions (@code{\\newglossaryentry}
etc.)#: to the @file{.bib} format required by @command{bib2gls}.")
    (license license:gpl3+)))

(define-public texlive-bibarts
  (package
    (name "texlive-bibarts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bibarts/" "source/latex/bibarts/"
                                     "tex/latex/bibarts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "130qdf75225zz1g2cr0rw0kz4pylyif5nz98wnqjsnly5kdxkz6k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:phases
           #~(modify-phases %standard-phases
               (add-after 'build 'build-and-install'bibsort
                 (lambda _
                   (mkdir-p "build")
                   (invoke "gcc" "-o" "build/bibsort"
                           "source/latex/bibarts/bibsort.c")
                   (install-file "build/bibsort"
                                 (string-append #$output "/bin")))))))
    (home-page "https://ctan.org/pkg/bibarts")
    (synopsis "Arts-style bibliographical information")
    (description
     "@code{BibArts} is a LaTeX package to assist in making bibliographical
features common in the arts and the humanities (history, political science,
philosophy, etc.).  @file{bibarts.sty} provides commands for quotations,
abbreviations, and especially for a formatted citation of literature,
journals (periodicals), edited sources, and archive sources.

It will also copy all citation information, abbreviations, and register key
words into lists for an automatically generated appendix.  These lists may
refer to page and footnote numbers. BibArts has nothing to do with BibTeX.
The lists are created by @command{bibsort}.  This program creates the
bibliography without using MakeIndex or BibTeX.")
    (license license:gpl3+)))

(define-public texlive-bibcop
  (package
    (name "texlive-bibcop")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/bibtex/bibcop/"
                                     "doc/man/man1/bibcop.1"
                                     "doc/man/man1/bibcop.man1.pdf"
                                     "scripts/bibcop/"
                                     "source/bibtex/bibcop/"
                                     "tex/latex/bibcop/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16w1iwiq7wfz7q4rfrv9pkf71m9yxrpxq70c8asy2vh73sh90szn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "bibcop.pl")))
    (inputs (list perl))
    (propagated-inputs (list texlive-iexec texlive-pgfopts))
    (home-page "https://ctan.org/pkg/bibcop")
    (synopsis "Style checker for .bib files")
    (description
     "This LaTeX package checks the quality of your @file{.bib} file and emits
warning messages if any issues are found.  For this, the TeX processor must be
run with the @samp{--shell-escape} option.  @command{bibcop} can also be used
as a standalone command line tool.")
    (license license:expat)))

(define-public texlive-biber-ms
  (package
    (name "texlive-biber-ms")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/bibtex/biber-ms/"
                                     "source/bibtex/biber-ms/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10r9jgarrbvqrz9nkjfkzsy3niggg5w6sjr7zi7bqy8zhkwf3hsf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biber-ms")
    (synopsis
     "BibTeX replacement for users of BibLaTeX (multiscript version)")
    (description
     "This is the multiscript version of Biber.  It must be used with the
multiscript version of @code{biblatex-ms}.")
    (license license:artistic2.0)))

(define-public texlive-bibexport
  (package
    (name "texlive-bibexport")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/bibexport/"
                                     "doc/bibtex/bibexport/" "scripts/bibexport/"
                                     "source/bibtex/bibexport/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "161056627w1lazfpld3lyjwfrl8j8gc4b6dzml46bzwf7mk9ifln"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:link-scripts #~(list "bibexport.sh")
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'build 'fix-bash-shebang
            (lambda _
              (substitute* "scripts/bibexport/bibexport.sh"
                (("/bin/bash") (which "bash"))))))))
    (home-page "https://ctan.org/pkg/bibexport")
    (synopsis "Extract a BibTeX file based on a @file{.aux} file")
    (description
     "This package provides a Bourne shell script that uses BibTeX to extract
bibliography entries that are @code{\\cite}'d in a document.  It can also
expand a BibTeX file, expanding the abbreviations (other than the built-in
ones like month names) and following the cross-references.")
    (license license:lppl1.3+)))

(define-public texlive-bibhtml
  (package
    (name "texlive-bibhtml")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/bibhtml/" "doc/bibtex/bibhtml/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fjpipxc885hk9pvjf3f0wsp84lr1d7flvs5c56jmlvryvc6mv0w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bibhtml")
    (synopsis "BibTeX support for HTML files")
    (description
     "Bibhtml consists of a Perl script and a set of BibTeX style files, which
together allow you to output a bibliography as a collection of HTML files.
The references in the text are linked directly to the corresponding
bibliography entry, and if a URL is defined in the entry within the BibTeX
database file, then the generated bibliography entry is linked to this.  The
package provides three different style files derived from each of the standard
@file{plain.bst} and @file{alpha.bst}, as well as two style files derived from
@file{abbrv.bst} and unsrt.bst (i.e., eight in total).")
    (license license:gpl3+)))

(define-public texlive-biblatex-abnt
  (package
    (name "texlive-biblatex-abnt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-abnt/"
                                     "tex/latex/biblatex-abnt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14j3yn8ijwaa547gzyw7ql8q871w5r9rprc6l1s5dhp7vz3kzk6z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-abnt")
    (synopsis "BibLaTeX style for Brazil's ABNT rules")
    (description
     "This package offers a BibLaTeX style for Brazil's ABNT (Brazilian
Association of Technical Norms) rules.")
    (license license:lppl1.3c)))

(define-public texlive-biblatex-ajc2020unofficial
  (package
    (name "texlive-biblatex-ajc2020unofficial")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-ajc2020unofficial/"
                                     "tex/latex/biblatex-ajc2020unofficial/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ngh68a7ihhvpdfz09c087pfqnnpj3mnm8c4jmw8krq52b79fr87"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-ajc2020unofficial")
    (synopsis "BibLaTeX style for the Australasian Journal of Combinatorics")
    (description
     "This is an unofficial BibLaTeX style for the Australasian Journal of
Combinatorics.  Note that the journal (as for 01 March 2020) does not accept
BibLaTeX, so you probably want to use @code{biblatex2bibitem}.")
    (license license:lppl1.3c)))

(define-public texlive-biblatex-anonymous
  (package
    (name "texlive-biblatex-anonymous")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-anonymous/"
                                     "tex/latex/biblatex-anonymous/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1q24xrr80i6xsq65gfvvi1s5qsp78g52qgn2nf2523gjnnzp4p7n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-anonymous")
    (synopsis "Tool to manage anonymous work with BibLaTeX")
    (description
     "The package provides tools to help manage anonymous work with BibLaTeX.
It will be useful, for example, in history or classical philology.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-apa6
  (package
    (name "texlive-biblatex-apa6")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-apa6/"
                                     "tex/latex/biblatex-apa6/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14xkqca4l4sb8jwlz6k28hmlya4m9474sv79icyzzq1v0vbqmgbq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-apa6")
    (synopsis "BibLaTeX citation and reference style for APA 6th Edition")
    (description
     "This is a fairly complete BibLaTeX style (citations and references) for
APA (American Psychological Association) 6th Edition conformant publications.
It implements and automates most of the guidelines in the APA 6th edition
style guide for citations and references.  An example document is also given
which typesets every citation and reference example in the APA 6th edition
style guide.  This is a legacy style for 6th Edition documents.  Please use
the BibLaTeX-apa style package for the latest APA edition conformance.")
    (license license:lppl1.3c)))

(define-public texlive-biblatex-archaeology
  (package
    (name "texlive-biblatex-archaeology")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-archaeology/"
                                     "source/latex/biblatex-archaeology/"
                                     "tex/latex/biblatex-archaeology/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "059mp6c1wgxkdjqrpwyx9yafw8dma75c3653rjc3sp66xx3akr8k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-archaeology")
    (synopsis "Collection of BibLaTeX styles for German prehistory")
    (description
     "This package provides additional BibLaTeX styles for German humanities.
Its core purpose is to enable the referencing rules of the Romano-Germanic
Commission (@emph{Romisch-Germanische Kommission}), the department of
prehistory of the German Archaeological Institute (@emph{Deutsches
Archaologisches Institut}), since these are referenced by most guidelines in
German prehistory and medieval archaeology and serve as a kind of template.
@code{biblatex-archaeology} provides verbose, numeric and author date styles
as well and adaptions to specific document types like exhibition and auction
catalogues.")
    (license license:lppl1.3c)))

(define-public texlive-biblatex-arthistory-bonn
  (package
    (name "texlive-biblatex-arthistory-bonn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-arthistory-bonn/"
                                     "tex/latex/biblatex-arthistory-bonn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0iwms7w1xqghdf3s0m91xzw4y7d20lvpv69ibl92cpjj5fggp0x8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-arthistory-bonn")
    (synopsis "BibLaTeX citation style for art historians")
    (description
     "This citation style covers the citation and bibliography guidelines of
the Kunsthistorisches Institut der Universitat Bonn for undergraduates.  It
introduces bibliography entry types for catalogs and features a tabular
bibliography, among other things.  Various options are available to change and
adjust the outcome according to one's own preferences.  The style is
compatible with English and German.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-bath
  (package
    (name "texlive-biblatex-bath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-bath/"
                                     "source/latex/biblatex-bath/"
                                     "tex/latex/biblatex-bath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c640csqvq0f9fd5d7xx4apllbwvr4cmi2x38863wlrvlnxa9kd7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-bath")
    (synopsis "Style recommended by the University of Bath Library")
    (description
     "This package provides a BibLaTeX style to format reference lists in the
Harvard style recommended by the University of Bath Library.")
    (license license:lppl1.3c)))

(define-public texlive-biblatex-bookinarticle
  (package
    (name "texlive-biblatex-bookinarticle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-bookinarticle/"
                                     "tex/latex/biblatex-bookinarticle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mhj3adqlirylhjqj8y0m8pinmark07zqvx00zl9rrdpagj6q4y8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-bookinarticle")
    (synopsis "Manage book edited in article")
    (description
     "This package provides three new BibLaTeX entry types --- @code{@@bookinarticle},
@code{@@bookinincollection} and @code{@@bookinthesis} --- to refer to a modern
edition of an old book, where this modern edition is provided in
a @code{@@article}, @code{@@incollection} or in a @code{@@thesis}.  The
package is now superseded by @code{biblatex-bookinother}.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-bookinother
  (package
    (name "texlive-biblatex-bookinother")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-bookinother/"
                                     "tex/latex/biblatex-bookinother/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "062ri08pwr5fh8v500dbgrc7nbxgi0jd864xfmvf601lwpwqn9c7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-bookinother")
    (synopsis "Manage book edited in other entry type")
    (description
     "This package provides new BibLaTeX entry types and fields for book
edited in other types, like for instance @code{@@bookinarticle}.  It offers
more types than the older package @code{biblatex-bookinarticle}, which it
supersedes.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-bwl
  (package
    (name "texlive-biblatex-bwl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-bwl/"
                                     "tex/latex/biblatex-bwl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "122qz05rc7c3pys6adg38xq0r123f4hspc3yyw8l2mzlpbbwm9y5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-bwl")
    (synopsis "BibLaTeX citations for FU Berlin")
    (description
     "The bundle provides a set of BibLaTeX implementations of bibliography
and citation styles for the Business Administration Department of the Free
University of Berlin.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-caspervector
  (package
    (name "texlive-biblatex-caspervector")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-caspervector/"
                                     "tex/latex/biblatex-caspervector/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m1x3r52i6z06gy3jqlhaqnc876mi0qwjywmwyapvm8kfa2my0p3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-caspervector")
    (synopsis "Simple citation style for Chinese users")
    (description
     "The package provides a simple and easily extensible biblography/citation
style for Chinese LaTeX users, using BibLaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-chem
  (package
    (name "texlive-biblatex-chem")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-chem/"
                                     "tex/latex/biblatex-chem/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y4fgnykh5x48cnbgyhgj04iqz05mvnzqvjn84vbr3mqmwjrndbl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-chem")
    (synopsis
     "BibLaTeX implementations of chemistry-related bibliography styles")
    (description
     "The bundle offers a set of styles to allow chemists to use BibLaTeX.
The package has complete styles for: all ACS journals; RSC journals using
standard (Chem.@: Commun.) style; and Angewandte Chem.@: style, (thus covering
a wide range of journals).")
    (license license:lppl1.3c)))

(define-public texlive-biblatex-chicago
  (package
    (name "texlive-biblatex-chicago")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-chicago/"
                                     "tex/latex/biblatex-chicago/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00y8h4hvmz17bn46936xfi1cy0rsh5y33pyc1hrkrrldabq8rxys"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-chicago")
    (synopsis "Chicago style files for BibLaTeX")
    (description
     "This is a BibLaTeX style that implements the Chicago author-date and
notes with bibliography style specifications given in the @emph{Chicago Manual
of Style}, 17th edition (with continuing support for the 16th edition, too).
The style implements entry types for citing audio-visual materials, among many
others.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-claves
  (package
    (name "texlive-biblatex-claves")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-claves/"
                                     "tex/latex/biblatex-claves/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08ydcv7qlbxaysh7jm3d4glrhp1fyd4fvvxc3jc4k50ga77ksqj0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-claves")
    (synopsis "Tool to manage claves of old literature with BibLaTeX")
    (description
     "When studying antic and medieval literature, we may find many different
texts published with the same title, or, in contrary, the same text published
with different titles.  To avoid confusion, scholars have published claves,
which are books listing ancient texts, identifying them by an identifier ---
a number or a string of text.  For example, for early Christianity, we have
the Bibliotheca Hagiographica Graeca, the Clavis Apocryphorum Novi Testamenti
and other claves.  It could be useful to print the identifier of a texts in
one specific clavis, or in many claves.  The package allows us to create new
field for different claves, and to present all these fields in a consistent
way.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-cv
  (package
    (name "texlive-biblatex-cv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-cv/"
                                     "tex/latex/biblatex-cv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17m6lqnr35y6vcfrrhlhxjf55b85py9miksswhkipyiaj3kphhb8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-cv")
    (synopsis "Create a CV from BibTeX files")
    (description
     "This package creates an academic curriculum vitae (CV) from a BibTeX
@file{.bib} file.  The package makes use of BibLaTeX and Biber to
automatically format, group, and sort the entries on a CV.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-dw
  (package
    (name "texlive-biblatex-dw")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-dw/"
                                     "tex/latex/biblatex-dw/bbx/"
                                     "tex/latex/biblatex-dw/cbx/"
                                     "tex/latex/biblatex-dw/lbx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vw008djg535hdwbmk5dqvaw0v6cm3lqmlvk8sfzybpqffw1crlr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-dw")
    (synopsis "Humanities styles for BibLaTeX")
    (description
     "This package provides a small collection of styles for the BibLaTeX
package.  It was designed for citations in the humanities and offers some
features that are not provided by the standard BibLaTeX styles.  The styles
are dependent on BibLaTeX and cannot be used without it.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-enc
  (package
    (name "texlive-biblatex-enc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-enc/"
                                     "tex/latex/biblatex-enc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k9sais0dknydcdy1a7fkkrb5grqap3q2jn8qk36x658nkjjb9ln"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-enc")
    (synopsis "BibLaTeX style for the Ecole nationale des chartes (Paris)")
    (description
     "This package provides a citation and bibliography style for use with
BibLaTeX.  It conforms to the bibliographic standards used at the Ecole
nationale des chartes (Paris), and may be suitable for a more general use in
historical and philological works.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-ext
  (package
    (name "texlive-biblatex-ext")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-ext/"
                                     "tex/latex/biblatex-ext/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0al97virwph44bmjhya9xq4y8kj7f4d2v7f2jahvfz2j00j78rr7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-ext")
    (synopsis "Extended BibLaTeX standard styles")
    (description
     "The BibLaTeX-ext bundle provides styles that slightly extend the
standard styles that ship with BibLaTeX.  The styles offered in this bundle
provide a simple interface to change some of the stylistic decisions made in
the standard styles.  At the same time they stay as close to their standard
counterparts as possible, so that most customisation methods can be applied
here as well.")
    (license license:lppl1.3c)))

(define-public texlive-biblatex-fiwi
  (package
    (name "texlive-biblatex-fiwi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-fiwi/"
                                     "tex/latex/biblatex-fiwi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "080m1xj1g8v6aavp2i0hipjk3iikjqd2i36by2fiq0ys5vl5vhnq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-fiwi")
    (synopsis "BibLaTeX styles for use in German humanities")
    (description
     "The package provides a collection of styles for BibLaTeX.  It was
designed for citations in German Humanities, especially film studies, and
offers some features that are not provided by the standard BibLaTeX styles.
The style is highly optimized for documents written in German, and the main
documentation is only available in German.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-gb7714-2015
  (package
    (name "texlive-biblatex-gb7714-2015")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-gb7714-2015/"
                                     "tex/latex/biblatex-gb7714-2015/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zhh9mwbywqbx0966amdngqpk7ayknklk2j11zc10rq7z68pjzb1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-gb7714-2015")
    (synopsis
     "BibLaTeX implementation of the GBT7714-2015 bibliography style for
Chinese users")
    (description
     "This package provides an implementation of the GBT7714-2015 bibliography
style.  This implementation follows the GBT7714-2015 standard and can be used
by simply loading BibLaTeX with the appropriate option.")
    (license license:lppl1.3c)))

(define-public texlive-biblatex-german-legal
  (package
    (name "texlive-biblatex-german-legal")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-german-legal/"
                                     "tex/latex/biblatex-german-legal/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14njaba2gvz338f8z4w3vi1qyf7yxx3l9c9nla6ggrw4rnicjpzs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-german-legal")
    (synopsis "Comprehensive citation style for German legal texts")
    (description
     "This package aims to provide citation styles (for footnotes and
bibliographies) for German legal texts.  It is currently focused on citations
in books (style german-legal-book), but may be extended to journal articles in
the future.")
    (license license:lppl1.3c)))

(define-public texlive-biblatex-gost
  (package
    (name "texlive-biblatex-gost")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-gost/"
                                     "tex/latex/biblatex-gost/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08zrbh6ipqg4r0bnjgh9sd5z7aismyi7s8fhkbgdmniw99c4qdc5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-gost")
    (synopsis "BibLaTeX support for GOST standard bibliographies")
    (description
     "The package provides BibLaTeX support for Russian bibliography style
GOST 7.0.5-2008")
    (license license:lppl1.3c)))

(define-public texlive-biblatex-historian
  (package
    (name "texlive-biblatex-historian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-historian/"
                                     "tex/latex/biblatex-historian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y9jvjyji39ly5pf72qhnnlsrixaxjxdx529lyav8bhd2zz3c5s7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-historian")
    (synopsis "BibLaTeX style based on the @emph{Turabian Manual}")
    (description
     "This package provides a BibLaTeX style, based on the @emph{Turabian
Manual} (a version of Chicago).")
    (license license:lppl)))

(define-public texlive-biblatex-ieee
  (package
    (name "texlive-biblatex-ieee")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-ieee/"
                                     "tex/latex/biblatex-ieee/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a3r2lvp4nr53gxpa40qa7zdgj2qpyygvcgcbprnvfxlqrk8lfm0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-ieee")
    (synopsis "IEEE style files for BibLaTeX")
    (description
     "This is a BibLaTeX style that implements the bibliography style of the
IEEE for BibLaTeX.  The implementation follows standard BibLaTeX conventions,
and can be used simply by loading BibLaTeX with the appropriate @samp{ieee}
option.")
    (license license:lppl1.3c)))

(define-public texlive-biblatex-ijsra
  (package
    (name "texlive-biblatex-ijsra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-ijsra/"
                                     "tex/latex/biblatex-ijsra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0phgbrp47f6pgayws29acsacm7dcb5w3asvwswx5a2rg30wj2fln"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-ijsra")
    (synopsis
     "BibLaTeX style for the International Journal of Student Research in
Archaeology")
    (description
     "This is the BibLaTeX style used for the journal International Journal of
Student Research in Archaeology.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-iso690
  (package
    (name "texlive-biblatex-iso690")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-iso690/"
                                     "tex/latex/biblatex-iso690/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07h16m8n8lydph2n567fnx2hzdw15mwyrcgs30x8anv9qxh0z6jf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-iso690")
    (synopsis "BibLaTeX style for ISO 690 standard")
    (description
     "The package provides a bibliography and citation style which conforms to
the latest revision of the international standard ISO 690:2010.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-jura2
  (package
    (name "texlive-biblatex-jura2")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-jura2/"
                                     "tex/latex/biblatex-jura2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cnsmk46j98z7wk7qs6v9f5m42x124v2nxrnq8n1jcs1jd03q6ry"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-jura2")
    (synopsis "Citation style for the German legal profession")
    (description
     "The package offers BibLaTeX support for citations in German legal texts.")
    (license license:lppl1.3c)))

(define-public texlive-biblatex-juradiss
  (package
    (name "texlive-biblatex-juradiss")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-juradiss/"
                                     "tex/latex/biblatex-juradiss/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13rwvj1ibhj0c46xr13wjyh68abkrvh2jcg2ccichh33crrxaql0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-juradiss")
    (synopsis "BibLaTeX stylefiles for German law theses")
    (description
     "The package provides a custom citation-style for typesetting a German
law thesis with LaTeX.")
    (license license:lppl)))

(define-public texlive-biblatex-license
  (package
    (name "texlive-biblatex-license")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-license/"
                                     "tex/latex/biblatex-license/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xz6zms984v5r8hq01f7ap245lfhqj577rc9ww57ccv4kgvgicqd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-license")
    (synopsis "Add license data to the bibliography")
    (description
     "This package is for adding license license:data to bibliography entries
via BibLaTeX's built-in related mechanism.  It provides a new related type
@code{license} and some bibmacros for typesetting these related entries.")
    (license license:lppl1.3c)))

(define-public texlive-biblatex-lncs
  (package
    (name "texlive-biblatex-lncs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-lncs/"
                                     "tex/latex/biblatex-lncs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0agr8dnyfyclj2h3yw8z23jqpvrh8jrm3bdxr9fwvb3l7fazq4mv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-lncs")
    (synopsis "BibLaTeX style for Springer Lecture Notes in Computer Science")
    (description
     "This is a BibLaTeX style for Springer Lecture Notes in Computer Science
(LNCS).  It extends the standard BiBTeX model by an acronym entry.")
    (license license:lppl1.3c)))

(define-public texlive-biblatex-lni
  (package
    (name "texlive-biblatex-lni")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-lni/"
                                     "tex/latex/biblatex-lni/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08vpynqkg22gs869yagh6v4drh0dnkdghqd1nvcq6gh3c56dlpni"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-lni")
    (synopsis "LNI style for BibLaTeX")
    (description
     "BibLaTeX style for the Lecture Notes in Informatics, which is published
by the Gesellschaft fur Informatik (GI e.V.).")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-luh-ipw
  (package
    (name "texlive-biblatex-luh-ipw")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-luh-ipw/"
                                     "tex/latex/biblatex-luh-ipw/bbx/"
                                     "tex/latex/biblatex-luh-ipw/cbx/"
                                     "tex/latex/biblatex-luh-ipw/lbx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18fnq2xjwsp5lq7vywbgzppbijqn4xarqga0g1rpj89g9q0zjs30"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-luh-ipw")
    (synopsis "BibLaTeX styles for social sciences")
    (description
     "The bundle is a small collection of styles for BibLaTeX.  It was
designed for citations in the Humanities, following the guidelines of style of
the institutes for the social sciences of the Leibniz University Hannover/LUH
(especially the Institute of Political Science).")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-manuscripts-philology
  (package
    (name "texlive-biblatex-manuscripts-philology")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-manuscripts-philology/"
                                     "tex/latex/biblatex-manuscripts-philology/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05d2z1w7wdzdinfw1j72y2d8f0nid0a6wsrvkwqkryl3nykyh4z5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-manuscripts-philology")
    (synopsis "Manage classical manuscripts with BibLaTeX")
    (description
     "The package adds a new entry type: @code{@@manuscript} to manage
manuscript in classical philology, for example to prepare a critical
edition.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-mla
  (package
    (name "texlive-biblatex-mla")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-mla/"
                                     "tex/latex/biblatex-mla/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09qlx067vhc4aflx9rjdbyq99xh3nzwlxj81cxp07mm2mykhxf39"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-mla")
    (synopsis "MLA style files for BibLaTeX")
    (description
     "The package provides BibLaTeX support for citations in the format
specified by the MLA handbook.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-morenames
  (package
    (name "texlive-biblatex-morenames")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-morenames/"
                                     "tex/latex/biblatex-morenames/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gwzxz1yqnq3q2fjrb4nf0370a90fbi6b20zvplj3lfiqmdkaiak"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-morenames")
    (synopsis "New names for standard BibLaTeX entry type")
    (description
     "This package adds new fields of ``name'' type to the standard entry
types of BibLaTeX.  For example, @samp{maineditor}, for a @code{@@collection},
means the editor of @code{@@mvcollection}, and not the editor of the
@code{@@collection}.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-ms
  (package
    (name "texlive-biblatex-ms")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/biblatex-ms/biblatex/"
                                     "bibtex/bst/biblatex-ms/"
                                     "doc/latex/biblatex-ms/"
                                     "tex/latex/biblatex-ms/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00xib8xvxl78qzxs66qmfyp4jdkcs3qx4ray2nwv1fffhj69aw3n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-etoolbox texlive-kvoptions texlive-logreq
                             texlive-pdftexcmds texlive-url))
    (home-page "https://ctan.org/pkg/biblatex-ms")
    (synopsis "Sophisticated bibliographies in LaTeX (multiscript version)")
    (description
     "This package is the multiscript' version of the BibLaTeX package
intended to solve the issues faced by those wishing to create multilingual
bibliographies.  It is intended to be backwards-compatible with the standard
BibLaTeX package and includes significantly enhanced optional functionality.

It requires the use of the multiscript version of Biber (biber-ms).")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-multiple-dm
  (package
    (name "texlive-biblatex-multiple-dm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-multiple-dm/"
                                     "tex/latex/biblatex-multiple-dm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07dp3ppz8kma5gh0bs98jnk7gvqqcp4l1ag60941myjvfsyqplxv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-multiple-dm")
    (synopsis "Load multiple datamodels in BibLaTeX")
    (description
     "The package adds the possibility to BibLaTeX to load data models from
multiple sources.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-musuos
  (package
    (name "texlive-biblatex-musuos")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-musuos/"
                                     "tex/latex/biblatex-musuos/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0iqp02yk8b9s18k8v78q2y5g507fsh2zk68dj0yc77gwa6gsmrmh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-musuos")
    (synopsis "BibLaTeX style for citations in @file{musuos.cls}")
    (description
     "The style is designed for use with the musuos class, but it should be
usable with other classes, too.")
    (license license:lppl)))

(define-public texlive-biblatex-nature
  (package
    (name "texlive-biblatex-nature")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-nature/"
                                     "tex/latex/biblatex-nature/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bpgcwpd8sw28dn7q8bkxpnpqb741216gaasvqdpah9kj53zfypg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-nature")
    (synopsis "BibLaTeX support for @emph{Nature}")
    (description
     "The bundle offers styles that allow authors to use BibLaTeX when
preparing papers for submission to the journal @emph{Nature}.")
    (license license:lppl1.3c)))

(define-public texlive-biblatex-nejm
  (package
    (name "texlive-biblatex-nejm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-nejm/"
                                     "source/latex/biblatex-nejm/"
                                     "tex/latex/biblatex-nejm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fa12hbzrqd7brz90zhn3lklbqvvn5sw5l3y8pnm5xx604dkdiiw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-nejm")
    (synopsis "BibLaTeX style for the New England Journal of Medicine (NEJM)")
    (description
     "This is a BibLaTeX numeric style based on the design of the New England
Journal of Medicine (NEJM).")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-nottsclassic
  (package
    (name "texlive-biblatex-nottsclassic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-nottsclassic/"
                                     "tex/latex/biblatex-nottsclassic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13rvxykjyah5vn44sfagf1ggqhh1hd1qhz9m6jb87yhwz5snkrxh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-nottsclassic")
    (synopsis "Citation style for the University of Nottingham")
    (description
     "This citation-style covers the citation and bibliography rules of the
University of Nottingham.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-opcit-booktitle
  (package
    (name "texlive-biblatex-opcit-booktitle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-opcit-booktitle/"
                                     "tex/latex/biblatex-opcit-booktitle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "078fzk4i7sknaxkgn2lr54bcslqbjjsr1nb0z7y46v7kpg2lpcrf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-opcit-booktitle")
    (synopsis "Use @samp{op.@: cit.}@: for the booktitle of a subentry")
    (description
     "The default citation styles use the @samp{op.@: cit.}@: form in order to
have a shorter reference when a title has already been cited.  However, when
you cite two entries which share the same booktitle but not the same title,
the @samp{op.@: cit.}@: mechanism does not work.  This package fixes this.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-oxref
  (package
    (name "texlive-biblatex-oxref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-oxref/"
                                     "source/latex/biblatex-oxref/"
                                     "tex/latex/biblatex-oxref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hhl331vxsffm7wnxpx846xzbs66pjbpqhgiblds7gmz5zz6ng1k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-oxref")
    (synopsis "BibLaTeX styles inspired by the @emph{Oxford Guide to Style}")
    (description
     "This bundle provides four BibLaTeX styles that implement (many of) the
stipulations and examples provided by the 2014 @emph{New Hart's Rules} and the
2002 @emph{Oxford Guide to Style}:
@itemize

@item @code{oxnotes} is a style similar to the standard @code{verbose},
intended for use with footnotes;

@item @code{oxnum} is a style similar to the standard @code{numeric}, intended
for use with numeric in-text citations;

@item @code{oxalph} is a style similar to the standard @code{alphabetic},
intended for use with alphabetic in-text citations;

@item @code{oxyear} is a style similar to the standard @code{author-year},
intended for use with parenthetical in-text citations.

@end itemize

The bundle provides support for a wide variety of content types, including
manuscripts, audiovisual resources, social media and legal references.")
    (license license:lppl1.3c)))

(define-public texlive-biblatex-philosophy
  (package
    (name "texlive-biblatex-philosophy")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-philosophy/"
                                     "source/latex/biblatex-philosophy/"
                                     "tex/latex/biblatex-philosophy/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05fapyb6wwyv4mwjhgg3gasvqkwpwd6jxv095hird9011n6drrzm"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-biblatex
                  texlive-cochineal
                  texlive-csquotes
                  texlive-etoolbox
                  texlive-fontaxes
                  texlive-fontsize
                  texlive-guitlogo
                  texlive-hologo
                  texlive-hypdoc
                  texlive-inconsolata
                  texlive-libertine
                  texlive-listings
                  texlive-ltxdockit
                  texlive-manfnt
                  texlive-mdframed
                  texlive-metalogo
                  texlive-microtype
                  texlive-needspace
                  texlive-newtx
                  texlive-parskip
                  texlive-pgf
                  texlive-sectsty
                  texlive-upquote
                  texlive-xcolor
                  texlive-xkeyval
                  texlive-xstring
                  texlive-zref))))
    (home-page "https://ctan.org/pkg/biblatex-philosophy")
    (synopsis "Styles for using BibLaTeX for work in philosophy")
    (description
     "The bundle offers two styles --- @code{philosophy-classic} and
@code{philosophy-modern} --- that facilitate the production of two different
kinds of bibliography, based on the author-year style, with options and
features to manage the information about the translation of foreign texts or
their reprints.  Though the package's default settings are based on the
conventions used in Italian publications, these styles can be used with every
language recognized by Babel, possibly with some simple redefinitions.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-phys
  (package
    (name "texlive-biblatex-phys")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-phys/"
                                     "tex/latex/biblatex-phys/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1q9l7ma3zpybx142adbiall4y5x4hc5kc536wpmiwkz29zi6w7ka"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-phys")
    (synopsis
     "BibLaTeX implementation of the AIP and APS bibliography style")
    (description
     "The package provides an implementation of the bibliography styles of
both the AIP and the APS for BibLaTeX.  This implementation follows standard
BibLaTeX conventions, and can be used simply by loading BibLaTeX with the
appropriate option: @samp{\\usepackage[style=phys]@{biblatex@}}.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-publist
  (package
    (name "texlive-biblatex-publist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-publist/"
                                     "tex/latex/biblatex-publist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xk80agsawp8amphpnk1s55kbp8rx5npphsadqi0nmclqi920f38"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-publist")
    (synopsis "BibLaTeX bibliography support for publication lists")
    (description
     "The package provides a BibLaTeX bibliography style file (@file{.bbx})
for publication lists.  The style file draws on BibLaTeX's @code{authoryear}
style, but provides some extra features often desired for publication lists,
such as the omission of the author's own name from author or editor data.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-readbbl
  (package
    (name "texlive-biblatex-readbbl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-readbbl/"
                                     "tex/latex/biblatex-readbbl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fr0p5c2v66vy86qx2m8i4p3p75d6qm506gv8xbfqckzyfzi9x6z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-readbbl")
    (synopsis "Read a @file{.bbl} file created by biber")
    (description
     "This small package modifies the BibLaTeX macro which reads a @file{.bbl}
file created by Biber.  It is thus possible to include a @file{.bbl} file into
the main document with the @code{environment} and send it to a publisher who
does not need to run the Biber program.  However, when the bibliography
changes one has to create a new @file{.bbl} file.")
    (license license:lppl)))

(define-public texlive-biblatex-realauthor
  (package
    (name "texlive-biblatex-realauthor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-realauthor/"
                                     "tex/latex/biblatex-realauthor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1av0vd7lwg5yad75b9fbi09s4bcaqd8bdz43kzyj2r7cimj8dpl0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-realauthor")
    (synopsis "Indicate the real author of a work")
    (description
     "This package allows using a new field @code{realauthor}, which
indicates the real author of a work, when published in a pseudepigraphic
name.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-sbl
  (package
    (name "texlive-biblatex-sbl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-sbl/"
                                     "makeindex/biblatex-sbl/"
                                     "tex/latex/biblatex-sbl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b04lwzmsgapf2x1y83jdmzsc0h59dwy35lglxwvmlwlv8czpx9s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-sbl")
    (synopsis "Society of Biblical Literature (SBL) style files for BibLaTeX")
    (description
     "The package provides BibLaTeX support for citations in the format
specified by the second edition of the Society of Biblical Literature (SBL)
Handbook of Style.  A style file for writing SBL student papers is also
included.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-science
  (package
    (name "texlive-biblatex-science")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-science/"
                                     "tex/latex/biblatex-science/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sw2bzhbgbfg5gajbm61x4243qrfna1ifbp9bl1swdmvw9g3hycd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-science")
    (synopsis "BibLaTeX implementation of the @emph{Science} bibliography style")
    (description
     "The bundle offers styles that allow authors to use BibLaTeX when
preparing papers for submission to the journal @emph{Science}.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-shortfields
  (package
    (name "texlive-biblatex-shortfields")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-shortfields/"
                                     "tex/latex/biblatex-shortfields/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14s6ykbnb6b2i811rjn44chv8f73yhnnywczn78zwbij5z6jgcjv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-shortfields")
    (synopsis "Use short forms of fields with BibLaTeX")
    (description
     "The BibLaTeX package provides @code{shortseries} and @code{shortjournal}
field, but the default styles don't use them.  It also provides a mechanism to
print the equivalence between short forms of fields and long
fields (@code{\\printbiblist}), but this mechanism does not allow mixing
between different type of short fields, for example, between short forms of
journal title and short forms of series titles.

This package provides a solution to these two problems.  If
a @code{shortjournal} field is defined, it prints it instead of the
@code{\\journal} field.  If a @code{shortseries} field is defined, it prints
it instead of the @code{\\series} field.  It provides
a @code{\\printbibshortfields} command to print a list of the sort forms of
the fields.  This list also includes the claves defined with the
@code{biblatex-claves} package.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-socialscienceshuberlin
  (package
    (name "texlive-biblatex-socialscienceshuberlin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-socialscienceshuberlin/"
                                     "tex/latex/biblatex-socialscienceshuberlin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1klcvjf8vz3bg0q7pmci6hhih52ph0z0hhkbv3iippyy33jhijrc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-socialscienceshuberlin")
    (synopsis "BibLaTeX-style for the social sciences at HU Berlin")
    (description
     "This is a BibLaTeX style for the social sciences at the
Humboldt-Universitat zu Berlin.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-software
  (package
    (name "texlive-biblatex-software")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-software/"
                                     "source/latex/biblatex-software/"
                                     "tex/latex/biblatex-software/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dlinydsrlcw898ccynx76mdv9jsvr4ninsqv2aggmj3g9xripn0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-software")
    (synopsis "BibLaTeX stylefiles for software products")
    (description
     "This package implements software entry types for BibLaTeX in the form of
a bibliography style extension.  It requires the Biber backend.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-source-division
  (package
    (name "texlive-biblatex-source-division")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-source-division/"
                                     "tex/latex/biblatex-source-division/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07y25624fpmx9hfmyyga8wh5cmvl14lqbmflglpl60jqsy622mgi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-source-division")
    (synopsis "References by division in classical sources")
    (description
     "The package enables the user to make reference to division marks (such
as book, chapter, section), in the document being referenced, in addition to
the page-based references that BibTeX-based citations have always had.  The
citation is made in the same way as the LaTeX standard, but what's inside the
square brackets may include the division specification.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-spbasic
  (package
    (name "texlive-biblatex-spbasic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-spbasic/"
                                     "tex/latex/biblatex-spbasic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "071d1iqy1scz3wncsfv1backp5b7ly28rn5k0wy67wwz1vxa0d17"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-spbasic")
    (synopsis "BibLaTeX style emulating Springer's old @file{spbasic.bst}")
    (description
     "This package provides a bibliography and citation style for BibLaTeX and
Biber for typesetting articles for Springer's journals.  It is the same as the
old BibTeX style @file{spbasic.bst}.")
    (license license:lppl)))

(define-public texlive-biblatex-subseries
  (package
    (name "texlive-biblatex-subseries")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-subseries/"
                                     "tex/latex/biblatex-subseries/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09kqqccn8dlaydz1v2szllryaxrj0c36z63ynhrv9dvd1sk0vdhd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-subseries")
    (synopsis "Manages subseries with BibLaTeX")
    (description
     "Some publishers organize book series with subseries.  In this case, two
numbers are associated with one volume: the number inside the series and the
number inside the subseries.  This package provides new fields to manage such
system.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-swiss-legal
  (package
    (name "texlive-biblatex-swiss-legal")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-swiss-legal/"
                                     "tex/latex/biblatex-swiss-legal/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x4dy1vxrbx0xkw3vysvcds0s1jz9w1pwri5ypiidj517sdsnff4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-swiss-legal")
    (synopsis
     "Bibliography and citation styles following Swiss legal practice")
    (description
     "The package provides BibLaTeX bibliography and citation styles for
documents written in accordance with Swiss legal citation standards in either
French or German.  However, the package is at present outdated and does not
work properly with newer versions of BibLaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-trad
  (package
    (name "texlive-biblatex-trad")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-trad/"
                                     "tex/latex/biblatex-trad/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19ma61dsdpsm52zm7wnkqccmx54g9gvh05d10c59q86ffv1dnlmx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-trad")
    (synopsis "Traditional BibTeX styles with BibLaTeX")
    (description
     "The bundle provides implementations of the traditional BibTeX styles
(@code{plain}, @code{abbrev}, @code{unsrt} and @code{alpha}) with BibLaTeX.")
    (license license:lppl1.3c)))

(define-public texlive-biblatex-true-citepages-omit
  (package
    (name "texlive-biblatex-true-citepages-omit")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-true-citepages-omit/"
                                     "tex/latex/biblatex-true-citepages-omit/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mfkmn5g6r61mlyf3vx98q18a042yjkmh3drid9vs0kaj66di4n5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-true-citepages-omit")
    (synopsis
     "Correct some limitations of BibLaTeX @samp{citepages=omit} option")
    (description
     "This package deals with a limitation of the @samp{citepages=omit} option
of the verbose family of BibLaTeX citestyles.  The option works when you
@code{\\cite[xx]@{key@}}, but not when you @code{\\cite[\\pno~xx, some
text]@{key@}}.  The package corrects this problem.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-unified
  (package
    (name "texlive-biblatex-unified")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-unified/"
                                     "tex/latex/biblatex-unified/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d9b20m10dlkii2zxj00xgascqarf8qv1vfz28v7hnm9vd54h3rw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-unified")
    (synopsis "BibLaTeX unified stylesheet for linguistics journals")
    (description
     "BibLaTeX-unified is an opinionated BibLaTeX implementation of the
Unified Stylesheet for Linguistics Journals.")
    (license license:lppl1.3c)))

(define-public texlive-biblatex-vancouver
  (package
    (name "texlive-biblatex-vancouver")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-vancouver/"
                                     "tex/latex/biblatex-vancouver/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sji214mi5garp5h3if1fh1rvck573cxg61rgdlyy543883nrxv7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-vancouver")
    (synopsis "Vancouver style for BibLaTeX")
    (description
     "This package provides the Vancouver reference style for BibLaTeX.  It is
based on the @code{numeric} style and requires Biber.")
    (license license:gpl3+)))

(define-public texlive-biblatex2bibitem
  (package
    (name "texlive-biblatex2bibitem")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex2bibitem/"
                                     "tex/latex/biblatex2bibitem/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cd9b7vhmlx2clqr2gpwqs4hjga9mjqlxj7m74kq555rn5ppkyyn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex2bibitem")
    (synopsis "Convert BibLaTeX-generated bibliography to bibitems")
    (description
     "Some journals accept the reference list only as @code{\\bibitems}.  If
you use BibTeX, there is no problem: just paste the content of the @file{.bbl}
file into your document.  However, there was no out-of-the-box way to do the
same for BibLaTeX, and you had to struggle with searching appropriate
@file{.bst} files, or formatting your reference list by hand, or something
like that.  Using the workaround provided by this package solves the
problem.")
    (license license:lppl1.3c)))

(define-public texlive-bibleref
  (package
    (name "texlive-bibleref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bibleref/"
                                     "source/latex/bibleref/"
                                     "tex/latex/bibleref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fgb6lljdsdvkbs4i7yvwvgjbpbc8vnki0wv3gdi9yq6s5j6lzv5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bibleref")
    (synopsis "Format @emph{Bible} citations")
    (description
     "The bibleref package offers consistent formatting of references to parts
of the Christian @emph{Bible}, in a number of well-defined formats.")
    (license license:lppl1.3+)))

(define-public texlive-bibleref-french
  (package
    (name "texlive-bibleref-french")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bibleref-french/"
                                     "source/latex/bibleref-french/"
                                     "tex/latex/bibleref-french/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12y9xdsz0swh3rndmzk7ch9fbszbhcp0ixb21jyy36xnb3x80wa5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bibleref-french")
    (synopsis "French translations for @code{bibleref}")
    (description
     "The package provides translations and alternative typesetting
conventions for use of @code{bibleref} in French.")
    (license license:lppl1.3+)))

(define-public texlive-bibleref-german
  (package
    (name "texlive-bibleref-german")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bibleref-german/"
                                     "tex/latex/bibleref-german/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nqky0x9j6w3xg2vaj29db7l0zjw88d7bl6vs8864hqz2i6h2pcw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bibleref-german")
    (synopsis "German adaptation of @code{bibleref}")
    (description
     "The package provides translations and various formats for the use of
@code{bibleref} in German documents.  The German naming of the Bible books
complies with the @emph{Loccumer Richtlinien} (Locum guidelines).  In
addition, the Vulgate (Latin Bible) is supported.")
    (license license:lppl1.3+)))

(define-public texlive-bibleref-lds
  (package
    (name "texlive-bibleref-lds")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bibleref-lds/"
                                     "source/latex/bibleref-lds/"
                                     "tex/latex/bibleref-lds/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wqmpzml3yyhzv7bx5wkfl2ni0qinz0kjzdanh6rx0bczp29dlfh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bibleref-lds")
    (synopsis
     "Bible references, including scriptures of the Church of Jesus Christ of
Latter Day Saints")
    (description
     "The package extends the @code{bibleref-mouth} package to support
references to the scriptures of The Church of Jesus Christ of Latter-day
Saints (LDS).")
    (license license:lppl1.3+)))

(define-public texlive-bibleref-mouth
  (package
    (name "texlive-bibleref-mouth")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bibleref-mouth/"
                                     "source/latex/bibleref-mouth/"
                                     "tex/latex/bibleref-mouth/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dakbx8rnjs9yjnn1xal9y0bmh165lqhbjj3bns974vkyb7nla4m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bibleref-mouth")
    (synopsis "Consistent formatting of @emph{Bible} references")
    (description
     "The package allows @emph{Bible} references to be formatted in
a consistent way.  It is similar to the @code{bibleref} package, except that
the formatting macros are all purely expandable --- that is, they are all
implemented in TeX's mouth.  This means that they can be used in any
expandable context, such as an argument to a @code{\\url} command.")
    (license license:lppl1.3+)))

(define-public texlive-bibleref-parse
  (package
    (name "texlive-bibleref-parse")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bibleref-parse/"
                                     "tex/latex/bibleref-parse/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01jhic1idgjgv9hsx5gih4230krfqm8pc3j7f4kn22w2jnw7fs68"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bibleref-parse")
    (synopsis "Specify @emph{Bible} passages in human-readable format")
    (description
     "The package parses @emph{Bible} passages that are given in human
readable format.  It accepts a wide variety of formats.  This allows for
a simpler and more convenient interface to the functionality of the
@code{bibleref} package.")
    (license license:lppl1.3+)))

(define-public texlive-biblist
  (package
    (name "texlive-biblist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblist/" "tex/latex/biblist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r7cd68yr8pnmqnr39qzp42kxqcx89cqzz81ig9y7qgicznji0i8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblist")
    (synopsis "Print a BibTeX database")
    (description
     "The package provides the means of listing an entire BibTeX database,
avoiding the potentially large (macro) impact associated with
@code{\\nocite@{*@}}.")
    (license license:gpl3+)))

(define-public texlive-bidihl
  (package
    (name "texlive-bidihl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/bidihl/" "tex/xelatex/bidihl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "021q2qhfl2ww95nbp63p3j7lv9wjj5s9wvn2sj5zyj1pcw75l8ir"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bidihl")
    (synopsis "Experimental Bidi-aware text highlighting")
    (description
     "This package provides experimental Bidi-aware text highlighting.")
    (license license:lppl1.3+)))

(define-public texlive-bibtexperllibs
  (package
    (name "texlive-bibtexperllibs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/ltx2unitxt.1"
                                     "doc/man/man1/ltx2unitxt.man1.pdf"
                                     "scripts/bibtexperllibs/"
                                     "source/support/bibtexperllibs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07frlvg53m6ps8gyh04kwwhsmyyvycqj72s31h4z82y9gxxajxc6"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bibtexperllibs")
    (synopsis "BibTeX Perl Libraries")
    (description
     "This package provides BibTeX related Perl libraries.")
    (license
     (list license:artistic2.0
           license:gpl1
           license:public-domain))))

(define-public texlive-bibtopic
  (package
    (name "texlive-bibtopic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bibtopic/"
                                     "source/latex/bibtopic/"
                                     "tex/latex/bibtopic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b4lhlw29y37c7pxmqvy4ahgb85bmxrgnr2jhzvdhzdm5y9md7a3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/bibtopic")
    (synopsis "Include multiple bibliographies in a document")
    (description
     "The package allows the user to include several bibliographies covering
different topics or bibliographic material into a document (e.g., one
bibliography for primary literature and one for secondary literature).  The
package provides commands to include either all references from a @file{.bib}
file, only the references actually cited or those not cited in your document.
The user has to construct a separate @file{.bib} file for each bibliographic
topic, each of which will be processed separately by BibTeX.  If you want to
have bibliographies specific to one part of a document, see the packages
@code{bibunits} or @code{chapterbib}.")
    (license license:gpl3+)))

(define-public texlive-bibtopicprefix
  (package
    (name "texlive-bibtopicprefix")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bibtopicprefix/"
                                     "source/latex/bibtopicprefix/"
                                     "tex/latex/bibtopicprefix/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fadq51adii1453v31xj7p328h4rvans1ynmxjcmnwhlj4hdjp5n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bibtopicprefix")
    (synopsis "Prefix references to bibliographies produced by
@code{bibtopic}")
    (description
     "The package permits users to apply prefixes (fixed strings) to
references to entries in bibliographies produced by the @code{bibtopic}
package.")
    (license license:lppl)))

(define-public texlive-bibunits
  (package
    (name "texlive-bibunits")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bibunits/"
                                     "source/latex/bibunits/"
                                     "tex/latex/bibunits/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hlz277lskhcs5xr0qn2rram957himj67hkwqqsjjap8khf7fz6v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bibunits")
    (synopsis "Multiple bibliographies in one document")
    (description
     "The package provide a mechanism to generate separate bibliographies for
different units (chapters, sections or bibunit-environments) of a text.  The
package separates the citations of each unit of text into a separate file to
be processed by BibTeX.  The global bibliography section produced by LaTeX may
also appear in the document and citations can be placed in both the local unit
and the global bibliographies at the same time.")
    (license license:lppl)))

(define-public texlive-binomexp
  (package
    (name "texlive-binomexp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/binomexp/"
                                     "source/latex/binomexp/"
                                     "tex/latex/binomexp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wmhsqqz2hy75x20srs1237yba4s00yrdhr52hkrh3nldzqwhqcc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/binomexp")
    (synopsis "Calculate Pascal's triangle")
    (description
     "The package calculates and prints rows of Pascal's triangle.  It may be
used to print successive rows of the triangle, or to print the rows inside an
@code{array} or @code{tabular} environment.")
    (license license:lppl)))

(define-public texlive-biocon
  (package
    (name "texlive-biocon")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biocon/" "tex/latex/biocon/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m3qqrl5z071w4zs8fs3wv0b4ix0s6cqh4ixzqj28d74aaf9r1y1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biocon")
    (synopsis "Typesetting biological species names")
    (description
     "The biocon--biological conventions--package aids the typesetting of some
biological conventions.  At the moment, it makes a good job of typesetting
species names (and ranks below the species level).  A distinction is made
between the Plant, Fungi, Animalia and Bacteria kingdoms.  There are default
settings for the way species names are typeset, but they can be customized.
Different default styles are used in different situations.")
    (license license:gpl3+)))

(define-public texlive-biolett-bst
  (package
    (name "texlive-biolett-bst")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/biolett-bst/"
                                     "doc/bibtex/biolett-bst/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xfr79xw0ih61s5qapx2adiyjj0d149nslpmkd1fw29g1v4zrjd2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biolett-bst")
    (synopsis "BibTeX style for the journal @emph{Biology Letters}")
    (description
     "This package provides a BibTeX style (@file{.bst}) file for the journal
@emph{Biology Letters} published by the Royal Society.")
    (license license:lppl1.0+)))

(define-public texlive-bitelist
  (package
    (name "texlive-bitelist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/bitelist/"
                                     "source/generic/bitelist/"
                                     "tex/generic/bitelist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jv9w2jgx8q2k9xx0n4azlngsh26zs37ihavq0xy4n62ajf64ps6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bitelist")
    (synopsis "Split list, in TeX's mouth")
    (description
     "The package provides commands for splitting a token list at the first
occurrence of another (specified) token list.  The package's mechanism differs
from those of packages providing similar features, in the following ways: the
method uses TeX's mechanism of reading delimited macro parameters; splitting
macros work by pure expansion, without assignments; the operation is carried
out in a single macro call.  A variant of the operation is provided, that
retains outer braces.")
    (license license:lppl1.3+)))

(define-public texlive-bitpattern
  (package
    (name "texlive-bitpattern")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bitpattern/"
                                     "source/latex/bitpattern/"
                                     "tex/latex/bitpattern/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00f423jran7qqg9fwy3p7w1lhi20cxzlvn4hzsrz5pwd87bmvxxb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bitpattern")
    (synopsis "Typeset bit pattern diagrams")
    (description
     "This package provides a package to typeset bit pattern diagrams such as those
used to describe hardware, data format or protocols.")
    (license license:lppl)))

(define-public texlive-bitter
  (package
    (name "texlive-bitter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/bitter/"
                                     "fonts/enc/dvips/bitter/"
                                     "fonts/map/dvips/bitter/"
                                     "fonts/tfm/huerta/bitter/"
                                     "fonts/truetype/huerta/bitter/"
                                     "fonts/type1/huerta/bitter/"
                                     "fonts/vf/huerta/bitter/"
                                     "tex/latex/bitter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xh3vssfrfkdrwzsmid7frm4n9gjb8x7czh8zyybdcvv9vb8n3d9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bitter")
    (synopsis "Bitter family of fonts with LaTeX support")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX, and LuaLaTeX support for
the Bitter family of fonts.  Bitter is a contemporary slab-serif typeface for
text.  There are regular and bold weights and an italic, but no bold italic.")
    (license (list license:lppl license:silofl1.1))))

(define-public texlive-bjfuthesis
  (package
    (name "texlive-bjfuthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bjfuthesis/"
                                     "tex/latex/bjfuthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qhb9kighs4ljmnn94qaihpllhwvmi76j3p8yylyjw2hzip102wr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bjfuthesis")
    (synopsis "Thesis class for Beijing Forestry University")
    (description
     "This is a class file for producing dissertations and theses according to
the @acronym{BJFU, Beijing Forestry University} guidelines for undergraduate
theses and dissertations.")
    (license license:gpl3)))

(define-public texlive-blacklettert1
  (package
    (name "texlive-blacklettert1")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/blacklettert1/"
                                     "fonts/tfm/public/blacklettert1/"
                                     "fonts/vf/public/blacklettert1/"
                                     "source/fonts/blacklettert1/"
                                     "tex/latex/blacklettert1/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fvrz3rbcdgzrg3rg3nfvdb52zxn9vhsx0xd8rc6xryzrqaib7q0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/blacklettert1")
    (synopsis "T1-encoded versions of Haralambous old German fonts")
    (description
     "This package contains virtual fonts that offer T1-alike encoded variants
of old German fonts Gothic, Schwabacher and Fraktur (which are also available
in Adobe type 1 format).  The package includes LaTeX macros to embed the fonts
into the LaTeX font selection scheme.")
    (license license:lppl1.2+)))

(define-public texlive-bmstu
  (package
    (name "texlive-bmstu")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bmstu/" "tex/latex/bmstu/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ipdwd78b5w4v85nqlbxf8gi42mdz19r5mdjj3agwlgb0z6icjra"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bmstu")
    (synopsis "LaTeX class for Bauman Moscow State Technical University")
    (description
     "The class defines commands and environments for creating reports and
explanatory notes in Bauman Moscow State Technical University (Russia).")
    (license
     (list license:lppl1.3+
           ;; File "bmstu-logo.pdf" is a logo of Bauman Moscow ;; State
           ;; Technical University and complies with fair use (article 1274 of
           ;; the Russian Civil Code).
           (license:fsdg-compatible "file://doc/latex/bmstu/README.md")))))

(define-public texlive-bmstu-iu8
  (package
    (name "texlive-bmstu-iu8")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bmstu-iu8/"
                                     "tex/latex/bmstu-iu8/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nb3dfaw0m3w179z46d7fbvibkp15wf4ws3xbvws0gymwyi4nx1m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bmstu-iu8")
    (synopsis "Class for IU8 reports")
    (description
     "This package consists of a class file and style files for writing
reports at the IU8 department of IU faculty of @acronym{BMSTU, Bauman Moscow
State Technical University}.  The class defines all headings, structure
elements and other things in respect of Russian standard GOST 7.32-2017.  But
there are correctives to be compatible with our local IU8 department
requirements.")
    (license license:expat)))

(define-public texlive-bodeplot
  (package
    (name "texlive-bodeplot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bodeplot/"
                                     "source/latex/bodeplot/"
                                     "tex/latex/bodeplot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b55y82gmxjyy9g1v2b85p1qr0hyf47jh345phbnyqxb9zk5kb5c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bodeplot")
    (synopsis "Draw Bode, Nyquist and Nichols plots with Gnuplot or
 @code{pgfplots}")
    (description
     "This is a LaTeX package to plot Bode, Nichols, and Nyquist diagrams.  It
provides added functionality over the similar @code{bodegraph} package:

@itemize
@item new @code{\\BodeZPK} and @code{\\BodeTF} commands to generate Bode plots
of any transfer function given either poles, zeros, gain, and delay, or
numerator and denominator coefficients and delay;
@item support for unstable poles and zeros;
@item support for complex poles and zeros;
@item support for general stable and unstable second order transfer functions;
@item support for both Gnuplot (default) and @code{pgfplots};
@item support for linear and asymptotic approximation of magnitude and phase
plots of any transfer function given poles, zeros, and gain.
@end itemize")
    (license license:lppl1.3c)))

(define-public texlive-bohr
  (package
    (name "texlive-bohr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bohr/" "tex/latex/bohr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02slnkmxha906y7z04dffamy0lywq95l9yvklxjlm2kvjhqv2wnw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bohr")
    (synopsis "Simple atom representation according to the Bohr model")
    (description
     "The package provides means for the creation of simple Bohr models of
atoms up to the atomic number 112.  In addition, commands are provided to
convert atomic numbers to element symbols or element names and vice versa.")
    (license license:lppl1.3+)))

(define-public texlive-boisik
  (package
    (name "texlive-boisik")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/boisik/"
                                     "fonts/source/public/boisik/"
                                     "fonts/tfm/public/boisik/"
                                     "tex/latex/boisik/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xg00nb28dgc8ch85n1mgj5n0cshkvyvgv98qawxn2xvx14vqw89"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     ;; FIXME: Font metrics generation fails for "bskmab10" font, with error:
     ;; "! Strange path (turning number is zero)".
     (list #:phases
           #~(modify-phases %standard-phases
               (delete 'generate-font-metrics))))
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/boisik")
    (synopsis "Font inspired by Baskerville design")
    (description
     "Boisik is a serif font set (inspired by the Baskerville typeface),
written in Metafont.  The set comprises roman and italic text fonts and maths
fonts.  LaTeX support is offered for use with OT1, IL2 and OM* encodings.")
    (license license:gpl2)))

(define-public texlive-boldtensors
  (package
    (name "texlive-boldtensors")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/boldtensors/"
                                     "tex/latex/boldtensors/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06c0wa4qai0qdbad44464nc5zap9bc03yjn89yagsr4dzxif0jrg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/boldtensors")
    (synopsis
     "Bold latin and greek characters through simple prefix characters")
    (description
     "This package provides bold latin and greek characters within
@code{\\mathversion@{normal@}}, by using @samp{~} and @samp{\"} as prefix
characters.")
    (license license:gpl3+)))

(define-public texlive-bookdb
  (package
    (name "texlive-bookdb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/bookdb/" "doc/bibtex/bookdb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0df6bzmc90af3v4nzv6hp9padpc7h680vm2hy8wzb268z3ld268h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bookdb")
    (synopsis "BibTeX style file for cataloguing a home library")
    (description
     "This package provides an extended book entry for use in cataloguing
a home library.  The extensions include fields for binding, category,
collator, condition, copy, illustrations, introduction, location, pages, size,
value, volumes.")
    (license license:lppl1.3+)))

(define-public texlive-bookhands
  (package
    (name "texlive-bookhands")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/bookhands/"
                                     "fonts/afm/public/bookhands/"
                                     "fonts/map/dvips/bookhands/"
                                     "fonts/source/public/bookhands/"
                                     "fonts/tfm/public/bookhands/"
                                     "fonts/type1/public/bookhands/"
                                     "source/fonts/bookhands/"
                                     "tex/latex/bookhands/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ssz80jwmd00x7d1x1xc6i61kbs30bc875bvakd5gymdw2kv7s3z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/bookhands")
    (synopsis "Collection of book-hand fonts")
    (description
     "This is a set of book-hand (Metafont) fonts and packages covering
manuscript scripts from the 1st century until Gutenberg and Caxton.  The
included hands are: Square Capitals (1st century onwards); Roman
Rustic (1st-6th centuries); Insular Minuscule (6th cenury onwards);
Carolingian Minuscule (8th-12th centuries); Early Gothic (11th-12th
centuries); Gothic Textura Quadrata (13th-15th centuries); Gothic Textura
Prescisus vel sine pedibus (13th century onwards); Rotunda (13-15th
centuries); Humanist Minuscule (14th century onwards); Uncial (3rd-6th
centuries); Half Uncial (3rd-9th centuries); Artificial Uncial (6th-10th
centuries); and Insular Majuscule (6th-9th centuries).")
    (license license:lppl)))

(define-public texlive-booktabs-de
  (package
    (name "texlive-booktabs-de")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/booktabs-de/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ld7zdr88xjhnnl2x734rxr7h0fz84awapmv50p1kzn6fczrwyam"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/booktabs-de")
    (synopsis "German version of @code{booktabs}")
    (description
     "This is a German translation of the @code{booktabs} package
documentation.")
    (license license:gpl3+)))

(define-public texlive-booktabs-fr
  (package
    (name "texlive-booktabs-fr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/booktabs-fr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xkqh6r2q835xaa92b24fzf61jsm85280570hivvwnch96i4fnh3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/booktabs-fr")
    (synopsis "French translation of @code{booktabs} documentation")
    (description
     "This package provides a French translation of @code{booktabs}
documentation.")
    (license license:lppl)))

(define-public texlive-boondox
  (package
    (name "texlive-boondox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/boondox/"
                                     "fonts/map/dvips/boondox/"
                                     "fonts/tfm/public/boondox/"
                                     "fonts/type1/public/boondox/"
                                     "fonts/vf/public/boondox/"
                                     "tex/latex/boondox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rsid25qlsbj3z60h8n22m8l6gyk4nbr598c6z9azldpxn88dz91"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/boondox")
    (synopsis "Mathematical alphabets derived from the STIX fonts")
    (description
     "The package contains a number of PostScript fonts derived from the STIX
OpenType fonts that may be used in maths mode in regular and bold weights for
Calligraphic, Fraktur and Double-struck alphabets.  Virtual fonts with metrics
suitable for maths mode are provided, as are LaTeX support files.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-borceux
  (package
    (name "texlive-borceux")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/borceux/"
                                     "tex/generic/borceux/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fil90jsiqg7b0if3yq0jxv4rh7vanj2yj9pv8pnfkhvqii4p821"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/borceux")
    (synopsis "Diagram macros by Francois Borceux")
    (description
     "The macros support the construction of diagrams, such as those that
appear in category theory texts.  The user gives the list of vertices and
arrows to be included, just as when composing a matrix, and the program takes
care of computing the dimensions of the arrows and realizing the page setting.
All the user has to do about the arrows is to specify their
type (monomorphism, pair of adjoint arrows, etc.) and their direction (north,
south-east, etc.); 12 types and 32 directions are available.")
    ;; "You may freely use, modify, and/or distribute each of the
    ;; files in this package without limitation."
    (license (license:fsf-free "file://doc/generic/borceux/README"))))

(define-public texlive-bosisio
  (package
    (name "texlive-bosisio")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bosisio/" "source/latex/bosisio/"
                                     "tex/latex/bosisio/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z4s0dgvwffy4356zj0m6kkk9lqzq1180km5sg5syvk11m7mxffn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/bosisio")
    (synopsis "Collection of packages by Francesco Bosisio")
    (description
     "This package provides a collection of packages containing: @code{accenti},
@code{dblfont}, @code{envmath}, @code{evenpage}, @code{graphfig},
@code{mathcmd}, @code{quotes}, and @code{sobolev}.")
    (license license:lppl)))

(define-public texlive-bpchem
  (package
    (name "texlive-bpchem")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bpchem/" "source/latex/bpchem/"
                                     "tex/latex/bpchem/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qm0w43iyh42l3srhqsgqq5yjxx3ghxamq6nh68qq6x4izlyv51z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bpchem")
    (synopsis "Typeset chemical names, formulae, etc")
    (description
     "The package provides support for typesetting simple chemical formulae,
those long IUPAC compound names, and some chemical idioms.  It also supports
the labelling of compounds and reference to labelled compounds.")
    (license license:lppl)))

(define-public texlive-br-lex
  (package
    (name "texlive-br-lex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/br-lex/" "tex/latex/br-lex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "154mjkywvyif57zvqbq5wxs84357148km2x0lqqdx6nanr3vwmxb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/br-lex")
    (synopsis "Class for typesetting Brazilian legal texts")
    (description
     "This class implements rules to typeset Brazilian legal texts.  Its
purpose is to be an easy-to-use implementation for the end-user.")
    (license license:lppl1.3+)))

(define-public texlive-braille
  (package
    (name "texlive-braille")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/braille/" "tex/latex/braille/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "021nxjz23gn8zjrrzxggjaqq3gv894c512x15kffywm8h5k0bzy5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/braille")
    (synopsis "Support for Braille")
    (description
     "This package allows the user to produce Braille documents on paper for
the blind without knowing Braille.  Python scripts @file{grade1.py} and
@file{grade2.py} convert ordinary text to grade 1 and 2 Braille tags; then,
the LaTeX package takes the tags and prints out corresponding Braille
symbols.")
    (license license:lppl1.3+)))

(define-public texlive-brandeis-dissertation
  (package
    (name "texlive-brandeis-dissertation")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/brandeis-dissertation/"
                                     "source/latex/brandeis-dissertation/"
                                     "tex/latex/brandeis-dissertation/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dsg285wcpfxd0p1fs1dac87c0csbv21zz76cdjgishasmqrxdmg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/brandeis-dissertation")
    (synopsis "Class for Brandeis University dissertations")
    (description
     "The class will enable the user to typeset a dissertation which adheres
to the formatting guidelines of Brandeis University @acronym{GSAS, Graduate
School of Arts and Sciences}.")
    (license license:lppl1.2+)))

(define-public texlive-brandeis-problemset
  (package
    (name "texlive-brandeis-problemset")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/brandeis-problemset/"
                                     "tex/latex/brandeis-problemset/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "172l1jmvacjg9j5fkyrmsrhsj5pyaaq8g9pfvkahcnhk3jfc3pnp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/brandeis-problemset")
    (synopsis "Document class for COSI Problem sets at Brandeis University")
    (description
     "Brandeis University's computer science courses often assign problem sets
which require fairly rigorous formatting.  This document class, which extends
@code{article}, provides a simple way to typeset these problem sets in LaTeX.")
    (license license:lppl1.3c)))

(define-public texlive-brandeis-thesis
  (package
    (name "texlive-brandeis-thesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/brandeis-thesis/"
                                     "source/latex/brandeis-thesis/"
                                     "tex/latex/brandeis-thesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03m5m5l8jw5jkrqc4pzmk0ghijlaw25r1bn9mhva6m9kxz1sj9q4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/brandeis-thesis")
    (synopsis "Class for Brandeis University M.A. theses")
    (description
     "@file{brandeis-thesis.cls} provides the structures and formatting
information for an M.A.@: thesis for the Brandeis University Graduate School
of Arts and Sciences.")
    (license license:lppl1.3c)))

(define-public texlive-breakcites
  (package
    (name "texlive-breakcites")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/breakcites/"
                                     "tex/latex/breakcites/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12jiw135xi12k0f46zmza4jw141gq919c6q0ijv8xlic0wra4gyy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/breakcites")
    (synopsis "Ensure that multiple citations may break at line end")
    (description
     "This package makes a very minor change to the operation of the
@code{\\cite} command so that multiple citations may break at line end.  Note
that the change is not necessary in unmodified LaTeX; however, there remain
packages that restore the undesirable behaviour of the command as provided in
LaTeX 2.09.  Neither @code{cite} nor @code{natbib} make this mistake.")
    ;; The file below states: "You may freely use, modify, and/or
    ;; distribute this package without limitation."
    (license (license:fsf-free "file://doc/latex/breakcites/README"))))

(define-public texlive-bropd
  (package
    (name "texlive-bropd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bropd/" "source/latex/bropd/"
                                     "tex/latex/bropd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cyyadfvrcym4vvxl9p9zb88692m0578nqljip12xxahb4srcyb9"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs (list (texlive-updmap.cfg
                          (list texlive-etoolbox
                                texlive-hypdoc))))
    (home-page "https://ctan.org/pkg/bropd")
    (synopsis "Simplified brackets and differentials in LaTeX")
    (description
     "The package simplifies the process of writing differential operators and
brackets in LaTeX.  The commands facilitate the easy manipulation of equations
involving brackets and allow partial differentials to be expressed in an
alternate form.")
    (license license:lppl1.3+)))

(define-public texlive-brushscr
  (package
    (name "texlive-brushscr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/brushscr/"
                                     "dvips/brushscr/"
                                     "fonts/afm/public/brushscr/"
                                     "fonts/map/dvips/brushscr/"
                                     "fonts/tfm/public/brushscr/"
                                     "fonts/type1/public/brushscr/"
                                     "fonts/vf/public/brushscr/"
                                     "tex/latex/brushscr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kdikrlhbqfcnb42y5pz93l8wkzbrn7hx5gjf05vkchcxq24nj5x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/brushscr")
    (synopsis "Handwriting script font")
    (description
     "The BrushScript font simulates hand-written characters; it is
distributed in Adobe Type 1 format (but is available in italic shape only).
The package includes the files needed by LaTeX in order to use that font.")
    (license license:public-domain)))

(define-public texlive-buctthesis
  (package
    (name "texlive-buctthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/buctthesis/"
                                     "source/xelatex/buctthesis/"
                                     "tex/xelatex/buctthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h8djmkc6jcn10g0w1qmw0mw8v42dsb7kijfv87qxw78i1cfsbax"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/buctthesis")
    (synopsis "Beijing University of Chemical Technology thesis template")
    (description
     "This package provides a LaTeX class and template for Beijing University
of Chemical Technology, supporting bachelor, master, and doctor theses.")
    (license license:lppl1.3c)))

(define-public texlive-burmese
  (package
    (name "texlive-burmese")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/burmese/"
                                     "fonts/map/dvips/burmese/"
                                     "fonts/tfm/public/burmese/"
                                     "fonts/type1/public/burmese/"
                                     "source/fonts/burmese/"
                                     "tex/latex/burmese/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04d022k7bqc7092xhsda0h5ma18b24hkmn0b7mlblpd3zf4qhs79"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          ;; The "birm.pl" script is located in the "source" part, and
          ;; therefore will not appear in any output.  This phase forces its
          ;; installation in "bin/" directory.
          (add-after 'install 'install-script
            (lambda _
              (install-file "source/fonts/burmese/birm.pl"
                            (string-append #$output "/bin")))))))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/burmese")
    (synopsis "Basic support for writing Burmese")
    (description
     "This package provides basic support for writing Burmese.  The package
provides a preprocessor (written in Perl), an Adobe Type 1 font, and LaTeX
macros.")
    ;; The package itself is under LPPL terms, but the preprocessor relies on
    ;; Knuth's.
    (license (list license:lppl license:knuth))))

(define-public texlive-bussproofs-extra
  (package
    (name "texlive-bussproofs-extra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bussproofs-extra/"
                                     "source/latex/bussproofs-extra/"
                                     "tex/latex/bussproofs-extra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08n6ww2fcijkisldrhbvvm52n3r4fy10bz1i4jyac7wnnpw8dd2p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bussproofs-extra")
    (synopsis "Extra commands for @file{bussproofs.sty}")
    (description
     "This package provides additional functionality for
@file{bussproofs.sty}; specifically, it allows for typesetting of
entire (sub)deductions.")
    (license license:lppl1.3c)))

(define-public texlive-bxbase
  (package
    (name "texlive-bxbase")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bxbase/" "tex/latex/bxbase/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19zhvwj55lihlj11mk322735z595al847wsg3p0s3a9zm17b0skk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bxbase")
    (synopsis "BX bundle base components")
    (description
     "The main purpose of this bundle is to serve as an underlying library for
other packages created by the same author.  However @code{bxbase} package
contains a few user-level commands and is of some use by itself.")
    (license license:expat)))

(define-public texlive-bxcjkjatype
  (package
    (name "texlive-bxcjkjatype")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bxcjkjatype/"
                                     "tex/latex/bxcjkjatype/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jhjhrfmabfdwzk2gv2zsaadj3907ajxic4dqzwaz43cip05iy3z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bxcjkjatype")
    (synopsis "Typeset Japanese with pdfLaTeX and CJK")
    (description
     "The package provides a working configuration of the CJK package,
suitable for Japanese typesetting of moderate quality.  Moreover, it
facilitates use of the CJK package for pLaTeX users, by providing commands
that are similar to those used by the pLaTeX kernel and some other packages
used with it.")
    (license license:expat)))

(define-public texlive-bxghost
  (package
    (name "texlive-bxghost")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bxghost/" "tex/latex/bxghost/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11hnnyd6h3r5fl9p23qj1zspwzgnamfah7xqj7l1prp6ygb322mn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bxghost")
    (synopsis "Ghost insertion for proper @code{xkanjiskip}")
    (description
     "The package provides two commands to help authors for documents in
Japanese to insert proper @code{xkanjiskips}.  It supports LuaTeX, XeTeX,
pTeX, upTeX, and ApTeX (pTeX-ng).")
    (license license:expat)))

(define-public texlive-bxjaholiday
  (package
    (name "texlive-bxjaholiday")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bxjaholiday/"
                                     "tex/latex/bxjaholiday/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n0h9g5lgaz00gn8wjai8w3pbg7bs02aaw7zi7h8l01i4lc8l1r1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bxjaholiday")
    (synopsis "Support for Japanese holidays")
    (description
     "This LaTeX package provides a command to convert dates to names of
Japanese holidays.  Another command, converting dates to the day of the week
in Japanese, is available as a free gift.")
    (license license:expat)))

(define-public texlive-bxjalipsum
  (package
    (name "texlive-bxjalipsum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bxjalipsum/"
                                     "tex/latex/bxjalipsum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00lmr20lb7yd98iblg0i3pqvxh80arivdgyvzkj5mj2ivil7vw9k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bxjalipsum")
    (synopsis "Dummy text in Japanese")
    (description
     "This package enables users to print some Japanese text that can be used
as dummy text.  It is a Japanese counterpart of the @code{lipsum} package.
Since there is no well-known nonsense text like Lipsum in the Japanese
language, the package uses some real text in public domain.")
    (license license:expat)))

(define-public texlive-bxjaprnind
  (package
    (name "texlive-bxjaprnind")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bxjaprnind/"
                                     "tex/latex/bxjaprnind/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0j2k06y63c7dgpcflrfrjy82g2746fnmpf8dk445lbqkbn1jypr5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bxjaprnind")
    (synopsis "Adjust the position of parentheses at paragraph head")
    (description
     "In Japanese typesetting, opening parentheses placed at the beginning of
paragraphs or lines are treated specially.  This package adjusts the position
of parentheses accordingly.")
    (license license:expat)))

(define-public texlive-bxjatoucs
  (package
    (name "texlive-bxjatoucs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bxjatoucs/"
                                     "fonts/tfm/public/bxjatoucs/"
                                     "tex/latex/bxjatoucs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1032lfp9qy4arzy06s5hkqlva7y182763wxfdql93yn68hcn85vd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bxjatoucs")
    (synopsis "Convert Japanese character code to Unicode")
    (description
     "This package is meant for macro or package developers: it provides
function-like macros that convert a character code value in one of several
Japanese encodings to a Unicode value.  Supported source encodings are:
ISO-2022-JP (jis), EUC-JP (euc), Shift_JIS (sjis), and the Adobe-Japan1 glyph
set.")
    (license license:expat)))

(define-public texlive-bxjscls
  (package
    (name "texlive-bxjscls")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bxjscls/" "source/latex/bxjscls/"
                                     "tex/latex/bxjscls/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qgv528s7n36j4276jkd0gazfh2nary6yqll8qv98pc2k049vblg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bxjscls")
    (synopsis "Japanese document class collection for all major engines")
    (description
     "This package provides an extended version of the Japanese document class
collection provided by @code{jsclasses}.  While the original version supports
only pLaTeX and upLaTeX, the extended version also supports pdfLaTeX, XeLaTeX
and LuaLaTeX, with the aid of suitable packages that provide capability of
Japanese typesetting.")
    (license license:bsd-2)))

(define-public texlive-bxorigcapt
  (package
    (name "texlive-bxorigcapt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bxorigcapt/"
                                     "tex/latex/bxorigcapt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gj61hjmyxsbfkrs1sh604b6dfl00kp39fcamlfzb8s197wsl9fv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bxorigcapt")
    (synopsis "Retain the original caption names when using Babel")
    (description
     "This package forces the caption names declared by the document class in
use to be used as the caption names for a specific language introduced by the
Babel package.")
    (license license:expat)))

(define-public texlive-bxwareki
  (package
    (name "texlive-bxwareki")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bxwareki/" "tex/latex/bxwareki/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "105fx28gy2f73127cpy3fdsmggw5a49bbr1b99kd5ydmwckwkp5g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bxwareki")
    (synopsis "Convert dates from Gregorian to Japanese calendar")
    (description
     "This LaTeX package provides commands to convert from the Gregorian
calendar to the Japanese rendering of the Japanese calendar.  You can choose
whether the numbers are written in Western numerals or kanji numerals.  Note
that the package only deals with dates in the year 1873 or later, where the
Japanese calendar is really a Gregorian calendar with a different notation of
years.")
    (license license:expat)))

(define-public texlive-bytefield
  (package
    (name "texlive-bytefield")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bytefield/"
                                     "source/latex/bytefield/"
                                     "tex/latex/bytefield/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qrq46c1x3g7kchi89srwbpssz721021jkpjfas38nlaxj70swaa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bytefield")
    (synopsis "Create illustrations for network protocol specifications")
    (description
     "The @code{bytefield} package helps the user create illustrations for
network protocol specifications and anything else that utilizes fields of
data.  These illustrations show how the bits and bytes are laid out in
a packet or in memory.")
    (license license:lppl1.3a)))

(define-public texlive-c-pascal
  (package
    (name "texlive-c-pascal")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/c-pascal/"
                                     "tex/generic/c-pascal/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kmxki1yclk7lzlidcvsdry7mzm58zzwq3rxgvmpawq2hs8hpcra"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/c-pascal")
    (synopsis "Typeset Python, C and Pascal programs")
    (description
     "This package provides a TeX macro package for easy typesetting programs
in Python, C and Pascal.  Program source files may also be input.")
    (license license:public-domain)))

(define-public texlive-c90
  (package
    (name "texlive-c90")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/enc/c90/" "fonts/enc/dvips/c90/"
                                     "source/fonts/enc/c90/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0g4rwimlqqzbbs8ar15nsf8qcr8bbyjacmklbgv4pmsls5ka9n3n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/c90")
    (synopsis "C90 font encoding for Thai")
    (description "This package provides C90 font encoding for Thai.")
    (license license:gpl2+)))

(define-public texlive-caladea
  (package
    (name "texlive-caladea")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/caladea/"
                                     "fonts/enc/dvips/caladea/"
                                     "fonts/map/dvips/caladea/"
                                     "fonts/tfm/huerta/caladea/"
                                     "fonts/truetype/huerta/caladea/"
                                     "fonts/type1/huerta/caladea/"
                                     "fonts/vf/huerta/caladea/"
                                     "tex/latex/caladea/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02pw132njvk23iwfwlfq5cbamqmgxap2h5pq23x3r8dbym1zpk9f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/caladea")
    (synopsis "Support for the Caladea family of fonts")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the Caladea family of fonts.")
    (license (list license:asl2.0 license:lppl))))

(define-public texlive-calculation
  (package
    (name "texlive-calculation")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/calculation/"
                                     "source/latex/calculation/"
                                     "tex/latex/calculation/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15sk3v1cwpjln4rp9k877awxaz9js5gbazlzjknmv5fv1cb4d09c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/calculation")
    (synopsis
     "Typesetting reasoned calculations, also called calculational proofs")
    (description
     "The @code{calculation} environment formats reasoned calculations, also
called calculational proofs.  The package allows steps and expressions to be
numbered (by LaTeX equation numbers, obeying the LaTeX @code{\\label} command
to refer to these numbers), and a step doesn't take vertical space if its hint
is empty.  An expression in a calculation can be given a comment; it is placed
at the side opposite to the equation numbers.  Calculations are allowed inside
hints although numbering and commenting is then disabled.")
    (license license:lppl1.3+)))

(define-public texlive-calligra
  (package
    (name "texlive-calligra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/calligra/"
                                     "fonts/source/public/calligra/"
                                     "fonts/tfm/public/calligra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1h9w2qifsd0sjr2czy6zbyvgvdl72nd1sn2hmxv0jsmbcjqak1ib"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/calligra")
    (synopsis "Calligraphic font")
    (description
     "This package provides a calligraphic font in the handwriting style.
The font is supplied as Metafont source.  LaTeX support of the font is
provided in the @code{calligra} package in the @code{fundus} bundle.")
    (license license:expat)))

(define-public texlive-calligra-type1
  (package
    (name "texlive-calligra-type1")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/calligra-type1/"
                                     "fonts/afm/public/calligra-type1/"
                                     "fonts/map/dvips/calligra-type1/"
                                     "fonts/type1/public/calligra-type1/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1v6zwghf8q70lls3hmwj8gc0n6d4ffjf1xjvq1k6w71shiga8bqi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/calligra-type1")
    (synopsis "Type 1 version of Calligra")
    (description
     "This is a Type 1 conversion of Peter Vanroose's Calligra handwriting
font.")
    (license license:expat)))

(define-public texlive-cantarell
  (package
    (name "texlive-cantarell")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cantarell/"
                                     "fonts/enc/dvips/cantarell/"
                                     "fonts/map/dvips/cantarell/"
                                     "fonts/opentype/gnome/cantarell/"
                                     "fonts/tfm/gnome/cantarell/"
                                     "fonts/type1/gnome/cantarell/"
                                     "fonts/vf/gnome/cantarell/"
                                     "tex/latex/cantarell/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11cj8z6wyzq92x66alas88qgrs4ap0xgvf0yr7h62vg5ym3618c8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cantarell")
    (synopsis "LaTeX support for the Cantarell font family")
    (description
     "Cantarell is a contemporary Humanist sans serif designed by Dave
Crossland and Jakub Steiner.  The present package provides support for this
font in LaTeX. It includes Type 1 versions of the fonts, converted for this
package using FontForge from its sources, for full support with Dvips.")
    (license (list license:silofl1.1 license:lppl1.3c))))

(define-public texlive-carlito
  (package
    (name "texlive-carlito")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/carlito/"
                                     "fonts/enc/dvips/carlito/"
                                     "fonts/map/dvips/carlito/"
                                     "fonts/tfm/google/carlito/"
                                     "fonts/truetype/google/carlito/"
                                     "fonts/type1/google/carlito/"
                                     "fonts/vf/google/carlito/"
                                     "tex/latex/carlito/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14hk51bgwpn4wr843g7w8wjwmadq0ca86gviayhwsz4zax68jhx6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/carlito")
    (synopsis "Support for Carlito sans-serif fonts")
    (description
     "The package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the Carlito family of sans serif fonts, designed by Lukasz Dziedzic.")
    (license license:silofl1.1)))

(define-public texlive-carolmin-ps
  (package
    (name "texlive-carolmin-ps")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/carolmin-ps/"
                                     "fonts/afm/public/carolmin-ps/"
                                     "fonts/map/dvips/carolmin-ps/"
                                     "fonts/type1/public/carolmin-ps/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1867h17l0ms2schmbrsjm4gajfmckm2x7ny2ijd9vf232l7s1b53"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/carolmin-t1")
    (synopsis "Adobe Type 1 format of Carolingian Minuscule fonts")
    (description
     "The bundle offers Adobe Type 1 format versions of Peter Wilson's
Carolingian Minuscule font set (part of the @code{bookhands} collection).  The
fonts in the bundle are ready-to-use replacements for the Metafont
originals.")
    (license license:lppl)))

(define-public texlive-cartonaugh
  (package
    (name "texlive-cartonaugh")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cartonaugh/"
                                     "source/latex/cartonaugh/"
                                     "tex/latex/cartonaugh/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05f6xslfv3d1n48j2ivl7vdgs12lzgzx8ccfv6l49ddgq0dssnir"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cartonaugh")
    (synopsis
     "LuaLaTeX package for drawing karnaugh maps with up to 6 variables")
    (description
     "This package, a fork of @code{karnaugh-map} package, draws karnaugh maps
with 2, 3, 4, 5, and 6 variables.  It also contains commands for filling the
karnaugh map with terms semi-automatically or manually.  Last but not least it
contains commands for drawing implicants on top of the map.")
    (license license:cc-by-sa3.0)))

(define-public texlive-cascade
  (package
    (name "texlive-cascade")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cascade/" "source/latex/cascade/"
                                     "tex/latex/cascade/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13950pv70hr21jn7f0hg4hyai3b28bwcnrd23l44mhynv4hbs5yz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cascade")
    (synopsis
     "Constructions with braces to present mathematical demonstrations")
    (description
     "The LaTeX package cascade provides a command @code{\\Cascade} to do
constructions to present mathematical demonstrations with successive braces
for the deductions.")
    (license license:lppl1.3+)))

(define-public texlive-cascadia-code
  (package
    (name "texlive-cascadia-code")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cascadia-code/"
                                     "fonts/enc/dvips/cascadia-code/"
                                     "fonts/map/dvips/cascadia-code/"
                                     "fonts/opentype/public/cascadia-code/"
                                     "fonts/tfm/public/cascadia-code/"
                                     "fonts/type1/public/cascadia-code/"
                                     "fonts/vf/public/cascadia-code/"
                                     "tex/latex/cascadia-code/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "015kjdr9lgbznmzz1pw57jw4dy4v4fk1qb3w6nizf1z3xza9b49r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cascadia-code")
    (synopsis "Cascadia Code font with support for LaTeX and pdfLaTeX")
    (description
     "Cascadia Code is a monospaced font by Microsoft.  This package provides
the Cascadia Code family of fonts with support for LaTeX and pdfLaTeX.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-cascadilla
  (package
    (name "texlive-cascadilla")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/cascadilla/"
                                     "doc/latex/cascadilla/"
                                     "tex/latex/cascadilla/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sl29gxjhkakaz7r48wfbvcxngnxdyixmh5awxnlsmrajxgdzh9l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cascadilla")
    (synopsis "Conform to the stylesheet of the Cascadilla Proceedings
Project")
    (description
     "The class provides an extension of the standard LaTeX @code{article}
class that may be used to typeset papers conforming to the stylesheet of the
Cascadilla Proceedings Project, which is used by a number of linguistics
conference proceedings.")
    (license license:lppl)))

(define-public texlive-catcodes
  (package
    (name "texlive-catcodes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/catcodes/"
                                     "source/generic/catcodes/"
                                     "tex/generic/catcodes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0di6rd5c0viiwvc6ncwndah38q318l3s1pf47ddmzjdq6rys9s33"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/catcodes")
    (synopsis "Generic handling of TeX category codes")
    (description
     "The bundle deals with category code switching; the packages of the
bundle should work with any TeX format (with the support of the
@code{plainpkg} package).  The bundle provides:
@itemize
@item @file{stacklet.sty}, which supports stacks that control the use of
different catcodes;
@item @file{actcodes.sty}, which deals with active characters;
@item @file{catchdq.sty}, which provides a simple quotation character control
mechanism.
@end itemize")
    (license license:lppl1.3+)))

(define-public texlive-causets
  (package
    (name "texlive-causets")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/causets/" "tex/latex/causets/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03n3k1xklf42k8ybvvg0hlakqavcsa2dap8hpj3ln007yr4m22g8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/causets")
    (synopsis "Draw causal set (Hasse) diagrams")
    (description
     "This LaTeX package uses TikZ to generate (Hasse) diagrams for causal sets
(causets) to be used inline with text or in mathematical expressions.  The
macros can also be used in the @code{tikzpicture} environment to annotate or
modify a diagram.")
    (license license:lppl1.3+)))

(define-public texlive-ccfonts
  (package
    (name "texlive-ccfonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ccfonts/" "source/latex/ccfonts/"
                                     "tex/latex/ccfonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r319fv1n9fsnnycza4z1j23dp03fww98a03hmcapkyr9pp9lvv4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/ccfonts")
    (synopsis "Support for Concrete text and math fonts in LaTeX")
    (description
     "This package provides LaTeX font definition files for the Concrete fonts
and a LaTeX package for typesetting documents using Concrete as the default
font family.  The files support OT1, T1, TS1, and Concrete mathematics
including AMS fonts (Ulrik Vieth's @code{concmath}).")
    (license license:lppl)))

(define-public texlive-ccool
  (package
    (name "texlive-ccool")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ccool/" "source/latex/ccool/"
                                     "tex/latex/ccool/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17xkwd8mrvl751rn6zvxaznac27rpvmi53rq8nwwlp6j1bdnaj94"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ccool")
    (synopsis "Key-value document command parser")
    (description
     "This package provides a key-value interface, @code{\\Ccool}, on top of
@code{xparse}'s document command parser.  Global options control input
processing and its expansion.  By default, they are set to meet likely
requirements, depending on context: the selected language, and which of text
and math mode is active.  These options can be overridden inline.  Polymorphic
commands can be generated by parameterizing the keys (for instance, one
parameter value for style, another for a property).  User input to
@code{\\Ccool} can optionally be serialized.  This can useful for typesetting
documents sharing the same notation.")
    (license license:lppl1.3c)))

(define-public texlive-cell
  (package
    (name "texlive-cell")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/cell/" "doc/latex/cell/"
                                     "tex/latex/cell/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0x2dw80z0kzisbwnx2xrmsk0biqbanmydzygg9zdymhcx7w5rz52"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cell")
    (synopsis "Bibliography style for Cell")
    (description
     "This is an APA-like style (cf.@: @file{apalike.bst} in the BibTeX
distribution), developed from the same author's JMB style.  A supporting LaTeX
package is also provided.")
    (license license:public-domain)))

(define-public texlive-cesenaexam
  (package
    (name "texlive-cesenaexam")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cesenaexam/"
                                     "source/latex/cesenaexam/"
                                     "tex/latex/cesenaexam/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05n61y7lqycnj22a80p5pa0ajr8c4zc5b73cc3c2x40w8yx85xcf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cesenaexam")
    (synopsis "Class file to typeset exams")
    (description
     "This LaTeX document class has been designed to typeset exams.")
    (license license:lppl1.3c)))

(define-public texlive-cfr-initials
  (package
    (name "texlive-cfr-initials")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cfr-initials/"
                                     "tex/latex/cfr-initials/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03isx6wck9q2nmn2gm6zmd1830d2v9bps5g1k9qw6y02wdac8az9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cfr-initials")
    (synopsis "LaTeX packages for use of initials")
    (description
     "This is a set of 23 tiny packages designed to make it easier to use
fonts from the initials package in LaTeX, e.g., with the @code{lettrine}
package.")
    (license license:lppl1.3+)))

(define-public texlive-cfr-lm
  (package
    (name "texlive-cfr-lm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cfr-lm/"
                                     "fonts/enc/dvips/cfr-lm/"
                                     "fonts/map/dvips/cfr-lm/"
                                     "fonts/tfm/public/cfr-lm/"
                                     "fonts/vf/public/cfr-lm/"
                                     "source/fonts/cfr-lm/"
                                     "tex/latex/cfr-lm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06zsvbnpg93gw7m0nfsxc1hcqi6idgdc3xwwwy954fx13dpvrqfi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cfr-lm")
    (synopsis "Enhanced support for the Latin Modern fonts")
    (description
     "The package supports a number of features of the Latin Modern fonts
which are not easily accessible via the default (La)TeX support.  In
particular, the package supports the use of the various styles of digits
available, small-caps and upright italic shapes, and alternative weights and
widths.  It also supports variable width typewriter and the @code{quotation}
font.

By default, the package uses proportional oldstyle digits and variable width
typewriter but this can be changed by passing appropriate options to the
package.  The package also supports using (for example) different styles of
digits within a document so it is possible to use proportional oldstyle digits
by default, say, but tabular lining digits within a particular table.")
    (license license:lppl1.3+)))

(define-public texlive-chbibref
  (package
    (name "texlive-chbibref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chbibref/" "tex/latex/chbibref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1k4cwy4z0kacikpvxkk3y68apw2x33sh06yccb1s894r1bn3c1qi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chbibref")
    (synopsis "Change the Bibliography and References title")
    (description
     "This package defines a single command, @code{\\setbibref}, which sets
whichever of @code{\\bibname} and @code{\\refname} is in use.")
    (license license:lppl)))

(define-public texlive-chem-journal
  (package
    (name "texlive-chem-journal")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/chem-journal/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01s4sbmc4g96cmnbhx9a6bqjskkrr6saq91cly2pfy5gr256vmnq"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chem-journal")
    (synopsis "Various BibTeX formats for journals in chemistry")
    (description
     "This package provides various BibTeX formats for journals in chemistry,
including @emph{Reviews in Computational Chemistry}, @emph{Journal of Physical
Chemistry}, @emph{Journal of Computational Chemistry}, and @emph{Physical
Chemistry Chemical Physics}.")
    (license license:gpl3+)))

(define-public texlive-chemarrow
  (package
    (name "texlive-chemarrow")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/chemarrow/"
                                     "fonts/afm/public/chemarrow/"
                                     "fonts/map/dvips/chemarrow/"
                                     "fonts/source/public/chemarrow/"
                                     "fonts/tfm/public/chemarrow/"
                                     "fonts/type1/public/chemarrow/"
                                     "source/fonts/chemarrow/"
                                     "tex/latex/chemarrow/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ky0v2psxamzilmijih88zxanmq2hnpv1yc18mcy9mpymcmvrhwr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/chemarrow")
    (synopsis "Arrows for use in chemistry")
    (description
     "This bundle consists of a font (available as Metafont source, MetaPost
source, and generated type 1 versions), and a package to use it.  The arrows
in the font are designed to look more like those in chemistry text-books than
do Knuth's originals.")
    (license license:public-domain)))

(define-public texlive-chembst
  (package
    (name "texlive-chembst")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/chembst/" "doc/latex/chembst/"
                                     "source/latex/chembst/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "026j8lv3kbxmbq6sc1n8rdrr47njgn5mn9im1mmppzk5bi7w6yzz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chembst")
    (synopsis "Collection of BibTeX files for chemistry journals")
    (description
     "The package offers a collection of advanced BibTeX style files suitable
for publications in chemistry journals.  Currently, style files for journals
published by the American Chemical Society, Wiley-VCH and The Royal Society of
Chemistry are available.  The style files support advanced features such as
automatic formatting of errata or creating an appropriate entry for
publications in @emph{Angewandte Chemie} where both English and German should
be cited simultaneously.")
    (license license:lppl)))

(define-public texlive-chemcompounds
  (package
    (name "texlive-chemcompounds")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chemcompounds/"
                                     "source/latex/chemcompounds/"
                                     "tex/latex/chemcompounds/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bk625vdd6i1dc2569ypcq27hin1yggvadf18463qb6xhyndplvf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chemcompounds")
    (synopsis "Simple consecutive numbering of chemical compounds")
    (description
     "The chemcompounds package allows for a simple consecutive numbering of
chemical compounds.  Optionally, it is possible to supply a custom name for
each compound.  The package differs from the @code{chemcono} package by not
generating an odd-looking list of compounds inside the text.")
    (license license:lppl)))

(define-public texlive-chemcono
  (package
    (name "texlive-chemcono")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chemcono/" "tex/latex/chemcono/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lwsizrypzn6vnhf7szg47b1synafihihq14wfc0ffrksq1c730c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chemcono")
    (synopsis "Support for compound numbers in chemistry documents")
    (description
     "This package provides a LaTeX package for using compound numbers in
chemistry documents.  It works like @code{\\cite} and the
@code{\\thebibliography}, using @code{\\fcite} and @code{\\theffbibliography}
instead.  It allows compound names in documents to be numbered and does not
affect the normal citation routines.")
    (license license:lppl)))

(define-public texlive-chemexec
  (package
    (name "texlive-chemexec")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chemexec/" "tex/latex/chemexec/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1al19xf107qizd7nr7297szqd2k8sf1i3ngpnw6kl6fkak5h7qdg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chemexec")
    (synopsis "Creating (chemical) exercise sheets")
    (description
     "The package provides environments and commands that the author needed
when preparing exercise sheets and other teaching material.  In particular,
the package supports the creation of exercise sheets, with separating printing
of solutions.")
    (license license:lppl1.3+)))

(define-public texlive-chemformula
  (package
    (name "texlive-chemformula")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chemformula/"
                                     "tex/latex/chemformula/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14w98hnhljfm62cxg2hml3razrxw9hkzm54v7ybnbhcp5mm7wvdm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-units))
    (home-page "https://ctan.org/pkg/chemformula")
    (synopsis "Command for typesetting chemical formulas and reactions")
    (description
     "The package provides a command to typeset chemical formulas and
reactions in support of other chemistry packages (such as
@code{chemmacros}).")
    (license license:lppl1.3c)))

(define-public texlive-chemgreek
  (package
    (name "texlive-chemgreek")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chemgreek/"
                                     "tex/latex/chemgreek/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rpcywz5w2im5ck0kp56dywiy1his01s817pngdf9xdn02qk517n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chemgreek")
    (synopsis "Upright Greek letters in chemistry")
    (description
     "The package provides upright Greek letters in support of other chemistry
packages (such as @code{chemmacros}).")
    (license license:lppl1.3+)))

(define-public texlive-chemmacros
  (package
    (name "texlive-chemmacros")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chemmacros/"
                                     "tex/latex/chemmacros/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jj7i00h83mhajwayn48x4qf0xz526jrjlj5zclqkgrb6kxmx978"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chemmacros")
    (synopsis "Collection of macros to support typesetting chemistry documents")
    (description
     "The bundle offers a collection of macros and commands which are intended
to make typesetting chemistry documents faster and more convenient.  Coverage
includes some nomenclature commands, oxidation numbers, thermodynamic data,
newman projections, etc.")
    (license license:lppl1.3c)))

(define-public texlive-chemnum
  (package
    (name "texlive-chemnum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chemnum/" "tex/latex/chemnum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ld2ja2by5y48v5k8x1mgmcpr75vkf8r8ni0fmvrpxh8xrv7mq4f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chemnum")
    (synopsis "Method for numbering chemical compounds")
    (description
     "The package defines a @code{\\label}- and @code{\\ref}-like commands for
compound numbers.")
    (license license:lppl1.3c)))

(define-public texlive-chemobabel
  (package
    (name "texlive-chemobabel")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chemobabel/"
                                     "source/latex/chemobabel/"
                                     "tex/latex/chemobabel/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ky7xcyln4j40b18anld77mxc2i4af75y9xdjisj2ixl3vkg5a1x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chemobabel")
    (synopsis "Convert chemical structures from ChemDraw, MDL molfile or SMILES")
    (description
     "This package provides a way to convert and include chemical structure
graphics from various chemical formats, such as ChemDraw files, MDL molfile or
SMILES notations using Open Babel.  To use this LaTeX package, it is necessary
to enable execution of the following external commands via
@samp{latex -shell-escape}: @command{obabel} (Open Babel) @command{inkscape}
or @command{rsvg-convert} (for SVG -> PDF/EPS conversion), @command{pdfcrop}
or @command{ps2eps} (optional; for cropping large margins of PDF/EPS).")
    (license license:bsd-2)))

(define-public texlive-chemplants
  (package
    (name "texlive-chemplants")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chemplants/"
                                     "tex/latex/chemplants/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "164g4wy0x7jqf5l7hzb05ir7yz130bw34b7pwr8bp4vcyp4wy3ai"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chemplants")
    (synopsis "Symbology to draw chemical plants with TikZ")
    (description
     "This package offers tools to draw simple or barely complex schemes of
chemical processes.  The package defines several standard symbols and styles
to draw process units and streams.  The guiding light of the package is the
UNICHIM regulation.")
    (license license:lppl1.3c)))

(define-public texlive-chemschemex
  (package
    (name "texlive-chemschemex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chemschemex/"
                                     "source/latex/chemschemex/"
                                     "tex/latex/chemschemex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09mjxj1gwddbpkriivn8x98z9hls4pcmpdqf24a7gz19whgs1qyk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chemschemex")
    (synopsis "Typeset and cross-reference chemical schemes based on TikZ code")
    (description
     "The package provides a comfortable means of typesetting chemical
schemes, and also offers automatic structure referencing.")
    (license license:lppl1.2+)))

(define-public texlive-chemsec
  (package
    (name "texlive-chemsec")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chemsec/" "source/latex/chemsec/"
                                     "tex/latex/chemsec/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1q41mfhnvh4ni7dn0krrrcr9sr6ma855j1hckbg8fl56dl2h7zlp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chemsec")
    (synopsis "Automated creation of numeric entity labels")
    (description
     "Packages provides creation of sequential numeric labels for entities in
a document.  The motivating example is chemical structures in a scientific
document.  The package can automatically output a full object name and label
on the first occurrence in the document and just labels only on subsequent
references.")
    (license license:lppl1.3+)))

(define-public texlive-chemstyle
  (package
    (name "texlive-chemstyle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chemstyle/"
                                     "source/latex/chemstyle/"
                                     "tex/latex/chemstyle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1s2k4h153yh0f50q9da390f3ihykvrhsd1zjgfsdb6404059in3p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chemstyle")
    (synopsis "Writing chemistry with style")
    (description
     "The package @code{chemstyle} provides an extensible system for
formatting chemistry documents according to the conventions of a number of
leading journals.  It also provides some handy chemistry-related macros.")
    (license license:lppl1.3+)))

(define-public texlive-cherokee
  (package
    (name "texlive-cherokee")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cherokee/"
                                     "fonts/source/public/cherokee/"
                                     "fonts/tfm/public/cherokee/"
                                     "tex/latex/cherokee/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cganm5d4gnkkhandancyd915w2x9kskj9qg81y54jcfyjz8gp51"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/cherokee")
    (synopsis "Font for the Cherokee script")
    (description
     "The Cherokee script was designed in 1821 by Segwoya.  The alphabet is
essentially syllabic, only 6 characters (a e i o s u) correspond to Roman
letters: the font encodes these to the corresponding roman letter.  The
remaining 79 characters have been arbitrarily encoded in the range 38-122; the
@code{cherokee} package provides commands that map each such syllable to the
appropriate character.")
    ;; "You may freely use, modify, and/or distribute this file, without
    ;; limitation.  If you make significant additions or improvements,
    ;; I request that you email me an updated version."
    (license
     (license:fsf-free "file://fonts/source/public/cherokee/cherokee.mf"))))

(define-public texlive-chess
  (package
    (name "texlive-chess")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/chess/"
                                     "fonts/source/public/chess/"
                                     "fonts/tfm/public/chess/" "tex/latex/chess/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "079naqw9bd5da3c2bsa0322kdjrfpwa35inrfznzgrfdk1w0irs7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/chess")
    (synopsis "Fonts for typesetting chess boards")
    (description
     "This is the original, and somewhat dated, TeX chess font package.
Potential users should consider @code{skak} (for alternative fonts, and
notation support), @code{texmate} (for alternative notation support), or
@code{chessfss} (for flexible font choices).")
    (license license:public-domain)))

(define-public texlive-chess-problem-diagrams
  (package
    (name "texlive-chess-problem-diagrams")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chess-problem-diagrams/"
                                     "source/latex/chess-problem-diagrams/"
                                     "tex/latex/chess-problem-diagrams/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m32dhwdfrgy1r3lq8j7hdaa79kniwwq3lanbkkn32dhybwa0b61"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chess-problem-diagrams")
    (synopsis "Package for typesetting chess problem diagrams")
    (description
     "This package provides macros to typeset chess problem diagrams including
fairy chess problems (mostly using rotated images of pieces) and other
boards.")
    (license license:lppl1.2+)))

(define-public texlive-chessboard
  (package
    (name "texlive-chessboard")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chessboard/"
                                     "source/latex/chessboard/"
                                     "tex/latex/chessboard/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nz66h6baz5m2jfzjzyccw0rcpkc6rfbq9cc759y875b47j8pkhx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chessboard")
    (synopsis "Print chess boards")
    (description
     "This package offers commands to print chessboards.  It can print partial
boards, hide pieces and fields, color the boards and put various marks on the
board.  It has a lot of options to place pieces on the board.  Using exotic
pieces (e.g., for fairy chess) is possible.")
    (license license:lppl)))

(define-public texlive-chessfss
  (package
    (name "texlive-chessfss")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chessfss/"
                                     "fonts/enc/dvips/chessfss/"
                                     "source/latex/chessfss/"
                                     "tex/latex/chessfss/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1l51famz3zx9v4v0mdxwk51xhaidwgfplf268q2f1ipif9h6ma5d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chessfss")
    (synopsis "Package to handle chess fonts")
    (description
     "This package offers commands to use and switch between chess fonts.
It uses the LaTeX font selection scheme (nfss).  The package doesn't parse,
format and print PGN input like e.g., the packages @code{skak} or
@code{texmate}; the aim of the package is to offer writers of chess packages
a bundle of commands for fonts, so that they don't have to implement all these
commands for themselves.  A normal user can use the package to print
e.g,. single chess symbols and simple diagrams.")
    (license license:lppl)))

(define-public texlive-chhaya
  (package
    (name "texlive-chhaya")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chhaya/" "source/latex/chhaya/"
                                     "tex/latex/chhaya/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1if47icrsy56sjza170cxcpcczwfh9k8jl7j22gwwam4msa4d1if"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chhaya")
    (synopsis "Linguistic glossing in Marathi language")
    (description
     "This package provides macros for linguistic glossing as per the rules
given by Mumbai University.")
    (license (list license:gpl3+
                   ;; Aalok (आलोक) copyleft license v1.0+.
                   (license:fsf-free "file://doc/latex/aalok/README.txt")
                   license:fdl1.3+))))

(define-public texlive-chicago
  (package
    (name "texlive-chicago")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/chicago/" "tex/latex/chicago/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mwrphf2g7v5yc0qij76dkzalgm3fhcm8zs7akgaypyk98cvxw8k"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chicago")
    (synopsis "Chicago bibliography style")
    (description
     "Chicago is a BibTeX style that follows the @samp{B} reference style of
the 13th Edition of the Chicago manual of style; a LaTeX package is also
provided.  The style was derived from the @code{newapa} style.")
    (license license:knuth)))

(define-public texlive-chicago-annote
  (package
    (name "texlive-chicago-annote")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/chicago-annote/"
                                     "doc/bibtex/chicago-annote/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16hqz4xf7mbnrnx8420ynykxr1l3slfvjq8d8s0mrw42v88965ni"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chicago-annote")
    (synopsis "Chicago-based annotated BibTeX style")
    (description
     "This is a revision of chicagoa.bst, using the commonly-used annote field
in place of the original's annotation.")
    (license license:lppl)))

(define-public texlive-chicagoa
  (package
    (name "texlive-chicagoa")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/chicagoa/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1za4fqlpirbr3qs894abnlwmrhsqbahniyyimy1dxal0cp61cfil"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chicagoa")
    (synopsis "Chicago bibliography style with annotations")
    (description
     "This is a modification of the author's @code{chicago} style, to support
an annotation field in bibliographies.")
    (license license:knuth)))

(define-public texlive-chifoot
  (package
    (name "texlive-chifoot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chifoot/" "tex/latex/chifoot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07hxfiasfbnmvq367nnjg56n21wxdw0r6i7bl5l4gxa0j9jvmpf0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chifoot")
    (synopsis "Chicago-style footnote formatting")
    (description
     "This package provides a very short snippet that sets the footnotes to be
conformant with the Chicago style, so the footnotes at the bottom of the page
are now marked with a full-sized number, rather than with a superscript
number.")
    (license license:lppl1.3+)))

(define-public texlive-chinesechess
  (package
    (name "texlive-chinesechess")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chinesechess/"
                                     "tex/latex/chinesechess/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15sszrrv1viaa74i57a81xhybhjq2vaxb188wl728hjzm8d0n0wm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chinesechess")
    (synopsis "Typeset Chinese chess with @code{l3draw}")
    (description
     "This LaTeX3 package based on @code{l3draw} provides macros and an
environment for Chinese chess manual writing.")
    (license license:lppl1.3c)))

(define-public texlive-chivo
  (package
    (name "texlive-chivo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/chivo/"
                                     "fonts/enc/dvips/chivo/"
                                     "fonts/map/dvips/chivo/"
                                     "fonts/opentype/public/chivo/"
                                     "fonts/tfm/public/chivo/"
                                     "fonts/type1/public/chivo/"
                                     "fonts/vf/public/chivo/"
                                     "source/fonts/chivo/"
                                     "tex/latex/chivo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dvcz42rw2y33amrjikgicy9r4c6m0c4cvv2h0sm7k5bympnj8w0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chivo")
    (synopsis "Using the Chivo fonts with LaTeX")
    (description
     "This work provides the necessary files to use the Chivo fonts with
LaTeX.  Chivo is a set of eight fonts provided by Hector Gatti and Omnibus
Team.")
    (license (list license:silofl1.1 license:lppl1.3c))))

(define-public texlive-chordbars
  (package
    (name "texlive-chordbars")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chordbars/"
                                     "tex/latex/chordbars/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qnggp8m2r7z5qmgpnqza0a2d3gcszdcypg6i78vr6p0zcmbadvh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chordbars")
    (synopsis "Print chord grids for pop/jazz tunes")
    (description
     "This Tikz-based music-related package is targeted at pop/jazz
guitar/bass/piano musicians.  They usually need only the chords and the song
structure.  This package produces rectangular song patterns with one square
per bar, with the chord shown inside the square.  It also handles the song
structure by showing the bar count and the repetitions of the patterns.")
    (license license:lppl1.3+)))

(define-public texlive-chordbox
  (package
    (name "texlive-chordbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chordbox/" "tex/latex/chordbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01css8dnzss7s711ry2rs2fi3bw70s0lgj0cwwdicjgi331zbq70"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chordbox")
    (synopsis "Draw chord diagrams")
    (description
     "This package provides two macros for drawing chord diagrams, as may be
found for example in chord charts/books and educational materials.  They are
composed as TikZ pictures and have several options to modify their
appearance.")
    (license license:lppl1.3+)))

(define-public texlive-chronosys
  (package
    (name "texlive-chronosys")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/chronosys/"
                                     "tex/generic/chronosys/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "145ap67ykdkp2f0ahasp9sjccrv1wzxdfl05nq6hbi6z65pk56s5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chronosys")
    (synopsis "Drawing time-line diagrams")
    (description
     "This package provides macros to produce time line diagrams.
Interfaces for Plain TeX, ConTeXt and LaTeX are provided.")
    (license license:lppl1.3+)))

(define-public texlive-chs-physics-report
  (package
    (name "texlive-chs-physics-report")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chs-physics-report/"
                                     "tex/latex/chs-physics-report/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "195f66yffi96qkrxb044mcaycyds0mp3fg3c3lhz1mpvbz0calpl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chs-physics-report")
    (synopsis "Physics lab reports for Carmel High School")
    (description
     "This package may optionally be used by students at Carmel High School in
Indiana in the United States to write physics lab reports for FW physics
courses.  As many students are beginners at LaTeX, it also attempts to
simplify the report-writing process by offering macros for commonly used
notation and by automatically formatting the documents for students who will
only use TeX for mathematics and not typesetting.")
    (license (list license:public-domain license:cc-by-sa3.0))))

(define-public texlive-chscite
  (package
    (name "texlive-chscite")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/chscite/" "doc/latex/chscite/"
                                     "source/latex/chscite/" "tex/latex/chscite/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q4mgvrbljbw7pmwjs4qcr91sfhbnbshhmygxqrkriyrfnqy6yfq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chscite")
    (synopsis "Bibliography style for Chalmers University of Technology")
    (description
     "The package, heavily based on the harvard package for Harvard-style
citations, provides a citation suite for students at Chalmers University of
Technology that follows given recommendations.")
    (license license:lppl1.2+)))

(define-public texlive-churchslavonic
  (package
    (name "texlive-churchslavonic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/churchslavonic/"
                                     "tex/latex/churchslavonic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m9sf9nwnlribfhh5lks4lfnkc5fglcr4x3y30g03hcqrwwi15ks"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-etoolbox
           texlive-fonts-churchslavonic
           texlive-hyphen-complete
           texlive-oberdiek
           texlive-xcolor))
    (home-page "https://ctan.org/pkg/churchslavonic")
    (synopsis "Typeset documents in Church Slavonic language using Unicode")
    (description
     "The package provides fonts, hyphenation patterns, and supporting macros
to typeset Church Slavonic texts.")
    (license license:expat)))

(define-public texlive-cinzel
  (package
    (name "texlive-cinzel")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cinzel/"
                                     "fonts/enc/dvips/cinzel/"
                                     "fonts/map/dvips/cinzel/"
                                     "fonts/tfm/ndiscovered/cinzel/"
                                     "fonts/truetype/ndiscovered/cinzel/"
                                     "fonts/type1/ndiscovered/cinzel/"
                                     "fonts/vf/ndiscovered/cinzel/"
                                     "tex/latex/cinzel/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qik1ji23w35350ajjxz5w39w1cy4lg582343nrhr9y8jl18kfap"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cinzel")
    (synopsis "LaTeX support for Cinzel and Cinzel Decorative fonts")
    (description
     "Cinzel and Cinzel Decorative fonts, designed by Natanael Gama,
find their inspiration in first century roman inscriptions, and are based on
classical proportions.  Cinzel is all-caps (similar to Trajan and
Michelangelo), but is available in three weights (Regular, Bold, Black).
There are no italic fonts, but there are Decorative variants, which can be
selected by the usual italic-selection commands in the package's LaTeX
support.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-citation-style-language
  (package
    (name "texlive-citation-style-language")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/citation-style-language/"
                                     "doc/man/man1/citeproc-lua.1"
                                     "doc/man/man1/citeproc-lua.man1.pdf"
                                     "scripts/citation-style-language/"
                                     "tex/latex/citation-style-language/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "135al26nwqq0v5pvl54cbkbi0pxcvdkaskys0v2cigan1b406pj2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "citeproc-lua.lua")))
    (propagated-inputs
     (list texlive-filehook
           texlive-l3kernel
           texlive-l3packages
           texlive-lua-uca
           texlive-lualibs
           texlive-luatex
           texlive-luaxml
           texlive-url))
    (home-page "https://ctan.org/pkg/citation-style-language")
    (synopsis "Bibliography formatting with Citation Style Language")
    (description
     "The Citation Style Language (CSL) is an XML-based language that defines
the formats of citations and bibliography.  There are currently thousands of
styles in CSL including the most widely used APA, Chicago, Vancouver, etc.
The citation-style-language package is aimed to provide another reference
formatting method for LaTeX that utilizes the CSL styles.  It contains
a citation processor implemented in pure Lua (@code{citeproc-lua}) which reads
bibliographic metadata and performs sorting and formatting on both citations
and bibliography according to the selected CSL style.  A LaTeX package
(@file{citation-style-language.sty}) is provided to communicate with the
processor.")
    (license (list license:expat license:cc-by-sa3.0))))

(define-public texlive-citeall
  (package
    (name "texlive-citeall")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/citeall/" "tex/latex/citeall/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sap2kns1b51zj0dmy70q77rw7dnhdjqab0rmyvpp2hgq5yk3mhq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/citeall")
    (synopsis "Cite all entries of a @file{.bbl} created with BibLaTeX")
    (description
     "This small package allows citing all entries of
a BibLaTeX (@file{.bbl}) file.")
    (license license:lppl1.3+)))

(define-public texlive-citeref
  (package
    (name "texlive-citeref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/citeref/" "tex/latex/citeref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k76msdfsf968cv3m1z8lcf6mlmy90gaaphrgkr7cs67pgyvq6jq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/citeref")
    (synopsis "Add reference-page-list to bibliography-items")
    (description
     "The package adds reference-page-list to bibliography-items.  It does its
job without using the indexing facilities, and needs no special
@code{\\cite}-replacement package.")
    (license license:bsd-4)))

(define-public texlive-cje
  (package
    (name "texlive-cje")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/cje/" "doc/latex/cje/"
                                     "tex/latex/cje/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0n24knrb0ayh9dnqg4l776p5wzh5j1bbqxvwpf7pcljcml94iaa7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cje")
    (synopsis "LaTeX document class for CJE articles")
    (description
     "The @code{cje} article class allows authors to format their papers to
@emph{Canadian Journal of Economics} style with minimum effort.  The class
includes options for two other formats: @code{review} (double spaced, for use
at the submission stage) and @code{proof} (used by the typesetters to prepare
the proof authors will receive for approval).")
    (license license:lppl1.3c)))

(define-public texlive-cjhebrew
  (package
    (name "texlive-cjhebrew")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cjhebrew/"
                                     "fonts/afm/public/cjhebrew/"
                                     "fonts/enc/dvips/cjhebrew/"
                                     "fonts/map/dvips/cjhebrew/"
                                     "fonts/tfm/public/cjhebrew/"
                                     "fonts/type1/public/cjhebrew/"
                                     "fonts/vf/public/cjhebrew/"
                                     "tex/latex/cjhebrew/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00rf55ck8y1ny1v242sbhcfchnq7q5mlsmmqppgqspd892ymlxh0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cjhebrew")
    (synopsis "Typeset Hebrew with LaTeX")
    (description
     "The @code{cjhebrew} package provides Adobe Type 1 fonts for Hebrew, and
LaTeX macros to support their use.  Hebrew text can be vocalised, and a few
accents are also available.  The package makes it easy to include Hebrew text
in other-language documents.")
    (license license:lppl)))

(define-public texlive-cjk
  (package
    (name "texlive-cjk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cjk/"
                                     "source/latex/cjk/contrib/wadalab/"
                                     "source/latex/cjk/texinput/KS/HLaTeX/"
                                     "source/latex/cjk/utils/"
                                     "tex/latex/cjk/contrib/wadalab/"
                                     "tex/latex/cjk/texinput/"
                                     "tex/latex/cjk/utils/pyhyphen/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "044r1mmszq3hjmlck87vmqp62j2z02bm7lda8wb17phs0grkws5z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-arphic
           texlive-cns
           texlive-garuda-c90
           texlive-norasi-c90
           texlive-uhc
           texlive-wadalab))
    (home-page "https://ctan.org/pkg/cjk")
    (synopsis "CJK language support")
    (description
     "CJK is a macro package for LaTeX, providing simultaneous support for
various Asian scripts in many encodings (including Unicode): Chinese (both
traditional and simplified), Japanese, Korean and Thai.  A special add-on
feature is an interface to the Emacs editor (@file{cjk-enc.el}) which gives
simultaneous, easy-to-use support to a bunch of other scripts in addition to
the above -- Cyrillic, Greek, Latin-based scripts, Russian and Vietnamese are
supported.")
    (license license:gpl2)))

(define-public texlive-cjk-gs-integrate
  (package
    (name "texlive-cjk-gs-integrate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cjk-gs-integrate/"
                                     "fonts/misc/cjk-gs-integrate/"
                                     "scripts/cjk-gs-integrate/"
                                     "source/fonts/cjk-gs-integrate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ml35bs1pr3kbdqnbclyy31ln8yigy609rsm9rc2y3j5ngmw2y8y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "cjk-gs-integrate.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/cjk-gs-integrate")
    (synopsis "Tools to integrate CJK fonts into Ghostscript")
    (description
     "This script searches a list of directories for CJK fonts, and makes them
available to an installed Ghostscript.  In the simplest case, with sufficient
privileges, a run without arguments should result in a complete setup of
Ghostscript.")
    (license license:gpl3)))

(define-public texlive-cjk-ko
  (package
    (name "texlive-cjk-ko")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cjk-ko/" "tex/latex/cjk-ko/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yj4j0xbdchi56xyk1fq3xj33xwr9v58yfq4d8798mmzi9bd00m9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-cjk))
    (home-page "https://ctan.org/pkg/cjk-ko")
    (synopsis "Extension of the CJK package for Korean typesetting")
    (description
     "The package supports typesetting UTF-8-encoded modern Korean documents
with the help of the LaTeX2e CJK package.  It provides some enhanced features
focused on Korean typesetting culture, one of them being allowing line-break
between Latin and CJK characters.")
    (license (list license:gpl3+ license:lppl license:public-domain))))

(define-public texlive-cjkpunct
  (package
    (name "texlive-cjkpunct")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cjkpunct/"
                                     "source/latex/cjkpunct/"
                                     "tex/latex/cjkpunct/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l4jnawgcsq7lzsrky7259diswxm06mn9mvgxgw8j0za10kvv4vb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cjkpunct")
    (synopsis "Adjust locations and kerning of CJK punctuation marks")
    (description "The package serves as a companion package for CJK.  It
adjust locations and kerning of CJK punctuation marks.")
    (license license:lppl1.3+)))

(define-public texlive-cjkutils
  (package
    (name "texlive-cjkutils")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/bg5conv.1"
                                     "doc/man/man1/bg5conv.man1.pdf"
                                     "doc/man/man1/cef5conv.1"
                                     "doc/man/man1/cef5conv.man1.pdf"
                                     "doc/man/man1/cefconv.1"
                                     "doc/man/man1/cefconv.man1.pdf"
                                     "doc/man/man1/cefsconv.1"
                                     "doc/man/man1/cefsconv.man1.pdf"
                                     "doc/man/man1/extconv.1"
                                     "doc/man/man1/extconv.man1.pdf"
                                     "doc/man/man1/hbf2gf.1"
                                     "doc/man/man1/hbf2gf.man1.pdf"
                                     "doc/man/man1/sjisconv.1"
                                     "doc/man/man1/sjisconv.man1.pdf"
                                     "hbf2gf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0by2g05xv5dndnd78jz9y73fyswqhfvcbzcw8rzhvpvd6inrcdq8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-cjkutils-bin))
    (home-page "https://ctan.org/pkg/cjk")
    (synopsis "CJK language support")
    (description
     "CJK is a macro package for LaTeX, providing simultaneous support for
various Asian scripts in many encodings (including Unicode): Chinese (both
traditional and simplified), Japanese, Korean and Thai.  A special add-on
feature is an interface to the Emacs editor (cjk-enc.el) which gives
simultaneous, easy-to-use support to a bunch of other scripts in addition to
the above --- Cyrillic, Greek, Latin-based scripts, Russian and Vietnamese are
supported.")
    (license license:gpl2)))

(define-public texlive-cjkutils-bin
  (package
    (inherit texlive-bin)
    (name "texlive-cjkutils-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs/" '())
            (delete-other-directories "utils/" '())
            (delete-other-directories "texk/" '("cjkutils"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-cjkutils-x" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/cjkutils"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/cjkutils"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list texlive-libkpathsea))
    (propagated-inputs '())
    (home-page (package-home-page texlive-cjkutils))
    (synopsis "Binaries for @code{texlive-cjkutils}")
    (description
     "This package provides the binaries for @code{texlive-cjkutils}.")
    (license (package-license texlive-cjkutils))))

(define-public texlive-clara
  (package
    (name "texlive-clara")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/clara/"
                                     "fonts/enc/dvips/clara/"
                                     "fonts/map/dvips/clara/"
                                     "fonts/opentype/public/clara/"
                                     "fonts/tfm/public/clara/"
                                     "fonts/type1/public/clara/"
                                     "fonts/vf/public/clara/"
                                     "tex/latex/clara/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "182iw362irf247frsy0dzrswnh1341jlwrlwhvx1hcrbrvhpbz42"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/clara")
    (synopsis "Clara serif font family")
    (description
     "Clara is a type family created specially by Seamas O Brogain.  The
family includes italic, bold, bold italic, and small capitals, while the
character set includes (monotonic) Greek, Cyrillic, ogham, phonetic and
mathematical ranges, scribal abbreviations and other specialist characters.
The fonts also include some OpenType features (such as ligature substitution,
small capitals, and old-style numerals) and variant forms for particular
languages.")
    (license (list license:silofl1.1 license:gpl2+))))

(define-public texlive-classicthesis
  (package
    (name "texlive-classicthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/classicthesis/"
                                     "tex/latex/classicthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0djx7vcrc1ksbgppdbwy31z5qd95flgsgqk6gpzpi3a5rc7h54nz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/classicthesis")
    (synopsis "Classically styled thesis package")
    (description
     "This package provides an elegant layout designed in homage to
Bringhurst's @emph{The Elements of Typographic Style}.  It makes use of
a range of techniques to get the best results achievable using TeX.  Included
in the bundle are templates to make thesis writing easier.")
    (license license:gpl2+)))

(define-public texlive-cleanthesis
  (package
    (name "texlive-cleanthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cleanthesis/"
                                     "tex/latex/cleanthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11fv49w1nydm5fvkp1p2375ywdfd5yh8hayqfnr6wdidzdycpg85"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cleanthesis")
    (synopsis "Clean LaTeX style for thesis documents")
    (description
     "The package offers a clean, simple, and elegant LaTeX style for thesis
documents.")
    (license license:lppl1.3+)))

(define-public texlive-clearsans
  (package
    (name "texlive-clearsans")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/clearsans/"
                                     "fonts/enc/dvips/clearsans/"
                                     "fonts/map/dvips/clearsans/"
                                     "fonts/tfm/intel/clearsans/"
                                     "fonts/truetype/intel/clearsans/"
                                     "fonts/type1/intel/clearsans/"
                                     "fonts/vf/intel/clearsans/"
                                     "tex/latex/clearsans/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sf84xxvq9rxb3n5nsggfswvdagynnz6clazk86w4k2a5r0qf8yw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/clearsans")
    (synopsis "Clear Sans fonts with LaTeX support")
    (description
     "Clear Sans was designed by Daniel Ratighan.  It is available in three
weights (regular, medium, and bold) with corresponding italics, plus light and
thin upright (without italics).

It has minimized, unambiguous characters and slightly narrow proportions,
making it ideal for UI design.  Its strong, recognizable forms avoid
distracting ambiguity, making Clear Sans comfortable for reading short UI
labels and long passages in both screen and print.  The fonts are available in
both TrueType and Type 1 formats.")
    (license (list license:asl2.0 license:lppl))))

(define-public texlive-cleveref
  (package
    (name "texlive-cleveref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cleveref/"
                                     "source/latex/cleveref/"
                                     "tex/latex/cleveref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18r8g6ipn1ly60gnp0yi0m409gm8lssbpmka5813i4l45281fk43"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cleveref")
    (synopsis "Intelligent cross-referencing")
    (description
     "The package enhances LaTeX's cross-referencing features, allowing the
format of references to be determined automatically according to the type of
reference.  The formats used may be customised in the preamble of a document;
Babel support is available (though the choice of languages remains limited:
currently Danish, Dutch, English, French, German, Italian, Norwegian, Russian,
Spanish and Ukrainian).

The package also offers a means of referencing a list of references, each
formatted according to its type.  In such lists, it can collapse sequences of
numerically-consecutive labels to a reference range.")
    (license license:lppl1.2+)))

(define-public texlive-clrscode
  (package
    (name "texlive-clrscode")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/clrscode/" "tex/latex/clrscode/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gl2ap3w7zanbrn1k2bcf3f75lfpakp5dd0w8m1jy46hyvha7jpd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/clrscode")
    (synopsis "Typesets pseudocode as in Introduction to Algorithms")
    (description
     "This package allows you to typeset pseudocode in the style of
@emph{Introduction to Algorithms}, Second edition, by Cormen, Leiserson,
Rivest, and Stein.  The package was written by the authors.  You use the
commands the same way the package's author did when writing the book, and your
output will look just like the pseudocode in the text.")
    (license license:lppl)))

(define-public texlive-clrscode3e
  (package
    (name "texlive-clrscode3e")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/clrscode3e/"
                                     "tex/latex/clrscode3e/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kcsrlvqs83fc9ianim3drqvz60xp2cfl6a554icnm39p1fjf80c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/clrscode3e")
    (synopsis "Typesets pseudocode as in @emph{Introduction to Algorithms}")
    (description
     "This package allows you to typeset pseudocode in the style of
@emph{Introduction to Algorithms}, Third edition, by Cormen, Leiserson,
Rivest, and Stein.  The package was written by the authors.  Use the commands
the same way the package's author did when writing the book, and your output
will look just like the pseudocode in the text.")
    (license license:lppl)))

(define-public texlive-cm-mf-extra-bold
  (package
    (name "texlive-cm-mf-extra-bold")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "fonts/source/public/cm-mf-extra-bold/"
                                     "fonts/tfm/public/cm-mf-extra-bold/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1l1cm32z8wcpj0cl7czqkhnwil3ail7a2bbzn70dnswpj0ka8k9n"))))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/cm-mf-extra-bold")
    (synopsis "Extra Metafont files for CM")
    (description
     "The bundle provides bold versions of @code{cmcsc}, @code{cmex},
@code{cmtex} and @code{cmtt} fonts (all parts of the standard Computer Modern
font distribution), as Metafont base files.")
    (license (list license:gpl3+ license:public-domain))))

(define-public texlive-cm-unicode
  (package
    (name "texlive-cm-unicode")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cm-unicode/"
                                     "fonts/afm/public/cm-unicode/"
                                     "fonts/enc/dvips/cm-unicode/"
                                     "fonts/map/dvips/cm-unicode/"
                                     "fonts/opentype/public/cm-unicode/"
                                     "fonts/type1/public/cm-unicode/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15ysic6vah1wircybhpm9915mr1bbc8b2jalia86ajiqbxn2l9h0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cm-unicode")
    (synopsis "Computer Modern Unicode font family")
    (description
     "This package provides Computer Modern Unicode fonts.  Some characters in
several fonts are copied from Blue Sky Type 1 fonts released by AMS.
Currently the fonts contain glyphs from Latin, Cyrillic, Greek code sets and
IPA extensions.  This font set contains 33 fonts.  This archive contains AFM,
PFB and OTF versions; the OTF version of the Computer Modern Unicode fonts
works with TeX engines that directly support OpenType features, such as XeTeX
and LuaTeX.")
    (license license:silofl1.1)))

(define-public texlive-cmathbb
  (package
    (name "texlive-cmathbb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cmathbb/"
                                     "fonts/enc/dvips/cmathbb/"
                                     "fonts/map/dvips/cmathbb/"
                                     "fonts/tfm/public/cmathbb/"
                                     "fonts/type1/public/cmathbb/"
                                     "fonts/vf/public/cmathbb/"
                                     "tex/latex/cmathbb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pmzsaskwcbyjihidy7hvz7s2cixhl7ccy0c9cbh2cm3md6gdrqh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cmathbb")
    (synopsis "Computer modern mathematical blackboard bold font")
    (description
     "This font contains all digits and latin letters uppercase and lowercase
for the Computer Modern font family in blackboard bold.")
    (license license:lppl1.3c)))

(define-public texlive-cmll
  (package
    (name "texlive-cmll")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cmll/"
                                     "fonts/map/dvips/cmll/"
                                     "fonts/source/public/cmll/"
                                     "fonts/tfm/public/cmll/"
                                     "fonts/type1/public/cmll/"
                                     "source/latex/cmll/"
                                     "tex/latex/cmll/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13q5ar2zaf7h6f2mzgxxqzaraziwl6asicbnyq6anfv2ky38rd72"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-euxm")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs (list texlive-euxm texlive-metafont))
    (home-page "https://ctan.org/pkg/cmll")
    (synopsis "Symbols for linear logic")
    (description
     "This is a very small font set that contain some symbols useful in linear
logic, which are apparently not available elsewhere.  Variants are included
for use with Computer Modern serif and sans-serif and with the AMS Euler
series.  The font is provided both as Metafont source, and in Adobe Type
1 format.  LaTeX support is provided.")
    (license license:lppl)))

(define-public texlive-cmpica
  (package
    (name "texlive-cmpica")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cmpica/"
                                     "fonts/source/public/cmpica/"
                                     "fonts/tfm/public/cmpica/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gpj2i588h6d0b5cl4xaik9nyx7w1sd8wik5q4mgmzspbkdk5a04"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/cmpica")
    (synopsis "Computer Modern Pica variant")
    (description
     "This is an approximate equivalent of the Xerox Pica typeface; the font
is optimised for submitting fiction manuscripts to mainline publishers.  The
font is a fixed-width one, rather less heavy than Computer Modern typewriter.
Emphasis for bold-face comes from a wavy underline of each letter.  The two
fonts are supplied as Metafont source.")
    (license license:public-domain)))

(define-public texlive-cmpj
  (package
    (name "texlive-cmpj")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/cmpj/" "doc/latex/cmpj/"
                                     "tex/latex/cmpj/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1drmil2vba85wa7ykrma452hwh7ggzsq33zrhch7rjnqaw7xihwv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cmpj")
    (synopsis "Style for the journal @emph{Condensed Matter Physics}")
    (description
     "The package contains macros and some documentation for typesetting
papers for submission to the @emph{Condensed Matter Physics} journal published
by the Institute for Condensed Matter Physics of the National Academy of
Sciences of Ukraine.")
    (license license:lppl)))

(define-public texlive-cmsrb
  (package
    (name "texlive-cmsrb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cmsrb/"
                                     "fonts/afm/public/cmsrb/"
                                     "fonts/enc/dvips/cmsrb/"
                                     "fonts/map/dvips/cmsrb/"
                                     "fonts/tfm/public/cmsrb/"
                                     "fonts/type1/public/cmsrb/"
                                     "fonts/vf/public/cmsrb/"
                                     "tex/latex/cmsrb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0f6ylk8n881sl0njbz7yqy98pbk51s6m73zldcsz2w62qnghd1x0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cmsrb")
    (synopsis "Computer Modern for Serbian and Macedonian")
    (description
     "This package provides provides Adobe Type 1 Computer Modern fonts for
the Serbian and Macedonian languages.  Although the @code{cm-super} package
provides great support for Cyrillic script in various languages, there remains
a problem with italic variants of some letters for Serbian and Macedonian.
This package includes the correct shapes for italic letters @code{\\cyrb},
@code{\\cyrg}, @code{\\cyrd}, @code{\\cyrp}, and @code{\\cyrt}.  It also
offers some improvements in letters and accents used in the Serbian language.
Supported encodings are: T1, T2A, TS1, X2 and OT2.  The OT2 encoding is
modified so that it is now easy to transcribe Latin text to Cyrillic.")
    (license license:gpl3+)))

(define-public texlive-cmtiup
  (package
    (name "texlive-cmtiup")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cmtiup/"
                                     "fonts/source/public/cmtiup/"
                                     "fonts/tfm/public/cmtiup/"
                                     "fonts/vf/public/cmtiup/"
                                     "tex/latex/cmtiup/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cdm10aybgc8ifi11fahl3hb18blmibk08b4b5m8q88150ic563r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/cmtiup")
    (synopsis "Upright punctuation with CM italic")
    (description
     "The @code{cmtiup} fonts address a problem with the appearance of
punctuation in italic text in mathematical documents.  To achieve this, all
punctuation characters are upright, and kerning between letters and
punctuation is adjusted to allow for the italic correction.  The fonts are
implemented as a set of @file{.vf} files; a package for support in LaTeX is
provided.")
    (license license:lppl1.3+)))

(define-public texlive-cmupint
  (package
    (name "texlive-cmupint")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cmupint/"
                                     "fonts/afm/public/cmupint/"
                                     "fonts/map/dvips/cmupint/"
                                     "fonts/source/public/cmupint/"
                                     "fonts/tfm/public/cmupint/"
                                     "fonts/type1/public/cmupint/"
                                     "tex/latex/cmupint/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1acgzx5b02900vzwvaq0j8w6x8jc1650kfhp992f3bcyd658aj62"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/cmupint")
    (synopsis "Upright integral symbols for Computer Modern")
    (description
     "This package contains various upright integral symbols to match the
Computer Modern font.")
    (license license:lppl)))

(define-public texlive-cochineal
  (package
    (name "texlive-cochineal")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cochineal/"
                                     "fonts/afm/public/cochineal/"
                                     "fonts/enc/dvips/cochineal/"
                                     "fonts/map/dvips/cochineal/"
                                     "fonts/opentype/public/cochineal/"
                                     "fonts/tfm/public/cochineal/"
                                     "fonts/type1/public/cochineal/"
                                     "fonts/vf/public/cochineal/"
                                     "tex/latex/cochineal/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lr07badgq7glvjbpvifif15y86kr58xf0ag937jlr5f7vbmk1ax"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cochineal")
    (synopsis "Cochineal fonts with LaTeX support")
    (description
     "Cochineal is a fork from the Crimson fonts (Roman, Italic, Bold,
@code{BoldItalic} only), which contain roughly 4200 glyphs in the four styles
mentioned above.  Cochineal adds more than 1500 glyphs in those styles so that
it is possible to make a TeX support collection that contains essentially all
glyphs in all styles.  The fonts are provided in OpenType and PostScript
formats.")
    (license (list license:silofl1.1 license:lppl1.3+))))

(define-public texlive-codeanatomy
  (package
    (name "texlive-codeanatomy")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/codeanatomy/"
                                     "source/latex/codeanatomy/"
                                     "tex/latex/codeanatomy/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1frkyj86kf9b3n08xlwfndiygllymp2lp7ra82zsnx4xzw1ff4as"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/codeanatomy")
    (synopsis "Typeset code with annotations")
    (description
     "The idea of this Package is to typeset illustrations of pieces of code
with annotations on each single part of code (Code Anatomy).  The origin of
this idea are code illustrations from the book @emph{Computer Science: An
Interdisciplinary Approach} from Robert Sedgewick and Kevin Wayne.")
    (license license:lppl1.3c)))

(define-public texlive-codicefiscaleitaliano
  (package
    (name "texlive-codicefiscaleitaliano")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/codicefiscaleitaliano/"
                                     "source/latex/codicefiscaleitaliano/"
                                     "tex/latex/codicefiscaleitaliano/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ij3vcikhwx1d55z2gsx4yb9fin9dhm8yjwc6apiwg353ipxwibw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/codicefiscaleitaliano")
    (synopsis "Test the consistency of the Italian personal Fiscal Code")
    (description
     "The alphanumeric string that forms the Italian personal Fiscal Code is
prone to be misspelled thus rendering a legal document invalid.  The package
quickly verifies the consistency of the fiscal code string, and can therefore
be useful for lawyers and accountants that use fiscal codes very frequently.")
    (license license:lppl1.3+)))

(define-public texlive-coelacanth
  (package
    (name "texlive-coelacanth")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/coelacanth/"
                                     "fonts/enc/dvips/coelacanth/"
                                     "fonts/map/dvips/coelacanth/"
                                     "fonts/opentype/public/coelacanth/"
                                     "fonts/tfm/public/coelacanth/"
                                     "fonts/type1/public/coelacanth/"
                                     "fonts/vf/public/coelacanth/"
                                     "tex/latex/coelacanth/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cwk36rm1m2qaphwlpnw6rhmsmkvsdpzqs7sv1c39qcyq853q4yj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/coelacanth")
    (synopsis "Coelacanth fonts with LaTeX support")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX, and LuaLaTeX support for
Coelecanth fonts, designed by Ben Whitmore.  Coelacanth is inspired by the
classic Centaur type design of Bruce Rogers, described by some as the most
beautiful typeface ever designed.  It aims to be a professional quality type
family for general book typesetting.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-collref
  (package
    (name "texlive-collref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/collref/" "source/latex/collref/"
                                     "tex/latex/collref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gvla01fypbdqvjg0zziy4cl2s6z441pvn3s8b45dvz4hy1hkfji"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/collref")
    (synopsis "Collect blocks of references into a single reference")
    (description
     "The package automatically collects multiple @code{\\bibitem} references,
which always appear in the same sequence in @code{\\cite}, into a single
@code{\\bibitem} block.")
    (license license:lppl1.3+)))

(define-public texlive-colorsep
  (package
    (name "texlive-colorsep")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "dvips/colorsep/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nf72pf2bjn8pcps45sn5dcjf1dkrww9wlpp1xbzl1h9i68p3h3h"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/colorsep")
    (synopsis "Color separation")
    (description
     "This package provides support for colour separation when using Dvips.")
    (license license:public-domain)))

(define-public texlive-comfortaa
  (package
    (name "texlive-comfortaa")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/comfortaa/"
                                     "fonts/enc/dvips/comfortaa/"
                                     "fonts/map/dvips/comfortaa/"
                                     "fonts/tfm/aajohan/comfortaa/"
                                     "fonts/truetype/aajohan/comfortaa/"
                                     "fonts/type1/aajohan/comfortaa/"
                                     "fonts/vf/aajohan/comfortaa/"
                                     "tex/latex/comfortaa/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ayh1f0f1a0qkngsk84zwzyx5kidb2n5wq2ksk0d7r68m8cbs981"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/comfortaa")
    (synopsis "Sans serif font, with LaTeX support")
    (description
     "Comfortaa is a sans-serif font, comfortable in every aspect, designed by
Johan Aakerlund.  This package provides support for this font in LaTeX, and
includes both the TrueType fonts, and conversions to Adobe Type 1 format.")
    (license (list license:silofl1.1 license:lppl1.3c))))

(define-public texlive-comicneue
  (package
    (name "texlive-comicneue")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/comicneue/"
                                     "fonts/enc/dvips/comicneue/"
                                     "fonts/map/dvips/comicneue/"
                                     "fonts/opentype/rozynski/comicneue/"
                                     "fonts/tfm/rozynski/comicneue/"
                                     "fonts/type1/rozynski/comicneue/"
                                     "fonts/vf/rozynski/comicneue/"
                                     "tex/latex/comicneue/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q9ckbypx5hn9004pgfyqnf1ddniqwq0fixps0acmifz8qspjih6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/comicneue")
    (synopsis "Use Comic Neue with TeX(-alike) systems")
    (description
     "Comic Neue is a well-known redesign of the (in)famous Comic Sans font.
The package provides the original OpenType font for XeTeX and LuaTeX users,
and also has converted Type1 files for pdfTeX users.")
    (license license:silofl1.1)))

(define-public texlive-commath
  (package
    (name "texlive-commath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/commath/" "tex/latex/commath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mvlqw78183mp8fdvcmrwxvf4cpqdb2sr6jif16rad0av602lnfr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/commath")
    (synopsis "Mathematics typesetting support")
    (description
     "This package provides a range of differential, partial differential and
delimiter commands, together with a @code{\\fullfunction} (function, with both
domain and range, and function operation) and various reference commands.")
    (license license:lppl)))

(define-public texlive-commutative-diagrams
  (package
    (name "texlive-commutative-diagrams")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/commutative-diagrams/"
                                     "tex/context/third/commutative-diagrams/"
                                     "tex/generic/commutative-diagrams/"
                                     "tex/latex/commutative-diagrams/"
                                     "tex/plain/commutative-diagrams/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nypxn0lzzddwcdm53y1i0l9kxjq01v6q30dnh4b9cd2ms9mwllh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/commutative-diagrams")
    (synopsis "CoDi: Commutative Diagrams for TeX")
    (description
     "This package provides a TikZ library for making commutative diagrams
easy to design, parse and tweak.")
    (license license:expat)))

(define-public texlive-compactbib
  (package
    (name "texlive-compactbib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/latex/compactbib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "077l73vb0rcxy1n51r3wmcb7gma6nn3xrl543a67n96lpp5xvnnk"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/compactbib")
    (synopsis "Multiple thebibliography environments")
    (description
     "This package allows a second bibliography, optionally with a different
title, after the main bibliography.")
    (license license:lppl)))

(define-public texlive-compare
  (package
    (name "texlive-compare")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/generic/compare/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0isr7gmskv55cr4f1fa7s478v6fh65q9ijxkmbpxj0448g9817w4"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/compare")
    (synopsis "Compare two strings")
    (description
     "The file defines a macro @code{\\compare}, which takes two arguments;
the macro expands to @samp{-1}, @samp{0}, @samp{1}, according as the first
argument is less than, equal to, or greater than the second argument.  Sorting
is alphabetic, using ASCII collating order.")
    (license license:public-domain)))

(define-public texlive-complexity
  (package
    (name "texlive-complexity")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/complexity/"
                                     "tex/latex/complexity/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yqv0qp4i6jkjkrsvjzq5r2x282y5maq6w5cbvkspp7d0g4sg0ph"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/complexity")
    (synopsis "Computational complexity class names")
    (description
     "Complexity is a LaTeX package that defines commands to typeset
Computational Complexity Classes such as @samp{$\\P$} and @samp{$\\NP$} (as
well as hundreds of others).  It also offers several options including which
font classes are typeset in and how many are defined (all of them or just the
basic, most commonly used ones).")
    (license license:lppl1.3c)))

(define-public texlive-computational-complexity
  (package
    (name "texlive-computational-complexity")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/computational-complexity/"
                                     "doc/latex/computational-complexity/"
                                     "source/latex/computational-complexity/"
                                     "tex/latex/computational-complexity/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12205p6i611vcywsvkq4qnkbgfyyrkxgrqhj93bfdy4n8y2802ir"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/computational-complexity")
    (synopsis "Class for the journal Computational Complexity")
    (description
     "The LaTeX2e class @code{cc} was written for the journal Computational
Complexity, and it can also be used for a lot of other articles.  You may like
it since it contains a lot of features such as more intelligent references,
a set of theorem definitions, an algorithm environment, and more.")
    (license license:lppl1.2+)))

(define-public texlive-concmath
  (package
    (name "texlive-concmath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/concmath/"
                                     "source/latex/concmath/"
                                     "tex/latex/concmath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lc1bj2yqbyn13bq4fwiqf1hijbj5kwxadifzbg1riscwal3z5vw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/concmath")
    (synopsis "Concrete Math fonts")
    (description
     "This package provides a LaTeX package and font definition files to
access the Concrete mathematics fonts, which were derived from Computer Modern
math fonts using parameters from Concrete Roman text fonts.")
    (license license:lppl)))

(define-public texlive-concmath-fonts
  (package
    (name "texlive-concmath-fonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/concmath-fonts/"
                                     "fonts/source/public/concmath-fonts/"
                                     "fonts/tfm/public/concmath-fonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09frgpcwpfkj9j9aaj5psb8kr12vgbr10plcvcipn0mjahdw9nnz"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-amsfonts")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-amsfonts texlive-metafont))
    (home-page "https://ctan.org/pkg/concmath-fonts")
    (synopsis "Concrete mathematics fonts")
    (description
     "The fonts are derived from the Computer Modern Mathematics fonts and
from Knuth's Concrete Roman fonts; they are distributed as Metafont source.
LaTeX support is offered by the @code{concmath} package.")
    (license license:lppl)))

(define-public texlive-concmath-otf
  (package
    (name "texlive-concmath-otf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/concmath-otf/"
                                     "fonts/opentype/public/concmath-otf/"
                                     "tex/latex/concmath-otf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0478gvi7v21nnbj19prfznkg4vzwb5w08rx4549kfqf0wnw57bpz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/concmath-otf")
    (synopsis "Concrete based OpenType Math font")
    (description
     "This package provides an OpenType version of the Concrete Math font
created by Ulrik Vieth in Metafont.  @file{concmath-otf.sty} is a replacement
for the original @file{concmath.sty} package to be used with LuaTeX or XeTeX
engines.")
    (license (list license:silofl1.1 license:lppl1.3+))))

(define-public texlive-concrete
  (package
    (name "texlive-concrete")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/concrete/"
                                     "fonts/source/public/concrete/"
                                     "fonts/tfm/public/concrete/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xras2ybr33xm27vl0ym3lyd954gizgyd6h84ivxg0zjpqpjanb1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/concrete")
    (synopsis "Concrete Roman fonts")
    (description
     "This package provides Concrete Roman fonts, designed by Donald Knuth,
originally for use with Euler mathematics fonts.  Alternative mathematics
fonts, based on the concrete parameter set are available as the
@code{concmath} fonts bundle.  LaTeX support is offered by the @code{beton},
@code{concmath} and @code{ccfonts} packages.  T1- and TS1-encoded versions of
the fonts are available in the @code{ecc} bundle, and Adobe Type 1 versions of
the @code{ecc} fonts are part of the @code{cm-super} bundle.")
    (license license:knuth)))

(define-public texlive-confproc
  (package
    (name "texlive-confproc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/confproc/" "doc/latex/confproc/"
                                     "makeindex/confproc/"
                                     "source/latex/confproc/"
                                     "tex/latex/confproc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1v3ppwxss1ans62j1pss8mcfjqmx708za7pmcm1wic7z7byc6xdb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/confproc")
    (synopsis "Set of tools for generating conference proceedings")
    (description
     "The @code{confproc} collection comprises a class, a BibTeX style, and
some scripts for generating conference proceedings.")
    (license license:lppl)))

(define-public texlive-conteq
  (package
    (name "texlive-conteq")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/conteq/" "source/latex/conteq/"
                                     "tex/latex/conteq/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14lj914i1h29pvg7knfn3ym9nsq6qxngbmkks4hircj0082m86pz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/conteq")
    (synopsis "Typeset multiline continued equalities")
    (description
     "The package provides an environment @code{conteq}, which will lay out
systems of continued equalities (or inequalities).  Several variant layouts of
the equalities are provided, and the user may define their own.")
    (license license:lppl1.3+)))

(define-public texlive-convbkmk
  (package
    (name "texlive-convbkmk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/convbkmk/" "scripts/convbkmk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0w4fm4az1smrw002sqjkiiz94x01z6jkrb0mf9wb8qxdwrxriql9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "convbkmk.rb")))
    (inputs (list ruby))
    (home-page "https://ctan.org/pkg/convbkmk")
    (synopsis
     "Correct pLaTeX/upLaTeX bookmarks in PDF created with @code{hyperref}")
    (description
     "The package provides a small Ruby script that corrects bookmarks in PDF
files created by pLaTeX or upLaTeX, using @code{hyperref}.")
    (license license:expat)))

(define-public texlive-cookingsymbols
  (package
    (name "texlive-cookingsymbols")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cookingsymbols/"
                                     "fonts/source/public/cookingsymbols/"
                                     "fonts/tfm/public/cookingsymbols/"
                                     "source/latex/cookingsymbols/"
                                     "tex/latex/cookingsymbols/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cqz5hvb1vcf4mgk7i960kjdbg9cbxkik62riy6l2n1ld2cnl81x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/cookingsymbols")
    (synopsis "Symbols for recipes")
    (description
     "The package provides 11 symbols for typesetting recipes: oven, gasstove,
topheat, fanoven, gloves and dish symbol (among others).  The symbols are
defined using Metafont.")
    (license license:lppl)))


(define-public texlive-cooperhewitt
  (package
    (name "texlive-cooperhewitt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cooperhewitt/"
                                     "fonts/enc/dvips/cooperhewitt/"
                                     "fonts/map/dvips/cooperhewitt/"
                                     "fonts/opentype/public/cooperhewitt/"
                                     "fonts/tfm/public/cooperhewitt/"
                                     "fonts/type1/public/cooperhewitt/"
                                     "fonts/vf/public/cooperhewitt/"
                                     "tex/latex/cooperhewitt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m81sxrwwsmzsan4iln2lsf16pijay7w9k29gjwlwikivvy21kj7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cooperhewitt")
    (synopsis "Cooper Hewitt family of sans serif fonts")
    (description
     "Cooper Hewitt is a contemporary sans serif, with characters composed of
modified-geometric curves and arches, by Chester Jenkins.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-cormorantgaramond
  (package
    (name "texlive-cormorantgaramond")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cormorantgaramond/"
                                     "fonts/enc/dvips/cormorantgaramond/"
                                     "fonts/map/dvips/cormorantgaramond/"
                                     "fonts/tfm/catharsis/cormorantgaramond/"
                                     "fonts/truetype/catharsis/cormorantgaramond/"
                                     "fonts/type1/catharsis/cormorantgaramond/"
                                     "fonts/vf/catharsis/cormorantgaramond/"
                                     "tex/latex/cormorantgaramond/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sd4g4s3d3nk4wrav3szzbihdj6saznnzm6kiyr4qqqgi5ib3ami"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cormorantgaramond")
    (synopsis "Cormorant Garamond family of fonts")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the Cormorant Garamond family of fonts, designed by Christian Thalman.  The
family includes light, regular, medium, semi-bold, and bold weights, with
italics.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-correctmathalign
  (package
    (name "texlive-correctmathalign")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/correctmathalign/"
                                     "tex/latex/correctmathalign/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zqla0gjv1b3x3z6g6fdb89c66ny7agshfmcsjjg42vlkz17ianm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/correctmathalign")
    (synopsis "Correct spacing of the alignment in expressions")
    (description
     "This package realigns the horizontal spacing of the alignments in some
mathematical environments.")
    (license license:bsd-2)))

(define-public texlive-countriesofeurope
  (package
    (name "texlive-countriesofeurope")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/countriesofeurope/"
                                     "fonts/afm/public/countriesofeurope/"
                                     "fonts/enc/dvips/countriesofeurope/"
                                     "fonts/map/dvips/countriesofeurope/"
                                     "fonts/opentype/public/countriesofeurope/"
                                     "fonts/tfm/public/countriesofeurope/"
                                     "fonts/type1/public/countriesofeurope/"
                                     "tex/latex/countriesofeurope/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07q0hrrlvadcc3vcl97gsgp1pbkmfhy60zm8ib65qd79m81kyxs0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/countriesofeurope")
    (synopsis "Font with the images of the countries of Europe")
    (description
     "The bundle provides a font CountriesOfEurope (in Adobe Type 1 format)
and the necessary metrics, together with LaTeX macros for its use.  The font
provides glyphs with a filled outline of the shape of each country; each glyph
is at the same cartographic scale.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-courier-scaled
  (package
    (name "texlive-courier-scaled")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/courier-scaled/"
                                     "tex/latex/courier-scaled/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1d61afhvx9s70mg9d97m0zyzqfdlwbgljwgkv0z87khxy4z33wy6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/courier-scaled")
    (synopsis "Provides a scaled Courier font")
    (description
     "This package sets the default typewriter font to Courier with a possible
scale factor (in the same way as the @code{helvet} package for Helvetica works
for sans serif).")
    (license license:lppl1.2+)))

(define-public texlive-courierten
  (package
    (name "texlive-courierten")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/courierten/"
                                     "fonts/enc/dvips/courierten/"
                                     "fonts/map/dvips/courierten/"
                                     "fonts/opentype/public/courierten/"
                                     "fonts/tfm/public/courierten/"
                                     "fonts/type1/public/courierten/"
                                     "fonts/vf/public/courierten/"
                                     "tex/latex/courierten/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xfra9x03zjx7jsk48kj7mmjng3rs45ydj258c4s6inl91m7i9w0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/courierten")
    (synopsis "Courier 10 Pitch BT with LaTeX support")
    (description
     "This is the font Courier 10 Pitch BT, with LaTeX support and an OpenType
conversion as well.")
    (license license:expat)))

(define-public texlive-covington
  (package
    (name "texlive-covington")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/covington/"
                                     "tex/latex/covington/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16ba3mzahkaza69a92mqrnrr7jx6r9alcwxgma03pppblfkz3k3q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/covington")
    (synopsis "LaTeX macros for Linguistics")
    (description
     "This package provides numerous minor LaTeX enhancements for linguistics,
including multiple accents on the same letter, interline glosses (word-by-word
translations), Discourse Representation Structures, and example numbering.")
    (license license:lppl1.3+)))

(define-public texlive-cquthesis
  (package
    (name "texlive-cquthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/cquthesis/"
                                     "doc/latex/cquthesis/"
                                     "source/latex/cquthesis/"
                                     "tex/latex/cquthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0591wd88zp4sgnv2avwqv8127c2g5zbhjr7y15xaahiy7s404hn2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cquthesis")
    (synopsis "LaTeX thesis template for Chongqing University")
    (description
     "CQUThesis stands for Chongqing University thesis template for LaTeX,
bearing the ability to support bachelor, master, doctor dissertations with
grace and speed.")
    (license license:lppl1.3+)))

(define-public texlive-create-theorem
  (package
    (name "texlive-create-theorem")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/create-theorem/"
                                     "tex/latex/create-theorem/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x7pr5xsmsy0a844nrfld18xiv7x0ckijnnjwd78y1hmsgd6cdqb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-crefthe))
    (home-page "https://ctan.org/pkg/create-theorem")
    (synopsis "Multilingual support for @code{theorem}-like environments")
    (description
     "This package provides commands for naming, initializing and configuring
@code{theorem}-like environments.  These commands have key-value based
interfaces and are especially useful in multilingual documents, allowing the
easy declaration of @code{theorem}-like environments that can automatically
adapt to the language settings.")
    (license license:lppl1.3c)))

(define-public texlive-crefthe
  (package
    (name "texlive-crefthe")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/crefthe/" "tex/latex/crefthe/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xszhn0bg077297w981miwjnsqylxam9x5bkpli2k0vj73xqmsqs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/crefthe")
    (synopsis "Cross referencing with proper definite articles")
    (description
     "By default, when using @code{cleveref}'s @code{\\cref} to reference
@code{theorem}-like environments, the names do not contain definite articles.
In languages such as French, Italian, Portuguese, Spanish, etc., this results
in incorrect grammar.  For this purpose, the current package offers
@code{\\crefthe}, which handles the definite articles properly (especially for
the article contractions in many European languages).")
    (license license:lppl1.3c)))

(define-public texlive-crimson
  (package
    (name "texlive-crimson")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/crimson/"
                                     "fonts/enc/dvips/crimson/"
                                     "fonts/map/dvips/crimson/"
                                     "fonts/opentype/kosch/crimson/"
                                     "fonts/tfm/kosch/crimson/"
                                     "fonts/type1/kosch/crimson/"
                                     "fonts/vf/kosch/crimson/"
                                     "tex/latex/crimson/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14zrb015cs5f5kdyjy987mx4jdvi7vr1830dvnnygvkpcacvc3mc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/crimson")
    (synopsis "Crimson fonts with LaTeX support")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX, and LuaLaTeX support for
the Crimson family of fonts, designed by Sebastian Kosch.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-crimsonpro
  (package
    (name "texlive-crimsonpro")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/crimsonpro/"
                                     "fonts/enc/dvips/crimsonpro/"
                                     "fonts/map/dvips/crimsonpro/"
                                     "fonts/tfm/public/crimsonpro/"
                                     "fonts/truetype/public/crimsonpro/"
                                     "fonts/type1/public/crimsonpro/"
                                     "fonts/vf/public/crimsonpro/"
                                     "tex/latex/crimsonpro/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pzsdm4i32pgwf726q5waga8lr37xfj1qj417kkblw3q3fgb4jsd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/crimsonpro")
    (synopsis "CrimsonPro fonts with LaTeX support")
    (description
     "The CrimsonPro fonts are designed by Jacques Le Bailly and derived
from the Crimson Text fonts designed by Sebastian Kosch.  The family
includes eight weights and italics for each weight.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-crossrefenum
  (package
    (name "texlive-crossrefenum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/crossrefenum/"
                                     "tex/generic/crossrefenum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07h7d47fxjj70h4bxd5sqz8abjnvgvkrnsy13a26imbarzg14db4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/crossrefenum")
    (synopsis
     "Smart typesetting of enumerated cross-references for various TeX formats")
    (description
     "@code{crossrefenum} lets TeX manage the formatting of bunches of
cross-references for you.  It features:

@itemize
@item automatic collapsing of references;
@item support for references by various criteria, including page and note
number, line number in ConTeXt, and @code{edpage} and @code{edline} when used
in conjunction with @code{reledmac};
@item handling of references combining two criteria (e.g., by page and note
number);
@item extension mechanisms to add support to other types of references without
modifying the internal macros.  Note that sorting is not supported.
@end itemize

It is written in Plain TeX as much as possible in order to make it compatible
with a wide array of formats.  For the moment, it works out of the box with
ConTeXt and LaTeX.")
    (license (list license:gpl3+ license:fdl1.3+))))

(define-public texlive-crossrefware
  (package
    (name "texlive-crossrefware")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/bbl2bib.1"
                                     "doc/man/man1/bbl2bib.man1.pdf"
                                     "doc/man/man1/bibdoiadd.1"
                                     "doc/man/man1/bibdoiadd.man1.pdf"
                                     "doc/man/man1/bibmradd.1"
                                     "doc/man/man1/bibmradd.man1.pdf"
                                     "doc/man/man1/biburl2doi.1"
                                     "doc/man/man1/biburl2doi.man1.pdf"
                                     "doc/man/man1/bibzbladd.1"
                                     "doc/man/man1/bibzbladd.man1.pdf"
                                     "doc/man/man1/ltx2crossrefxml.1"
                                     "doc/man/man1/ltx2crossrefxml.man1.pdf"
                                     "doc/support/crossrefware/"
                                     "scripts/crossrefware/"
                                     "tex/latex/crossrefware/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01ajqi1ba7fhidzpfrnvpszl5bkcjgnxp06fvxd1h7d5c5229iyi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts
           #~(list "bbl2bib.pl"
                   "bibdoiadd.pl"
                   "bibmradd.pl"
                   "biburl2doi.pl"
                   "bibzbladd.pl"
                   "ltx2crossrefxml.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/crossrefware")
    (synopsis "Scripts for working with @url{crossref.org}")
    (description
     "This bundle contains the following scripts:
@itemize

@item @file{bibdoiadd.pl}: add DOI numbers to papers in a given @file{.bib}
file,

@item @file{bibzbladd.pl}: add Zbl numbers to papers in a given @file{.bib}
file,

@item @file{bibmradd.pl}: add MR numbers to papers in a given @file{.bib}
file,

@item @file{bbl2bib.pl}: convert @code{thebibliography} environment to
a @file{.bib} file,

@item @file{biburl2doi.pl}: convert URLs pointing to @url{doi.org} to DOIs,

@item @file{ltx2crossrefxml.pl}: tool for the creation of XML files for
submitting to @url{crossref.org}.

@end itemize")
    (license license:gpl3+)))

(define-public texlive-crossword
  (package
    (name "texlive-crossword")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/crossword/"
                                     "source/latex/crossword/"
                                     "tex/latex/crossword/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yxjhni6jw7j7wnz6g6d1bmri8afvqsj58bar0aqliyfhr55xzai"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/crossword")
    (synopsis "Typeset crossword puzzles")
    (description
     "This is an extended grid-based puzzle package, designed to take all
input (both grid and clues) from the same file.  The package can
typeset grids with holes in them, and can deal with several sorts of
puzzle:
@itemize

@item the classical puzzle contains numbers for the words and clues
for the words to be filled in;

@item the numbered puzzle contains numbers in each cell where
identical numbers represent identical letters; the goal is to find out
which number corresponds to which letter;

@item the fill-in type of puzzle consists of a grid and a list of
words; the goal is to place all words in the grid;

@item Sudoku and Kakuro puzzles involve filling in grids of numbers
according to their own rules; format may be block-separated, or
separated by thick lines.

@end itemize")
    (license license:expat)))

(define-public texlive-crosswrd
  (package
    (name "texlive-crosswrd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/crosswrd/"
                                     "source/latex/crosswrd/"
                                     "tex/latex/crosswrd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yhsrfn49wj579ms3smd1z97rjqnsi1wrsgrjs570bllgf09bcir"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/crosswrd")
    (synopsis "Macros for typesetting crossword puzzles")
    (description
     "The package provides a LaTeX method of typesetting crosswords, and
assists the composer ensure that the grid all goes together properly.")
    (license license:lppl)))

(define-public texlive-cryptocode
  (package
    (name "texlive-cryptocode")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cryptocode/"
                                     "source/latex/cryptocode/"
                                     "tex/latex/cryptocode/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0i22bdg2mn305vlmpy32yqbsp7kf5ld54vdvjzq49n8v00qxy286"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cryptocode")
    (synopsis
     "Pseudocode, protocols, game-based proofs, black-box reductions in cryptography")
    (description
     "The @code{cryptocode} package provides a set of macros to ease the
typesetting of pseudocode, algorithms and protocols.  In addition it comes
with a wide range of tools to typeset cryptographic papers.  This includes
simple predefined commands for concepts such as a security parameter or
advantage terms but also flexible and powerful environments to layout
game-based proofs or black-box reductions.")
    (license license:lppl1.3+)))

(define-public texlive-cryst
  (package
    (name "texlive-cryst")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cryst/" "fonts/afm/public/cryst/"
                                     "fonts/source/public/cryst/"
                                     "fonts/tfm/public/cryst/"
                                     "fonts/type1/public/cryst/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05lbldwghpdrmw0ffncs86k5pn04zi0shkk40ycca3kb0h3fa3h8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/cryst")
    (synopsis "Font for graphical symbols used in crystallography")
    (description
     "This package provides the Cryst font, which contains graphical symbols
used in crystallography.  It provided as an Adobe Type 1 font, and as Metafont
source.")
    (license license:lppl)))

(define-public texlive-csassignments
  (package
    (name "texlive-csassignments")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/csassignments/"
                                     "source/latex/csassignments/"
                                     "tex/latex/csassignments/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gdrsh0iyg8dz0pnb9ak099qrznp54x37qqwd7kllw8jjzdcaqg1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/csassignments")
    (synopsis "Extend @code{article} class for computer science assignments")
    (description
     "This class wraps the default @code{article} and extends it for
a homogeneous look of hand-in assignments at university (RWTH Aachen
University, Computer Science Department), specifically in the field of
computer science, but easily extensible to other fields.  It provides macros
for structuring exercises, aggregating points, and displaying a grading table,
as well as several macros for easier math mode usage.")
    (license license:expat)))

(define-public texlive-cuprum
  (package
    (name "texlive-cuprum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cuprum/"
                                     "fonts/map/dvips/cuprum/"
                                     "fonts/tfm/public/cuprum/"
                                     "fonts/truetype/public/cuprum/"
                                     "tex/latex/cuprum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wimmwjpx6dg41ncpjbrsxfv41ayppy87f1b8r38vyg0vw6vcsz5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cuprum")
    (synopsis "Cuprum font family support for LaTeX")
    (description
     "This package provides support for the Cuprum font family.")
    (license license:silofl1.1)))

(define-public texlive-custom-bib
  (package
    (name "texlive-custom-bib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/custom-bib/"
                                     "source/latex/custom-bib/"
                                     "tex/latex/custom-bib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hzy0j9k55ygkzvgs3y2jz435267l3g4isqynr64978zhyqybqpd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:phases
           #~(modify-phases %standard-phases
               ;; The installation process requires ".mbs" files to be
               ;; available when generating the package.  Extend TEXINPUTS to
               ;; include their location.
               (add-before 'build 'extend-texinputs
                 (lambda _
                   (setenv "TEXINPUTS"
                           (string-append (getcwd)
                                          "/tex/latex/custom-bib/:")))))))
    (home-page "https://ctan.org/pkg/custom-bib")
    (synopsis "Customised BibTeX styles")
    (description
     "This package generates customized BibTeX bibliography styles from
a generic file using @code{docstrip} driven by parameters generated by a menu
application.  It includes support for the Harvard style of citations.")
    (license license:lppl)))

(define-public texlive-customdice
  (package
    (name "texlive-customdice")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/customdice/"
                                     "source/latex/customdice/"
                                     "tex/latex/customdice/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jwhvg13rla5pav0z4wns4s0x25myiqcinv592g6kqnbgwzj4q7g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/customdice")
    (synopsis "Simple commands for drawing customisable dice")
    (description
     "The @code{customdice} package for LaTeX, LuaLaTeX and XeTeX that
provides functionality for drawing dice.  The aim is to provide
highly-customisable but simple-to-use commands, allowing: adding custom text
to dice faces; control over colouring; control over sizing.")
    (license license:cc-by-sa4.0)))

(define-public texlive-cvss
  (package
    (name "texlive-cvss")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cvss/" "source/latex/cvss/"
                                     "tex/latex/cvss/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hs931xcj7jai901nvfvi942x403sda7xslq14bfjls0v74lkhbd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cvss")
    (synopsis "Compute and display CVSS base scores")
    (description
     "The Common Vulnerability Scoring System (CVSS) is an open framework for
communicating the characteristics and severity of software vulnerabilities.
CVSS consists of three metric groups: Base, Temporal, and Environmental.  This
package allows the user to compute CVSS3.1 base scores and use them in
documents, i.e., it only deals with the Base score.  Temporal and
Environmental scores will be part of a future release.")
    (license license:lppl1.3c)))

(define-public texlive-cweb-old
  (package
    (name "texlive-cweb-old")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/plain/cweb-old/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vx235zpflqpnrfa9kqq7wmc1rylg5bw1r26knfzvh3w1swbp4ai"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cweb-old")
    (synopsis "Obsolete files from CWEB")
    (description
     "This package contains parts of CWEB that are no longer useful.")
    (license license:knuth)))

(define-public texlive-dad
  (package
    (name "texlive-dad")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/dad/"
                                     "fonts/afm/public/dad/"
                                     "fonts/map/dvips/dad/"
                                     "fonts/ofm/public/dad/"
                                     "fonts/ovf/public/dad/"
                                     "fonts/tfm/public/dad/"
                                     "fonts/type1/public/dad/"
                                     "tex/lualatex/dad/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mkfhdai5m1fwj9x0rkpklvcrp3synfxl67dp6cb0bfz3w8nmis0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dad")
    (synopsis "Simple typesetting system for mixed Arabic/Latin documents")
    (description
     "This package allows simple typesetting in Arabic script, intended for
mixed Arabic/Latin script usage in situations where heavy-duty solutions are
discouraged.  The system operates with both Unicode and transliterated input,
allowing the user to choose the most appropriate approach for every
situation.")
    (license license:lppl)))

(define-public texlive-dancers
  (package
    (name "texlive-dancers")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "fonts/source/public/dancers/"
                                     "fonts/tfm/public/dancers/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nni21f6y9gynx1lsymb3pmh6w761q21idq60fib90hvv9jjd85q"))))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/dancers")
    (synopsis "Font for Conan Doyle's @emph{The Dancing Men}")
    (description
     "The (Sherlock Holmes) book contains a code which uses dancing men as
glyphs.  The alphabet as given is not complete, lacking @samp{f}, @samp{j},
@samp{k}, @samp{q}, @samp{u}, @samp{w}, @samp{x} and @samp{z}, so those
letters in the font are not due to Conan Doyle.

The code required word endings to be marked by the dancing man representing
the last letter to be holding a flag: these are coded as A-Z.  In some cases,
the man has no arms, making it impossible for him to hold a flag.  In these
cases, he is wearing a flag on his hat in the character.  The font is
distributed as Metafont source.")
    ;; "This font may be freely used, modified and distributed."
    (license
     (license:fsf-free "file://fonts/source/public/dancers/dancers.mf"))))

(define-public texlive-dashrule
  (package
    (name "texlive-dashrule")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dashrule/"
                                     "source/latex/dashrule/"
                                     "tex/latex/dashrule/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0glnb77dmhl9svgxpz1s8ivsbmr0cy1a0sz68vfx1plfkxfglbyl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dashrule")
    (synopsis "Draw dashed rules")
    (description
     "The @code{dashrule} package makes it easy to draw a huge variety of
dashed rules (i.e., lines) in LaTeX.  It provides a command,
@code{\\hdashrule}, which draws horizontally dashed rules using the same
syntax as @code{\\rule}, but with an additional parameter that specifies the
pattern of dash segments and the space between those segments.  Those rules
are fully compatible with every @code{LaTeX} back-end processor.")
    (license license:lppl)))

(define-public texlive-dantelogo
  (package
    (name "texlive-dantelogo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/dantelogo/"
                                     "fonts/enc/dvips/dantelogo/"
                                     "fonts/map/dvips/dantelogo/"
                                     "fonts/opentype/public/dantelogo/"
                                     "fonts/tfm/public/dantelogo/"
                                     "fonts/type1/public/dantelogo/"
                                     "fonts/vf/public/dantelogo/"
                                     "tex/latex/dantelogo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19wz5qyr4bhd0dwp0y38ql87s3103yimg5b6r2mjz4mz0dsiyy1b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dantelogo")
    (synopsis "Font for DANTE's logo")
    (description
     "The DANTE font for the logo of @url{https://www.dante.de, DANTE}, the
German speaking TeX users group.  The font includes only the five characters
@samp{d}, @samp{a}, @samp{n}, @samp{t}, and @samp{e}.  @file{dantelogo.sty}
provides an interface for LuaLaTeX, XeLaTeX, and pdfLaTeX.")
    (license license:lppl)))

(define-public texlive-dccpaper
  (package
    (name "texlive-dccpaper")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dccpaper/"
                                     "source/latex/dccpaper/"
                                     "tex/latex/dccpaper/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qqsg3mwai186phw0yij9fm1f9df0m4l24fbyzhf0vswclk2rmpk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dccpaper")
    (synopsis
     "Typeset papers for the @emph{International Journal of Digital Curation}")
    (description
     "The LaTeX class @code{ijdc-v14} produces camera-ready papers and
articles suitable for inclusion in the @emph{International Journal of Digital
Curation}, with applicability from volume 14 onwards; a legacy class
@code{ijdc-v9} is provided for papers and articles written for volumes 9-13.
The similar @code{idcc} class can be used for submissions to the International
Digital Curation Conference, beginning with the 2015 conference.")
    (license (list license:lppl1.3c license:cc-by4.0))))

(define-public texlive-decision-table
  (package
    (name "texlive-decision-table")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/decision-table/"
                                     "source/latex/decision-table/"
                                     "tex/latex/decision-table/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14cgf142wmi2qlrxaa8dmyr7grb7d33ngfpg8sbrm82a78cvl1yc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/decision-table")
    (synopsis "Create Decision Model and Notation decision tables")
    (description
     "The decision-table package allows for an easy way to generate decision
tables in the Decision Model and Notation (DMN) format.  This package ensures
consistency in the tables (i.e., fontsize), and is thus a better alternative
to inserting tables via images.

The decision-table package adds the @code{\\dmntable} command, with which
tables can be created.  This command expands into a tabular, so it can be used
within a @code{table} or @code{figure} environment.  Furthermore, this allows
labels and captions to be added seamlessly.  It is also possible to place
multiple DMN tables in one table/figure environment.")
    (license license:lppl1.3c)))

(define-public texlive-dejavu-otf
  (package
    (name "texlive-dejavu-otf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/dejavu-otf/"
                                     "tex/latex/dejavu-otf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vn16rb816w7kdqkyqxr01w1qd654s1f3k368q0cj0ab1247q7q8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dejavu-otf")
    (synopsis "Support for the TTF and OTF DejaVu fonts")
    (description
     "The @code{dejavu-otf} package supports the TTF fonts from the DejaVu
project and the OpenType version of the TeXGyre Math.")
    (license license:lppl1.3+)))

(define-public texlive-delim
  (package
    (name "texlive-delim")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/delim/" "source/latex/delim/"
                                     "tex/latex/delim/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12h0zqn46yrqf079a6k939g3pv843rs417va4g2r39rhb2fvh6r8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/delim")
    (synopsis "Simplify typesetting mathematical delimiters")
    (description
     "The package permits simpler control of delimiters without excessive use
of @code{\\big} commands and the like.")
    (license license:lppl1.2+)))

(define-public texlive-delimseasy
  (package
    (name "texlive-delimseasy")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/delimseasy/"
                                     "tex/latex/delimseasy/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0afgcnwqcbw34wgfryzk1rjw82qakl6nq98gl2w1aw5lkgi4fb9p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/delimseasy")
    (synopsis "Delimiter commands that are easy to use and resize")
    (description
     "This package provides commands to give an easy way to control the size
and blackness of delimiters: append 1-4 @samp{b}s to command for larger sizes;
prepend @samp{B} for for boldface.  These commands reduce the likelihood of
incomplete delimiter pairs and typically use fewer characters than the LaTeX
default.")
    (license license:lppl1.3+)))

(define-public texlive-delimset
  (package
    (name "texlive-delimset")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/delimset/"
                                     "source/latex/delimset/"
                                     "tex/latex/delimset/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vkfk09g7vys4dfa01dxhznczdjklmj90lsw25glbcl1hxr1c1fn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/delimset")
    (synopsis
     "Typeset and declare sets of delimiters with convenient size control")
    (description
     "@code{delimset} is a LaTeX2e package to typeset and declare sets of
delimiters in math mode whose size can be adjusted conveniently.")
    (license license:lppl1.3+)))

(define-public texlive-denisbdoc
  (package
    (name "texlive-denisbdoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/denisbdoc/"
                                     "source/latex/denisbdoc/"
                                     "tex/latex/denisbdoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ypd5xl3psg11jss9n7g1qihd7rag480j63wxkvgifhi4kainypc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/denisbdoc")
    (synopsis "Personal dirty package for documenting packages")
    (description
     "This package provides a personal dirty package for documenting packages.")
    (license license:lppl1.3c)))

(define-public texlive-derivative
  (package
    (name "texlive-derivative")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/derivative/"
                                     "tex/latex/derivative/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06c1ha4w8i3f6k77cjr82cn1rl7jbk82q1n24dd3l7ha4d7qncjp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/derivative")
    (synopsis "Nice and easy derivatives")
    (description
     "Typesetting derivatives and differentials in a consistent way are clumsy
and require care to ensure the preferred formatting.  Several packages have
been developed for this purpose, each with its own features and drawbacks,
with the most ambitious one being @code{diffcoeff}.  While this package is
comparable to diffcoeff in terms of features, it takes a different approach.
One difference is this package provides more options to tweak the format of
the derivatives and differentials.  However, the automatic calculation of the
total order isn't as developed as the one in @code{diffcoeff}.  This package
makes it easy to write derivatives and differentials consistently with its
predefined commands.  It also provides a set of commands that can define
custom derivatives and differential operators.  The options follow
a consistent naming scheme making them easy to use and understand.")
    (license license:lppl1.3+)))

(define-public texlive-diadia
  (package
    (name "texlive-diadia")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/diadia/" "scripts/diadia/"
                                     "tex/latex/diadia/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sjnjabgqsv6v45sffkkzm78fnx89vmk836dajsvck5pd5nvkzxv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "diadia.lua")))
    (home-page "https://ctan.org/pkg/diadia")
    (synopsis "Package to keep a diabetes diary")
    (description
     "The @code{diadia} package allows you to keep a diabetes diary.  Usually,
this means keeping record of certain medical values like blood sugar, blood
pressure, pulse or weight.  It might also include other medical,
pharmaceutical or nutritional data (HbA1c, insulin doses, carbohydrate units).

The @code{diadia} package supports all of this plus more --- simply by adding
more columns to the data file!  It is able to evaluate the data file and
typesets formatted tables and derived plots.  Furthermore, it supports
medication charts and info boxes.")
    (license license:lppl)))

(define-public texlive-diagbox
  (package
    (name "texlive-diagbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/diagbox/" "source/latex/diagbox/"
                                     "tex/latex/diagbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zr7ih8jr56j727gf3l1q87rlrqn3zfz8cm7hs2q5l1f3y1gmcgh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/diagbox")
    (synopsis "Table heads with diagonal lines")
    (description
     "The package's principal command, @code{\\diagbox}, takes two
arguments (texts for the slash-separated parts of the box), and an optional
argument with which the direction the slash will go, the box dimensions, etc.,
may be controlled.  The package also provides @code{\\slashbox} and
@code{\\backslashbox} commands for compatibility with the now removed slashbox
package, which it supersedes.")
    (license license:lppl1.3+)))

(define-public texlive-dice
  (package
    (name "texlive-dice")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/dice/"
                                     "fonts/source/public/dice/"
                                     "fonts/tfm/public/dice/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ky33hg66d0x8bcjmdq4ilynpb25mm82x93wzwnz11y59nv4cvsl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/dice")
    (synopsis "Font for die faces")
    (description
     "This package provides a Metafont font that can produce die faces in 2D
or with various 3D effects.")
    (license license:lppl)))

(define-public texlive-dictsym
  (package
    (name "texlive-dictsym")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/dictsym/"
                                     "fonts/afm/public/dictsym/"
                                     "fonts/map/dvips/dictsym/"
                                     "fonts/map/vtex/dictsym/"
                                     "fonts/tfm/public/dictsym/"
                                     "fonts/type1/public/dictsym/"
                                     "tex/latex/dictsym/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ygnnmg2m57wzj1iz2wznvdbsi8323804s74a2ic7q1akpy5n2ac"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dictsym")
    (synopsis "DictSym font and macro package")
    (description
     "This directory contains the DictSym Type1 font designed by Georg
Verweyen and all files required to use it with LaTeX.  The font provides
a number of symbols commonly used in dictionaries.  The accompanying macro
package makes the symbols accessible as LaTeX commands.")
    (license license:lppl)))

(define-public texlive-din1505
  (package
    (name "texlive-din1505")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/din1505/" "doc/latex/din1505/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ggi58kra06k8r4drkhnlap9khvscpji78j8v92s3gzh8qmsjhp4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/din1505")
    (synopsis "Bibliography styles for German texts")
    (description
     "This package provides a set of bibliography styles that conform to DIN
1505, and match the original BibTeX standard set (@code{plain}, @code{unsrt},
@code{alpha} and @code{abbrv}), together with a style @code{natdin} to work with
@code{natbib}.")
    (license license:knuth)))

(define-public texlive-dingbat
  (package
    (name "texlive-dingbat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/dingbat/"
                                     "fonts/source/public/dingbat/"
                                     "fonts/tfm/public/dingbat/"
                                     "source/latex/dingbat/" "tex/latex/dingbat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12vhykmz1xzvrdzp61qy0q69fnxjjvc9m8v8kras92v49f6m4z7a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/dingbat")
    (synopsis "Two dingbat symbol fonts")
    (description
     "The package provides the fonts (@code{ark10} and @code{dingbat}),
specified in Metafont; support macros are also provided for use in LaTeX.  An
Adobe Type 1 version of the fonts is available in the @code{niceframe} fonts
bundle.")
    (license license:lppl)))

(define-public texlive-diffcoeff
  (package
    (name "texlive-diffcoeff")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/diffcoeff/"
                                     "tex/latex/diffcoeff/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01x16jh9d69pa085ib0di6x3vbgmz722byw73d0kjj8fpr4z4pnj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/diffcoeff")
    (synopsis "Write differential coefficients easily and consistently")
    (description
     "This package allows the easy and consistent writing of ordinary, partial
and other derivatives of arbitrary (algebraic or numeric) order.  For mixed
partial derivatives, the total order of differentiation is calculated by the
package.  Optional arguments allow specification of points of
evaluation (ordinary derivatives), or variables held constant (partial
derivatives), and the placement of the differentiand (numerator or appended).
The package is built on xtemplate and the configurability it enables,
extending to differentials (including simple line elements) and jacobians.")
    (license license:lppl1.3c)))

(define-public texlive-digiconfigs
  (package
    (name "texlive-digiconfigs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/digiconfigs/"
                                     "tex/latex/digiconfigs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13682as94lpy3qws03ymgz380fkkihwppzdwijig85j1yq098wqg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/digiconfigs")
    (synopsis "Writing ``configurations''")
    (description
     "In Stochastic Geometry and Digital Image Analysis some problems can be
solved in terms of so-called ``configurations''.  A configuration is basically
a square matrix of @code{\\circ} and @code{\\bullet} symbols.  This package
provides a convenient and compact mechanism for displaying these
configurations.")
    (license license:lppl)))

(define-public texlive-dijkstra
  (package
    (name "texlive-dijkstra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dijkstra/" "tex/latex/dijkstra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xjq51x4g1xngp8npicgnpmbkzk0rnj992pmhizjv0j92zmaikqm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dijkstra")
    (synopsis "Dijkstra algorithm for LaTeX")
    (description
     "This small package uses the Dijkstra algorithm for weighted
graphs,directed or not: the search table of the shortest path can be
displayed, the minimum distance between two vertices and the corresponding
path are stored in macros.")
    (license license:lppl1.3c)))

(define-public texlive-dinat
  (package
    (name "texlive-dinat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/dinat/" "doc/bibtex/dinat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05ab7aq8h08a8pcl3si2lki569sf201bygf3ra95dpqhs1ijxaag"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dinat")
    (synopsis "Bibliography style for German texts")
    (description
     "This package provides bibliography style files intended for texts in
german.  They draw up bibliographies in accordance with the german DIN 1505,
parts 2 and 3.")
    (license license:public-domain)))

(define-public texlive-dirtree
  (package
    (name "texlive-dirtree")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/dirtree/"
                                     "source/generic/dirtree/"
                                     "tex/generic/dirtree/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1righlip75ry0yc6kbpijq423k4m625byzgb55d32s7c0imvj41v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dirtree")
    (synopsis "Display trees in the style of Windows Explorer")
    (description
     "This package is designed to emulate the way Windows Explorer displays
directory and file trees, with the root at top left, and each level of subtree
displaying one step in to the right.  The macros work equally well with Plain
TeX and with LaTeX.")
    (license license:lppl)))

(define-public texlive-disser
  (package
    (name "texlive-disser")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/disser/" "makeindex/disser/"
                                     "source/latex/disser/" "tex/latex/disser/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sxvj4cka9xqzl2s3c465fm19lc1b8hyar1chjb51y42q4mx2bmg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/disser")
    (synopsis "Class and templates for typesetting dissertations in Russian")
    (description
     "Disser comprises a document class and set of templates for typesetting
dissertations in Russian.  One of its primary advantages is a simplicity of
format specification for titlepage, headers and elements of automatically
generated lists (table of contents, list of figures, etc).  Bibliography
styles, that conform to the requirements of the Russian standard GOST
R 7.0.11-2011, are provided.")
    (license license:lppl1.3+)))

(define-public texlive-dithesis
  (package
    (name "texlive-dithesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dithesis/" "tex/latex/dithesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yz53jabca56k65pddhl68d3384k2f2jn4zrfkg2d4x8aa1dnvvx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dithesis")
    (synopsis "Class for undergraduate theses at the University of Athens")
    (description
     "The class conforms to the requirements of the Department of Informatics
and Telecommunications at the University of Athens regarding the preparation
of undergraduate theses, as of Sep 1, 2011.  The class is designed for use
with XeLaTeX.")
    (license license:lppl)))

(define-public texlive-dk-bib
  (package
    (name "texlive-dk-bib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/dk-bib/"
                                     "bibtex/bst/dk-bib/"
                                     "bibtex/csf/dk-bib/"
                                     "doc/latex/dk-bib/"
                                     "source/latex/dk-bib/"
                                     "tex/latex/dk-bib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bwmaja41mivsrcx3j9p0yplqccw62fd9wn6v1yx138kg0ayib1n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dk-bib")
    (synopsis "Danish variants of standard BibTeX styles")
    (description
     "Dk-bib is a translation of the four standard BibTeX style files (@code{abbrv},
@code{alpha}, @code{plain} and @code{unsrt}) and the @code{apalike} style file
into Danish.  The files have been extended with URL, ISBN, ISSN, annote and
printing fields which can be enabled through a LaTeX style file.  Dk-bib also
comes with a couple of Danish sorting order files for BibTeX8.")
    (license (list license:knuth license:gpl2+))))

(define-public texlive-dnp
  (package
    (name "texlive-dnp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "fonts/sfd/dnp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jlvb0nps1ij4sgbg3clgbk34p80la1fhh9zihn9fhl9nrqk637r"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dnp")
    (synopsis "Subfont numbers for DNP font encoding")
    (description "This package provides subfont numbers for DNP font encoding.")
    ;; This is part of the CJK package, use the same GPL license.
    (license license:gpl2)))

(define-public texlive-docbytex
  (package
    (name "texlive-docbytex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/docbytex/"
                                     "tex/generic/docbytex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09x4xpyq89jjjsp4yzrifcazz0p2f5w7785g8pvss8v0wwsb0lav"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/docbytex")
    (synopsis "Creating documentation from source code")
    (description
     "The package creates documentation from C source code, or other
programming languages.")
    ;; README states: "You can do anything with the files from DocBy.TeX
    ;; package without any limit".
    (license (license:fsf-free "file://doc/generic/docbytex/README"))))

(define-public texlive-doipubmed
  (package
    (name "texlive-doipubmed")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/doipubmed/"
                                     "source/latex/doipubmed/"
                                     "tex/latex/doipubmed/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1432hh1pr5r6izfcqlbvl1lxpradidrwpfkvjr25ds1rlh240y66"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/doipubmed")
    (synopsis "Special commands for use in bibliographies")
    (description
     "The package provides the commands @code{\\doi}, @code{\\pubmed} and
@code{\\citeurl}.  These commands are primarily designed for use in
bibliographies.  A @code{LaTeX2HTML} style file is also provided.")
    (license license:lppl)))

(define-public texlive-domitian
  (package
    (name "texlive-domitian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/domitian/"
                                     "fonts/enc/dvips/domitian/"
                                     "fonts/map/dvips/domitian/"
                                     "fonts/opentype/public/domitian/"
                                     "fonts/tfm/public/domitian/"
                                     "fonts/type1/public/domitian/"
                                     "fonts/vf/public/domitian/"
                                     "tex/latex/domitian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10pg90kdwklz2rsbcafhcld4zdchmxzr6cszrajwrky8hfz67dkg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/domitian")
    (synopsis "Drop-in replacement for Palatino")
    (description
     "The Domitian fonts are an OpenType font family, based on the Palatino
design by Hermann Zapf (1918-2015), as implemented in Palladio.  Domitian is
meant as a drop-in replacement for Adobe's version of Palatino.  It extends
Palladio with small capitals, old-style figures and scientific inferiors.  The
metrics have been adjusted to more closely match Adobe Palatino, and hinting
has been improved.")
    ;; Use any of the three licenses.
    (license (list license:lppl1.3c license:silofl1.1 license:agpl3))))

(define-public texlive-dosepsbin
  (package
    (name "texlive-dosepsbin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/dosepsbin.1"
                                     "doc/man/man1/dosepsbin.man1.pdf"
                                     "doc/support/dosepsbin/"
                                     "scripts/dosepsbin/"
                                     "source/support/dosepsbin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "117crwcdpirvvm9srrzjn40marg00q16rzyqipm3xxbmwv52i93c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "dosepsbin.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/dosepsbin")
    (synopsis "Deal with DOS binary EPS files")
    (description
     "This package provides a Encapsulated PostScript (EPS) file may given in
a special binary format to support the inclusion of a thumbnail.  This file
format, commonly known as DOS EPS format, starts with a binary header that
contains the positions of the possible sections: PostScript (PS); Windows
Metafile Format (WMF); and Tag Image File Format (TIFF).  The PS section must
be present and either the WMF file or the TIFF file should be given.  The
package provides a Perl program that will extract any of the sections of such
a file, in particular providing a text'-form EPS file for use with (La)TeX.")
    (license license:artistic2.0)))

(define-public texlive-doublestroke
  (package
    (name "texlive-doublestroke")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/doublestroke/"
                                     "fonts/map/dvips/doublestroke/"
                                     "fonts/source/public/doublestroke/"
                                     "fonts/tfm/public/doublestroke/"
                                     "fonts/type1/public/doublestroke/"
                                     "tex/latex/doublestroke/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0v9g025l0qfw4zrjkm9yypcsramwl2di997jgnznxpxms0v6ib7c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/doublestroke")
    (synopsis "Typeset mathematical double stroke symbols")
    (description
     "This package provides a font based on Computer Modern Roman useful for
typesetting the mathematical symbols for the natural numbers, whole numbers,
rational numbers, real numbers and complex numbers; coverage includes all
Roman capital letters, @samp{1}, @samp{h} and @samp{k}.  The font is available
both as Metafont source and in Adobe Type 1 format, and LaTeX macros for its
use are provided.")
    (license license:knuth)))

(define-public texlive-dowith
  (package
    (name "texlive-dowith")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/dowith/"
                                     "source/generic/dowith/"
                                     "tex/generic/dowith/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qlrcjac1qszgrap5v4g0d27g9k5ajqgyy493hmc9yh5wa9wmkmp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dowith")
    (synopsis "Apply a command to a list of items")
    (description
     "The package provides macros for applying a command to all elements of
a list without separators, and also for extending and reducing macros storing
such lists.  Applications in mind belonged to LaTeX, but the package should
work with other formats as well.")
    (license license:lppl1.3+)))

(define-public texlive-dozenal
  (package
    (name "texlive-dozenal")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/dozenal/"
                                     "fonts/afm/public/dozenal/"
                                     "fonts/map/dvips/dozenal/"
                                     "fonts/source/public/dozenal/"
                                     "fonts/tfm/public/dozenal/"
                                     "fonts/type1/public/dozenal/"
                                     "source/fonts/dozenal/"
                                     "tex/latex/dozenal/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fhdcnpjpfxaqshddw6vxy0f8c1c3yn8p11aab8fkhnfg3pnllck"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/dozenal")
    (synopsis "Typeset documents using base twelve numbering")
    (description
     "The package supports typesetting documents whose counters are
represented in base twelve, also called @dfn{dozenal}.  It includes a macro
for converting positive whole numbers to dozenal from decimal (base ten)
representation.  The package also includes a few other macros and redefines
all the standard counters to produce dozenal output.  Fonts, in Roman, italic,
slanted, and boldface versions, provide ten and eleven.  The fonts were
designed to blend well with the Computer Modern fonts, and are available both
as Metafont source and in Adobe Type 1 format.")
    (license license:lppl1.3+)))

(define-public texlive-dramatist
  (package
    (name "texlive-dramatist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dramatist/"
                                     "source/latex/dramatist/"
                                     "tex/latex/dramatist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17x10jaa7f9rnqfrnvgw225n5ypqrmacbpsfpl5zdhx9abbjh793"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dramatist")
    (synopsis "Typeset dramas, both in verse and in prose")
    (description
     "This package is intended for typesetting drama of any length.  It
provides two environments for typesetting dialogues in prose or in verse; new
document divisions corresponding to acts and scenes; macros that control the
appearance of characters and stage directions; and automatic generation of
a ``dramatis personae'' list.")
    (license license:gpl3+)))

(define-public texlive-drawmatrix
  (package
    (name "texlive-drawmatrix")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/drawmatrix/"
                                     "source/latex/drawmatrix/"
                                     "tex/latex/drawmatrix/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14y9xah06ya8krg7ckmhbmxs113g1vw0x2ryldapww7qi08i78yx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/drawmatrix")
    (synopsis "Draw visual representations of matrices in LaTeX")
    (description
     "The package provides macros to visually represent matrices.  Various
options allow changing the visualizations, e.g., drawing rectangular,
triangular, or banded matrices.")
    (license license:expat)))

(define-public texlive-drawstack
  (package
    (name "texlive-drawstack")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/drawstack/"
                                     "tex/latex/drawstack/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qv2j7crg4b1ggxvmjb6zf0cxmr4mmpk382l7w3dqhywf9lr722v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/drawstack")
    (synopsis "Draw execution stacks")
    (description
     "This simple LaTeX package provides support for drawing execution stack
(typically to illustrate assembly language notions).  The code is written on
top of TikZ.")
    (license license:lppl1.3+)))

(define-public texlive-droit-fr
  (package
    (name "texlive-droit-fr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/droit-fr/" "tex/latex/droit-fr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lx4k3w7mzldhwykpfvhv05v7fhd1jibra80kz0zf9s0jga8sq4a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/droit-fr")
    (synopsis "Document class and bibliographic style for French law")
    (description
     "The bundle provides a toolkit intended for students writing a thesis in
French law.  It features a LaTeX document class, a bibliographic style for
BibLaTeX package, a practical example of french thesis document, and
documentation.  The class assumes use of Biber and BibLaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-drm
  (package
    (name "texlive-drm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/drm/"
                                     "fonts/afm/public/drm/"
                                     "fonts/map/dvips/drm/"
                                     "fonts/opentype/public/drm/"
                                     "fonts/source/public/drm/"
                                     "fonts/tfm/public/drm/"
                                     "fonts/type1/public/drm/"
                                     "source/fonts/drm/"
                                     "tex/latex/drm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fxmwakgy7inin85pjad5rdqg11flrw8mlsh86ga6ghqcw69zhwq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/drm")
    (synopsis "Complete family of fonts written in Metafont")
    (description
     "The package provides access to the DRM (Don's Revised Modern) family of
fonts, which includes a variety of optical sizes in Roman (in four weights),
italic, and small caps, among other shapes, along with a set of symbols and
ornaments.  It is intended to be a full-body text font, but its larger sizes
can also be used for simple display purposes, and its significant body of
symbols can stand on its own.  It comes complete with textual (old-style) and
lining figures, and even has small-caps figures.  It also comes with
extensible decorative rules to be used with ornaments from itself or other
fonts, along with an extremely flexible ellipsis package.")
    (license license:lppl1.3+)))

(define-public texlive-droid
  (package
    (name "texlive-droid")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/droid/"
                                     "fonts/enc/dvips/droid/"
                                     "fonts/map/dvips/droid/"
                                     "fonts/tfm/ascender/droid/droidsans/"
                                     "fonts/tfm/ascender/droid/droidsansmono/"
                                     "fonts/tfm/ascender/droid/droidserif/"
                                     "fonts/truetype/ascender/droid/droidsans/"
                                     "fonts/truetype/ascender/droid/droidsansmono/"
                                     "fonts/truetype/ascender/droid/droidserif/"
                                     "fonts/type1/ascender/droid/droidsans/"
                                     "fonts/type1/ascender/droid/droidsansmono/"
                                     "fonts/type1/ascender/droid/droidserif/"
                                     "fonts/vf/ascender/droid/droidsans/"
                                     "fonts/vf/ascender/droid/droidsansmono/"
                                     "fonts/vf/ascender/droid/droidserif/"
                                     "tex/latex/droid/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10lgw5yv0s48rwydycq6lxj5dfyna7iflnhz1zq42akg21n595vx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/droid")
    (synopsis "LaTeX support for the Droid font families")
    (description
     "The Droid typeface family was designed by Steve Matteson.  The Droid
family consists of Droid Serif, Droid Sans and Droid Sans Mono fonts.  The
bundle includes the fonts in both TrueType and Adobe Type 1 formats.")
    (license (list license:lppl1.3c license:asl2.0))))

(define-public texlive-dsptricks
  (package
    (name "texlive-dsptricks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dsptricks/"
                                     "tex/latex/dsptricks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pjc78c195nkj493qyc0dxbr9d1488dc528vzkpgcgrf0g5pxm96"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dsptricks")
    (synopsis "Macros for Digital Signal Processing (DSP) plots")
    (description
     "The package provides a set of @code{LaTeX} macros (based on PSTricks)
for plotting the kind of graphs and figures that are usually employed in
digital signal processing publications.  DSPTricks provides facilities for
standard discrete-time lollipop plots, continuous-time and frequency plots,
and pole-zero plots.  The companion package
DSPFunctions (@file{dspfunctions.sty}) provides macros for computing frequency
responses and DFTs, while the package DSPBlocks (@file{dspblocks.sty})
supports DSP block diagrams.")
    (license license:lppl)))

(define-public texlive-dsserif
  (package
    (name "texlive-dsserif")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/dsserif/"
                                     "fonts/afm/public/dsserif/"
                                     "fonts/map/dvips/dsserif/"
                                     "fonts/tfm/public/dsserif/"
                                     "fonts/type1/public/dsserif/"
                                     "source/fonts/dsserif/"
                                     "tex/latex/dsserif/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dl8380lyv8r5kfrlhi5r4iwadb52m1397z68qwa65c5p2px1y3i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dsserif")
    (synopsis "Double-struck serifed font for mathematical use")
    (description
     "DSSerif is a mathematical font package with double struck serifed
digits, upper and lower case letters, in regular and bold weights.  The design
was inspired by the STIX double struck fonts, which are sans serif, but
starting from a Courier-like base.")
    (license (list license:silofl1.1 license:lppl1.3+))))

(define-public texlive-duerer
  (package
    (name "texlive-duerer")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/duerer/"
                                     "fonts/source/public/duerer/"
                                     "fonts/tfm/public/duerer/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x5s9qnmhhpj54l6cd0pzd9gmd0ipr95j60rcs73c66wwfjw0xki"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/duerer")
    (synopsis "Computer Duerer fonts")
    (description
     "These fonts are designed for titling use, and consist of capital roman
letters only.  Together with the normal set of base shapes, the family also
offers an informal shape.  The distribution is as Metafont source.  LaTeX
support is available in the @code{duerer-latex} bundle.")
    (license license:public-domain)))

(define-public texlive-duerer-latex
  (package
    (name "texlive-duerer-latex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/duerer-latex/"
                                     "tex/latex/duerer-latex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17ni6hrcblkbzn1f8cn2mvrc01sjqmi8qi2dxy82z14llr23qmbh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/duerer-latex")
    (synopsis "LaTeX support for the Duerer fonts")
    (description
     "This package provides LaTeX support for Hoenig's Computer Duerer fonts,
using their standard fontname names.")
    (license license:gpl3+)))

(define-public texlive-dutchcal
  (package
    (name "texlive-dutchcal")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/dutchcal/"
                                     "fonts/afm/public/dutchcal/"
                                     "fonts/map/dvips/dutchcal/"
                                     "fonts/tfm/public/dutchcal/"
                                     "fonts/type1/public/dutchcal/"
                                     "fonts/vf/public/dutchcal/"
                                     "tex/latex/dutchcal/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "173c5k6q35ljbqdi00kplxss0n1aiss8nvigdv33mlkqpg7i74qg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dutchcal")
    (synopsis "Reworking of ESSTIX13, adding a bold version")
    (description
     "This package reworks the mathematical calligraphic font ESSTIX13,
adding a bold version.  LaTeX support files are included.")
    (license license:lppl)))

(define-public texlive-dvgloss
  (package
    (name "texlive-dvgloss")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dvgloss/" "source/latex/dvgloss/"
                                     "tex/latex/dvgloss/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fs5ghbyl3qhg1v0iljjqn723a93m4l7f873h3h81pcga75mng4s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dvgloss")
    (synopsis "Facilities for setting interlinear glossed text")
    (description
     "The package provides extensible macros for setting interlinear glossed
text --- useful, for instance, for typing linguistics papers.")
    (license license:lppl)))

(define-public texlive-dyntree
  (package
    (name "texlive-dyntree")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dyntree/" "source/latex/dyntree/"
                                     "tex/latex/dyntree/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1j891cswgcyv5b4l6an0sa6vfwkn6lxswx55hsv2sdkkfbpb7dnd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dyntree")
    (synopsis "Construct Dynkin tree diagrams")
    (description
     "The package is intended for users needing to typeset a Dynkin Tree
Diagram---a group theoretical construct consisting of cartan coefficients in
boxes connected by a series of lines.  Such a diagram is a tool for working
out the states and their weights in terms of the fundamental weights and the
simple roots.")
    ;; Package mentions LGPL without any reference to the version.  Assuming
    ;; LGPL 2.1+.
    (license license:lgpl2.1+)))

(define-public texlive-e-french
  (package
    (name "texlive-e-french")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/e-french/"
                                     "makeindex/e-french/"
                                     "tex/generic/e-french/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14qxxfjlxygprs1ndhnn9mhz9hkb4j2dqikni5cvva457bivm4l9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/e-french")
    (synopsis "Comprehensive LaTeX support for French-language typesetting")
    (description
     "E-french is a distribution that keeps alive the work of Bernard
Gaulle (now deceased), under a free licence.  It replaces the old full
@code{frenchpro} (the professional distribution) and the light-weight
@code{frenchle} packages.")
    (license license:lppl1.3+)))

(define-public texlive-ean
  (package
    (name "texlive-ean")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/ean/" "tex/generic/ean/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zyxjpc0ggas43lpvl1l1mknqmd94q0cqgw6w2by29w3r8wafjh9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ean")
    (synopsis "Macros for making EAN barcodes")
    (description "This package provides EAN-8 and EAN-13 forms.")
    (license license:gpl3+)))

(define-public texlive-easing
  (package
    (name "texlive-easing")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/easing/"
                                     "source/latex/easing/"
                                     "tex/latex/easing/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1j6y1i6cz7pcgrd6pisk6f11r30lrr4cnbhhdshl48wp97byjnw4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/easing")
    (synopsis "Easing functions for @code{pgfmath}")
    (description
     "This library implements a collection of easing functions and adds them
to the PGF mathematical engine.")
    (license license:lppl1.3+)))

(define-public texlive-ebgaramond
  (package
    (name "texlive-ebgaramond")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/ebgaramond/"
                                     "fonts/enc/dvips/ebgaramond/"
                                     "fonts/map/dvips/ebgaramond/"
                                     "fonts/opentype/public/ebgaramond/"
                                     "fonts/tfm/public/ebgaramond/"
                                     "fonts/type1/public/ebgaramond/"
                                     "fonts/vf/public/ebgaramond/"
                                     "tex/latex/ebgaramond/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cm0cyfh3cmm7d6pjqbpi32yqssq062mgmdb9lfkkydh3k4visjj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ebgaramond")
    (synopsis "LaTeX support for EBGaramond fonts")
    (description
     "EB Garamond is a revival by Georg Duffner of the 16th century fonts
designed by Claude Garamond.  The LaTeX support package works for (pdf)LaTeX,
XeLaTeX and LuaLaTeX users; configuration files for use with @code{microtype}
are provided.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-ebgaramond-maths
  (package
    (name "texlive-ebgaramond-maths")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/ebgaramond-maths/"
                                     "fonts/enc/dvips/ebgaramond-maths/"
                                     "fonts/map/dvips/ebgaramond-maths/"
                                     "fonts/tfm/public/ebgaramond-maths/"
                                     "tex/latex/ebgaramond-maths/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rjrf360d7nsny4cxn5fa0gwpph28cx0v9mrr20sbx1vrv9aqvp9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ebgaramond-maths")
    (synopsis "LaTeX support for EBGaramond fonts in mathematics")
    (description
     "This package provides some LaTeX support for the use of EBGaramond12 in
mathematics.")
    (license license:lppl1.3+)))

(define-public texlive-ebook
  (package
    (name "texlive-ebook")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ebook/" "tex/latex/ebook/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i9zixl8wiwmfrhrzwm2adgwm5kzqk5xaq5nq9bks9i2ayvmiij2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ebook")
    (synopsis "Helps creating an ebook by providing an @code{ebook} class")
    (description
     "The package defines a command @code{\\ebook} that defines page layout,
fonts, and font-sizes for documents to be rendered as PDF-ebooks on small
ebook-readers.")
    (license license:public-domain)))

(define-public texlive-ebsthesis
  (package
    (name "texlive-ebsthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ebsthesis/"
                                     "source/latex/ebsthesis/"
                                     "tex/latex/ebsthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vmnkjnpg840rdgbim7gz2frzgr9dycmzqyj9kylicz5nvc4nk5x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ebsthesis")
    (synopsis "Typesetting theses for economics")
    (description
     "The @code{ebsthesis} class and @code{ebstools} package facilitate the
production of camera-ready manuscripts in conformance with the guidelines of
Gabler Verlag and typographical rules established by the European Business
School.")
    (license license:lppl)))

(define-public texlive-ecc
  (package
    (name "texlive-ecc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/ecc/" "fonts/source/public/ecc/"
                                     "fonts/tfm/public/ecc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06mznqh1k9ff8rpifxkphv3yk9ym6zcvz3x1ksk677n6fp5a5jkh"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ec")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ec texlive-metafont))
    (home-page "https://ctan.org/pkg/ecc")
    (synopsis "Sources for the European Concrete fonts")
    (description
     "The Metafont sources and TFM files of the European Concrete Fonts.
This is the T1-encoded extension of Knuth's Concrete fonts, including also the
corresponding text companion fonts.  Adobe Type 1 versions of the fonts are
available as part of the @code{cm-super} font bundle.")
    (license license:lppl)))

(define-public texlive-ecltree
  (package
    (name "texlive-ecltree")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ecltree/" "tex/latex/ecltree/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ki5zzpl8dkz7zwyccmsxfnfq7vl5vlx3gi1py64mgqxfxp0rivw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ecltree")
    (synopsis "Trees using Epic and Eepic macros")
    (description
     "The package recursively draws trees: each subtree is defined in
a @code{bundle} environment, with a set of leaves described by @code{\\chunk}
macros.  A chunk may have a @code{bundle} environment inside it.")
    (license license:lppl)))

(define-public texlive-eco
  (package
    (name "texlive-eco")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/eco/" "fonts/tfm/public/eco/"
                                     "fonts/vf/public/eco/" "source/fonts/eco/"
                                     "tex/latex/eco/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b2g3bmldad4vfx9qd3sakhayl9knijwn26xwysxrzc3rnfnz5w2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eco")
    (synopsis "Old style numerals using EC fonts")
    (description
     "This package provides a set of font metric files and virtual fonts for
using the EC fonts with old-style numerals.  The style file @file{eco.sty} is
sufficient to use the @code{eco} fonts but if you intend to use other font
families as well, e.g., PostScript fonts, try @code{altfont}.")
    (license license:gpl3+)))

(define-public texlive-ecobiblatex
  (package
    (name "texlive-ecobiblatex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ecobiblatex/"
                                     "tex/latex/ecobiblatex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09569x2dx1h6a63ji44ipkx0nvapc9mgkgrqvc552x62c97zcf21"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ecobiblatex")
    (synopsis
     "Global Ecology and Biogeography BibLaTeX styles for the Biber backend")
    (description
     "This bundle provides a set of styles for creating bibliographies using
BibLaTeX in the style of the @emph{Global Ecology and Biogeography} journal.")
    (license license:lppl1.3+)))

(define-public texlive-econ-bst
  (package
    (name "texlive-econ-bst")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/econ-bst/"
                                     "doc/bibtex/econ-bst/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zs07qznvz8hwlinacaas6lpyc6l2zmpcc1m3xxdkszl95xfc3md"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/econ-bst")
    (synopsis "BibTeX style for economics papers")
    (description
     "This is a BibTeX style file for papers in economics.  It provides the
following features: author-year type citation reference style used in
economics papers highly customizable use of certified random order, as
proposed by Ray Robson (2018)")
    (license license:lppl1.3+)))

(define-public texlive-econometrics
  (package
    (name "texlive-econometrics")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/econometrics/"
                                     "tex/latex/econometrics/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09sjgdsa93pfz7iha335z4xdh80939iqrwr3jxdmdxjyracz61vs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/econometrics")
    (synopsis
     "Simplified mathematic notation in economic and econometric writing")
    (description
     "Econometrics is a package that defines some commands that simplify
mathematic notation in economic and econometrics writing.  The commands are
related to the notation of vectors, matrices, sets, calligraphic and roman
letters statistical distributions constants and symbols matrix operators and
statistical operators.")
    (license license:lppl1.3+)))

(define-public texlive-economic
  (package
    (name "texlive-economic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/economic/"
                                     "doc/bibtex/economic/" "tex/latex/economic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b530sy5bf7f6xa4bakm5agnzx0dckafxkqsy9gv2rk2803qsf6c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/economic")
    (synopsis "BibTeX support for submitting to economics journals")
    (description
     "The bundle offers macros and BibTeX styles for the @emph{American
Economic Review} (AER), the @emph{American Journal of Agricultural
Economics} (AJAE), the @emph{Canadian Journal of Economics} (CJE), the
@emph{European Review of Agricultural Economics} (ERAE), the
@emph{International Economic Review} (IER) and @emph{Economica}.

The macro sets are based on (and require) the @code{harvard} package, and all
provide variations of author-date styles of presentation.")
    (license license:lppl)))

(define-public texlive-ecothesis
  (package
    (name "texlive-ecothesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ecothesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1avnq2y5l2bc2lkf2g16p2vh77dabv52jr6jrm4jfm1wdapc6fmq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ecothesis")
    (synopsis "LaTeX thesis template for the Universidade Federal de Vicosa")
    (description
     "The package provides a LaTeX thesis template for the @acronym{UFV,
Universidade Federal de Vicosa}, Brazil.")
    (license license:lppl1.3c)))

(define-public texlive-eczar
  (package
    (name "texlive-eczar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/eczar/"
                                     "fonts/opentype/public/eczar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r7alay4g12gn7sr6d584y04qzi77qiialmsq1wfxay7a2h8c3rn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eczar")
    (synopsis "Font family supporting Devanagari and Latin script")
    (description
     "Eczar is a type family designed by Vaibhav Singh.  The fonts support
over 45+3 languages in Latin and Devanagari scripts in 5 weights.")
    (license license:silofl1.1)))

(define-public texlive-edfnotes
  (package
    (name "texlive-edfnotes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/edfnotes/"
                                     "source/latex/edfnotes/"
                                     "tex/latex/edfnotes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "074db5fanasjzk7clj0l4ka3x1qpmvczwxix0l2v6sjjmyb4xfz4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/edfnotes")
    (synopsis "Critical annotations to footnotes with @code{ednotes}")
    (description
     "The package modifies the annotation commands and label-test mechanism of
the ednotes package so that critical notes appear on the pages and in the
order that one would expect.")
    (license license:lppl1.3+)))

(define-public texlive-edmac
  (package
    (name "texlive-edmac")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/edmac/" "source/latex/edmac/"
                                     "tex/generic/edmac/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pflqzrzfyw725ypc6lcryzzbizk13j69h4875r6q4fs763kv3w1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/edmac")
    (synopsis "Typeset critical editions")
    (description
     "This is the type example package for typesetting scholarly critical
editions.")
    (license license:gpl2)))

(define-public texlive-egameps
  (package
    (name "texlive-egameps")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/egameps/" "tex/latex/egameps/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wlki6y54czvvq7cvs7pvsvl1fhd8laaj5j52jv1v8w1msh5mlpr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/egameps")
    (synopsis "LaTeX package for typesetting extensive games")
    (description
     "The style is intended to have enough features to draw any extensive game
with relative ease.  The facilities of PSTricks are used for graphics.")
    (license license:lppl)))

(define-public texlive-eiad
  (package
    (name "texlive-eiad")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/eiad/"
                                     "fonts/source/public/eiad/"
                                     "fonts/tfm/public/eiad/" "tex/latex/eiad/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0il058v1x79w5faxyalysdmfsgbxc3a1nq8kraffawpqw6wjcrbj"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-sauter")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont texlive-sauter))
    (home-page "https://ctan.org/pkg/eiad")
    (synopsis "Traditional style Irish fonts")
    (description
     "This package provides traditional style Irish fonts, in both lower and
upper case 32 letters are defined (18 plain ones, 5 long vowels and
9 aspirated consonants).  The ligature agus is also made available.  The
remaining characters (digits, punctuation and accents) are inherited from the
Computer Modern family of fonts.")
    (license license:public-domain)))

(define-public texlive-eiad-ltx
  (package
    (name "texlive-eiad-ltx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/eiad-ltx/"
                                     "fonts/source/public/eiad-ltx/"
                                     "source/latex/eiad-ltx/"
                                     "tex/latex/eiad-ltx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qqwzl345v6hn0gp46flvhhzacgv810qjn575bhigqq726zl4kz7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eiad-ltx")
    (synopsis "LaTeX support for the @code{eiad} font")
    (description
     "The package provides macros to support use of the @code{eiad} fonts in
OT1 encoding.  Also offered are a couple of Metafont files described in the
font package, but not provided there.")
    (license license:lppl)))

(define-public texlive-einfart
  (package
    (name "texlive-einfart")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/einfart/" "tex/latex/einfart/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hlj00jp7s9b22r4a8l5fc98hnsblmn05v1ryqxknkcj6qdvrj9d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-minimalist))
    (home-page "https://ctan.org/pkg/einfart")
    (synopsis "Write your articles in a simple and clear way")
    (description
     "This package provides a LaTeX class for typesetting articles with a
simple and clear design.  Currently, it has native support for Chinese
(simplified and traditional), English, French, German, Italian, Japanese,
Portuguese (European and Brazilian), Russian and Spanish typesetting.  It
compiles with either XeLaTeX or LuaLaTeX.  This is part of the
@code{minimalist} class series and depends on that package.")
    (license license:lppl1.3c)))

(define-public texlive-ejpecp
  (package
    (name "texlive-ejpecp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ejpecp/" "source/latex/ejpecp/"
                                     "tex/latex/ejpecp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "083abggngg89nj4ra0a33j3s6wf0jba814lc4zp5sh64pc2x8h0j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ejpecp")
    (synopsis "Class for EJP and ECP")
    (description
     "The class is designed for typesetting articles for the mathematical
research periodicals @emph{Electronic Journal of Probability} (EJP) and
@emph{Electronic Communications in Probability} (ECP).")
    (license license:lppl1.2+)))

(define-public texlive-ekaia
  (package
    (name "texlive-ekaia")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ekaia/" "source/latex/ekaia/"
                                     "tex/latex/ekaia/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n6zinzcg3win9nn86ljf8fcwsxxn6dq1gjnnw1si8ca01zdyx45"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ekaia")
    (synopsis
     "Article format for the Basque Country Science and Technology Journal
@emph{Ekaia}")
    (description
     "The package provides the article format for publishing the Basque
Country Science and Technology Journal @emph{Ekaia} at the University of the
Basque Country.")
    (license license:lppl1.2+)))

(define-public texlive-ektype-tanka
  (package
    (name "texlive-ektype-tanka")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/ektype-tanka/"
                                     "fonts/truetype/public/ektype-tanka/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05jyx7dgbi19n6g8f4a5f8lkalld2p7lrlrfy1pj961hx65zbj80"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ektype-tanka")
    (synopsis "Devanagari fonts by EkType")
    (description
     "This package provides a collection of some Devanagari fonts by EkType:
Mukta, Baloo, Modak, and Jaini.")
    (license license:lppl1.3c)))

(define-public texlive-elbioimp
  (package
    (name "texlive-elbioimp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/elbioimp/"
                                     "source/latex/elbioimp/"
                                     "tex/latex/elbioimp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1iwsahllfw975cs11llr0ghx80wf5kmw5zrbs4iqviai12ipnkd2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/elbioimp")
    (synopsis
     "LaTeX document class for the @emph{Journal of Electrical Bioimpedance}")
    (description
     "This package provides a document class for writing articles to the
@emph{Journal of Electrical Bioimpedance}.")
    (license license:lppl)))

(define-public texlive-electrum
  (package
    (name "texlive-electrum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/electrum/"
                                     "fonts/afm/arkandis/electrum/"
                                     "fonts/enc/dvips/electrum/"
                                     "fonts/map/dvips/electrum/"
                                     "fonts/tfm/arkandis/electrum/"
                                     "fonts/type1/arkandis/electrum/"
                                     "fonts/vf/arkandis/electrum/"
                                     "source/fonts/electrum/"
                                     "tex/latex/electrum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k8yckfh7pw2p3gy2j4ss9l42dmdbdnb7nsliz0j05g7wkkcp05w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/electrumadf")
    (synopsis "Electrum ADF fonts collection")
    (description
     "Electrum ADF is a slab-serif font featuring optical and italic
small-caps; additional ligatures and an alternate @samp{Q}; lining, hanging,
inferior and superior digits; and four weights.  The fonts are provided in
Adobe Type 1 format and the support material enables use with LaTeX. Licence
is mixed: LPPL for LaTeX support; GPL with font exception for the fonts.")
    ;; LPPL for LaTeX support, GPL with font exception for the fonts.
    (license (list license:lppl license:gpl2+))))

(define-public texlive-eledform
  (package
    (name "texlive-eledform")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/eledform/"
                                     "source/latex/eledform/"
                                     "tex/latex/eledform/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sslbwabzpvx314bfmr6gy1p8nrh89v5mnkgdcby9w42hnfqiw2n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eledform")
    (synopsis "Define textual variants")
    (description
     "The package provides commands to formalize textual variants in critical
editions typeset using @code{eledmac}.")
    (license license:lppl1.3+)))

(define-public texlive-eledmac
  (package
    (name "texlive-eledmac")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/eledmac/" "source/latex/eledmac/"
                                     "tex/latex/eledmac/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a4579g3rykcgbwjqbky260lx6x7mc41i6cqhi83anf3zilsii0r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eledmac")
    (synopsis "Typeset scholarly editions")
    (description
     "This package provides a package for typesetting scholarly critical editions,
replacing the established @code{ledmac} package.  The package supports
indexing by page and by line numbers, and simple @code{tabular}- and
@code{array}-style environments.  The package is distributed with the related
@code{eledpar} package.  The package is now superseded by @code{reledmac}.")
    (license license:lppl1.3+)))

(define-public texlive-els-cas-templates
  (package
    (name "texlive-els-cas-templates")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/els-cas-templates/"
                                     "doc/latex/els-cas-templates/"
                                     "tex/latex/els-cas-templates/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1drp6gykqn4yaxjsiamsn8v5zv7nhvlqiblfhqg85fq3yl4q1sqk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/els-cas-templates")
    (synopsis "Elsevier updated LaTeX templates")
    (description
     "This bundle provides two class and corresponding template files for
typesetting journal articles supposed to go through Elsevier's updated
workflow.  One of the sets is meant for one-column, the other for two-column
layout.  These are now accepted for submitting articles both in Elsevier's
electronic submission system and elsewhere.")
    (license license:lppl1.2+)))

(define-public texlive-elsarticle
  (package
    (name "texlive-elsarticle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/elsarticle/"
                                     "doc/latex/elsarticle/"
                                     "source/latex/elsarticle/"
                                     "tex/latex/elsarticle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1616ql7yhf6fr66szgnpkxd2sz8vx22w25annf11i2zmr698k3aa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/elsarticle")
    (synopsis "Class for articles for submission to Elsevier journals")
    (description
     "This class for typesetting journal articles is accepted for submitted
articles both in Elsevier's electronic submission system and elsewhere.")
    (license license:lppl1.2+)))

(define-public texlive-elteikthesis
  (package
    (name "texlive-elteikthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/elteikthesis/"
                                     "tex/latex/elteikthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12lm8xsk7jwfhykfw3cz8knj4jphsmqzzs8v359fgpxnpqwnw5cw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/elteikthesis")
    (synopsis "Thesis template for Eotvos Lorand University (Informatics)")
    (description
     "This package provides a bachelor and master thesis template for the
Eotvos Lorand University, Faculty of Informatics (Budapest, Hungary).  The
template supports producing both Hungarian and English theses.")
    (license license:expat)))

(define-public texlive-eltex
  (package
    (name "texlive-eltex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/eltex/" "tex/latex/eltex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p6wy61n5q93mp07kv7bkp5nnsshshs6wrrhixicn0vankcgnm7w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eltex")
    (synopsis "Simple circuit diagrams in LaTeX picture mode")
    (description
     "The macros enable the user to draw simple circuit diagrams in the
picture environment, with no need of special resources.  The macros are
appropriate for drawing for school materials.  The circuit symbols accord to
the various parts of the standard IEC 617.")
    (license license:lppl)))

(define-public texlive-elvish
  (package
    (name "texlive-elvish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/elvish/"
                                     "fonts/source/public/elvish/"
                                     "fonts/tfm/public/elvish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vmvkc97a7j93jhdp0wbz4mqvk5q2kxjy5dlklwl5jawggagm7r4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/elvish")
    (synopsis "Fonts for typesetting Tolkien Elvish scripts")
    (description
     "The bundle provides fonts for Cirth and for Tengwar.  The Tengwar fonts
are supported by macros in @file{teng.tex}, or by the (better documented)
@code{tengtex} package.")
    ;; "If you produce modifications that seem useful, you are asked to send
    ;; them to me, so that they can be incorporated into the master files."
    (license (license:non-copyleft "file://doc/fonts/elvish/README"))))

(define-public texlive-emf
  (package
    (name "texlive-emf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/emf/" "tex/latex/emf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1w1wrvb2agq8vw2n8qg0mj3as09nygaxvjj6ji90qd865fj7lwzl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/emf")
    (synopsis "Support for the EMF symbol")
    (description
     "This package provides LaTeX support for the symbol for the EMF in
electric circuits and electrodynamics.  It provides support for multiple
symbols but does not provide any fonts.  The fonts themselves must be acquired
otherwise.")
    (license license:gpl3)))

(define-public texlive-emisa
  (package
    (name "texlive-emisa")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/emisa/" "source/latex/emisa/"
                                     "tex/latex/emisa/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02f8blixqqbn7k3h2sn59b9d8i2lxqnh2zwdk4gv7wyjr9l0sc1x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:phases
           #~(modify-phases %standard-phases
               ;; "emisa.ins" apparently wants to generate itself!  Fix that.
               (add-after 'unpack 'fix-ins
                 (lambda _
                   (substitute* "source/latex/emisa/emisa.ins"
                     (("\\\\file\\{\\\\jobname\\.ins\\}.*") "")))))))
    (home-page "https://ctan.org/pkg/emisa")
    (synopsis "LaTeX package for preparing manuscripts for the journal
@emph{EMISA}")
    (description
     "The EMISA LaTeX package is provided for preparing manuscripts for
submission to @acronym{EMISA, Enterprise Modelling and Information Systems
Architectures}, and for preparing accepted submissions for publication as well
as for typesetting the final document by the editorial office.")
    (license license:lppl1.3c)))

(define-public texlive-endiagram
  (package
    (name "texlive-endiagram")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/endiagram/"
                                     "tex/latex/endiagram/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07vm7ka7651mp5kk7m4ipk6agh4afmnq5ns1mjxvssb2wxfli3f0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/endiagram")
    (synopsis "Easy creation of potential energy curve diagrams")
    (description
     "The package provides the facility of drawing potential energy curve
diagrams with just a few simple commands.")
    (license license:lppl1.3+)))

(define-public texlive-engtlc
  (package
    (name "texlive-engtlc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/engtlc/" "tex/latex/engtlc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xl0x6yanf2933p4ajlwzlrxjrn36kkdy6bm7cy10s1nys3y3pqk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/engtlc")
    (synopsis "Support for users in telecommunications engineering")
    (description
     "The package provides a wide range of abbreviations for terms used in
telecommunications engineering.")
    (license license:lppl1.3+)))

(define-public texlive-iexec
  (package
    (name "texlive-iexec")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/iexec/" "source/latex/iexec/"
                                     "tex/latex/iexec/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pskdinm7rqsrb8xdz980wvxqjv018zj70l6gki0pch98ygwmg8d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-pgf))
    (home-page "https://ctan.org/pkg/iexec")
    (synopsis "Execute shell commands and input their output")
    (description
     "With the help of the @code{\\iexec} command, you can execute a shell
command and then input its output into your document.  This package also lets
you use any special symbols inside your command.")
    (license license:expat)))

(define-public texlive-eolang
  (package
    (name "texlive-eolang")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/eolang/"
                                     "doc/man/man1/eolang.1"
                                     "doc/man/man1/eolang.man1.pdf"
                                     "scripts/eolang/"
                                     "source/latex/eolang/"
                                     "tex/latex/eolang/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "143k0j6cyysisraags5i1cp90199b7f6hdjg1rar6ysrrfvp9dhv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-amsfonts
           texlive-amsmath
           texlive-fancyvrb
           texlive-iexec
           texlive-pgf
           texlive-pgfopts
           texlive-stmaryrd))
    (home-page "https://ctan.org/pkg/eolang")
    (synopsis "Formulas and graphs for the EO programming language")
    (description
     "This LaTeX package helps you write φ-calculus formulas and
@url{https://github.com/objectionary/sodg, SODG} graphs for the
@url{https://www.eolang.org, EO} programming language.")
    (license license:expat)))

(define-public texlive-epigrafica
  (package
    (name "texlive-epigrafica")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/epigrafica/"
                                     "fonts/afm/public/epigrafica/"
                                     "fonts/enc/dvips/epigrafica/"
                                     "fonts/map/dvips/epigrafica/"
                                     "fonts/tfm/public/epigrafica/"
                                     "fonts/type1/public/epigrafica/"
                                     "fonts/vf/public/epigrafica/"
                                     "tex/latex/epigrafica/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1s18ykapm50xyvrw5ls9gzc3m8r6pnjaplryr7q469k69455fh6z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/epigrafica")
    (synopsis "Greek and Latin font")
    (description
     "Epigrafica is a Greek and Latin font, forked from the development of the
Cosmetica font, which is a similar design to Optima and includes Greek.")
    (license license:gpl3+)))

(define-public texlive-eplain
  (package
    (name "texlive-eplain")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/eplain/"
                                     "doc/info/eplain.info"
                                     "doc/man/man1/eplain.1"
                                     "doc/man/man1/eplain.man1.pdf"
                                     "source/eplain/"
                                     "tex/eplain/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00nmqhfckrf8ygw6i93d5xnf85i8a88ryadb5ml73w4rllwjxr72"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:create-formats #~(list "eplain")
           #:phases
           #~(modify-phases %standard-phases
               (add-after 'install 'symlink-binaries
                 (lambda* (#:key inputs #:allow-other-keys)
                   (let ((pdftex (search-input-file inputs "bin/pdftex"))
                         (bin (string-append #$output "/bin")))
                     (mkdir-p bin)
                     (with-directory-excursion bin
                       (symlink pdftex "eplain"))))))))
    (propagated-inputs
     (list texlive-babel
           texlive-cm
           texlive-firstaid
           texlive-hyphen-complete
           texlive-knuth-lib
           texlive-l3backend
           texlive-l3kernel
           texlive-latex
           texlive-latex-fonts
           texlive-pdftex
           texlive-plain
           texlive-tex-ini-files
           texlive-unicode-data))
    (home-page "https://ctan.org/pkg/eplain")
    (synopsis "Extended plain TeX macros")
    (description
     "This package provides an extended version of the plain TeX format,
adding support for bibliographies, tables of contents, enumerated lists,
verbatim input of files, numbered equations, tables, two-column output,
footnotes, hyperlinks in PDF output and commutative diagrams.  Eplain can also
load some of the more useful LaTeX packages, notably @code{graphics},
@code{graphicx} (an extended version of graphics), @code{color},
@code{autopict} (a package instance of the LaTeX picture code), @code{psfrag},
and @code{url}.")
    (license license:gpl2+)))

(define-public texlive-epsdice
  (package
    (name "texlive-epsdice")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/epsdice/" "source/latex/epsdice/"
                                     "tex/latex/epsdice/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09h3jqb44vl1jpb3hf6gbpfpbvfv6lvdvjmp4xpzhl1zs672wccj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/epsdice")
    (synopsis "Scalable dice font")
    (description
     "The @code{epsdice} package defines a single command @code{\\epsdice}
that takes a numeric argument (in the range 1-6), and selects a face image
from a file that contains each of the 6 possible die faces.  The graphic file
is provided in both Encapsulated PostScript and PDF formats.")
    (license license:lppl)))

(define-public texlive-epslatex-fr
  (package
    (name "texlive-epslatex-fr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/epslatex-fr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xs9977g9g3i6sipkf7i9jdl8sdm69ci3161a4p7k66qbizi7zvb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fepslatex")
    (synopsis "French version of @emph{Graphics in LaTeX}")
    (description
     "This is the French translation of @code{epslatex}, and describes how to
use imported graphics in LaTeX(2e) documents.")
    (license license:gpl3+)))

(define-public texlive-eqexpl
  (package
    (name "texlive-eqexpl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/eqexpl/" "tex/latex/eqexpl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0crbq63m7ra20a1s1yka2v24spfvi86ls1v8asswdrf83zkdpibi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eqexpl")
    (synopsis "Align explanations for formulas")
    (description
     "This package tries to create perfectly formatted explanation of
components of a formula.")
    (license license:cc-by-sa4.0)))

(define-public texlive-eqnarray
  (package
    (name "texlive-eqnarray")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/eqnarray/"
                                     "source/latex/eqnarray/"
                                     "tex/latex/eqnarray/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0w01rh4a1yglfm9fqkhry1d6bs47caj0dsna9j648z0pxvdf1v38"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eqnarray")
    (synopsis "More generalised equation arrays with numbering")
    (description
     "This package defines an @code{equationarray} environment, that allows
more than three columns, but otherwise behaves like LaTeX's @code{eqnarray}
environment.  This environment is similar, in some ways, to the @code{align}
environment of @code{amsmath}.")
    (license license:gpl3)))

(define-public texlive-eqnnumwarn
  (package
    (name "texlive-eqnnumwarn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/eqnnumwarn/"
                                     "tex/latex/eqnnumwarn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06z6rb0q5qln5knamwxljzw5h373r2xh159ml9akw4kb2cdk3bri"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eqnnumwarn")
    (synopsis "Warn for a displaced equation number")
    (description
     "Sometimes an equation is too long that an equation number will be
typeset below the equation itself, but yet not long enough to yield an
@samp{overfull \\hbox} warning.  The @code{eqnnumwarn} package modifies the
standard @code{amsmath} numbered equation environments to throw a warning
whenever this occurs.")
    (license license:lppl1.3+)))

(define-public texlive-erdc
  (package
    (name "texlive-erdc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/erdc/" "source/latex/erdc/"
                                     "tex/latex/erdc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sqq0zd89jx2l4n1hpas4c4y4p3mh1mbnfigjbal9xg2h5pijkv1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/erdc")
    (synopsis "Style for reports by US Army Corps of Engineers")
    (description
     "This package provides a class for typesetting Technical Information
Reports of the Engineer Research and Development Center, US Army Corps of
Engineers.")
    (license license:lppl)))

(define-public texlive-erewhon
  (package
    (name "texlive-erewhon")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/erewhon/"
                                     "fonts/afm/public/erewhon/"
                                     "fonts/enc/dvips/erewhon/"
                                     "fonts/map/dvips/erewhon/"
                                     "fonts/opentype/public/erewhon/"
                                     "fonts/tfm/public/erewhon/"
                                     "fonts/type1/public/erewhon/"
                                     "fonts/vf/public/erewhon/"
                                     "tex/latex/erewhon/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02qhg27y24b533gnx90f8a1b7j06i369qswmpccq5a6gaaab8xcv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/erewhon")
    (synopsis "Font package derived from Heuristica and Utopia")
    (description
     "Erewhon is based on the Heuristica package, which is based in turn on
Utopia.  Erewhon adds a number of new features --- small caps in all styles
rather than just regular, added figure styles (proportional, inferior,
numerator, denominator) and superior letters.  The size is 6% smaller than
Heuristica, matching that of UtopiaStd.")
    (license (list license:silofl1.1 license:lppl1.3+))))

(define-public texlive-erewhon-math
  (package
    (name "texlive-erewhon-math")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/erewhon-math/"
                                     "fonts/opentype/public/erewhon-math/"
                                     "tex/latex/erewhon-math/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0g3f4p2zacans6zp59zrjk5blgrsyhqpx98qkgi4w0klxiclxa1c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/erewhon-math")
    (synopsis "Utopia based OpenType math font")
    (description
     "Erewhon Math is an OpenType version of the Fourier Type1 fonts designed
by Michel Bovani.")
    (license (list license:silofl1.1 license:lppl1.3+))))

(define-public texlive-esrelation
  (package
    (name "texlive-esrelation")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/esrelation/"
                                     "fonts/map/dvips/esrelation/"
                                     "fonts/source/public/esrelation/"
                                     "fonts/tfm/public/esrelation/"
                                     "fonts/type1/public/esrelation/"
                                     "source/fonts/esrelation/"
                                     "tex/latex/esrelation/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "168pjrn3pgyqb79nvwk4rykb214jj1fvygnlb18rx7nrnzdmagjw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/esrelation")
    (synopsis "Symbol set for describing relations between ordered pairs")
    (description
     "This package provides an math symbol font, by Tauba Auerbach, for
describing relations between ordered pairs, using Metafont.")
    (license license:lppl1.3+)))

(define-public texlive-esstix
  (package
    (name "texlive-esstix")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/esstix/"
                                     "fonts/afm/esstix/"
                                     "fonts/map/dvips/esstix/"
                                     "fonts/tfm/public/esstix/"
                                     "fonts/type1/public/esstix/"
                                     "fonts/vf/public/esstix/"
                                     "tex/latex/esstix/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wfl7q6yx7pflzy402ldx7p3zw3xgvgvilrdzv7pm0w937a3qkm9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/esstix")
    (synopsis "PostScript versions of the ESSTIX, with macro support")
    (description
     "These fonts represent translation to PostScript Type 1 of the ESSTIX
fonts.  ESSTIX seem to have been a precursor to the STIX project.  The
accompanying virtual fonts with customized metrics and LaTeX support files
allow their use as @code{calligraphic}, @code{fraktur} and
@code{double-struck} (blackboard bold) in maths mode.")
    (license license:silofl1.1)))

(define-public texlive-estcpmm
  (package
    (name "texlive-estcpmm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/estcpmm/" "source/latex/estcpmm/"
                                     "tex/latex/estcpmm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09fp8vidb9wzdsm05nira4p8dyjn75i1jhhwnr6k17pdrad1sqrj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/estcpmm")
    (synopsis "Style for Munitions Management Project Reports")
    (description
     "This package provides a class which supports typesetting Cost and
Performance Reports and Final Reports for Munitions Management Reports, US
Environmental Security Technology Certification Program.")
    (license license:lppl)))

(define-public texlive-esvect
  (package
    (name "texlive-esvect")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/esvect/"
                                     "fonts/map/dvips/esvect/"
                                     "fonts/source/public/esvect/"
                                     "fonts/tfm/public/esvect/"
                                     "fonts/type1/public/esvect/"
                                     "source/latex/esvect/"
                                     "tex/latex/esvect/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15sr1rm86aamfy186v2zvvcjsw5rhcq6ph5ckpfn275vjp3fazrf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/esvect")
    (synopsis "Vector arrows")
    (description
     "This package can be used to write vectors using an arrow which differs
from the Computer Modern one.  You have the choice between several kinds of
arrows.  The package consists of the relevant Metafont code and a package to
use it.")
    (license license:gpl3+)))

(define-public texlive-etbb
  (package
    (name "texlive-etbb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/etbb/"
                                     "fonts/afm/public/etbb/"
                                     "fonts/enc/dvips/etbb/"
                                     "fonts/map/dvips/etbb/"
                                     "fonts/opentype/public/etbb/"
                                     "fonts/tfm/public/etbb/"
                                     "fonts/type1/public/etbb/"
                                     "fonts/vf/public/etbb/"
                                     "tex/latex/etbb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0f07wz9qgvp9m3s4n7rzh2r5fq4h03ffxqpw5wv17imz2bvr1dr3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/etbb")
    (synopsis "Expansion of Edward Tufte's ET-Bembo family")
    (description
     "The Bembo-like font family, ETbb, expands ET-Bembo features to include
a full set of figure styles, small caps in all styles, superior letters and
figures, inferior figures, a new capital Sharp @samp{S} with small caps
version, along with macros to activate these features in LaTeX.")
    (license (list license:expat license:lppl1.3+))))

(define-public texlive-etsvthor
  (package
    (name "texlive-etsvthor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/etsvthor/" "tex/latex/etsvthor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lrvxr2lrfq1vkfkx7sjrm8fsxv8aalkpi0x0wmkdizc6n2wlhx4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/etsvthor")
    (synopsis "Some useful abbreviations for members of e.t.s.v. Thor")
    (description
     "``e.t.s.v.  Thor'' stands for Elektrotechnische Studievereniging Thor,
a study association of Electrical Engeering at the Eindhoven University of
Technology.  This package provides abbreviations useful for creating meeting
notes or other documents within the association.")
    (license license:lppl1.3c)))

(define-public texlive-euclideangeometry
  (package
    (name "texlive-euclideangeometry")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/euclideangeometry/"
                                     "source/latex/euclideangeometry/"
                                     "tex/latex/euclideangeometry/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pzqagrkr0w67n4v3z3q37p1rk3zk8sp2z2kl86rcqq5zi1rf9cl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/euclideangeometry")
    (synopsis "Draw geometrical constructions")
    (description
     "This package provides tools to draw most of the geometrical
constructions that a high school instructor or bachelor degree professor might
need to teach geometry.  The connection to Euclide depends on the fact that in
his times calculations were made with ruler, compass and also with
ellipsograph.  This package extends the functionalities of the @code{curve2e}
package.")
    (license license:lppl1.3c)))

(define-public texlive-euler-math
  (package
    (name "texlive-euler-math")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/euler-math/"
                                     "fonts/opentype/public/euler-math/"
                                     "tex/latex/euler-math/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18vd27yqmch97xrjpw3wwhf4v74m97nxd2azr0vl5gbx3sx6igii"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/euler-math")
    (synopsis "OpenType version of Hermann Zapf's Euler maths font")
    (description
     "@file{Euler-Math.otf} is an OpenType version of Hermann Zapf's Euler
maths font.  A style file @file{euler-math.sty} is provided as a replacement
of the @code{eulervm} package for LuaLaTeX and XeLaTeX users.")
    (license (list license:silofl1.1 license:lppl1.3+))))

(define-public texlive-euxm
  (package
    (name "texlive-euxm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "fonts/source/public/euxm/"
                                     "fonts/tfm/public/euxm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10dqknqlqrga9m2lgd74zx5hk4qcbkfvlzjgr304p94w3k7pclqc"))))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/euxm")
    (synopsis "Extended Euler")
    (description
     "This package extends Euler font to include two additional characters
needed for Concrete Math.")
    (license license:knuth)))

(define-public texlive-evangelion-jfm
  (package
    (name "texlive-evangelion-jfm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/evangelion-jfm/"
                                     "source/luatex/evangelion-jfm/"
                                     "tex/luatex/evangelion-jfm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g174ck75h43gppv2c7ihbf815zc07fchc56c5bidywfv09c4y3s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/evangelion-jfm")
    (synopsis "Japanese font metric supporting many advanced features")
    (description
     "This package provides a Japanese font metric supporting vertical and
horizontal typesetting, linegap punctuations, extended fonts, and more
interesting and helpful features using traditional and simplified Chinese or
Japanese fonts under LuaTeX-ja.  It also makes full use of the priority
feature, meeting the standards, and allows easy customisation.")
    (license license:expat)))

(define-public texlive-expex
  (package
    (name "texlive-expex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/expex/" "tex/generic/expex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0is4cdpsqycaw8xzc6x1gkg4ldk8v6a1i52qmxw13q8k10qh6b95"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/expex")
    (synopsis "Linguistic examples and glosses, with reference capabilities")
    (description
     "The package provides macros for typesetting linguistic examples and
glosses, with a refined mechanism for referencing examples and parts of
examples.  The package can be used with LaTeX or with Plain TeX.")
    (license license:lppl)))

(define-public texlive-expose-expl3-dunkerque-2019
  (package
    (name "texlive-expose-expl3-dunkerque-2019")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/expose-expl3-dunkerque-2019/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xij1ycxnc3hfzkl0bfs03s0zzzv6xsj3myvykb6n836j1g66g2y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/expose-expl3-dunkerque-2019")
    (synopsis "Using @code{expl3} to implement some numerical algorithms")
    (description
     "This is an article, in French, based on a presentation made in Dunkerque
for the @emph{Stage LaTeX} on 12 June 2019.  The article gives three examples
of code in @code{expl3} with (lots of) comments: Knuth's algorithm to create
a list of primes, the sieve of Eratosthenes, Kaprekar sequences.  The package
contains the code itself, the documentation as a PDF file, and all the files
needed to produce it.")
    (license license:lppl1.3+)))

(define-public texlive-extarrows
  (package
    (name "texlive-extarrows")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/extarrows/"
                                     "tex/latex/extarrows/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fspc9vgz1vwi5lamv30czh6pp1vqsrk6f2ynqygq166rfxxm1gz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/extarrows")
    (synopsis "Extra arrows beyond those provided in @code{amsmath}")
    (description
     "This package provides arrows to supplement @code{\\xleftarrow} and
@code{\\xrightarrow} of the @code{amsath} package.")
    ;; Package mentions LGPL without any reference to the version.  Assuming
    ;; LGPL 2.1+.
    (license license:lgpl2.1+)))

(define-public texlive-extpfeil
  (package
    (name "texlive-extpfeil")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/extpfeil/"
                                     "source/latex/extpfeil/"
                                     "tex/latex/extpfeil/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11vri2kij4y3da2v1gsps66jf4r529w4nqbgbfajrxh2nhfb60iv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/extpfeil")
    (synopsis "Extensible arrows in mathematics")
    (description
     "The package provides some more extensible arrows (usable in the same way
as @code{\\xleftarrow} from @code{amsmath}), and a simple command to create
new ones.")
    (license license:lppl1.3+)))

(define-public texlive-facture
  (package
    (name "texlive-facture")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/facture/"
                                     "source/xelatex/facture/"
                                     "tex/xelatex/facture/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04a9h99vqrb25pqwl3gn24kw7pm87i3bwq24inhfvac3sj7wq97k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/facture")
    (synopsis "Generate an invoice")
    (description
     "This package provides a simple class that allows production of an invoice,
with or without VAT; different addresses for delivery and for billing are
permitted.")
    (license license:cc-by-sa2.0)))

(define-public texlive-facture-belge-simple-sans-tva
  (package
    (name "texlive-facture-belge-simple-sans-tva")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/facture-belge-simple-sans-tva/"
                                     "tex/xelatex/facture-belge-simple-sans-tva/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zs2hcc5lhzvfkv83wym1rax58mryylq9b7i358ln0pklnm2gncx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/facture-belge-simple-sans-tva")
    (synopsis "Simple Belgian invoice without VAT")
    (description
     "This package can be used to generate invoices for Belgian individuals
who do not have a VAT number and who wish to do occasional work, or to carry
out paid additional activities during their free time up to 6,000 euros per
calendar year (amount indexed annually) without having to pay tax or social
security contributions (see the website Activites complementaires).  The
package can also generate expense reports.  All totals are calculated
automatically, in the invoice and in the expense report.")
    (license license:lppl1.3c)))

(define-public texlive-faktor
  (package
    (name "texlive-faktor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/faktor/" "source/latex/faktor/"
                                     "tex/latex/faktor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sridf0sn775n9ivrbfxz2fgrcm0wl7ajbhr4509ck0pq2n5hq17"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/faktor")
    (synopsis "Typeset quotient structures with LaTeX")
    (description
     "The package provides the means to typeset factor structures, as are used
in many areas of algebraic notation.  The structure is similar to the A/B that
is provided by the @code{nicefrac} package (part of the @code{units}
distribution), and by the @code{xfrac} package; the most obvious difference is
that the numerator and denominator's sizes do not change in the
@code{\\faktor} command.")
    (license license:lppl)))

(define-public texlive-fascicules
  (package
    (name "texlive-fascicules")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fascicules/"
                                     "source/latex/fascicules/"
                                     "tex/latex/fascicules/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hsap900psylamhn3my7gsn7n06glqczcff0yw53zs9gjwyh4s13"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fascicules")
    (synopsis "Create mathematical manuals for schools")
    (description
     "This package enables LaTeX users to create math books for middle and
high schools.  It provides commands to create the front page of the manual and
the chapters.  Each chapter can consist of three sections: the lesson, the
exercises and the activities.")
    (license license:lppl)))

(define-public texlive-fbb
  (package
    (name "texlive-fbb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/fbb/"
                                     "fonts/enc/dvips/fbb/"
                                     "fonts/map/dvips/fbb/"
                                     "fonts/opentype/public/fbb/"
                                     "fonts/tfm/public/fbb/"
                                     "fonts/type1/public/fbb/"
                                     "fonts/vf/public/fbb/"
                                     "tex/latex/fbb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "012zfxq6hdz9m4pn6dxqv3lsbr809r10mj795w96cijzrys4zww1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fbb")
    (synopsis "Bembo-like font")
    (description
     "The package provides a Bembo-like font package based on Cardo but with
many modifications, adding Bold Italic, small caps in all styles, six figure
choices in all styles, updated kerning tables, added figure tables and
corrected f-ligatures.  Both OpenType and Adobe Type 1 versions are provided;
all necessary support files are provided.  The font works well with
@code{newtxmath}'s @code{libertine} option.")
    (license (list license:silofl1.1 license:lppl1.3+))))

(define-public texlive-fbithesis
  (package
    (name "texlive-fbithesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fbithesis/"
                                     "source/latex/fbithesis/"
                                     "tex/latex/fbithesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1650ilscm47x606piwx7a8z08lhkq87g8k0z40ii3ig0c3p9isgl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/fbithesis")
    (synopsis "Computer Science thesis class for University of Dortmund")
    (description
     "At the department of computer science at the University of Dortmund
there are cardboard cover pages for research or internal reports like master
and phd theses.  The main function of this LaTeX2e document-class is
a replacement for the @code{\\maketitle} command to typeset a title page that
is adjusted to these cover pages.")
    (license license:lppl1.3+)))

(define-public texlive-fbs
  (package
    (name "texlive-fbs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/fbs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18h6n8azrnk2qabv30kpa8gmj2ljkvx0nqs8qb9r8dxxnhng78ch"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fbs")
    (synopsis "BibTeX style for @emph{Frontiers in Bioscience}")
    (description
     "This package provides a BibTeX style file made with @code{custom}-bib to
fit @emph{Frontiers in Bioscience} requirements.")
    (license license:lppl)))

(define-public texlive-fcavtex
  (package
    (name "texlive-fcavtex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/fcavtex/" "doc/latex/fcavtex/"
                                     "tex/latex/fcavtex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l87wlh9mzh0hysfw35mlx3asqw7lvwc55yiqr01jbmv1hwgfnl6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fcavtex")
    (synopsis "Thesis class for the FCAV/UNESP, Brazil")
    (description
     "This package provides a class and a bibliography style for the
@acronym{FCAV-UNESP, Faculdade de Ciencias Agrarias e Veterinarias de
Jaboticabal UNESP} Brazilian university, written based on the institution
rules for thesis publications.")
    (license license:lppl1.3+)))

(define-public texlive-fcltxdoc
  (package
    (name "texlive-fcltxdoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fcltxdoc/"
                                     "source/latex/fcltxdoc/"
                                     "tex/latex/fcltxdoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qb0l622svj1bqs0p05mcf30f4xy432aa4qzk6w4rlckssdfiwva"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fcltxdoc")
    (synopsis "Macros for use in the author's documentation")
    (description
     "The package is not advertised for public use, but is necessary for the
support of others of the author's packages (which are compiled under the
@code{ltxdoc} class).")
    (license license:lppl1.3+)))

(define-public texlive-fdsymbol
  (package
    (name "texlive-fdsymbol")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/fdsymbol/"
                                     "doc/latex/fdsymbol/"
                                     "fonts/enc/dvips/fdsymbol/"
                                     "fonts/map/dvips/fdsymbol/"
                                     "fonts/opentype/public/fdsymbol/"
                                     "fonts/source/public/fdsymbol/"
                                     "fonts/tfm/public/fdsymbol/"
                                     "fonts/type1/public/fdsymbol/"
                                     "source/latex/fdsymbol/"
                                     "tex/latex/fdsymbol/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qw2bmw48xppn9jj5m46l3lr1zja6nall0a3vvpcfjd66ai3hmca"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/fdsymbol")
    (synopsis "Maths symbol font")
    (description
     "FdSymbol is a maths symbol font, designed as a companion to the Fedra
family, but it might also fit other contemporary typefaces.")
    (license license:silofl1.1)))

(define-public texlive-fduthesis
  (package
    (name "texlive-fduthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fduthesis/"
                                     "source/latex/fduthesis/"
                                     "tex/latex/fduthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1w8dqld77pjcv5si3d1xmvphy908g5sqndy8rrbbi5rm2cqw6a5s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fduthesis")
    (synopsis "LaTeX thesis template for Fudan University")
    (description
     "This package is a LaTeX thesis template package for Fudan University.
It can make it easy to write theses both in Chinese and English.")
    (license license:lppl1.3c)))

(define-public texlive-fei
  (package
    (name "texlive-fei")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fei/" "source/latex/fei/"
                                     "tex/latex/fei/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13f2sn9pazq6ak37025wr20mi11069paw8hd7qlrcy10bn7bkbl7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fei")
    (synopsis "Class for academic works at FEI University Center, Brazil")
    (description
     "@code{fei} is a class created by graduate students and LaTeX enthusiasts
that allows students from FEI University Center to create their academic
works, be it a monograph, masters dissertation or PhD thesis, under the
typographic rules of the institution.  The class makes it possible to create
a full academic work, supporting functionalities such as cover, title page,
catalog entry, dedication, summary, lists of figures, tables, algorithms,
acronyms and symbols, multiple authors, index, references, appendices and
attachments.  @code{fei} is loosely based in the Brazilian National Standards
Organization (@acronym{ABNT, Associacao Brasileira de Normas Tecnicas}).")
    (license license:lppl1.3c)))

(define-public texlive-fetamont
  (package
    (name "texlive-fetamont")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/fetamont/"
                                     "fonts/afm/public/fetamont/"
                                     "fonts/map/dvips/fetamont/"
                                     "fonts/opentype/public/fetamont/"
                                     "fonts/source/public/fetamont/"
                                     "fonts/tfm/public/fetamont/"
                                     "fonts/type1/public/fetamont/"
                                     "metapost/fetamont/"
                                     "source/fonts/fetamont/"
                                     "tex/latex/fetamont/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bs911vyn54i61vv3rhr0xcp6myap2s8ww6p1fd30ld1ha6nsrf6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    ;; FIXME: Generating font metrics require unpackaged "mf2outline.py"
    ;; script.
    (arguments
     (list #:phases
           #~(modify-phases %standard-phases
               (delete 'generate-font-metrics))))
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/fetamont")
    (synopsis "Extended version of Knuth's Logo typeface")
    (description
     "The @code{fetamont} typeface was designed in Metafont and extends the
Logo fonts to complete the Type 1 encoding.")
    (license license:lppl1.3+)))

(define-public texlive-feyn
  (package
    (name "texlive-feyn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/feyn/"
                                     "fonts/source/public/feyn/"
                                     "fonts/tfm/public/feyn/"
                                     "source/fonts/feyn/" "tex/latex/feyn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kd5xs1xffgplpapj6rjv4aaz7pfjfh8rspy2xrabbf03npkdqz5"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-sauter")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont texlive-sauter))
    (home-page "https://ctan.org/pkg/feyn")
    (synopsis "Font for in-text Feynman diagrams")
    (description
     "Feyn may be used to produce relatively simple Feynman diagrams within
equations in a LaTeX document.  While the @code{feynmf} package is good at
drawing large diagrams for figures, the present package and its fonts allow
diagrams within equations or text, at a matching size.  The fonts are
distributed as Metafont source, and macros for their use are also provided.")
    (license license:bsd-2)))

(define-public texlive-fge
  (package
    (name "texlive-fge")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/fge/"
                                     "fonts/map/dvips/fge/"
                                     "fonts/source/public/fge/"
                                     "fonts/tfm/public/fge/"
                                     "fonts/type1/public/fge/"
                                     "source/fonts/fge/"
                                     "tex/latex/fge/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00q9rf8jrb6jl5c10kn6axnlza6q02xan2gf88rd736v0wpi4936"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/fge")
    (synopsis "Font for Frege's @emph{Grundgesetze der Arithmetik}")
    (description
     "The package provides fonts for Frege's @emph{Grundgesetze der
Arithmetik}.  The fonts are provided as Metafont source and Adobe Type 1 (pfb)
files.  A small LaTeX package (@code{fge}) is included.")
    (license license:lppl)))

(define-public texlive-figbas
  (package
    (name "texlive-figbas")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/figbas/"
                                     "fonts/afm/public/figbas/"
                                     "fonts/map/dvips/figbas/"
                                     "fonts/tfm/public/figbas/"
                                     "fonts/type1/public/figbas/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07dc19989sx968hbn3h2m1bbplp8zqh1yj9v92mcp54876rk8bbp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/figbas")
    (synopsis "Mini-fonts for figured-bass notation in music")
    (description
     "This package consists of three mini-fonts (and associated metrics) of
conventional ligatures for the figured-bass notations 2+, 4+, 5+, 6+ and 9+ in
music manuscripts.  The fonts are usable with Computer Modern Roman and Sans,
and Palatino/Palladio, respectively.")
    (license license:lppl)))

(define-public texlive-figbib
  (package
    (name "texlive-figbib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/figbib/" "doc/latex/figbib/"
                                     "tex/latex/figbib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wvglj3z86xjz1bi5931hxm9b2kn6r4j7391di26wmsyhdajs2yz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/figbib")
    (synopsis "Organize figure databases with BibTeX")
    (description
     "FigBib lets you organize your figures in BibTeX databases.  Some FigBib
features are:
@itemize

@item store and manage figures in a BibTeX database;

@item Include figures in your LaTeX document with one short command;

@item generate a list of figures containing more or other information than the
figure captions;

@item control with one switch where to output the figures, either as usual
float objects or in a separate part at the end of your document.

@end itemize")
    (license license:lppl)))

(define-public texlive-filecontentsdef
  (package
    (name "texlive-filecontentsdef")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/filecontentsdef/"
                                     "source/latex/filecontentsdef/"
                                     "tex/latex/filecontentsdef/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pmjvxjsfnyzx3bl10n8is7l27l11mrw22g3w41f72kric0vfd65"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/filecontentsdef")
    (synopsis "@code{filecontents}, @code{macro}, and @code{verbatim}")
    (description
     "The package provides two environments called @code{filecontentsdef} and
@code{filecontentshere}.  They are derived from the LaTeX @code{filecontents}
environment.  In addition to the file creation they either store
the (verbatim) contents in a macro (@code{filecontentsdef}) or typeset
them (verbatim) on the spot (@code{filecontentshere}).  The author developed
the package to display TeX code verbatim in documentation and the same time
produce the corresponding files during the LaTeX run in order to embed them in
the PDF as file attachment annotations (by using Scott Pakin's package
@code{attachfile}).")
    (license license:lppl1.3+)))

(define-public texlive-firamath
  (package
    (name "texlive-firamath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/firamath/"
                                     "fonts/opentype/public/firamath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sc3ip9mvyqlbsj7vfcb1yaxlc32w18kqrqm051v5y2bbvp53s0p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/firamath")
    (synopsis "Fira sans serif font with Unicode math support")
    (description
     "Fira Math is a sans-serif font with Unicode math support.  The design of
this font is based on Fira Sans and FiraGO.  Fira Math is distributed in
OpenType format and can be used with the @code{unicode-math} package under
XeLaTeX or LuaLaTeX.  More support is offered by the @code{firamath-otf}
package.")
    (license license:silofl1.1)))

(define-public texlive-firamath-otf
  (package
    (name "texlive-firamath-otf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/firamath-otf/"
                                     "tex/latex/firamath-otf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "094b56is939li9cadqz2b7mz86ji5dnryi8k54nym8qmjsdx2gd1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-firamath))
    (home-page "https://ctan.org/pkg/firamath-otf")
    (synopsis "Use OpenType math font Fira Math")
    (description
     "The package offers XeTeX and LuaTeX support for the sans serif OpenType
Fira Math font.")
    (license license:lppl1.3+)))

(define-public texlive-fixdif
  (package
    (name "texlive-fixdif")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fixdif/" "source/latex/fixdif/"
                                     "tex/latex/fixdif/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l15mkwbnk0k2qqdnkady5n3iqyj0w7f8k23rxnbyrk5835crl67"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fixdif")
    (synopsis "Macros for typesetting differential operators")
    (description
     "This package redefines the @code{\\d} command in LaTeX and provides an
interface to define new commands for differential operators.  It is compatible
with pdfTeX, XeTeX and LuaTeX, and can also be used with the
@code{unicode-math} package.")
    (license license:lppl1.3c)))

(define-public texlive-fixfoot
  (package
    (name "texlive-fixfoot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fixfoot/" "tex/latex/fixfoot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1anyswchln7y7a6x72ay6hm3ck36byxk2ciia0w6y100iqcpq2sl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fixfoot")
    (synopsis "Multiple use of the same footnote text")
    (description
     "This package provides a @code{\\DeclareFixedFootnote} command to provide
a single command for a frequently-used footnote.  The package ensures that
only one instance of the footnote text appears on each page (LaTeX needs to be
run several times to achieve this).")
    (license license:lppl)))

(define-public texlive-fixjfm
  (package
    (name "texlive-fixjfm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/fixjfm/" "tex/generic/fixjfm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0x3wf7v03jqczvxaslqw422bvccvna31jl5sgld6llvfh7b0ziyx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fixjfm")
    (synopsis "Fix JFM (for *pTeX)")
    (description
     "This package fixes several bugs in the JFM format.  Both LaTeX and plain
TeX are supported.")
    (license license:knuth)))

(define-public texlive-fixltxhyph
  (package
    (name "texlive-fixltxhyph")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fixltxhyph/"
                                     "source/latex/fixltxhyph/"
                                     "tex/latex/fixltxhyph/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wjrq2gplal5hpij758c4mk6s6aidqp2h25mvf7jmbbzq2nfsyq1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fixltxhyph")
    (synopsis "Allow hyphenation of partially-emphasised substrings")
    (description
     "The package fixes the problem of TeX failing to hyphenate letter strings
that seem (to TeX} to be words, but which are followed by an apostrophe and
then an emphasis command.  The cause of the problem is not the apostrophe, but
the font change in the middle of the string.  The problem arises in Catalan,
French, Italian and Romansh.")
    (license license:lppl1.3+)))

(define-public texlive-fixmath
  (package
    (name "texlive-fixmath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fixmath/" "source/latex/fixmath/"
                                     "tex/latex/fixmath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15vwikvxxd8wagbfxjb1am3savciyppkq0bdk3zdxp09zg0dx2ra"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fixmath")
    (synopsis "Make maths comply with ISO 31-0:1992 to ISO 31-13:1992")
    (description
     "LaTeX's default style of typesetting mathematics does not comply with
the International Standards ISO 31-0:1992 to ISO 31-13:1992 which require that
uppercase Greek letters always be typset upright, as opposed to italic (even
though they usually represent variables) and allow for typsetting of variables
in a boldface italic style (even though the required fonts are available).
This package ensures that uppercase Greek be typeset in italic style, that
upright @samp{$\\Delta$} and @samp{$\\Omega$} symbols are available through
the commands @code{\\upDelta} and @code{\\upOmega}; and provides a new math
alphabet @code{\\mathbold} for boldface italic letters, including Greek.")
    (license license:lppl1.3c)))

(define-public texlive-fnspe
  (package
    (name "texlive-fnspe")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fnspe/" "tex/latex/fnspe/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wvr0jp8qyrrx907diphgjzvgq0alc922bmx905sndnwqzfl8fhd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fnspe")
    (synopsis "Macros for supporting mainly students of FNSPE CTU in Prague")
    (description
     "This package is primary intended for students of FNSPE CTU in Prague but
many other students or scientists can found this package as useful.  This
package implements different standards of tensor notation, interval notation
and complex notation.  Further many macros and shortcuts are added, e.g., for
spaces, operators, physics unit, etc.")
    (license license:lppl)))

(define-public texlive-foekfont
  (package
    (name "texlive-foekfont")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/foekfont/"
                                     "fonts/map/dvips/foekfont/"
                                     "fonts/tfm/public/foekfont/"
                                     "fonts/type1/public/foekfont/"
                                     "tex/latex/foekfont/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01l6mj5dh52cdaqdkv74j8qw2pfd6w7x53n856vsjgdha4r8362y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/foekfont")
    (synopsis "Title font of the @emph{Mads Fok} magazine")
    (description
     "The bundle provides the Foek font, an Adobe Type 1 font, and LaTeX
support for its use.")
    (license license:gpl3+)))

(define-public texlive-fonetika
  (package
    (name "texlive-fonetika")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/fonetika/"
                                     "fonts/afm/public/fonetika/"
                                     "fonts/map/dvips/fonetika/"
                                     "fonts/tfm/public/fonetika/"
                                     "fonts/truetype/public/fonetika/"
                                     "fonts/type1/public/fonetika/"
                                     "tex/latex/fonetika/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1d19a9v3innfq9602w8rd2ffn0yd52fz4wmdva6qnix0jgadc1ka"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fonetika")
    (synopsis "Support for the Danish Dania phonetic system")
    (description
     "Fonetika Dania is a font bundle with a serif font and a sans serif font
for the Danish phonetic system Dania.  Both fonts exist in regular and bold
weights.  LaTeX support is provided.")
    ;; The license is GPL3+, except for the fonts and metrics of the Fonetika
    ;; Dania Iwonae, which are under GUST Font Nosource License.
    (license (list license:gpl3+ license:gfl1.0))))

(define-public texlive-fontawesome
  (package
    (name "texlive-fontawesome")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/fontawesome/"
                                     "fonts/enc/dvips/fontawesome/"
                                     "fonts/map/dvips/fontawesome/"
                                     "fonts/opentype/public/fontawesome/"
                                     "fonts/tfm/public/fontawesome/"
                                     "fonts/type1/public/fontawesome/"
                                     "tex/latex/fontawesome/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m3wl0jc00h8r4w3fa5vkf062hmaadb2rvf3x9lm4pb0c99ia5x9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fontawesome")
    (synopsis "Font containing web-related icons")
    (description
     "The package offers access to the large number of web-related icons
provided by the FontAwesome font.")
    (license license:lppl1.3+)))

(define-public texlive-fontawesome5
  (package
    (name "texlive-fontawesome5")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/fontawesome5/"
                                     "fonts/enc/dvips/fontawesome5/"
                                     "fonts/map/dvips/fontawesome5/"
                                     "fonts/opentype/public/fontawesome5/"
                                     "fonts/tfm/public/fontawesome5/"
                                     "fonts/type1/public/fontawesome5/"
                                     "tex/latex/fontawesome5/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17cfqa2jjg3lp0damwy8kfdihmchx55994rrc897kcdba865rrwg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fontawesome5")
    (synopsis "Font Awesome 5 with LaTeX support")
    (description
     "This package provides LaTeX support for the included Font Awesome 5 icon
set.")
    (license (list license:silofl1.1 license:lppl1.3c))))

(define-public texlive-fontmfizz
  (package
    (name "texlive-fontmfizz")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/fontmfizz/"
                                     "fonts/truetype/public/fontmfizz/"
                                     "tex/latex/fontmfizz/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z0k7n1yyisv3igw77bj3r8hywyz55ciylb3fjx9dpdcrwv3kngd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fontmfizz")
    (synopsis "Font Mfizz icons for use in LaTeX")
    (description
     "The MFizz font provides scalable vector icons representing programming
languages, operating systems, software engineering, and technology.  It can be
seen as an extension to FontAwesome.")
    (license license:expat)))

(define-public texlive-fontsize
  (package
    (name "texlive-fontsize")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fontsize/"
                                     "source/latex/fontsize/"
                                     "tex/latex/fontsize/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1y061r4hadb2c26dgch6lrjw6f4j87zj1gj5lgzgx0hyyz58snqy"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments
     (list #:tex-format "latex"
           #:phases
           #~(modify-phases %standard-phases
               (add-after 'unpack 'fix-circular-dependency
                 ;; Documentation doesn't build, and generates a circular
                 ;; dependency with BIBLATEX-PHILOSOPHY package.  Since we're
                 ;; not interested in re-building the whole documentation,
                 ;; just skip that part.
                 (lambda _
                   (substitute* "source/latex/fontsize/fontsize.dtx"
                     (("\\[style=philosophy-classic\\]") "")
                     (("\\\\DocInput\\{fontsize\\.dtx\\}") "")))))))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-biblatex
                  texlive-booktabs
                  texlive-caption
                  texlive-cochineal
                  texlive-csquotes
                  texlive-etoolbox
                  texlive-fontaxes
                  texlive-guitlogo
                  texlive-hologo
                  texlive-hypdoc
                  texlive-inconsolata
                  texlive-libertine
                  texlive-listings
                  texlive-ltxdockit
                  texlive-manfnt
                  texlive-mathalpha
                  texlive-mdframed
                  texlive-metalogo
                  texlive-microtype
                  texlive-needspace
                  texlive-newtx
                  texlive-parskip
                  texlive-pgf
                  texlive-sectsty
                  texlive-siunitx
                  texlive-tabu
                  texlive-upquote
                  texlive-xcolor
                  texlive-xkeyval
                  texlive-xstring
                  texlive-zref))))
    (home-page "https://ctan.org/pkg/fontsize")
    (synopsis
     "Small package to set arbitrary sizes for the main font of the document")
    (description
     "The package allows you to set arbitrary sizes for the main font of the
document, through the @emph{fontsize=<size>} option.")
    (license license:lppl1.3+)))

(define-public texlive-fonttable
  (package
    (name "texlive-fonttable")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fonttable/"
                                     "source/latex/fonttable/"
                                     "tex/latex/fonttable/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mb83zzx5wk92x6zz28k42wmi82hyd1h7fb3p9imjssn6qb73356"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fonttable")
    (synopsis "Print font tables from a LaTeX document")
    (description
     "This is a package version of @file{nfssfont.tex}; it enables you to
print a table of the characters of a font and/or some text (for demonstration
or testing purposes), from within a document.")
    (license license:lppl1.3c)))

(define-public texlive-footbib
  (package
    (name "texlive-footbib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/footbib/" "source/latex/footbib/"
                                     "tex/latex/footbib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kv8nh82b16bmhxh2291ahznhjgm5g4qskqwdba66w48wkhzr32j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/footbib")
    (synopsis "Bibliographic references as footnotes")
    (description
     "The package makes bibliographic references appear as footnotes.  It
defines a command @code{\\footcite} which is similar to the LaTeX
@code{\\cite} command but the references cited in this way appear at the
bottom of the pages.  This @code{foot} bibliography does not conflict with the
standard one and both may exist simultaneously in a document.  The command
@code{\\cite} may still be used to produce the standard bibliography.  The
@code{foot} bibliography uses its own style and bibliographic database which
may be specified independently of the standard one.  Any standard bibliography
style may be used.")
    (license license:lppl)))

(define-public texlive-formal-grammar
  (package
    (name "texlive-formal-grammar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/formal-grammar/"
                                     "source/latex/formal-grammar/"
                                     "tex/latex/formal-grammar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00vr0gdz6jikdycsbfn7n8ddb8391h9fl314vjf8yxz25rn75qz4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/formal-grammar")
    (synopsis "Typeset formal grammars")
    (description
     "This package provides a new environment and associated commands to
typeset BNF grammars.  It allows easily writing formal grammars.  Its
original motivation was to typeset grammars for beamer presentations,
therefore, there are macros to emphasize or downplay some parts of the
grammar (which is the main novelty compared to other BNF packages).")
    (license license:lppl1.3+)))

(define-public texlive-formation-latex-ul
  (package
    (name "texlive-formation-latex-ul")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/formation-latex-ul/"
                                     "source/latex/formation-latex-ul/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c8c7sdzfrqld0nq8s3xmdxlskws37mjg9z4ag9i82z4kr1ffb56"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/formation-latex-ul")
    (synopsis "Introductory LaTeX course in French")
    (description
     "This package contains the supporting documentation, slides, exercise files,
and templates for an introductory LaTeX course (in French) prepared for
Universite Laval, Quebec, Canada.")
    (license license:cc-by4.0)))

(define-public texlive-forum
  (package
    (name "texlive-forum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/forum/"
                                     "fonts/enc/dvips/forum/"
                                     "fonts/map/dvips/forum/"
                                     "fonts/opentype/public/forum/"
                                     "fonts/tfm/public/forum/"
                                     "fonts/type1/public/forum/"
                                     "fonts/vf/public/forum/"
                                     "tex/latex/forum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07sbzd2da3i5adlbgrrxd7igyailzjwxvr3pcwmb9wl9jry1gg9m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/forum")
    (synopsis "Forum fonts with LaTeX support")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the Forum font, designed by Denis Masharov.  Forum has antique, classic Roman
proportions.  It can be used to set body texts and works well in titles and
headlines too.  It is truly multilingual, with glyphs for Central and Eastern
Europe, Baltics, Cyrillic and Asian Cyrillic communities.  There is currently
just a regular weight and an artificially emboldened bold.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-fouridx
  (package
    (name "texlive-fouridx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fouridx/" "source/latex/fouridx/"
                                     "tex/latex/fouridx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mlinh47gcazi3icyvkixhdkwd1wkpffq8snabhh4bjsvh6m8sxz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fouridx")
    (synopsis "Left sub- and superscripts in maths mode")
    (description
     "The package enables left subscripts and superscripts in maths mode.  The
sub- and superscripts are raised for optimum fitting to the symbol indexed, in
such a way that left and right sub- and superscripts are set on the same
level, as appropriate.  The package provides an alternative to the use of the
@code{\\sideset} command in the @code{amsmath} package.")
    (license license:lppl)))

(define-public texlive-fouriernc
  (package
    (name "texlive-fouriernc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/fouriernc/"
                                     "fonts/afm/public/fouriernc/"
                                     "fonts/tfm/public/fouriernc/"
                                     "fonts/vf/public/fouriernc/"
                                     "tex/latex/fouriernc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gg9l6zvyi98jg1w7z33pxsnmh7lqjcs2zakhj3pbv2q7ysxnppw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fouriernc")
    (synopsis "Use New Century Schoolbook text with Fourier maths fonts")
    (description
     "This package provides a LaTeX mathematics font setup for use with New
Century Schoolbook text.")
    (license license:lppl)))

(define-public texlive-francais-bst
  (package
    (name "texlive-francais-bst")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/francais-bst/"
                                     "doc/bibtex/francais-bst/"
                                     "source/bibtex/francais-bst/"
                                     "tex/latex/francais-bst/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07a0kqdwg9bzf1kgw11xn2344qdj52kgjc1iqz61hpirqlwfgw8s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/francais-bst")
    (synopsis "Bibliographies conforming to French typographic standards")
    (description
     "The package provides bibliographies (in French) conforming to the rules
in @emph{Guide de la communication ecrite} (Malo, M., Quebec Amerique, 1996).
The BibTeX styles were generated using @code{custom-bib} and they are
compatible with @code{natbib}.")
    (license license:lppl1.3+)))

(define-public texlive-frcursive
  (package
    (name "texlive-frcursive")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/frcursive/"
                                     "fonts/map/dvips/frcursive/"
                                     "fonts/source/public/frcursive/"
                                     "fonts/tfm/public/frcursive/"
                                     "fonts/type1/public/frcursive/"
                                     "tex/latex/frcursive/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04pqic407b0pfri5sydhbani0fxw0bxy3fl6x4isg2m2z73p4qqa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/frcursive")
    (synopsis "French cursive hand fonts")
    (description
     "This package provides a hand-writing font in the style of the French
academic running-hand.  The font was written in Metafont and has been
converted to Adobe Type 1 format.  LaTeX support is provided.")
    (license license:lppl1.2+)))

(define-public texlive-frederika2016
  (package
    (name "texlive-frederika2016")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/frederika2016/"
                                     "fonts/opentype/public/frederika2016/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10pvx4n4ahn8b251fzz8crg9pijpclan5w4b6jc7m7jjsykzw8xj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/frederika2016")
    (synopsis "OpenType Greek calligraphy font")
    (description
     "Frederika2016 is an attempt to digitize Hermann Zapf's Frederika font.
The font is the Greek companion of Virtuosa by the same designer.  This font
is a calligraphy font and this is an initial release.")
    (license license:silofl1.1)))

(define-public texlive-frenchmath
  (package
    (name "texlive-frenchmath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/frenchmath/"
                                     "source/latex/frenchmath/"
                                     "tex/latex/frenchmath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03z3dgdv8kcgwv5bilqavfc17lhhz9ybqcp3kawqyra55grlz5mb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/frenchmath")
    (synopsis "Typesetting mathematics according to French rules")
    (description
     "The package provides:

@itemize
@item capital letters in roman (upright shape) in mathematical mode according
to French rule (can be optionally disabled),
@item optionally lowercase Greek letters in upright shape,
@item correct spacing in math mode after commas, before a semicolon and around
square brackets,
@item some useful macros and aliases for symbols used in France such as
@code{\\infeg}, @code{\\supeg}, @code{\\paral}, @item several macros for
writing french operator names like @emph{pgcd}, @emph{ppcm}, @emph{Card},
@emph{rg}, @emph{Vect}.
@end itemize")
    (license license:lppl1.3+)))

(define-public texlive-frimurer
  (package
    (name "texlive-frimurer")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/frimurer/"
                                     "fonts/afm/public/frimurer/"
                                     "fonts/enc/dvips/frimurer/"
                                     "fonts/tfm/public/frimurer/"
                                     "fonts/type1/public/frimurer/"
                                     "source/fonts/frimurer/"
                                     "tex/latex/frimurer/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "072mbcn6272rs1sw85xznk0f7psqh3dkz8y0hayn8y7a83vcrfgr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/frimurer")
    (synopsis "Access to the @emph{frimurer} cipher for use with LaTeX")
    (description
     "This package provides access to the @emph{frimurer} cipher for use with
LaTeX.")
    (license license:gpl3)))

(define-public texlive-frletter
  (package
    (name "texlive-frletter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/frletter/" "tex/latex/frletter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h8lsfmv0icb616kwhkqqbfh64l43vwc63p4bl8sw9xy2lfal5xm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/frletter")
    (synopsis "Typeset letters in the French style")
    (description
     "This package provides a small class for typesetting letters in France.
No assumption is made about the language in use.  The class represents a small
modification of the @code{beletter} class, which is itself a modification of
the standard LaTeX @code{letter} class.")
    (license license:public-domain)))

(define-public texlive-frontespizio
  (package
    (name "texlive-frontespizio")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/frontespizio/"
                                     "source/latex/frontespizio/"
                                     "tex/latex/frontespizio/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17xqq0n2b0acpqq2hd5c5qi5fsrhyjwm1c452i3rbdmf1xkqvkvy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/frontespizio")
    (synopsis "Create a frontispiece for Italian theses")
    (description
     "Typesetting a frontispiece independently of the layout of the main
document is difficult.  This package provides a solution by producing an
auxiliary TeX file to be typeset on its own and the result is automatically
included at the next run.  The markup necessary for the frontispiece is
written in the main document in a @code{frontespizio} environment.
Documentation is mainly in Italian, as the style is probably apt only to
theses in Italy.")
    (license license:lppl)))

(define-public texlive-frpseudocode
  (package
    (name "texlive-frpseudocode")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/frpseudocode/"
                                     "tex/latex/frpseudocode/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jsrx1slbbqx9hg0a3f7xylxfly2cinw2g5vhhvvgxpp356v6ick"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/frpseudocode")
    (synopsis "French translation for the @code{algorithmicx} package")
    (description
     "This package is intended for use alongside @code{algorithmicx} package.
Its aim is to provide a French translation of terms and words used in
algorithms to make it integrate seamlessly in a French written document.")
    (license license:lppl1.3c)))

(define-public texlive-ftc-notebook
  (package
    (name "texlive-ftc-notebook")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ftc-notebook/"
                                     "tex/latex/ftc-notebook/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "068fc2wisryvgr8zqmkiwnyrrh5rmmw5njl41rn70bvv9qdgh31y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ftc-notebook")
    (synopsis "Typeset FIRST Tech Challenge (FTC) notebooks")
    (description
     "This LaTeX package will greatly simplify filling entries for your FIRST
Tech Challenge (FTC) engineering or outreach notebook.  We developed this
package to support most frequently used constructs encountered in an FTC
notebook: meetings, tasks, decisions with pros and cons, tables, figures with
explanations, team stories and bios, and more.")
    (license license:lppl1.3+)))

(define-public texlive-functan
  (package
    (name "texlive-functan")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/functan/" "source/latex/functan/"
                                     "tex/latex/functan/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "077jfm145bnan63r1rlqlmy15zqj89fl4nwksdpyd67zcda3k1vf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/functan")
    (synopsis "Macros for functional analysis and PDE theory")
    (description
     "This package provides a convenient and coherent way to deal with name of
functional spaces (mainly Sobolev spaces) in functional analysis and PDE
theory.  It also provides a set of macros for dealing with norms, scalar
products and convergence with some object oriented flavor (it gives the
possibility to override the standard behavior of norms, ...).")
    (license license:lppl)))

(define-public texlive-gaceta
  (package
    (name "texlive-gaceta")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gaceta/" "tex/latex/gaceta/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17w2i3qmks9qpdwpx0hy0mjrl5xhrc8hmz9s0229xnhf6h12yb1r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gaceta")
    (synopsis "Class to typeset @code{La Gaceta de la RSME}")
    (description
     "The class will typeset papers for @emph{La Gaceta de la Real Sociedad
Matematica Espanola}.")
    (license license:lppl)))

(define-public texlive-gamebook
  (package
    (name "texlive-gamebook")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gamebook/"
                                     "source/latex/gamebook/"
                                     "tex/latex/gamebook/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ksyr0hb1bfhc1lbbnzlj7ih8xw516djkn0lddnn07sb6hpzl8x4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gamebook")
    (synopsis "Typeset gamebooks and other interactive novels")
    (description
     "This package provides the means in order to lay-out gamebooks with LaTeX.
A simple gamebook example is included with the package, and acts as
a tutorial.")
    (license license:lppl1.3+)))

(define-public texlive-gamebooklib
  (package
    (name "texlive-gamebooklib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gamebooklib/"
                                     "source/latex/gamebooklib/"
                                     "tex/latex/gamebooklib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0j85xsvsw6xlkjr6z1qrbsld4kddhbcrbbsw9ci6azr6w47bh5vd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gamebooklib")
    (synopsis "Macros for setting numbered entries in shuffled order")
    (description
     "This package provides macros and environments to allow the user to
typeset a series of cross-referenced, numbered entries, shuffled into random
order, to produce an interactive novel or @dfn{gamebook}.  This allows entries
to be written in natural order and shuffled automatically into a repeatable
non-linear order.  Limited support is provided for footnotes to appear at the
natural position: the end of each entry, or the end of each page, whichever is
closest to the footnote mark.

This is unrelated to the @code{gamebook} package which is more concerned with
the formatting of entries rather than their order.  The two packages can be
used together or separately.")
    (license license:lppl1.3+)))

(define-public texlive-gammas
  (package
    (name "texlive-gammas")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/gammas/" "doc/latex/gammas/"
                                     "tex/latex/gammas/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jj8lbwlydsih01d637zxpj97ncd44qmf7azgpzn77s8fi760p8n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gammas")
    (synopsis "Template for the @emph{GAMM Archive for Students}")
    (description
     "This is the official document class for typesetting journal articles for
@emph{GAMM Archive for Students}, the open-access online journal run by the
@acronym{GAMM, Gesellschaft fur angewandte Mathematik und Mechanik} Juniors.")
    (license license:lppl1.3c)))

(define-public texlive-garamond-libre
  (package
    (name "texlive-garamond-libre")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/garamond-libre/"
                                     "fonts/enc/dvips/garamond-libre/"
                                     "fonts/map/dvips/garamond-libre/"
                                     "fonts/opentype/public/garamond-libre/"
                                     "fonts/tfm/public/garamond-libre/"
                                     "fonts/type1/public/garamond-libre/"
                                     "fonts/vf/public/garamond-libre/"
                                     "tex/latex/garamond-libre/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mmfxpdy2r5wd51b8f2l0qb7d6nncypzfs4bmimcm68s4l0rzsw4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/garamond-libre")
    (synopsis "Garamond Libre font face")
    (description
     "Garamond Libre is an old-style font family.  It is a true Garamond,
i.e., it is based off the designs of 16th-century French engraver Claude
Garamond (also spelled Garamont).  The Roman design is Garamond's; the italics
are from a design by Robert Granjon.  The upright Greek font is after a design
by Firmin Didot; the italic Greek font is after a design by Alexander Wilson.
The font family includes support for Latin, Greek (monotonic and polytonic)
and Cyrillic scripts, as well as small capitals, old-style figures, superior
and inferior figures, historical ligatures, Byzantine musical symbols, the IPA
and swash capitals.")
    (license (list license:expat license:lppl))))

(define-public texlive-garamond-math
  (package
    (name "texlive-garamond-math")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/garamond-math/"
                                     "fonts/opentype/public/garamond-math/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ay8qmcn8glzn0bpg4qqs3k6dr9h7lljal239qvxfvg1fzj76h4n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/garamond-math")
    (synopsis "OTF math font matching EB Garamond")
    (description
     "Garamond-Math is an OpenType math font matching EB Garamond (Octavio
Pardo) and EB Garamond (Georg Mayr-Duffner).  Many mathematical symbols are
derived from other fonts, others are made from scratch.")
    (license license:silofl1.1)))

(define-public texlive-gastex
  (package
    (name "texlive-gastex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gastex/" "dvips/gastex/"
                                     "tex/latex/gastex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l56wi6z5zm7sks2pa3yvamkfxsz53ziprnpr0ay141z0l8bd3rl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gastex")
    (synopsis "Graphs and Automata Simplified in TeX")
    (description
     "GasTeX is a set of LaTeX macros which enable the user to draw graphs, automata,
nets, diagrams, etc., very easily, in the LaTeX @code{picture} environment.")
    (license license:lppl)))

(define-public texlive-gb4e
  (package
    (name "texlive-gb4e")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gb4e/" "tex/latex/gb4e/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pi6n59v8vrrm2qaff8z28kwb0xa6nykgrfi9r0lxc8f1d2r5k7f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gb4e")
    (synopsis "Linguistic tools")
    (description
     "This package provides an environment for linguistic examples, tools for
glosses, and various other goodies.")
    (license license:lppl1.2+)))

(define-public texlive-gbt7714
  (package
    (name "texlive-gbt7714")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/gbt7714/" "doc/bibtex/gbt7714/"
                                     "source/bibtex/gbt7714/"
                                     "tex/latex/gbt7714/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pmkbh0axh0qnc08fjn5g7pbw59n543siy4l9q3bihnyid11i5qp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-bibtex texlive-natbib texlive-url))
    (home-page "https://ctan.org/pkg/gbt7714")
    (synopsis "China's bibliography style standard GB/T 7714-2015 for BibTeX")
    (description
     "The package provides a BibTeX implementation for the Chinese national
bibliography style standard GB/T 7714-2015.  It consists of two @file{.bst}
files for numerical and author-year styles as well as a LaTeX package which
provides the citation style defined in the standard.

The package is compatible with @code{natbib} and supports language
detection (Chinese and English) for each biblilography entry.")
    (license license:lppl1.3c)))

(define-public texlive-gchords
  (package
    (name "texlive-gchords")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gchords/" "tex/latex/gchords/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wchfk25v6rh5nffjyn8bypwjsqc9pi2rjrw3np65a0sxxc0sl1v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gchords")
    (synopsis "Typeset guitar chords")
    (description
     "This package provides a LaTeX package for typesetting of guitar chord
diagrams, including options for chord names, finger numbers and typesetting
above lyrics.  The bundle also includes a TCL script (@file{chordbox.tcl})
that provides a graphical application which creates LaTeX files that use
@file{gchords.sty}.")
    (license license:gpl3+)))

(define-public texlive-gene-logic
  (package
    (name "texlive-gene-logic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gene-logic/"
                                     "tex/latex/gene-logic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13nibrf1f1w92ia7fj8yfa44w9c5wiyy1ndaby5p6bbjdjcxhyv9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gene-logic")
    (synopsis "Typeset logic formulae, etc")
    (description
     "The package provides a facility to typeset certain logic formulae.  It
provides an environment like @code{eqnarray}, a @code{newtheorem}-like
environment (NewTheorem), and several macros.")
    (license license:isc)))

(define-public texlive-genealogy
  (package
    (name "texlive-genealogy")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/genealogy/"
                                     "fonts/source/public/genealogy/"
                                     "fonts/tfm/public/genealogy/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "155ifff77s5cwjk1gkib7gcdx1mcrzzbca35mm8f9w5rzg1d5x7k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/genealogy")
    (synopsis "Compilation of genealogy fonts")
    (description
     "This package provides a simple compilation of the genealogical symbols
found in the @code{wasy} and @code{gen} fonts, adding the male and female
symbols to Knuth's @code{gen} font, and so avoiding loading two fonts when you
need only genealogical symbols.  The font is distributed as Metafont source.")
    (license license:lppl)))

(define-public texlive-geradwp
  (package
    (name "texlive-geradwp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/geradwp/" "source/latex/geradwp/"
                                     "tex/latex/geradwp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g2kh2wdlf6y8wvs7r1zl2ws8ysrjzsk1k0032jci8ik9kx9wlg9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/geradwp")
    (synopsis "Document class for the @emph{Cahiers du GERAD} series")
    (description
     "This package provides the @code{geradwp} class, a class based on
@code{article} and compatible with LaTeX.  With this class, researchers at
GERAD will be able to write their working paper while complying to all the
presentation standards required by the @emph{Cahiers du GERAD} series.")
    (license license:lppl1.3c)))

(define-public texlive-geschichtsfrkl
  (package
    (name "texlive-geschichtsfrkl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/geschichtsfrkl/"
                                     "source/latex/geschichtsfrkl/"
                                     "tex/latex/geschichtsfrkl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mplym0rkfl8pxzw31m1p117pbfz1s59180bhbwi2wgj4225p4w7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/geschichtsfrkl")
    (synopsis "BibLaTeX style for historians")
    (description
     "The package provides a BibLaTeX style, (mostly) meeting the requirements
of the History Faculty of the University of Freiburg (Germany).")
    (license license:lppl)))

(define-public texlive-gfdl
  (package
    (name "texlive-gfdl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gfdl/" "source/latex/gfdl/"
                                     "tex/latex/gfdl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yiyhks3097sz686sar1jnkska669hp7v2sv1fm7n0d4j00zm816"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gfdl")
    (synopsis "Support for using GFDL in LaTeX")
    (description
     "The @acronym{GFDL, GNU Free Documentation License} is a popular license
used for programming manuals, documentations and various other textual works
too, but using this license with LaTeX is not very convenient.  This package
aims to help users in easily using the license without violating any rules of
the license.  With a handful of commands, users can rest assured that their
document will be perfectly licensed under GFDL.")
    (license (list license:gpl3+ license:fdl1.3+))))

(define-public texlive-gfsartemisia
  (package
    (name "texlive-gfsartemisia")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/gfsartemisia/"
                                     "fonts/afm/public/gfsartemisia/"
                                     "fonts/enc/dvips/gfsartemisia/"
                                     "fonts/map/dvips/gfsartemisia/"
                                     "fonts/opentype/public/gfsartemisia/"
                                     "fonts/tfm/public/gfsartemisia/"
                                     "fonts/type1/public/gfsartemisia/"
                                     "fonts/vf/public/gfsartemisia/"
                                     "tex/latex/gfsartemisia/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09kk65sn5wj70dksrywszdbwg2gg9wzdy9m25xj09d8k7hdirayn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gfsartemisia")
    (synopsis "Modern Greek font design")
    (description
     "GFS Artemisia is a relatively modern font, designed as a general purpose
font in the same sense as Times is nowadays treated.  The font supports the
Greek and Latin alphabets.  LaTeX support is provided, using the OT1, T1 and
LGR encodings.")
    (license (list license:silofl1.1 license:lppl1.0+))))

(define-public texlive-gfsbodoni
  (package
    (name "texlive-gfsbodoni")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/gfsbodoni/"
                                     "fonts/afm/public/gfsbodoni/"
                                     "fonts/enc/dvips/gfsbodoni/"
                                     "fonts/map/dvips/gfsbodoni/"
                                     "fonts/opentype/public/gfsbodoni/"
                                     "fonts/tfm/public/gfsbodoni/"
                                     "fonts/type1/public/gfsbodoni/"
                                     "fonts/vf/public/gfsbodoni/"
                                     "tex/latex/gfsbodoni/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a4l6ijf7lqb8g7cz1fly3c73aq14pybr0cvpn86lsw3sg7cy9jk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gfsbodoni")
    (synopsis "Greek and Latin font based on Bodoni")
    (description
     "Bodoni's Greek fonts in the 18th century broke, for the first time,
with the Byzantine cursive tradition of Greek fonts.  GFS Bodoni resurrects
his work for general use.  The font family supports both Greek and Latin
letters.  LaTeX support of the fonts is provided, offering OT1, T1 and LGR
encodings.  The fonts themselves are provided in Adobe Type 1 and OpenType
formats.")
    (license license:silofl1.1)))

(define-public texlive-gfscomplutum
  (package
    (name "texlive-gfscomplutum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/gfscomplutum/"
                                     "fonts/afm/public/gfscomplutum/"
                                     "fonts/enc/dvips/gfscomplutum/"
                                     "fonts/map/dvips/gfscomplutum/"
                                     "fonts/opentype/public/gfscomplutum/"
                                     "fonts/tfm/public/gfscomplutum/"
                                     "fonts/type1/public/gfscomplutum/"
                                     "fonts/vf/public/gfscomplutum/"
                                     "tex/latex/gfscomplutum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "018hpaijnky23brhqmqsq2zm7h5w4y42vdfawba62qlz5m1zijn1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gfscomplutum")
    (synopsis "Greek font with a long history")
    (description
     "GFS Complutum derives from a minuscule-only font cut in the 16th
century.  An unsatisfactory set of majuscules were added in the early 20th
century, but its author died before he could complete the revival of the font.
The Greek Font Society has released this version, which has a new set of
majuscules.")
    (license license:silofl1.1)))

(define-public texlive-gfsdidot
  (package
    (name "texlive-gfsdidot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/gfsdidot/"
                                     "fonts/afm/public/gfsdidot/"
                                     "fonts/enc/dvips/gfsdidot/"
                                     "fonts/map/dvips/gfsdidot/"
                                     "fonts/opentype/public/gfsdidot/"
                                     "fonts/tfm/public/gfsdidot/"
                                     "fonts/type1/public/gfsdidot/"
                                     "fonts/vf/public/gfsdidot/"
                                     "tex/latex/gfsdidot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sh1xv2fvb0y9vfzl0wl8fps4474fkvvh82fbqgfm83ri8h8p4ck"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gfsdidot")
    (synopsis "Greek font based on Didot's work")
    (description
     "The design of Didot's 1805 Greek typeface was influenced by the
neoclassical ideals of the late 18th century.  The font was brought to Greece
at the time of the 1821 Greek Revolution, by Didot's son, and was very widely
used.  The font supports the Greek alphabet, and is accompanied by a matching
Latin alphabet based on Zapf's Palatino.  LaTeX support is provided, using the
OT1, T1, TS1, and LGR encodings.")
    (license license:silofl1.1)))

(define-public texlive-gfsdidotclassic
  (package
    (name "texlive-gfsdidotclassic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/gfsdidotclassic/"
                                     "fonts/opentype/public/gfsdidotclassic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cpsmgrq2x6ym9xb63msvm6pc4p2qyi2k40hmxmzhi979ch8gkaz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gfsdidotclassic")
    (synopsis "Classic version of GFSDidot")
    (description
     "This is the classic version of GFSDidot provided for Unicode TeX
engines.")
    (license license:silofl1.1)))

(define-public texlive-gfsneohellenic
  (package
    (name "texlive-gfsneohellenic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/gfsneohellenic/"
                                     "fonts/afm/public/gfsneohellenic/"
                                     "fonts/enc/dvips/gfsneohellenic/"
                                     "fonts/map/dvips/gfsneohellenic/"
                                     "fonts/opentype/public/gfsneohellenic/"
                                     "fonts/tfm/public/gfsneohellenic/"
                                     "fonts/type1/public/gfsneohellenic/"
                                     "fonts/vf/public/gfsneohellenic/"
                                     "tex/latex/gfsneohellenic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "109zgqj63ffryy42zi64p6r37jmzj5ma3d8bgn7mz3gc2scr1bpc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gfsneohellenic")
    (synopsis "Font in the Neo-Hellenic style")
    (description
     "The Neo-Hellenic style evolved in academic circles in the 19th and 20th
century; the present font follows a cut commissioned from Monotype in 1927.
The font supports both Greek and Latin characters, and has been adjusted to
work well with the @code{cmbright} fonts for mathematics support.  LaTeX
support of the fonts is provided, offering OT1, T1 and LGR encodings.")
    (license license:silofl1.1)))

(define-public texlive-gfsneohellenicmath
  (package
    (name "texlive-gfsneohellenicmath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/gfsneohellenicmath/"
                                     "fonts/opentype/public/gfsneohellenicmath/"
                                     "tex/latex/gfsneohellenicmath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08yzv6qww3qvbg8bp4k8ibd46j1a41ysw4k8fi5nazchf3py7qb0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gfsneohellenicmath")
    (synopsis "Math font in the Neo-Hellenic style")
    (description
     "The GFSNeohellenic font, a historic font first designed by Victor
Scholderer, now has native support for Mathematics.  A useful application is
in Beamer documents since this is a sans math font.")
    (license license:silofl1.1)))

(define-public texlive-gfssolomos
  (package
    (name "texlive-gfssolomos")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/gfssolomos/"
                                     "fonts/afm/public/gfssolomos/"
                                     "fonts/enc/dvips/gfssolomos/"
                                     "fonts/map/dvips/gfssolomos/"
                                     "fonts/opentype/public/gfssolomos/"
                                     "fonts/tfm/public/gfssolomos/"
                                     "fonts/type1/public/gfssolomos/"
                                     "fonts/vf/public/gfssolomos/"
                                     "tex/latex/gfssolomos/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zjbmnkfnaiq7pmpv0xhp5vag2dww70049knf759lf2s0ygnmaaa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gfssolomos")
    (synopsis "Greek-alphabet font")
    (description
     "Solomos is a font which traces its descent from
a calligraphically-inspired font of the mid-19th century.  LaTeX support, for
use with the LGR encoding only, is provided.")
    (license license:silofl1.1)))

(define-public texlive-ghab
  (package
    (name "texlive-ghab")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ghab/"
                                     "fonts/source/public/ghab/"
                                     "tex/latex/ghab/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jknnlcigk6aa48xqvxd67015fxjlmmp36p52c95xrii4lv3m0zk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ghab")
    (synopsis "Typeset ghab boxes in LaTeX")
    (description
     "The package defines a command @code{\\darghab} that will typeset its
argument in a box with a decorated frame.  The width of the box may be set
using an optional argument.")
    (license license:lppl)))

(define-public texlive-ghsystem
  (package
    (name "texlive-ghsystem")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ghsystem/" "tex/latex/ghsystem/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a8plly9zcbym67yzk6rp5mlk12lngmhdx6c3riar2w86nlvq55l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ghsystem")
    (synopsis "Globally harmonised system of chemical (etc) naming")
    (description
     "The package provides the means to typeset all the hazard and
precautionary statements and pictograms in a straightforward way.  The
statements are taken from EU regulation 1272/2008.")
    (license license:lppl1.3+)))

(define-public texlive-gillcm
  (package
    (name "texlive-gillcm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gillcm/"
                                     "fonts/map/dvips/gillcm/"
                                     "fonts/tfm/public/gillcm/"
                                     "fonts/vf/public/gillcm/"
                                     "tex/latex/gillcm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cz6aqcq2fv6hb2yv2ymc3j6myb8y73gyqbyigabwc909fmh5qdm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gillcm")
    (synopsis "Alternative unslanted italic Computer Modern fonts")
    (description
     "This is a demonstration of the use of virtual fonts for unusual effects:
the package implements unslanted italic Computer Modern fonts.")
    (license license:bsd-3)))

(define-public texlive-gillius
  (package
    (name "texlive-gillius")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/gillius/"
                                     "fonts/enc/dvips/gillius/"
                                     "fonts/map/dvips/gillius/"
                                     "fonts/opentype/arkandis/gillius/"
                                     "fonts/tfm/arkandis/gillius/"
                                     "fonts/type1/arkandis/gillius/"
                                     "fonts/vf/arkandis/gillius/"
                                     "tex/latex/gillius/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0f2jr70ab5qnmla1n7iwhiw9x9q5fdzw9lcgjzji8rdqlsgq1451"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gillius")
    (synopsis "Gillius fonts with LaTeX support")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the Gillius and Gillius No.@: 2 families of sans serif fonts and condensed
versions of them, designed by Hirwen Harendal.")
    (license (list license:gpl2+ license:lppl))))

(define-public texlive-glosmathtools
  (package
    (name "texlive-glosmathtools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/glosmathtools/"
                                     "tex/latex/glosmathtools/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rw194qxxf38fp1xczzjvsa6vb0jxz88cgc2s5fqx2k4fwg989kh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/glosmathtools")
    (synopsis
     "Mathematical nomenclature tools based on the @code{glossaries} package")
    (description
     "This package can be used to generate a mathematical nomenclature (also
called list of symbols or notation).  It is based on the @code{glossaries}
package.  Its main features are:

@itemize
@item symbol categories (e.g., latin, greek),
@item automatic but customizable symbol sorting,
@item easy subscript management,
@item easy accentuation management,
@item abbreviation support (with first use definition),
@item bilingual nomenclatures (for bilingual documents),
@item bilingual abbreviations.
@end itemize")
    (license license:lppl1.3c)))

(define-public texlive-gloss-occitan
  (package
    (name "texlive-gloss-occitan")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gloss-occitan/"
                                     "source/latex/gloss-occitan/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h9w7gk7klwhackx30c7wa2xv23jy2r75zvgs22crhv40h8blj3f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gloss-occitan")
    (synopsis "Polyglossia support for Occitan")
    (description
     "This package provides Occitan language description file for
Polyglossia.")
    (license license:lppl1.3+)))

(define-public texlive-glossaries
  (package
    (name "texlive-glossaries")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/glossaries/"
                                     "doc/man/man1/makeglossaries-lite.1"
                                     "doc/man/man1/makeglossaries-lite.man1.pdf"
                                     "doc/man/man1/makeglossaries.1"
                                     "doc/man/man1/makeglossaries.man1.pdf"
                                     "scripts/glossaries/"
                                     "source/latex/glossaries/"
                                     "tex/latex/glossaries/base/"
                                     "tex/latex/glossaries/expl/"
                                     "tex/latex/glossaries/rollback/"
                                     "tex/latex/glossaries/styles/"
                                     "tex/latex/glossaries/test-entries/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pnmvrs927p35b3p7kbqvrrhz244aw44y1ziv7w7616igl1bblnx"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts #~(list "makeglossaries" "makeglossaries-lite.lua")))
    (inputs (list perl))
    (propagated-inputs
     (list texlive-amsmath
           texlive-datatool
           texlive-etoolbox
           texlive-mfirstuc
           texlive-tracklang
           texlive-xfor
           texlive-xkeyval))
    (home-page "https://ctan.org/pkg/glossaries")
    (synopsis "Create glossaries and lists of acronyms")
    (description
     "The glossaries package supports acronyms and multiple glossaries, and has
provision for operation in several languages (using the facilities of either
Babel or Polyglossia).  New entries are defined to have a name and description
(and optionally an associated symbol).  Support for multiple languages is
offered, and plural forms of terms may be specified.  An additional package,
@code{glossaries-accsupp}, can make use of the @code{accsupp} package
mechanisms for accessibility support for PDF files containing glossaries.  The
user may define new glossary styles, and preambles and postambles can be
specified.  There is provision for loading a database of terms, but only terms
used in the text will be added to the relevant glossary.

The package uses an indexing program to provide the actual glossary; either
MakeIndex or Xindy may serve this purpose, and a Perl script is provided to
serve as interface.  The package supersedes @code{glossary} package (which is
now obsolete).")
    (license license:lppl1.3+)))

(define-public texlive-gmverse
  (package
    (name "texlive-gmverse")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gmverse/" "tex/latex/gmverse/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13vs1w9pfl4is5f5papwqqm83kmb17d4z7gv8nxkswnav9v5cl56"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gmverse")
    (synopsis "Package for typesetting (short) poems")
    (description
     "This package provides a redefinition of the @code{verse} environment to
make the @code{\\\\} command optional for line ends and to give it
a possibility of optical centering and right-hanging alignment of lines broken
because of length.")
    (license license:lppl)))

(define-public texlive-gnu-freefont
  (package
    (name "texlive-gnu-freefont")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/gnu-freefont/"
                                     "fonts/opentype/public/gnu-freefont/"
                                     "fonts/truetype/public/gnu-freefont/"
                                     "source/fonts/gnu-freefont/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14bq8i7n6zhy8352pmhd5d9l4p152c6bgarz17wfp2p00kzs47aw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gnu-freefont")
    (synopsis "Unicode font, with rather wide coverage")
    (description
     "The package provides a set of outline (i.e., OpenType} fonts covering as
much as possible of the Unicode character set.  The set consists of three
typefaces: one monospaced and two proportional (one with uniform and one with
modulated stroke).")
    (license license:gpl3)))

(define-public texlive-go
  (package
    (name "texlive-go")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/go/" "fonts/source/public/go/"
                                     "fonts/tfm/public/go/" "source/fonts/go/"
                                     "tex/latex/go/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cvxfz9m7fx62iiz00f7qlywrmwwnpk0xzlyv63c90ji9xzfawcv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/go")
    (synopsis "Fonts and macros for typesetting go games")
    (description
     "The macros provide for nothing more complicated than the standard
19x19 board; the fonts are written in Metafont.")
    (license license:public-domain)))

(define-public texlive-gofonts
  (package
    (name "texlive-gofonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/gofonts/"
                                     "fonts/enc/dvips/gofonts/"
                                     "fonts/map/dvips/gofonts/"
                                     "fonts/tfm/bh/gofonts/"
                                     "fonts/truetype/bh/gofonts/"
                                     "fonts/type1/bh/gofonts/"
                                     "fonts/vf/bh/gofonts/"
                                     "tex/latex/gofonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07ysxm10xwg6cc781gdppidq1s87bqli4x6shkarjl29pxcncn61"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gofonts")
    (synopsis "GoSans and GoMono fonts with LaTeX support")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the GoSans and GoMono families of fonts designed by the Bigelow & Holmes
foundry.  GoSans is available in three weights: Regular, Medium, and
Bold (with corresponding italics).  GoMono is available in regular and bold,
with italics.")
    (license (list license:bsd-3 license:lppl))))

(define-public texlive-gost
  (package
    (name "texlive-gost")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/gost/" "bibtex/csf/gost/"
                                     "doc/bibtex/gost/" "source/bibtex/gost/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rsqk4r1r741ggvpgg7g51knlaqrrdq9g8yiix66vx3n5v1arp26"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gost")
    (synopsis "BibTeX styles to format according to GOST")
    (description
     "This package provides BibTeX styles to format bibliographies in English,
Russian or Ukrainian according to GOST 7.0.5-2008 or GOST 7.1-2003.  Both
8-bit and Unicode (UTF-8) versions of each @code{BibTeX} style, in each case
offering a choice of sorted and unsorted.  Further, a set of three
styles (which do not conform to current standards) are retained for backwards
compatibility.")
    (license license:lppl1.3c)))

(define-public texlive-gothic
  (package
    (name "texlive-gothic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/gothic/"
                                     "fonts/source/public/gothic/"
                                     "fonts/tfm/public/gothic/"
                                     "source/fonts/gothic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08hqp2a0ch67d38p2jca6cvx72vc6dagb04a9w6ff7dniqp6gps2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    ;; FIXME: Font metrics generation fails with "! Strange path (turning
    ;; number is zero)." error.
    (arguments
     (list #:phases
           #~(modify-phases %standard-phases
               (delete 'generate-font-metrics))))
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/gothic")
    (synopsis "Collection of old German-style fonts")
    (description
     "This package provides a collection of fonts that reproduce those used in
old German printing and handwriting.  The set comprises Gothic, Schwabacher
and Fraktur fonts, a pair of handwriting fonts, Sutterlin and Schwell, and
a font containing decorative initials.  In addition, there are two re-encoding
packages for Haralambous's fonts, providing T1, using virtual fonts, and OT1
and T1, using Metafont.")
    ;; This is a collection of packages, with various licenses.
    (license (list license:lppl1.2+ license:lppl1.3c license:public-domain))))

(define-public texlive-gotoh
  (package
    (name "texlive-gotoh")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gotoh/" "source/latex/gotoh/"
                                     "tex/latex/gotoh/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h08ygzlhv1mpd27yfv8slvgfwa250z7alpv99p6768jafysp3k9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gotoh")
    (synopsis "Implementation of the Gotoh sequence alignment algorithm")
    (description
     "This package calculates biological sequence alignment with the Gotoh algorithm.
The package also provides an interface to control various settings including
algorithm parameters.")
    (license license:expat)))

(define-public texlive-gradstudentresume
  (package
    (name "texlive-gradstudentresume")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gradstudentresume/"
                                     "tex/latex/gradstudentresume/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jimvivx5vf1jy7yszvx2zbf13r0brqc0avz8lcx1rsqa3d7rjcn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gradstudentresume")
    (synopsis "Generic template for graduate student resumes")
    (description
     "The package offers a template for graduate students writing an academic
CV.  The goal is to create a flexible template that can be customized based on
each specific individual's needs.")
    (license license:lppl1.3+)))

(define-public texlive-grant
  (package
    (name "texlive-grant")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/grant/" "source/latex/grant/"
                                     "tex/latex/grant/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cihhr3fqjbn2grkps5wl6aqx19s78vgklmriw2jqg27fqgv5q2p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/grant")
    (synopsis "Classes for formatting federal grant proposals")
    (description
     "This package provides LaTeX classes for formatting federal grant
proposals:
@itemize
@item grant: base class for formatting grant proposals;
@item grant-arl: Army Research Laboratory;
@item grant-darpa: Defense Advanced Research Projects Agency;
@item grant-doe: Department of Energy;
@item grant-nih: National Institutes of Health;
@item grant-nrl: Naval Research Laboratory;
@item grant-nsf: National Science Foundation;
@item grant-onr: Office of Naval Research.
@end itemize")
    (license license:expat)))

(define-public texlive-greenpoint
  (package
    (name "texlive-greenpoint")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/greenpoint/"
                                     "fonts/source/public/greenpoint/"
                                     "fonts/tfm/public/greenpoint/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1y5an7lgx975ppb8s1abx494s4m115k137f82hy08iwdx9l1plj5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/greenpoint")
    (synopsis "Green Point logo")
    (description
     "This package provides a Metafont-implementation of the logo commonly
known as @emph{Der Grune Punkt} (``The Green Point'').  In Austria, it can be
found on nearly every bottle.  It should not be confused with the Recycle
logo.")
    (license license:gpl3+)))

(define-public texlive-gregoriotex
  (package
    (name "texlive-gregoriotex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/gregoriotex/"
                                     "fonts/source/gregoriotex/"
                                     "fonts/truetype/public/gregoriotex/"
                                     "scripts/gregoriotex/"
                                     "source/luatex/gregoriotex/"
                                     "tex/lualatex/gregoriotex/"
                                     "tex/luatex/gregoriotex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lnpq6rfdb6dg543cmbsm817ziim6arxnzxzbn0wn8i8aw681idr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-gregoriotex-bin))
    (home-page "https://ctan.org/pkg/gregoriotex")
    (synopsis "Engraving gregorian chant scores")
    (description
     "Gregorio is a software application for engraving gregorian chant scores
on a computer.  Gregorio's main job is to convert a gabc file (simple text
representation of a score) into a GregorioTeX file, which makes TeX able to
create a PDF of your score.")
    (license license:gpl3)))

(define-public texlive-gregoriotex-bin
  (package
    (inherit texlive-bin)
    (name "texlive-gregoriotex-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("gregorio"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-gregorio" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/gregorio"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/gregorio"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list texlive-libkpathsea))
    (propagated-inputs '())
    (home-page (package-home-page texlive-gregoriotex))
    (synopsis "Binary for @code{texlive-gregoriotex}")
    (description
     "This package provides the binary for @code{texlive-gregoriotex}.")
    (license (package-license texlive-gregoriotex))))

(define-public texlive-grotesq
  (package
    (name "texlive-grotesq")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/grotesq/"
                                     "fonts/afm/urw/grotesq/"
                                     "fonts/map/dvips/grotesq/"
                                     "fonts/tfm/urw/grotesq/"
                                     "fonts/type1/urw/grotesq/"
                                     "fonts/vf/urw/grotesq/"
                                     "tex/latex/grotesq/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12q0n6z442j725drp3919k2qk7kg9fas4cqz415a8lj1nmvg60i4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/urw-grotesq")
    (synopsis "URW Grotesq font pack for LaTeX")
    (description
     "The directory contains a copy of the Type 1 font URW Grotesq 2031
Bold, with supporting files for use with (La)TeX.")
    (license license:gpl3+)))

(define-public texlive-grundgesetze
  (package
    (name "texlive-grundgesetze")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/grundgesetze/"
                                     "source/latex/grundgesetze/"
                                     "tex/latex/grundgesetze/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hpl336bn33qjmq2bhqn94fjdxlcxs0lxm4sdr124dnagdnksl4n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/grundgesetze")
    (synopsis "Typeset Frege's @emph{Grundgesetze der Arithmetik}")
    (description
     "The package defines maths mode commands for typesetting Gottlob Frege's
concept-script in the style of his @emph{Grundgesetze der Arithmetik} (Basic
Laws of Arithmetic).")
    (license license:gpl2)))

(define-public texlive-gsemthesis
  (package
    (name "texlive-gsemthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gsemthesis/"
                                     "source/latex/gsemthesis/"
                                     "tex/latex/gsemthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wwd6pddxb91gj6jr6zc0xy0sr0s0mbdjzyw856w9ds0lp0k6cl9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gsemthesis")
    (synopsis "Geneva School of Economics and Management PhD thesis format")
    (description
     "The class provides a PhD thesis template for the @acronym{GSEM,
Geneva School of Economics and Management}, University of Geneva, Switzerland.
The class provides utilities to easily set up the cover page, the front matter
pages, the page headers, etc., conformant to the official guidelines of the
GSEM Faculty for writing PhD dissertations.")
    (license license:lppl1.3+)))

(define-public texlive-gtrcrd
  (package
    (name "texlive-gtrcrd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gtrcrd/" "tex/latex/gtrcrd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ndnzkm84ynn3wcnfg6j6fcl87wmd3g9w5d17g1z6qp340asrkp9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gtrcrd")
    (synopsis "Add chords to lyrics")
    (description
     "The package provides the means to specify guitar chords to be played
with each part of the lyrics of a song.  The syntax of the macros reduces the
chance of failing to provide a chord where one is needed, and the structure of
the macros ensures that the chord specification appears immediately above the
start of the lyric.")
    (license license:lppl1.3+)))

(define-public texlive-gu
  (package
    (name "texlive-gu")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gu/" "tex/latex/gu/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13gw8gk03s3ha7xwn6vfix7w50if3gvlqywn1l6z5zi3qbfaapvr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gu")
    (synopsis "Typeset crystallographic group-subgroup-schemes")
    (description
     "The package simplifies typesetting of simple crystallographic
group-subgroup-schemes in the Barnighausen formalism.  It defines a new
environment @code{stammbaum}, wherein all elements of the scheme are defined.
Afterwards all necessary dimensions are calculated and the scheme is drawn.
Currently two steps of symmetry reduction are supported.")
    (license license:lppl)))

(define-public texlive-gudea
  (package
    (name "texlive-gudea")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/gudea/"
                                     "fonts/enc/dvips/gudea/"
                                     "fonts/map/dvips/gudea/"
                                     "fonts/tfm/public/gudea/"
                                     "fonts/type1/public/gudea/"
                                     "fonts/vf/public/gudea/"
                                     "tex/latex/gudea/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kj53idgxyqwishg0vibhhrj443016z61c0jl7rx91a508vbwbn2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gudea")
    (synopsis "Gudea font face with support for LaTeX and pdfLaTeX")
    (description
     "This package provides the Gudea family of fonts designed by Agustina
Mingote, with support for LaTeX and pdfLaTeX.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-guide-to-latex
  (package
    (name "texlive-guide-to-latex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/guide-to-latex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wc5pclv27af2zr6kjjahjzxxlab31d8970jvxr9lxiqllvkxyab"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/guide-to-latex")
    (synopsis "Examples and more from @emph{Guide to LaTeX}, by Kopka and Daly")
    (description
     "This package contains material presented in the book @emph{Guide to LaTeX},
4th edition, by Helmut Kopka and Patrick W. Daly as code, sample figures,
processed files, as well as solutions to the exercises.")
    (license license:lppl1.3c+)))

(define-public texlive-guitar
  (package
    (name "texlive-guitar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/guitar/" "source/latex/guitar/"
                                     "tex/latex/guitar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rywmlz59mjm59n4607qk9fa62w1c9qv9iyyja8k9vb4pc9yijrc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/guitar")
    (synopsis "Guitar chords and song texts")
    (description
     "This package provides (La)TeX macros for typesetting guitar chords over
song texts.  Note that this package only places arbitrary TeX code over the
lyrics.  To typeset the chords graphically (and not only by name), the author
recommends use of an additional package such as @code{gchords}.")
    (license license:lppl1.3+)))

(define-public texlive-guitarchordschemes
  (package
    (name "texlive-guitarchordschemes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/guitarchordschemes/"
                                     "tex/latex/guitarchordschemes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "189xx0y549ss4ip8x2f1rpcqyad5njrni785sxmy2cghqbdcgzzn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/guitarchordschemes")
    (synopsis "Guitar chord and scale tablatures")
    (description
     "This package provides two commands (@code{\\chordscheme} and
@code{\\scales}).  With those commands it is possible to draw schematic
diagrams of guitar chord tablatures and scale tablatures.  Both commands know
a range of options that allow wide customization of the output.")
    (license license:lppl1.3+)))

(define-public texlive-guitartabs
  (package
    (name "texlive-guitartabs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/guitartabs/"
                                     "tex/latex/guitartabs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hk5yl7za7mm6cpg9g4z5wnq4m2nwm41sq8w7m8ic38sr85n67zz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/guitartabs")
    (synopsis "Class for drawing guitar tablatures easily")
    (description
     "This package provides is a simple LaTeX2e class that allows guitarists
to create basic guitar tablatures using LaTeX.")
    (license license:lppl1.3c)))

(define-public texlive-guitlogo
  (package
    (name "texlive-guitlogo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/guitlogo/"
                                     "source/latex/guitlogo/"
                                     "tex/latex/guitlogo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fwp3w5b51qs9jr9xq0hl0hsqbx7dkj7qgwjpay88sflycv3qpba"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/guitlogo")
    (synopsis "Macros for typesetting the GuIT logo")
    (description
     "This package provides some commands useful to correctly write the logo
of @emph{Gruppo Utilizzatori Italiani di TeX} (Italian TeX User Group), using
the default document color or any other color the user may ever choose, in
conformity with the logo's scheme as seen on the group's website
@url{https://www.guitex.org}.  Likewise, commands are provided that simplify
the writing of the GuIT acronym's complete expansion, of the addresses of the
group's internet site and public forum, and the meeting GuITmeeting and the
magazine @emph{Ars TeXnica}'s logo.  Optionally, using @code{hyperref}, the
outputs of the above cited commands can become hyperlinks to the group's
website @url{https://www.guitex.org}.  The Documentation is available in
Italian only.")
    (license license:lppl1.3a)))

(define-public texlive-gustlib
  (package
    (name "texlive-gustlib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/gustlib/" "bibtex/bst/gustlib/"
                                     "doc/plain/gustlib/" "tex/plain/gustlib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jfmsx5zw9yb8fkhw4fad82m48n7fs1inmx471mr7ys0i7y1l92v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gustlib")
    (synopsis "Plain macros for much core and extra functionality, from GUST")
    (description
     "This package includes Plain TeX macros adding extra functionalities.
This comprises bibliography support, token manipulation, cross-references,
verbatim, determining length of a paragraph's last line, multicolumn output,
Polish bibliography and index styles, prepress and color separation, graphics
manipulation, and tables.")
    (license (list license:knuth license:public-domain))))

(define-public texlive-gustprog
  (package
    (name "texlive-gustprog")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/gustprog/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07qx4xvyqb4p0cx0macjgyg0pcxgcmdxmzfsx9ah5s0dqvminwrc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gustprog")
    (synopsis "Utility programs for Polish users of TeX")
    (description
     "This package provides utility programs for Polish users of TeX.  These
programs are provided as sources, not installed in the @file{bin}
directories.")
    (license license:public-domain)))

(define-public texlive-gzt
  (package
    (name "texlive-gzt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gzt/" "source/latex/gzt/"
                                     "tex/latex/gzt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01vzqnh7fxpsd23q98n9x828lyjrvjlfkb9zv0sxydamp5qy3pn5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gzt")
    (synopsis "Bundle of classes for @emph{La Gazette des Mathematiciens}")
    (description
     "This bundle provides two classes and BibLaTeX styles for the French
journal @emph{La Gazette des Mathematiciens}: @code{gzt} for the complete
issues of the journal, aimed at the Gazette's team, @code{gztarticle},
intended for authors who wish to publish an article in the Gazette.  This
class's goals are to faithfully reproduce the layout of the Gazette, thus
enabling the authors to be able to work their document in actual conditions,
and provide a number of tools (commands and environments) to facilitate the
drafting of documents, in particular those containing mathematical formulas.")
    (license license:lppl1.3c)))

(define-public texlive-h2020proposal
  (package
    (name "texlive-h2020proposal")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/h2020proposal/"
                                     "tex/latex/h2020proposal/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fq43vpq3ixj6fc99fbmj129487xxzcmz22gisqmn469bam5qxj5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/h2020proposal")
    (synopsis "LaTeX class and template for EU H2020 RIA proposal")
    (description
     "This package consists of a class file as well as FET and ICT proposal
templates for writing EU H2020 RIA proposals and generating automatically the
many cross-referenced tables that are required.")
    (license license:gpl3)))

(define-public texlive-hacm
  (package
    (name "texlive-hacm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/hacm/"
                                     "fonts/map/dvips/hacm/"
                                     "fonts/tfm/public/hacm/"
                                     "fonts/type1/public/hacm/"
                                     "fonts/vf/public/hacm/"
                                     "tex/latex/hacm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19n0mlb96ix4vlqaw95fgwah7mbn80l6jm1dim8sigagmhh3bimd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hacm")
    (synopsis "Font support for the Arka language")
    (description
     "The package supports typesetting @emph{hacm}, the alphabet of the
constructed language Arka.  The bundle provides nine official fonts, in Adobe
Type 1 format.")
    (license license:lppl1.3+)))

(define-public texlive-hagenberg-thesis
  (package
    (name "texlive-hagenberg-thesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hagenberg-thesis/"
                                     "tex/latex/hagenberg-thesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dp2mrf4smpllrgszi0cx5w42lm144qs3jvr44h6k98ibsfxdv9h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hagenberg-thesis")
    (synopsis
     "LaTeX classes, style files and example documents for academic
manuscripts")
    (description
     "This package provides a collection of modern LaTeX classes, style files
and example documents for authoring Bachelor, master or diploma theses and
related academic manuscripts in English and German.  It includes comprehensive
tutorials (in English and German) with detailed instructions and authoring
guidelines.")
    (license license:cc-by4.0)))

(define-public texlive-hamnosys
  (package
    (name "texlive-hamnosys")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/hamnosys/"
                                     "fonts/truetype/public/hamnosys/"
                                     "source/fonts/hamnosys/"
                                     "tex/latex/hamnosys/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1iilp1npy23azk7gjb3m6g9p9f853lbpn9cvply90g2s9jdw0bd9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hamnosys")
    (synopsis "Font for sign languages")
    (description
     "The Hamburg Notation System, HamNoSys for short, is a system for the
phonetic transcription of signed languages.  This package makes HamNoSys
available in XeLaTeX and LuaLaTeX.  The package provides a Unicode font for
rendering HamNoSys symbols as well as three methods for entering them.")
    (license license:lppl1.3c)))

(define-public texlive-hands
  (package
    (name "texlive-hands")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "fonts/source/public/hands/"
                                     "fonts/tfm/public/hands/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0x0vdn7hq6k7wr7yxn8pnkvjhjq3mfl781ijrs2mpvjqygqffzag"))))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/hands")
    (synopsis "Pointing hand font")
    (description
     "This package provides right- and left-pointing hands in both
black-on-white and white-on-black realisation.  The font is distributed as
Metafont source.")
    (license license:public-domain)))

(define-public texlive-hanoi
  (package
    (name "texlive-hanoi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/plain/hanoi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09a7cv76naxzdach5507wdqnjp12amvlia7kw0jh224ydmkzfx9x"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hanoi")
    (synopsis "Tower of Hanoi in TeX")
    (description
     "The Plain TeX program (typed in the shape of the towers of Hanoi) serves
both as a game and as a TeX programming exercise.  As a game, it will solve
the towers with (up to) 15 discs.")
    (license license:public-domain)))

(define-public texlive-happy4th
  (package
    (name "texlive-happy4th")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/happy4th/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x950scxbvcgwycpakflpklc775pknjab620g099dnsfrpb76f4a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/happy4th")
    (synopsis "Firework display in obfuscated TeX")
    (description
     "The output PDF file gives an amusing display, as the reader pages
through it.")
    (license license:public-domain)))

(define-public texlive-har2nat
  (package
    (name "texlive-har2nat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/har2nat/" "tex/latex/har2nat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13akhwjx48lkch46pk2syzizham3rk81ihrzbwxsvapa1fw74dzg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/har2nat")
    (synopsis "Replace the @code{harvard} package with @code{natbib}")
    (description
     "This small package allows a LaTeX document containing the citation
commands provided by the @code{harvard} package to be compiled using the
@code{natbib} package.")
    (license license:lppl)))

(define-public texlive-harmony
  (package
    (name "texlive-harmony")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/harmony/" "tex/latex/harmony/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ky4aiv3zvykfwalf1md4lzjbr9pc14i93xsxdwl25jcsi2kvjk7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/harmony")
    (synopsis "Typeset harmony symbols, etc., for musicology")
    (description
     "The package @file{harmony.sty} helps typesetting harmony symbols for
musicology.")
    (license license:lppl)))

(define-public texlive-hanzibox
  (package
    (name "texlive-hanzibox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/hanzibox/"
                                     "source/xelatex/hanzibox/"
                                     "tex/xelatex/hanzibox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bgbybzz5h79i2l3mbjxm11x9nsxm366c6d2mha9j5qabjghakya"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ctex")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ctex))
    (home-page "https://ctan.org/pkg/hanzibox")
    (synopsis
     "Boxed Chinese characters with Pinyin above and translation below")
    (description
     "This is a LaTeX package written to simplify the input of Chinese with
Hanyu Pinyin and translation.  Hanyu Pinyin is placed above Chinese with the
@code{xpinyin} package, and the translation is placed below.  The package can
be used as a utility for learning to write and pronounce Chinese characters,
for Chinese character learning plans, presentations, exercise booklets and
other documentation work.")
    (license license:lppl1.3c)))

(define-public texlive-harvard
  (package
    (name "texlive-harvard")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/harvard/" "bibtex/bst/harvard/"
                                     "doc/latex/harvard/" "source/latex/harvard/"
                                     "tex/latex/harvard/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qcw1rrvcgcz26pwcmsfd7gs4bzlq1n4zws92xqsr5fi95pr8q7k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/harvard")
    (synopsis "Harvard citation package for use with LaTeX")
    (description
     "This is a re-implementation, for LaTeX, of the original Harvard package.
The bundle contains the LaTeX package, several BibTeX styles, and a Perl
package for use with LaTeX2HTML.

Harvard is an author-year citation style (all but the first author are
suppressed in second and subsequent citations of the same entry); the package
defines several variant styles: @file{apsr.bst} for the @emph{American
Political Science Review}; @file{agsm.bst} for Australian government
publications; @file{dcu.bst} from the Design Computing Unit of the University
of Sydney; @file{kluwer.bst}, which aims at the format preferred in Kluwer
publications; @file{nederlands.bst} which deals with sorting Dutch names with
prefixes (such as van) according to Dutch rules, together with several styles
whose authors offer no description of their behaviour.")
    (license license:lppl)))

(define-public texlive-harvmac
  (package
    (name "texlive-harvmac")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/harvmac/" "tex/plain/harvmac/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bxa9vvkg79xk3nakdc5an2py6gwbv9ml66xmz1hp1llbg3562vf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/harvmac")
    (synopsis "Macros for scientific articles")
    (description "This package provides macros for scientific articles.")
    (license license:cc-by3.0)))

(define-public texlive-havannah
  (package
    (name "texlive-havannah")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/havannah/"
                                     "source/latex/havannah/"
                                     "tex/latex/havannah/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kw71rr5jhn0gx89jynwxxgd6ddzpmr0wb5qnsh0drljmacq49ai"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/havannah")
    (synopsis "Diagrams of board positions in the games of Havannah and Hex")
    (description
     "This package defines macros for typesetting diagrams of board positions
in the games of Havannah and Hex.")
    (license license:lppl1.2+)))

(define-public texlive-hecthese
  (package
    (name "texlive-hecthese")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hecthese/"
                                     "source/latex/hecthese/"
                                     "tex/latex/hecthese/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "167bbbfnzjdw6rxvqb49szn9gf2x9v4m47yxs32ragbhzn4rvixw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hecthese")
    (synopsis "Class for dissertations and theses at HEC Montreal")
    (description
     "This package provides the @code{hecthese} class, a class based on
@code{memoir} and compatible with LaTeX.  Using this class, postgraduate
students at HEC Montreal will be able to write their dissertation or thesis
while complying with all the presentation standards required by the
University.  This class is meant to be as flexible as possible; in particular,
there are very few hard-coded features except those that take care of the
document's layout.

Dissertations and theses at HEC Montreal can be written on a per-chapter or
per-article basis.  Documents that are written on a per-article basis require
a bibliography for each of the included articles and a general bibliography
for the entire document.  The @code{hecthese} class takes care of these
requirements.")
    (license license:lppl1.3c)))

(define-public texlive-helmholtz-ellis-ji-notation
  (package
    (name "texlive-helmholtz-ellis-ji-notation")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/helmholtz-ellis-ji-notation/"
                                     "fonts/opentype/public/helmholtz-ellis-ji-notation/"
                                     "source/fonts/helmholtz-ellis-ji-notation/"
                                     "tex/latex/helmholtz-ellis-ji-notation/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d2l682v0qsh5x6ab6f0swnbb70niahx145szzhm92ls1lsmkzck"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/helmholtz-ellis-ji-notation")
    (synopsis "In-line microtonal just intonation accidentals")
    (description
     "The Helmholtz-Ellis JI Pitch Notation (HEJI), devised in the early 2000s
by Marc Sabat and Wolfgang von Schweinitz, explicitly notates the raising and
lowering of the untempered diatonic Pythagorean notes by specific microtonal
ratios defined for each prime.  It provides visually distinctive logos
distinguishing families of justly tuned intervals that relate to the harmonic
series.  These take the form of strings of additional accidental symbols based
on historical precedents, extending the traditional sharps and flats.  Since
its 2020 update, HEJI version 2 (HEJI2) provides unique microtonal symbols
through the 47-limit.  This package is a simple LaTeX implementation of HEJI2
that allows for in-line typesetting of microtonal accidentals for use within
theoretical texts, program notes, symbol legends, etc.  Documents must be
compiled using XeLaTeX.")
    (license license:cc-by4.0)))

(define-public texlive-hep
  (package
    (name "texlive-hep")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hep/" "tex/latex/hep/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p7phgv3d4xch9c9qwkpgrpc34nzijxfxiqkpnc9b9a3xfwh71sg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hep")
    (synopsis "Convenience wrapper for High Energy Physics packages")
    (description
     "This package loads the author's @code{hepunits} and @code{hepnicenames}
packages, and a selection of others that are useful in High Energy Physics
papers, etc.")
    (license license:lppl)))

(define-public texlive-hep-bibliography
  (package
    (name "texlive-hep-bibliography")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hep-bibliography/"
                                     "source/latex/hep-bibliography/"
                                     "tex/latex/hep-bibliography/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00zz26cp361z3wx9c8h7qq798xqm9gh945vg81hp9s4fpdd4wgzk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hep-bibliography")
    (synopsis "Acronym extension for glossaries")
    (description
     "The @code{hep-bibliography} package extends the BibLaTeX package with
some functionality mostly useful for high energy physics.  In particular it
makes full use of all BibTeX fields provided by Discover High-Energy
Physics.")
    (license license:lppl1.3c)))

(define-public texlive-hep-font
  (package
    (name "texlive-hep-font")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/hep-font/"
                                     "source/fonts/hep-font/"
                                     "tex/latex/hep-font/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k2kjq50zd5rdgwcgj3c803d68xx3zl77qp39nxzshbm3nks2sb9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hep-font")
    (synopsis "Latin modern extended by Computer Modern")
    (description
     "The @code{hep-font} package loads standard font packages and extends the
usual Latin Modern implementations by replacing missing fonts with Computer
Modern counterparts.")
    (license license:lppl1.3c)))

(define-public texlive-hep-math-font
  (package
    (name "texlive-hep-math-font")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/hep-math-font/"
                                     "source/fonts/hep-math-font/"
                                     "tex/latex/hep-math-font/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0v1fbll0knibmzsnbl7jiip99r79zr21f0kjkq9p5r49a55nwpi3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hep-math-font")
    (synopsis "Extended Greek and sans-serif math")
    (description
     "The @code{hep-math-font} package adjust the math fonts to be sans-serif
if the document is sans-serif.  Additionally Greek letters are redefined to be
always italic and upright in math and text mode respectively.  Some math font
macros are adjusted to give more consistently the naively expected results.")
    (license license:lppl1.3c)))

(define-public texlive-hep-paper
  (package
    (name "texlive-hep-paper")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hep-paper/"
                                     "source/latex/hep-paper/"
                                     "tex/latex/hep-paper/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "192q9nhqmdxrfz1qh5i211k1b9g0cvlgdg5j85r1zx6lwfrrzfdi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hep-paper")
    (synopsis "Publications in @emph{High Energy Physics}")
    (description
     "This package aims to provide a single style file containing most
configurations and macros necessary to write appealing publications in
@emph{High Energy Physics}.  Instead of reinventing the wheel by introducing
newly created macros, hep-paper preferably loads third party packages as long
as they are light-weight enough.  For usual publications it suffices to load
the @code{hep-paper} package, without optional arguments, in addition to the
@code{article} class.")
    (license license:lppl1.3c)))

(define-public texlive-hep-reference
  (package
    (name "texlive-hep-reference")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hep-reference/"
                                     "source/latex/hep-reference/"
                                     "tex/latex/hep-reference/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1931sdr8ivh2aslrs3gzi1cvp1djcisypfzsyn6xjgjsbvrnw96k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hep-reference")
    (synopsis "Adjustments for publications in High Energy Physics")
    (description
     "This package makes some changes to the reference, citation and footnote
macros to improve the default behavior of LaTeX for High Energy Physics
publications.")
    (license license:lppl1.3c)))

(define-public texlive-hepnames
  (package
    (name "texlive-hepnames")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hepnames/" "tex/latex/hepnames/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wvqf4r7p8bkvxwp7mvqnngxillbpii38i413q8acz0777bpassl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hepnames")
    (synopsis "Pre-defined high energy particle names")
    (description
     "Hepnames provides a pair of LaTeX packages, @code{heppennames} and @code{hepnicenames},
providing a large set of pre-defined high energy physics particle names built
with the @code{hepparticles} package.  The packages are based on
@file{pennames.sty} by Michel Goosens and Eric van Herwijnen.  Heppennames
re-implements the particle names in @file{pennames.sty}, with some additions
and alterations and greater flexibility and robustness due to the
@code{hepparticles} structures, which were written for this purpose.
Hepnicenames provides the main non-resonant particle names from
@code{heppennames} with more friendly names.")
    (license license:lppl)))

(define-public texlive-hepparticles
  (package
    (name "texlive-hepparticles")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hepparticles/"
                                     "tex/latex/hepparticles/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k8nzw5py23zvp4r4hgddjd2xypcpw85h4slad1yk43zxivb33n7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hepparticles")
    (synopsis "Macros for typesetting high energy physics particle names")
    (description
     "HEPparticles is a set of macros for typesetting high energy particle names,
to meet the following criteria:

@enumerate
@item The main particle name is a Roman or Greek symbol, to be typeset in
upright font in normal contexts.
@item Additionally a superscript or subscript may follow the main symbol.
@item Particle resonances may also have a resonance specifier which is typeset
in parentheses following the main symbol.  In general the parentheses may also
be followed by sub- and superscripts.
@item The particle names are expected to be used both in and out of
mathematical contexts.
@item If the surrounding text is bold or italic then the particle name should
adapt to that context as best as possible (this may not be possible for Greek
symbols).  As a consequence, well-known problems with boldness of particle
names in section titles, headers and tables of contents automatically
disappear if these macros are used.
@end enumerate")
    (license license:lppl)))

(define-public texlive-hepthesis
  (package
    (name "texlive-hepthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hepthesis/"
                                     "tex/latex/hepthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10yrdsrvnb259fi2qyjldwc6h55s5z8vadr5pf6sbaihyqnv9igg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hepthesis")
    (synopsis "Class for academic reports, especially PhD theses")
    (description
     "@code{hepthesis} is a LaTeX class for typesetting large academic
reports, in particular PhD theses.  In particular, @code{hepthesis} offers:

@itemize
@item attractive semantic environments for various rubric sections;
@item extensive options for draft production, screen viewing and binding-ready
output;
@item helpful extensions of existing environments, including equation and
tabular;
@item support for quotations at the start of the thesis and each chapter.
@end itemize

The class is based on @code{scrbook}, from the KOMA-Script bundle.")
    (license license:lppl)))

(define-public texlive-hepunits
  (package
    (name "texlive-hepunits")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hepunits/"
                                     "tex/latex/hepunits/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k89jdw5hpav5wr2imrb5wcasi53qswnqqn6jb89kh5crbrywrlz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hepunits")
    (synopsis "Set of units useful in high energy physics applications")
    (description
     "@code{hepunits} is a LaTeX package built on the SIunits package which
adds a collection of useful @acronym{HEP, High Energy Physics} units to the
existing SIunits set.")
    (license license:lppl)))

(define-public texlive-heros-otf
  (package
    (name "texlive-heros-otf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/heros-otf/"
                                     "tex/latex/heros-otf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17ac8a8r5hvf76lifap070c4746jdhva9arcn1s0bqrs6kydfm56"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/heros-otf")
    (synopsis "Using the OpenType fonts TeX Gyre Heros")
    (description
     "This package can only be used with LuaLaTeX or XeLaTeX.  It does the
font setting for the OpenType font TeX Gyre Heros.  The condensed versions of
the fonts are also supported.  The missing typefaces for slanted text are
defined.")
    (license license:lppl1.3+)))

(define-public texlive-heuristica
  (package
    (name "texlive-heuristica")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/heuristica/"
                                     "fonts/enc/dvips/heuristica/"
                                     "fonts/map/dvips/heuristica/"
                                     "fonts/opentype/public/heuristica/"
                                     "fonts/tfm/public/heuristica/"
                                     "fonts/type1/public/heuristica/"
                                     "fonts/vf/public/heuristica/"
                                     "tex/latex/heuristica/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bpf3iikl3yv35bkihrnr7hjhvb0jgjpz01flllkp9zvbfl3kcb6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/heuristica")
    (synopsis "Fonts extending Utopia, with LaTeX support files")
    (description
     "The fonts extend the Utopia set with Cyrillic glyphs, additional figure
styles, ligatures and Small Caps in Regular style only.  Macro support, and
maths fonts that match the Utopia family, are provided by the Fourier and the
Mathdesign font packages.")
    (license license:silofl1.1)))

(define-public texlive-hexboard
  (package
    (name "texlive-hexboard")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hexboard/"
                                     "source/latex/hexboard/"
                                     "tex/latex/hexboard/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04z0qhajbjn55mqax4kaw53h7s6g84iy1yh0pfhzj3ib7gd4cpw4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hexboard")
    (synopsis "For drawing Hex boards and games")
    (description
     "@code{hexboard} is a package for LaTeX that should also work with LuaTeX
and XeTeX, that provides functionality for drawing Hex boards and games.")
    (license license:cc-by-sa4.0)))

(define-public texlive-hexgame
  (package
    (name "texlive-hexgame")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hexgame/" "tex/latex/hexgame/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qr9v7225k6xzykw3rdsxf2sa3b5asvmd767i88jwimmacwi2cp1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hexgame")
    (synopsis "Provide an environment to draw a hexgame-board")
    (description
     "Hex is a mathematical game invented by the Danish mathematician Piet
Hein and independently by the mathematician John Nash.  This package defines
an environment that enables the user to draw such a game in a trivial way.")
    (license license:lppl)))

(define-public texlive-hfbright
  (package
    (name "texlive-hfbright")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/hfbright/"
                                     "fonts/afm/public/hfbright/"
                                     "fonts/enc/dvips/hfbright/"
                                     "fonts/map/dvips/hfbright/"
                                     "fonts/type1/public/hfbright/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1aw4h2law9q7sn2ppf3pxdazsk9kypss3chvca3741w8bzhxq5qr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hfbright")
    (synopsis "@code{hfbright} fonts")
    (description
     "These are Adobe Type 1 versions of the OT1-encoded and maths parts of
the Computer Modern Bright fonts.")
    (license license:lppl)))

(define-public texlive-hfoldsty
  (package
    (name "texlive-hfoldsty")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/hfoldsty/"
                                     "fonts/tfm/public/hfoldsty/"
                                     "fonts/vf/public/hfoldsty/"
                                     "source/fonts/hfoldsty/"
                                     "tex/latex/hfoldsty/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0skzw845i1b3lq76m4an4mpkm2w82hlpirnx4pckz3138nr1rlpf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hfoldsty")
    (synopsis "Old style numerals with EC fonts")
    (description
     "The @code{hfoldsty} package provides virtual fonts for using old-style
figures with the European Computer Modern fonts.  It does a similar job as the
@code{eco} package but includes a couple of improvements, i.e., better kerning
with guillemets, and support for character protruding using the
@code{pdfcprot} package.")
    (license license:gpl3+)))

(define-public texlive-hfutexam
  (package
    (name "texlive-hfutexam")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hfutexam/" "tex/latex/hfutexam/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14zvjkj0icdzb8bq31c5gv3nmw52s0969nlcbacbaxhgmkix9lfk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hfutexam")
    (synopsis "Exam class for Hefei University of Technology, China")
    (description
     "This package provides an exam class for Hefei University of
Technology (China).")
    (license license:lppl1.3c)))

(define-public texlive-hfutthesis
  (package
    (name "texlive-hfutthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/hfutthesis/"
                                     "tex/xelatex/hfutthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i7ljf5521f9dynrcnim0m4jzz2qkvpsb4pjvxbj5c7pr85gc34r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hfutthesis")
    (synopsis "LaTeX thesis template for Hefei University of Technology")
    (description
     "This project is based on the HFUT_Thesis LaTeX template of Hefei
University of Technology compiled on the basis of @code{ustctug} and
@code{ustcthesis}, in accordance with the latest version of @emph{Hefei
University of Technology Graduate Dissertation Writing Specifications} and
@emph{Hefei University of Technology Undergraduate Graduation Project (Thesis)
Work Implementation Rules}.")
    (license license:lppl1.3c)))

(define-public texlive-hithesis
  (package
    (name "texlive-hithesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/hithesis/"
                                     "doc/xelatex/hithesis/"
                                     "makeindex/hithesis/"
                                     "source/xelatex/hithesis/"
                                     "tex/xelatex/hithesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0w701f0ivf7k8jb2jiy5lhns4qiflyrslyiplm6aca67g2rcqgwn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:phases
           #~(modify-phases %standard-phases
               ;; "hithesis.ins" writes files to "./figures" Create these
               ;; directories first to prevent an error.
               (add-before 'build 'prepare-build
                 (lambda _
                   (mkdir-p "build/figures"))))))
    (home-page "https://ctan.org/pkg/hithesis")
    (synopsis "Harbin Institute of Technology thesis template")
    (description
     "@code{hithesis} is a LaTeX thesis template package for Harbin Institute
of Technology supporting bachelor, master, doctor dissertations.")
    (license license:lppl1.3a)))

(define-public texlive-hindmadurai
  (package
    (name "texlive-hindmadurai")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/hindmadurai/"
                                     "fonts/enc/dvips/hindmadurai/"
                                     "fonts/map/dvips/hindmadurai/"
                                     "fonts/opentype/public/hindmadurai/"
                                     "fonts/tfm/public/hindmadurai/"
                                     "fonts/type1/public/hindmadurai/"
                                     "fonts/vf/public/hindmadurai/"
                                     "tex/latex/hindmadurai/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15bf8hka7f04l7zpkaav1azbailjv21w15iidbaxx9n2d4plf2kk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hindmadurai")
    (synopsis "HindMadurai font face with support for LaTeX and pdfLaTeX")
    (description
     "This package provides the HindMadurai family of fonts designed by the
Indian Type Foundry, with support for LaTeX and pdfLaTeX.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-historische-zeitschrift
  (package
    (name "texlive-historische-zeitschrift")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/historische-zeitschrift/"
                                     "tex/latex/historische-zeitschrift/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1w8zhk1darw39lrgs4i1p8zk78a1q7skc93ac8qczbrw5pln27k5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/historische-zeitschrift")
    (synopsis "BibLaTeX style for the journal @emph{Historische Zeitschrift}")
    (description
     "The package provides citations according with the house style of the
@emph{Historische Zeitschrift}, a German historical journal.")
    (license license:lppl)))

(define-public texlive-hitex
  (package
    (name "texlive-hitex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/hitex/base/"
                                     "doc/man/man1/hishrink.1"
                                     "doc/man/man1/hishrink.man1.pdf"
                                     "doc/man/man1/histretch.1"
                                     "doc/man/man1/histretch.man1.pdf"
                                     "doc/man/man1/hitex.1"
                                     "doc/man/man1/hitex.man1.pdf"
                                     "makeindex/hitex/"
                                     "tex/hitex/base/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wim25zd8wmqc2g8l9lk2gwwq51fwmj46hj8bmzbzy1a455ih0zq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:create-formats #~(list "hilatex" "hitex")))
    (propagated-inputs
     (list texlive-babel
           texlive-cm
           texlive-etex
           texlive-firstaid
           texlive-hitex-bin
           texlive-hyphen-base
           texlive-knuth-lib
           texlive-l3backend
           texlive-l3kernel
           texlive-latex
           texlive-latex-fonts
           texlive-plain
           texlive-tex-ini-files
           texlive-unicode-data))
    (home-page "https://ctan.org/pkg/hitex")
    (synopsis "TeX extension writing HINT output for on-screen reading")
    (description
     "This package provides a TeX extension that generates HINT output.  The
HINT file format is an alternative to the DVI and PDF formats which was
designed specifically for on-screen reading of documents.  Especially on
mobile devices, reading DVI or PDF documents can be cumbersome.  Mobile
devices are available in a large variety of sizes but typically are not large
enough to display documents formatted for a4/letter-size paper.  To compensate
for the limitations of a small screen, users are used to alternating between
landscape (few long lines) and portrait (more short lines) mode.  The HINT
format supports variable and varying screen sizes, leveraging the ability of
TeX to format a document for nearly-arbitrary values of @code{\\hsize} and
@code{\\vsize}.")
    (license license:x11)))

(define-public texlive-hitex-bin
  (package
    (inherit texlive-bin)
    (name "texlive-hitex-bin")
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons* "--disable-web2c"
                 "--enable-hitex"
                 (delete "--disable-hitex"
                         (delete "--enable-web2c" #$flags))))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/web2c"
                  (let ((bin (string-append #$output "/bin"))
                        (files '("hishrink" "histretch" "hitex")))
                    (for-each (lambda (f) (invoke "make" f)) files)
                    (for-each (lambda (f) (install-file f bin)) files)
                    (with-directory-excursion bin
                      (symlink "hitex" "hilatex"))))))))))
    (native-inputs (list pkg-config))
    (home-page (package-home-page texlive-hitex))
    (synopsis "Binaries for @code{texlive-hitex}")
    (description
     "This package provides the binaries for @code{texlive-hitex}.")
    (license (package-license texlive-hitex))))

(define-public texlive-hitszbeamer
  (package
    (name "texlive-hitszbeamer")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/hitszbeamer/"
                                     "doc/latex/hitszbeamer/"
                                     "source/latex/hitszbeamer/"
                                     "tex/latex/hitszbeamer/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00c23sdhkvr79lzag8v1j5hyzf5iwmkr07xnz0s0n3haicbfzz44"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hitszbeamer")
    (synopsis "Beamer theme for Harbin Institute of Technology, ShenZhen")
    (description
     ;; XXX: Cannot use @acronym and @comma here, because Guile Texinfo does
     ;; not support this combination.
     "This is a Beamer theme designed for HITSZ (Harbin Institute of
Technology, ShenZhen).")
    (license license:lppl1.3c)))

(define-public texlive-hitszthesis
  (package
    (name "texlive-hitszthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/hitszthesis/"
                                     "doc/latex/hitszthesis/"
                                     "makeindex/hitszthesis/"
                                     "source/latex/hitszthesis/"
                                     "tex/latex/hitszthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m1wr3iq1nzcymvnamgna0iiqb3ndllflgawzjjv85aay9jszra0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hitszthesis")
    (synopsis
     "Dissertation template for Harbin Institute of Technology, ShenZhen")
    (description
     ;; XXX: Cannot use @acronym and @comma here, because Guile Texinfo does
     ;; not support this combination.
     "This package provides a dissertation template for HITSZ (Harbin
Institute of Technology, ShenZhen), including bachelor, master and doctor
dissertations.")
    (license license:lppl1.3c)))

(define-public texlive-hmtrump
  (package
    (name "texlive-hmtrump")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/hmtrump/"
                                     "fonts/truetype/public/hmtrump/"
                                     "tex/lualatex/hmtrump/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03r1f784ipr2j38y2xy8agl94xwcmyv4pxd0l42iclmx08rczb9q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hmtrump")
    (synopsis "Describe card games")
    (description
     "This package provides a font with LuaLaTeX support for describing
card games.")
    (license
     (list (license:fsf-free
            "doc/lualatex/hmtrump/nkd04_playing_cards_index/LICENSE")
           license:cc-by-sa4.0))))

(define-public texlive-hobete
  (package
    (name "texlive-hobete")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hobete/" "tex/latex/hobete/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gccpxh3bfj4sbnag8rjrz8hyrx3107mwxpydl0bcdn8dxyjkfi2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hobete")
    (synopsis "Unofficial Beamer theme for the University of Hohenheim")
    (description
     "The package provides a Beamer theme which features the Ci colors of the
University of Hohenheim.  Please note that this is not an official theme, and
that there will be no support for it from the University.")
    (license license:lppl)))

(define-public texlive-horoscop
  (package
    (name "texlive-horoscop")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/horoscop/"
                                     "source/latex/horoscop/"
                                     "tex/latex/horoscop/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08acv1sg37qzq3h14kxv62xhrzrv4psgpychshj3gmzvp4vz0jsn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/horoscop")
    (synopsis "Generate astrological charts in LaTeX")
    (description
     "The @code{horoscop} package provides a unified interface for
astrological font packages; typesetting with @code{pict2e} of standard wheel
charts and some variations, in PostScript- and PDF-generating TeX engines; and
access to external calculation software (Astrolog and Swiss Ephemeris) for
computing object positions.")
    (license license:public-domain)))

(define-public texlive-hrlatex
  (package
    (name "texlive-hrlatex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hrlatex/" "source/latex/hrlatex/"
                                     "tex/latex/hrlatex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16npkf18gy8clwkzvm0qysfv90wb6979cppj5rykn1x0icsvw2ix"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hrlatex")
    (synopsis "LaTeX support for Croatian documents")
    (description
     "This package simplifies creation of new documents for the (average)
Croatian user.  As an example, a class file @code{hrdipl.cls} (designed for
the graduation thesis at the University of Zagreb) and sample thesis documents
are included.")
    (license license:lppl)))

(define-public texlive-hu-berlin-bundle
  (package
    (name "texlive-hu-berlin-bundle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/hu-berlin-bundle/"
                                     "source/lualatex/hu-berlin-bundle/"
                                     "tex/lualatex/hu-berlin-bundle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y9qldwr231qh06djvck5zmvqva9hxppn8mx9a7isikr9d5152y9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hu-berlin-bundle")
    (synopsis "LaTeX classes for the Humboldt-Universitat zu Berlin")
    (description
     "This package provides files according to the corporate design of the
Humboldt-Universitat zu Berlin.  This is not an official package by the
university itself, and not officially approved by it.")
    (license (list license:lppl1.3c license:gpl2 license:bsd-3))))

(define-public texlive-huaz
  (package
    (name "texlive-huaz")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/huaz/" "tex/latex/huaz/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "103wnzw8401d1ckc31y6ga75bph0ls71hxs0hdkszw719ghm7vjr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/huaz")
    (synopsis "Automatic Hungarian definite articles")
    (description
     "In Hungarian there are two definite articles, @samp{a} and @samp{az},
which are determined by the pronunciation of the subsequent word.  The
@code{huaz} package helps the user to insert automatically the correct
definite article for cross-references and other commands containing text.")
    (license license:lppl1.3+)))

(define-public texlive-hulipsum
  (package
    (name "texlive-hulipsum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hulipsum/"
                                     "source/latex/hulipsum/"
                                     "tex/latex/hulipsum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1w62vawh2l49bgm7ivprmz61b71qsf38xdsrq6x2dc2ywzvs4z2f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hulipsum")
    (synopsis "Hungarian dummy text (Lorum ipse)")
    (description
     "Lorem ipsum is an improper Latin filler dummy text, cf.@: the
@code{lipsum} package.  It is commonly used for demonstrating the textual
elements of a document template.  Lorum ipse is a Hungarian variation of Lorem
ipsum. (Lorum is a Hungarian card game, and ipse is a Hungarian slang word
meaning bloke.)  With this package you can typeset 150 paragraphs of Lorum
ipse.")
    (license license:lppl1.3+)))

(define-public texlive-hustthesis
  (package
    (name "texlive-hustthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/hustthesis/"
                                     "doc/latex/hustthesis/"
                                     "source/latex/hustthesis/"
                                     "tex/latex/hustthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12sacpq43wjkr0j0ziszw37achyc7cf0z5kajqdfb5d7ksas0j2n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hustthesis")
    (synopsis "Unofficial thesis template for Huazhong University")
    (description
     "The package provides an unofficial thesis template in LaTeX for Huazhong
University of Science and Technology.")
    (license license:lppl1.3+)))

(define-public texlive-hvarabic
  (package
    (name "texlive-hvarabic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hvarabic/" "tex/latex/hvarabic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kjx2x3fnpqw6hybw7ifdlqad4mmbacba290qwlhhggpjrxsvp39"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hvarabic")
    (synopsis "Macros for RTL typesetting")
    (description
     "This package provides some macros for right-to-left typesetting.  It
uses by default the Arabic fonts Scheherazade and ALM fixed, the only
monospaced Arabic font.  The package only works with LuaLaTeX or XeLaTeX.")
    (license license:lppl1.3c)))

(define-public texlive-ibarra
  (package
    (name "texlive-ibarra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/ibarra/"
                                     "fonts/enc/dvips/ibarra/"
                                     "fonts/map/dvips/ibarra/"
                                     "fonts/tfm/public/ibarra/"
                                     "fonts/truetype/public/ibarra/"
                                     "fonts/type1/public/ibarra/"
                                     "fonts/vf/public/ibarra/"
                                     "tex/latex/ibarra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mjf3mk95rs7qr2f4qpwa249kqycmbj0d13d3d0sc9lqkl0yza4w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ibarra")
    (synopsis "LaTeX support for the Ibarra Real Nova family of fonts")
    (description
     "The Ibarra Real Nova is a revival of a typeface designed by Geronimo Gil
for the publication of @emph{Don Quixote} for the Real Academia de la Lengua
in 1780.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-ibrackets
  (package
    (name "texlive-ibrackets")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ibrackets/"
                                     "source/latex/ibrackets/"
                                     "tex/latex/ibrackets/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "037c2g7dfr2c5l99ry0fvmwxh15jx9lq1hh4fwgcpnglh73lmkhp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ibrackets")
    (synopsis "Intelligent brackets")
    (description
     "This small package provides a new definition of brackets @samp{[} and
@samp{]} as active characters to get correct blank spaces in mathematical mode
when using for open intervals.")
    (license license:lppl1.3+)))

(define-public texlive-icite
  (package
    (name "texlive-icite")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/icite/" "source/latex/icite/"
                                     "tex/latex/icite/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a3gqnjbyn33ld3j66pfrrsv502zdrsag0glhar82fbba21qlj9w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/icite")
    (synopsis "Indices locorum citatorum")
    (description
     "The package is designed to produce from BibTeX or BibLaTeX
bibliographical databases the different indices of authors and works cited
which are called indices locorum citatorum.  It relies on a specific
@code{\\icite} command and can operate with either BibTeX or BibLaTeX.")
    (license (list license:gpl3+ license:cc-by-sa4.0))))

(define-public texlive-ietfbibs
  (package
    (name "texlive-ietfbibs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/bibtex/ietfbibs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18ypa96z1gclq4amka28sv26pm7lycak68zf4b3sf1bx4ldnzmxq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ietfbibs")
    (synopsis "Generate BibTeX entries for various IETF index files")
    (description
     "The package provides scripts to translate IETF index files to BibTeX
files.")
    (license license:expat)))

(define-public texlive-ifsym
  (package
    (name "texlive-ifsym")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/ifsym/"
                                     "fonts/source/public/ifsym/"
                                     "fonts/tfm/public/ifsym/" "tex/latex/ifsym/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07r16sgqc65wf8c8ijgmnmwq50yrlvjlmzbnk0czgnwqrbdz642g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/ifsym")
    (synopsis "Collection of symbols")
    (description
     "This package provides a set of symbol fonts, written in Metafont, offering
(respectively) clock-face symbols, geometrical symbols, weather symbols,
mountaineering symbols, electronic circuit symbols and a set of miscellaneous
symbols.  A LaTeX package is provided, that allows the user to load only those
symbols needed in a document.")
    (license license:lppl1.0+)))

(define-public texlive-ijqc
  (package
    (name "texlive-ijqc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/ijqc/" "doc/bibtex/ijqc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18sqc8k21l15zlplpaimdcg8g75z3lrlc0qcb6wx838980gn961r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ijqc")
    (synopsis "BibTeX style file for the @emph{Intl. J. Quantum Chem}")
    (description
     "@file{ijqc.bst} is a BibTeX style file to support publication in Wiley's
@emph{International Journal of Quantum Chemistry}.")
    (license license:lppl)))

(define-public texlive-imfellenglish
  (package
    (name "texlive-imfellenglish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/imfellenglish/"
                                     "fonts/enc/dvips/imfellenglish/"
                                     "fonts/map/dvips/imfellenglish/"
                                     "fonts/opentype/iginomarini/imfellenglish/"
                                     "fonts/tfm/iginomarini/imfellenglish/"
                                     "fonts/type1/iginomarini/imfellenglish/"
                                     "fonts/vf/iginomarini/imfellenglish/"
                                     "tex/latex/imfellenglish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pw4nsw4pl1nf99j58sy37064712by6kqcb40xkrcl5d9czx45bh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/imfellenglish")
    (synopsis "IM Fell English fonts with LaTeX support")
    (description
     "Igino Marini has implemented digital revivals of fonts bequeathed to
Oxford University by Dr.@: John Fell, Bishop of Oxford and Dean of Christ
Church in 1686.  This package provides the English family, consisting of
Roman, Italic and Small-Cap fonts.")
    (license license:silofl1.1)))

(define-public texlive-impatient
  (package
    (name "texlive-impatient")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/impatient/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03cjl3lg7k7p4h8drw7vcbw6ymgmm2clv6sgfs3hdixs8dmab1b2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/impatient")
    (synopsis "@emph{TeX for the Impatient} book")
    (description
     "@emph{TeX for the Impatient} is a book on TeX, Plain TeX and Eplain.")
    (license license:fdl1.3+)))

(define-public texlive-impatient-cn
  (package
    (name "texlive-impatient-cn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/impatient-cn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pc20pb0las3slam1d9hmqigipmr6r98wwif12m33mm750vmq65i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/impatient")
    (synopsis "Chinese translation of @emph{TeX for the Impatient} book")
    (description
     "@emph{TeX for the Impatient} is a book (of around 350 pages) on TeX,
Plain TeX and Eplain.  This is its Chinese translation.")
    (license license:fdl1.3+)))

(define-public texlive-impatient-fr
  (package
    (name "texlive-impatient-fr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/impatient-fr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qwdllmi0ci304smf4yl6g8ah083jrch9clkyav7r5qsxnhwxbxh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/impatient")
    (synopsis "French translation of @emph{TeX for the Impatient} book")
    (description
     "@emph{TeX for the Impatient} is a book (of around 350 pages) on TeX,
Plain TeX and Eplain.  This is its French translation.")
    (license license:fdl1.3+)))

(define-public texlive-impnattypo
  (package
    (name "texlive-impnattypo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/impnattypo/"
                                     "source/latex/impnattypo/"
                                     "tex/latex/impnattypo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05ddbpxvybr0a7sg1ximsifvgjg83qwx5pd9xcc22bliz3j5ixvm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/impnattypo")
    (synopsis "Support typography of l'Imprimerie Nationale Francaise")
    (description
     "The package provides useful macros implementing recommendations by the
French Imprimerie Nationale.")
    (license license:lppl1.3+)))

(define-public texlive-import
  (package
    (name "texlive-import")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/import/" "tex/latex/import/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wlzs31li6nvzigkxw59bbpmyqrkzpdangvjqq3z7wl6y79sic6g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/import")
    (synopsis "Establish input relative to a directory")
    (description
     "The commands @code{\\import@{full_path@}@{file@}} and
@code{\\subimport@{path_extension@}@{file@}} set up input through standard
LaTeX mechanisms (@code{\\input}, @code{\\include} and
@code{\\includegraphics}) to load files relative to the imported directory.
There are also @code{\\includefrom}, @code{\\subincludefrom}, and starred
variants of the commands.")
    (license license:public-domain)))

(define-public texlive-imsproc
  (package
    (name "texlive-imsproc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/imsproc/"
                                     "tex/xelatex/imsproc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1akzdc4nas4fkmlhm6xp97xw65vm5bif73jq2ki5if5kwssxc38z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/imsproc")
    (synopsis "Typeset IMS conference proceedings")
    (description
     "The class typesets papers for IMS (Iranian Mathematical Society)
conference proceedings.  The class uses the XePersian package.")
    (license license:lppl1.3+)))

(define-public texlive-includernw
  (package
    (name "texlive-includernw")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/includernw/"
                                     "tex/latex/includernw/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kc14nq0f3jybidifvr6gjfy4ggs5qkbs1syv1k7bw3xrdmpplb8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/includernw")
    (synopsis "Include .Rnw inside .tex")
    (description
     "This package is for including @file{.Rnw} (knitr/sweave) files inside
@file{.tex} files.  It requires that you have R and the R-package @code{knitr}
installed.")
    (license license:lppl1.3c)))

(define-public texlive-initials
  (package
    (name "texlive-initials")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/initials/"
                                     "dvips/initials/"
                                     "fonts/afm/public/initials/"
                                     "fonts/map/dvips/initials/"
                                     "fonts/tfm/public/initials/"
                                     "fonts/type1/public/initials/"
                                     "tex/latex/initials/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hbvk2qjrhcx2l8nkca1s5lj65k5xd2v2fnk4zjxjpwdcwxf09zp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/initials")
    (synopsis "Adobe Type 1 decorative initial fonts")
    (description
     "This package provides Adobe Type 1 decorative initial fonts.  For each
font, at least a @file{.pfb} and a @file{.tfm} file is provided, with an
@file{.fd} file for use with LaTeX.")
    (license license:lppl)))

(define-public texlive-inlinebib
  (package
    (name "texlive-inlinebib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/inlinebib/"
                                     "doc/bibtex/inlinebib/"
                                     "tex/latex/inlinebib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13kfygh2r8s038rnskxnj91h08k8xs6cln16vzsy1j59c82idvkb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/inlinebib")
    (synopsis "Citations in footnotes")
    (description
     "This package provides a BibTeX style and a LaTeX package that allow for
a full bibliography at the end of the document as well as citation details in
footnotes.")
    (license license:lppl)))

(define-public texlive-install-latex-guide-zh-cn
  (package
    (name "texlive-install-latex-guide-zh-cn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/install-latex-guide-zh-cn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hs9pqhbf5pkdk3a29xnicj7i8zxgf3vazf2mmm4z6fc4b0kfpjk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/install-latex-guide-zh-cn")
    (synopsis "Short introduction to LaTeX installation written in Chinese")
    (description
     "This package will introduce the operations related to installing TeX
Live and mainly introducing command line operations, in Chinese.")
    (license license:lppl1.3c)))

(define-public texlive-inter
  (package
    (name "texlive-inter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/inter/"
                                     "fonts/enc/dvips/inter/"
                                     "fonts/map/dvips/inter/"
                                     "fonts/opentype/public/inter/"
                                     "fonts/tfm/public/inter/"
                                     "fonts/type1/public/inter/"
                                     "fonts/vf/public/inter/"
                                     "tex/latex/inter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bfxp3ar62p1jddjisjnv3aqml00ckkz4fawacsjbb369jq9v0aj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/inter")
    (synopsis "Inter font face with support for LaTeX, XeLaTeX, and LuaLaTeX")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the Inter Sans family of fonts, designed by Rasmus Andersson.  Inter is
a typeface specially designed for user interfaces with focus on high
legibility of small-to-medium sized text on computer screens.  The family
features a tall x-height to aid in readability of mixed-case and lower-case
text.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-interval
  (package
    (name "texlive-interval")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/interval/" "tex/latex/interval/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16qp8q95s8y4pvd7idh6nzz04nb81sm7w36gc2nc5sjmvjw1sk4f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/interval")
    (synopsis "Format mathematical intervals, ensuring proper spacing")
    (description
     "When typing an open interval as $]a,b[$, a closing bracket is being used
in place of an opening fence and vice versa.  This leads to wrong spacing.
The @code{\\interval} macro provided by this package attempts to solve this.
The package also supports fence scaling and ensures that the enclosing fences
will end up having the proper closing and opening types.")
    (license license:lppl1.3+)))

(define-public texlive-intro-scientific
  (package
    (name "texlive-intro-scientific")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/intro-scientific/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bzgi3zg0lm6zwjnac90ihaqwcvhindfdphjijv7mh11ii0qxlmf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/intro-scientific")
    (synopsis "Introducing scientific/mathematical documents using LaTeX")
    (description
     "@emph{Writing Scientific Documents Using LaTeX} is an article
introducing the use of LaTeX in typesetting scientific documents.  It covers
the basics of creating a new LaTeX document, special typesetting
considerations, mathematical typesetting and graphics.  It also touches on
bibliographic data and BibTeX.")
    (license license:lppl)))

(define-public texlive-ionumbers
  (package
    (name "texlive-ionumbers")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ionumbers/"
                                     "source/latex/ionumbers/"
                                     "tex/latex/ionumbers/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rbm4z2qg1ifwslxdsgzdcni701s3q32i2iaqldm7g7jinn8bivn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ionumbers")
    (synopsis "Restyle numbers in maths mode")
    (description
     "@code{ionumbers} stands for input/output numbers.  The package restyles
numbers in maths mode.  If a number in the input file is written, e.g., as
@samp{$3,231.44$} as commonly used in English texts, the package is able to
restyle it to be output as @samp{$3\\,231{,}44$} as commonly used in German
texts (and vice versa).  This may be useful, for example, if you have a large
table and want to include it in texts with different output conventions
without the need to change the table.

The package can also automatically group digits left of the decimal separator
(thousands) and right of the decimal separator (thousandths) in triplets
without the need of specifying commas (English) or points (German) as
separators.  E.g., the input @samp{$1234.567890$} can be output as
@samp{$1\\,234.\\,567\\,890$}.

Finally, an @emph{e} starts the exponent of the number.  For example,
@samp{$21e6$} may be output as @samp{$26\\times10\\,^@{6@}$}.")
    (license license:gpl3+)))

(define-public texlive-iopart-num
  (package
    (name "texlive-iopart-num")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/iopart-num/"
                                     "doc/bibtex/iopart-num/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n30ncmg0djhpdfa9jl5mv188347xmqsv08vgf2v4ipx7czhjm7v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/iopart-num")
    (synopsis "Numeric citation style for IOP journals")
    (description
     "This package provides a BibTeX style providing numeric citation in
Harvard-like format.  Intended for use with Institute of Physics (IOP)
journals, including @emph{Journal of Physics}.")
    (license license:lppl)))

(define-public texlive-ipaex
  (package
    (name "texlive-ipaex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/ipaex/"
                                     "fonts/truetype/public/ipaex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zpvpdpry4ckgbs79hy0gv8cc98x9c0cizzdqzg2qkx8clp8y1bn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ipaex")
    (synopsis "IPA (Japanese) fonts")
    (description
     "The fonts provide fixed-width glyphs for Kana and Kanji characters,
proportional width glyphs for Western characters.")
    (license license:ipa)))

(define-public texlive-ipaex-type1
  (package
    (name "texlive-ipaex-type1")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/ipaex-type1/"
                                     "fonts/enc/dvips/ipaex-type1/"
                                     "fonts/map/dvips/ipaex-type1/"
                                     "fonts/tfm/public/ipaex-type1/"
                                     "fonts/type1/public/ipaex-type1/"
                                     "tex/latex/ipaex-type1/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "123m8i8gvyq3cncn8s11qzk976ml89aqcyapx2zs6phg9h090bc8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ipaex-type1")
    (synopsis "IPAex fonts converted to Type-1 format Unicode sub-fonts")
    (description
     "The package contains the IPAex Fonts converted into Unicode sub-fonts in
Type 1 format, which is most suitable for use with the CJK package.")
    (license license:ipa)))

(define-public texlive-is-bst
  (package
    (name "texlive-is-bst")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/is-bst/" "doc/bibtex/is-bst/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bdkk1s5nfqy95h9ia08h4kpij4khj1y5z6byxgn7fsvcxncl1cb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/is-bst")
    (synopsis "Extended versions of standard BibTeX styles")
    (description
     "The bundle contains an extended version (@file{xbtxbst.doc}) of the
source of the standard BibTeX styles, together with corresponding versions of
the standard styles.  The styles offer support for CODEN, ISBN, ISSN, LCCN,
and PRICE fields, extended PAGES fields, the PERIODICAL entry, and extended
citation label suffixing.")
    (license license:knuth)))

(define-public texlive-icsv
  (package
    (name "texlive-icsv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/icsv/" "source/latex/icsv/"
                                     "tex/latex/icsv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "133rbbq86qkd749bd20wdnjqddpwydm27ndh5yp2waimgij3cm8d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/icsv")
    (synopsis "Class for typesetting articles for the ICSV conference")
    (description
     "This is an ad-hoc class for typesetting articles for the ICSV
conference.")
    (license license:lppl)))

(define-public texlive-ieeeconf
  (package
    (name "texlive-ieeeconf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ieeeconf/"
                                     "source/latex/ieeeconf/"
                                     "tex/latex/ieeeconf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1f7v199mc1dw2fhp30qdkx48dyzk5mqmbqr91c1jm235isgs4fam"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ieeeconf")
    (synopsis "Macros for IEEE conference proceedings")
    (description
     "The IEEEconf class implements the formatting dictated by the IEEE
Computer Society Press for conference proceedings.")
    (license license:lppl)))

(define-public texlive-ieeepes
  (package
    (name "texlive-ieeepes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/ieeepes/" "doc/latex/ieeepes/"
                                     "tex/latex/ieeepes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12nvllxxswww9p9l1h3ygak3g4j8ngmypxcbbw2jwwa8kh43yiqi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ieeepes")
    (synopsis "IEEE Power Engineering Society Transactions")
    (description
     "This package supports typesetting of transactions, as well as
discussions and closures, for the IEEE Power Engineering Society Transactions
journals.")
    (license license:lppl)))

(define-public texlive-ieeetran
  (package
    (name "texlive-ieeetran")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/ieeetran/"
                                     "bibtex/bst/ieeetran/" "doc/latex/ieeetran/"
                                     "tex/latex/ieeetran/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0j7vv8hp0ymzmclyrk23zmixcclhlm1g241y8dk3dl18zsj00f1c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ieeetran")
    (synopsis "Document class for IEEE Transactions journals and conferences")
    (description
     "The class and its BibTeX style enable authors to produce
officially-correct output for the @acronym{IEEE, Institute of Electrical and
Electronics Engineers} transactions, journals and conferences.")
    (license license:lppl1.3+)))

(define-public texlive-ijmart
  (package
    (name "texlive-ijmart")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/ijmart/" "doc/latex/ijmart/"
                                     "source/latex/ijmart/" "tex/latex/ijmart/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18fpf0na5y1nxz0c7r43f560dp4r8yawx8vj8356vdmw6d5r15h0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ijmart")
    (synopsis "LaTeX Class for the @emph{Israel Journal of Mathematics}")
    (description
     "The @emph{Israel Journal of Mathematics} is published by The Hebrew
University Magnes Press.  This class provides LaTeX support for its authors
and editors.  It strives to achieve the distinct look and feel of the journal,
while having the interface similar to that of the @code{amsart} document
class.  This will help authors already familiar with @code{amsart} to easily
submit manuscripts for the @emph{Israel Journal of Mathematics} or to put the
preprints in arXiv with minimal changes in the LaTeX source.")
    (license license:lppl)))

(define-public texlive-ijsra
  (package
    (name "texlive-ijsra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ijsra/" "tex/latex/ijsra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k6a92c6fhwafrw3m4fcj0dj29ip0zb28aiz861cx2mac92hyqgs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ijsra")
    (synopsis
     "International Journal of Student Research in Archaeology's LaTeX
document class")
    (description
     "This is a document class called ijsra which is used for the
International Journal of Student Research in Archaeology.")
    (license license:lppl1.3+)))

(define-public texlive-imac
  (package
    (name "texlive-imac")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/imac/" "doc/latex/imac/"
                                     "tex/latex/imac/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06sc9irv318fc5zgngwrcdwx84pnhyhwh59jiq9sb8iayy1yxldh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/imac")
    (synopsis "International Modal Analysis Conference format")
    (description
     "This package provides a set of files for producing correctly formatted
documents for the International Modal Analysis Conference.  The bundle
provides a LaTeX package and a BibTeX style file.")
    (license license:gpl3+)))

(define-public texlive-imakeidx
  (package
    (name "texlive-imakeidx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/imakeidx/"
                                     "source/latex/imakeidx/"
                                     "tex/latex/imakeidx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1s65kbzafx5q7519pbxjldb87flws0mgg76yxi7a5mgxrnkfy961"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/imakeidx")
    (synopsis "Package for producing multiple indexes")
    (description
     "The package enables the user to produce and typeset one or more indexes
simultaneously with a document.  The package is known to work in LaTeX
documents processed with pdfLaTeX, XeLaTeX and LuaLaTeX.  If
@command{makeindex} is used for processing the index entries, no particular
setting up is needed.  When using Xindy or other programs, it is necessary to
enable shell escape; shell escape is also needed if @command{splitindex} is
used.")
    (license license:lppl1.3+)))

(define-public texlive-imtekda
  (package
    (name "texlive-imtekda")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/imtekda/" "source/latex/imtekda/"
                                     "tex/latex/imtekda/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pbv50c6g024dhyw8mpnnyafp18pvf0cqy7j1fvhrbqwf13bn37x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/imtekda")
    (synopsis "IMTEK thesis class")
    (description
     "The class permits typesetting of diploma, bachelor's and master's theses
for the @acronym{IMTEK, Institute of Microsystem Technology} at the University
of Freiburg (Germany).  The class is based on the KOMA-Script class
@code{scrbook}.")
    (license license:lppl)))

(define-public texlive-inkpaper
  (package
    (name "texlive-inkpaper")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/inkpaper/" "tex/latex/inkpaper/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yybzasv4708cw139k2dcqgi85lm6ard4ra9j78hrcdbnpnkqmw0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/inkpaper")
    (synopsis "Mathematical paper template")
    (description
     "InkPaper is designed to write mathematical papers, especially designed
for mathematics students, ZJGS students, and magazine editors.")
    (license license:gpl3)))

(define-public texlive-iodhbwm
  (package
    (name "texlive-iodhbwm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/iodhbwm/" "tex/latex/iodhbwm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10zqg2cyz7vcnsbgqajwlilakjzr23nhn49sqy82555zkqi27gsa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/iodhbwm")
    (synopsis "Unofficial template of the DHBW Mannheim")
    (description
     "This package provides an unofficial template of the DHBW Mannheim for
the creation of bachelor thesis, studies or project work with LaTeX.  The aim
of the package is the quick creation of a basic framework without much
effort.")
    (license license:lppl1.3+)))

(define-public texlive-iscram
  (package
    (name "texlive-iscram")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/iscram/" "tex/latex/iscram/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13p0nr6cwkchykdllf0ii035yjq7hxczb1g7qc7l7jaywfszr5ph"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/iscram")
    (synopsis "LaTeX class to publish article to ISCRAM conferences")
    (description
     "This is a LaTeX class to publish article to @acronym{ISCRAM,
International Conference on Information Systems for Crisis Response and
Management}.")
    (license license:lppl1.3+)))

(define-public texlive-isodate
  (package
    (name "texlive-isodate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/isodate/" "source/latex/isodate/"
                                     "tex/latex/isodate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bha4qpa1hi5i4npr00wz4qvzzc4yw4qydjjmm8n878p8cfygvga"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/isodate")
    (synopsis "Tune the output format of dates according to language")
    (description
     "This package provides ten output formats of the commands @code{\\today},
@code{\\printdate}, @code{\\printdateTeX}, and @code{\\daterange} (partly
language dependent).  The commands @code{\\printdate} and
@code{\\printdateTeX} print any date.  The command @code{\\daterange} prints
a date range and leaves out unnecessary year or month entries.  This package
supports German (old and new rules), Austrian, US English, British English,
French, Danish, Swedish, and Norwegian.")
    (license license:lppl)))

(define-public texlive-isomath
  (package
    (name "texlive-isomath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/isomath/" "tex/latex/isomath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jjz2hp9g6swjfbcd43j12dvsvgwgfid6v6lf3n1c87aq6jqx8ly"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/isomath")
    (synopsis "Mathematics style for science and technology")
    (description
     "The package provides tools for a mathematical style that conforms to the
International Standard ISO 80000-2 and is common in science and technology.
It changes the default shape of capital Greek letters to italic, sets up bold
italic and sans-serif bold italic math alphabets with Latin and Greek
characters, and defines macros for markup of vector, matrix and tensor
symbols.")
    (license license:lppl)))

(define-public texlive-itnumpar
  (package
    (name "texlive-itnumpar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/itnumpar/"
                                     "source/latex/itnumpar/"
                                     "tex/latex/itnumpar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jjl1mskg0vsxfjg2wpnqi0y462mv2qrfsg15zjri83zwrilaa6f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/itnumpar")
    (synopsis "Spell numbers in words (Italian)")
    (description
     "Sometimes we need to say ``Capitolo primo'' or ``Capitolo uno'' instead
of ``Capitolo 1'', that is, spelling the number in words instead of the usual
digit form.  This package provides support for spelling out numbers in Italian
words, both in cardinal and in ordinal form.")
    (license license:lppl)))

(define-public texlive-jablantile
  (package
    (name "texlive-jablantile")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/jablantile/"
                                     "fonts/source/public/jablantile/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14cxmph6hhzvb06jdqr6d428p1kg3mvbgw2nk133ggrr2k3wjppg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jablantile")
    (synopsis "Metafont version of tiles in the style of Slavik Jablan")
    (description
     "This is a Metafont font to implement the modular tiles described by
Slavik Jablan.")
    (license license:public-domain)))

(define-public texlive-jacow
  (package
    (name "texlive-jacow")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jacow/" "tex/latex/jacow/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wdmk9zl3916hgj3f16dlfvrxxlr7ffmjih2nipgfz376ryvnbgf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jacow")
    (synopsis
     "Class for submissions to the proceedings of conferences on JACoW.org")
    (description
     "The @code{jacow} class is used for submissions to the proceedings of
conferences on @acronym{JACoW, Joint Accelerator Conferences Website}, an
international collaboration that publishes the proceedings of accelerator
conferences held around the world.")
    (license license:lppl1.3c)))

(define-public texlive-jamtimes
  (package
    (name "texlive-jamtimes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jamtimes/"
                                     "fonts/map/dvips/jamtimes/"
                                     "fonts/tfm/public/jamtimes/"
                                     "fonts/vf/public/jamtimes/"
                                     "tex/latex/jamtimes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03ww7w963hgsxazlrabg4f0h35rd8jbr9ga11lrhqf66b6zvpyv1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jamtimes")
    (synopsis "Expanded Times Roman fonts")
    (description
     "The package offers LaTeX support for the expanded Times Roman font,
which has been used for many years in the @emph{Journal d'Analyse
Mathematique}.  Mathematics support is based on the Belleek fonts.")
    (license license:bsd-3)))

(define-public texlive-jbact
  (package
    (name "texlive-jbact")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/jbact/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0z0x6jrxaayp3w441r1zwlqirvv23g0b8h9xgy6r3ppi71glzqvp"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jbact")
    (synopsis "BibTeX style for biology journals")
    (description
     "The style is a development of @file{apalike.bst} in the BibTeX bundle.
The style serves two journals --- if the user executes
@samp{\\nocite@{TitlesOn@}}, the style serves for the @emph{Journal of
Theoretical Biology}; otherwise it serves for the @emph{Journal of Molecular
Biology}.")
    (license license:knuth)))

(define-public texlive-jeuxcartes
  (package
    (name "texlive-jeuxcartes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jeuxcartes/"
                                     "tex/latex/jeuxcartes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bs4jz87sh5mj0ka40w9lh4hq3pmlwmvm94fpmj8zwk1m7r74b7q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jeuxcartes")
    (synopsis "Macros to insert playing cards")
    (description
     "This package provides macros to insert playing cards, single, or
hand, or random-hand, Poker or French Tarot or Uno, from PNG files.")
    (license
     (list license:cc-by-sa4.0
           license:expat
           license:lgpl2.1
           license:lppl1.3c
           license:public-domain))))

(define-public texlive-jfmutil
  (package
    (name "texlive-jfmutil")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/jfmutil/" "scripts/jfmutil/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c23wak28a1kwgsk6bw1ifa794zywmqzm7a6w5g883nmbfmsq388"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "jfmutil.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/jfmutil")
    (synopsis "Utility to process pTeX-extended TFM and VF")
    (description
     "This program provides functionality to process data files (JFM and VF) that
form logical fonts used in (u)pTeX.  The functions currently available
include:
@itemize
@item The mutual conversion between Japanese virtual fonts (pairs of VF and
JFM) and files in the ZVP format, which is an original text format
representing data in virtual fonts.  This function can be seen as
a counterpart to the @code{vftovp} and @code{vptovf} programs.
@item The mutual conversion between VF files alone and files in the ZVP0
format, which is a subset of the ZVP format.
@end itemize")
    (license license:expat)))

(define-public texlive-jigsaw
  (package
    (name "texlive-jigsaw")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jigsaw/" "tex/latex/jigsaw/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qpbsff6saxv2qp4fzyqrprxjy2434ylm11snyc3d59imdmksq0b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jigsaw")
    (synopsis "Draw jigsaw pieces with TikZ")
    (description
     "This is a small LaTeX package to draw jigsaw pieces with TikZ.  It is
possible to draw individual pieces and adjust their shape, create tile
patterns or automatically generate complete jigsaws.")
    (license license:lppl1.3c)))

(define-public texlive-jkmath
  (package
    (name "texlive-jkmath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jkmath/" "tex/latex/jkmath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gqm6wfarf20yi3cq2h4lbnqp39fif1wg6gpkvbqpy6zlndbdb0r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jkmath")
    (synopsis "Macros for mathematics that make the code more readable")
    (description
     "Inspired by the @code{physicspackage}, the package defines some simple
macros for mathematical notation which make the code more readable or allow
flexibility in typesetting material.")
    (license license:lppl)))

(define-public texlive-jmb
  (package
    (name "texlive-jmb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/jmb/" "tex/latex/jmb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a5nz825jppq3pl1263w2sbm0a48kmmndppfpp7vi69n5j2248dy"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jmb")
    (synopsis "BibTeX style for the @emph{Journal of Theoretical Biology}")
    (description
     "This BibTeX bibliography style is for the @emph{Journal of Molecular
Biology} and @emph{Journal of Theoretical Biology}; the accompanying LaTeX
package is a close relative of @code{apalike.sty} in the BibTeX distribution;
it features author-date references.")
    (license license:knuth)))

(define-public texlive-jmlr
  (package
    (name "texlive-jmlr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jmlr/" "source/latex/jmlr/"
                                     "tex/latex/jmlr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "125zcy1363xlay5ss411x1rl7nyidbh5aygvcr8q8j3qp4yqajrn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jmlr")
    (synopsis "Class files for the @emph{Journal of Machine Learning Research}")
    (description
     "The @code{jmlr} bundle provides a class for authors (@code{jmlr}) and
a class for production editors (@code{jmlrbook}) for the @emph{Journal of
Machine Learning Research}.  The @code{jmlrbook} class can be used to combine
articles written using the @code{jmlr} class into a book.")
    (license license:lppl1.3+)))

(define-public texlive-jneurosci
  (package
    (name "texlive-jneurosci")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/jneurosci/"
                                     "doc/latex/jneurosci/"
                                     "tex/latex/jneurosci/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1y010df0hxqsjb1q571z4s3vnz2q03l2n4lycg6z89b2yyvdplsv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jneurosci")
    (synopsis "BibTeX style for the @emph{Journal of Neuroscience}")
    (description
     "This is a slightly modified version of the @code{namedplus} style, which
fully conforms with the @emph{Journal of Neuroscience} citation style.  It
should be characterised as an author-date citation style; a BibTeX style and
a LaTeX package are provided.")
    (license license:lppl)))

(define-public texlive-jnuexam
  (package
    (name "texlive-jnuexam")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jnuexam/" "tex/latex/jnuexam/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0n4nj9k5ahk2fncgdxbmq20kzar7jskwqcpiz76kdv136ci3c176"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jnuexam")
    (synopsis "Exam class for Jinan University")
    (description
     "The package provides an exam class for Jinan University (China).")
    (license license:lppl1.3+)))

(define-public texlive-josefin
  (package
    (name "texlive-josefin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/josefin/"
                                     "fonts/enc/dvips/josefin/"
                                     "fonts/map/dvips/josefin/"
                                     "fonts/tfm/public/josefin/"
                                     "fonts/truetype/public/josefin/"
                                     "fonts/type1/public/josefin/"
                                     "fonts/vf/public/josefin/"
                                     "tex/latex/josefin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ja91mkcpgvdycqxlfa1xfay427b3d7akq8pcdwvgakzgf9bkb1s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/josefin")
    (synopsis "Josefin fonts with LaTeX support")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the Josefin Sans family of fonts, designed by Santiago Orozco.  Josefin Sans
is available in seven weights, with corresponding italics.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-jourcl
  (package
    (name "texlive-jourcl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jourcl/" "tex/latex/jourcl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wbq0mjl6931267qiw0nrfqxa4blpddqyv27m3wggbpbrz9hvakb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jourcl")
    (synopsis "Cover letter for journal submissions")
    (description
     "Paper submissions to journals are usually accompanied by a cover letter.
This package provides a LaTeX class and a template for such a cover letter
with the following main features:

@itemize

@item minimalistic design,

@item custom image,

@item pre-defined commands for journal name, author, date, etc.

@item many macros contained in this package speed up the process of
preparing the necessary ingredients for the cover letter;

@item macros for recommending up to three reviewers and editors;

@item ORCID logo and link to the submitting author's ORCID page;

@item controls for adding a ``conflict of interest'' statement and declaration;

@item custom greeting;

@item predefined valedictions for different types of submissions.

@end itemize")
    (license license:cc-by-sa4.0)))

(define-public texlive-jpsj
  (package
    (name "texlive-jpsj")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jpsj/" "tex/latex/jpsj/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gvszj0igklm8b0p268j59ysfbahh03c6nbm6gpzkan3p4ijabdi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jpsj")
    (synopsis
     "Document class for @emph{Journal of the Physical Society of Japan}")
    (description
     "This package provides a document class for @emph{Journal of the Physical
Society of Japan}.")
    (license license:lppl)))

(define-public texlive-junicode
  (package
    (name "texlive-junicode")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/junicode/"
                                     "fonts/enc/dvips/junicode/"
                                     "fonts/map/dvips/junicode/"
                                     "fonts/opentype/public/junicode/"
                                     "fonts/tfm/public/junicode/"
                                     "fonts/truetype/public/junicode/"
                                     "fonts/type1/public/junicode/"
                                     "fonts/vf/public/junicode/"
                                     "tex/latex/junicode/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qm6p9dhibyp2q6slw2fw1ph230rak8vqvk4mdhx4fls3i6zfcfj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/junicode")
    (synopsis "TrueType font for medievalists")
    (description
     "Junicode is a TrueType font with many OpenType features for
antiquarians (especially medievalists) based on typefaces used by the Oxford
Press in the late 17th and early 18th centuries.  It works well with
Xe(La)TeX.")
    (license license:silofl1.1)))

(define-public texlive-jupynotex
  (package
    (name "texlive-jupynotex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jupynotex/"
                                     "tex/latex/jupynotex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dfb20pv1ws89ckk80hnj57w64m4whmm8s66wh2lb9s3a2rd0brk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jupynotex")
    (synopsis "Include whole or partial Jupyter notebooks in LaTeX documents")
    (description
     "This package provides a Python script and a LaTeX @file{.sty} file which
can be used together to include Jupyter Notebooks (all of them, or some
specific cells) as part of a LaTeX document.  It will convert the Jupyter
Notebook format to proper LaTeX so it gets included seamlessly, supporting
text, LaTeX, images, etc.")
    (license license:asl2.0)))

(define-public texlive-jura
  (package
    (name "texlive-jura")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jura/" "source/latex/jura/"
                                     "tex/latex/jura/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lxss00mymcxljzaqmwj9zpy9cpc71a0a4g6bqrzvgspj506jdp7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jura")
    (synopsis "Document class for German legal texts")
    (description
     "This package implements the standard layout for German term papers in law
(one-and-half linespacing, 7 cm margins, etc.).  It includes @code{alphanum}
that permits alphanumeric section numbering (e.g., @samp{A. Introduction};
@samp{III. International Law}).")
    (license license:gpl3+)))

(define-public texlive-juraabbrev
  (package
    (name "texlive-juraabbrev")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/juraabbrev/"
                                     "makeindex/juraabbrev/"
                                     "source/latex/juraabbrev/"
                                     "tex/latex/juraabbrev/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xybpc9j3x0gvq8hs5hrbb6ivilmp8ayjp6bq8xd7gsy7awag5d7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/juraabbrev")
    (synopsis "Abbreviations for typesetting (German) juridical documents")
    (description
     "This package should be helpful for people working on (German) law.  It
helps you to handle abbreviations and creates a list of those (pre-defined)
abbreviations that have actually been used in the document.")
    (license license:gpl3+)))

(define-public texlive-jurabib
  (package
    (name "texlive-jurabib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/jurabib/" "bibtex/bst/jurabib/"
                                     "doc/latex/jurabib/" "source/latex/jurabib/"
                                     "tex/latex/jurabib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z8n654n0f97qayql0111smpydwmdf6i22bg55i6nh5al2jcsbbb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jurabib")
    (synopsis
     "Extended BibTeX citation support for the humanities and legal texts")
    (description
     "This package enables automated citation with BibTeX for legal studies
and the humanities.  In addition, the package provides commands for specifying
editors in a commentary in a convenient way.  Simplified formatting of the
citation as well as the bibliography entry is also provided.  It is possible
to display the (short) title of a work only if an authors is cited with
multiple works.  Giving a full citation in the text, conforming to the
bibliography entry, is supported.  Several options are provided which might be
of special interest for those outside legal studies--for instance, displaying
multiple full citations.  In addition, the format of last names and first
names of authors may be changed easily.  Cross references to other footnotes
are possible.  Language dependent handling of bibliography entries is possible
by the special language field.")
    (license license:gpl3+)))

(define-public texlive-juramisc
  (package
    (name "texlive-juramisc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/juramisc/" "tex/latex/juramisc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ka6gmlb0vlg0317ihjnlklvaajj4rrbi7c2iisngz69fgjm26iy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/juramisc")
    (synopsis "Typesetting German juridical documents")
    (description
     "This package provides a collection of classes for typesetting court
sentences, legal opinions, books and dissertations for German lawyers.
A @code{jurabook} class is also provided, which may not yet be complete.")
    (license license:lppl)))

(define-public texlive-jurarsp
  (package
    (name "texlive-jurarsp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/jurarsp/" "doc/latex/jurarsp/"
                                     "source/latex/jurarsp/" "tex/latex/jurarsp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03lwp5v6fmq2zhiwaf4qj52k44grzh119il4pdp2fvgl2q4a39sm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jurarsp")
    (synopsis
     "Citations of judgements and official documents in (German) juridical
documents")
    (description
     "This package should be helpful for people working on (German) law.
It (ab)uses BibTeX for citations of judgements and official documents.  For
this purpose, a special BibTeX-style is provided.")
    (license license:gpl3+)))

(define-public texlive-jwjournal
  (package
    (name "texlive-jwjournal")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jwjournal/"
                                     "tex/latex/jwjournal/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "037brrxgd0zdjcac41n8gpvqiwj4n77f2q93bpdgla20ldyk7m51"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-einfart))
    (home-page "https://ctan.org/pkg/jwjournal")
    (synopsis "Personal class for writing journals")
    (description
     "This LaTeX document class enables the user to turn simple pure text
entries into a colorful and nicely formatted journal.")
    (license license:lppl1.3c)))

(define-public texlive-karnaugh
  (package
    (name "texlive-karnaugh")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/karnaugh/" "tex/latex/karnaugh/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zpn2q5v9dv8196h9186b9wx2hbp0j9l1fg6k2pdqhwxgdcgssxh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/karnaugh")
    (synopsis "Typeset Karnaugh-Veitch-maps")
    (description
     "The package provides macros for typesetting Karnaugh-Maps and
Veitch-Charts in a simple and user-friendly way.  Karnaugh-Maps and
Veitch-Charts are used to display and simplify logic functions manually.
These macros can typeset Karnaugh-Maps and Veitch-Charts with up to ten
variables.")
    (license license:lppl1.0+)))

(define-public texlive-karnaugh-map
  (package
    (name "texlive-karnaugh-map")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/karnaugh-map/"
                                     "source/latex/karnaugh-map/"
                                     "tex/latex/karnaugh-map/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01gcffk9vys81b0ad1rxlqnq8i8yflfhby43fr46h7li6p08rx09"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/karnaugh-map")
    (synopsis "LaTeX package for drawing Karnaugh maps with up to 6 variables")
    (description
     "This package draws Karnaugh maps with 2, 3, 4, 5, and 6 variables.  It
also contains commands for filling the karnaugh map with terms
semi-automatically or manually.  Last but not least it contains commands for
drawing implicants on top of the map.")
    (license license:cc-by-sa3.0)))

(define-public texlive-karnaughmap
  (package
    (name "texlive-karnaughmap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/karnaughmap/"
                                     "source/latex/karnaughmap/"
                                     "tex/latex/karnaughmap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wwgdcpv5chr7frnlf2j56yiwk5m28bixbv83p2h4f3jl10v5hwi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/karnaughmap")
    (synopsis "Typeset Karnaugh maps")
    (description
     "This package provides an easy to use interface to typeset Karnaugh maps
using TikZ.  Though similar to the @code{karnaugh} macros, it provides
a key-value system to customize Karnaugh maps and a proper LaTeX package.")
    (license license:lppl1.2+)))

(define-public texlive-kaytannollista-latexia
  (package
    (name "texlive-kaytannollista-latexia")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/kaytannollista-latexia/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0w45gqrvbjfzqsx84flyf150zj8jw1wcd1zfhd361nzazqz7b0xw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/kaytannollista-latexia")
    (synopsis "Practical manual for LaTeX (Finnish)")
    (description
     "@emph{Kaytannollista Latexia} is a practical manual for LaTeX written in
the Finnish language.  The manual covers most of the topics that a typical
document author needs.  So it can be a useful guide for beginners as well as
a reference manual for advanced users.")
    (license license:cc-by-sa4.0)))

(define-public texlive-kdgdocs
  (package
    (name "texlive-kdgdocs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/kdgdocs/" "source/latex/kdgdocs/"
                                     "tex/latex/kdgdocs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yjd6y3h8m08zwhnd0bg3153xapxxqy2i23i30fcvv5mj5pnnql8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/kdgdocs")
    (synopsis "Document classes for Karel de Grote University College")
    (description
     "The bundle provides two classes for usage by @acronym{KdG, Karel de
Grote} University College professors and master students: @code{kdgcoursetext}
for writing course texts, and @code{kdgmasterthesis} for writing master's
theses.")
    (license license:lppl1.3+)))

(define-public texlive-kdpcover
  (package
    (name "texlive-kdpcover")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/kdpcover/"
                                     "source/latex/kdpcover/"
                                     "tex/latex/kdpcover/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "116pzg0bdrj78vs2sq196jcwnv16b734kqnhfcg3fka4mf6jk2d1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-anyfontsize
           texlive-geometry
           texlive-graphics
           texlive-microtype
           texlive-pgf
           texlive-setspace
           texlive-textpos
           texlive-tools
           texlive-xcolor
           texlive-xifthen
           texlive-xkeyval))
    (home-page "https://ctan.org/pkg/kdpcover")
    (synopsis "Covers for books published by Kindle Direct Publishing")
    (description
     "The problem this class solves is the necessity to change the size of the
cover PDF according to the number of pages in the book --- the bigger the
book, the larger the spine of the book must be.  The provided class makes the
necessary calculations on-the-fly, using the @code{qpdf} tool.")
    (license license:expat)))

(define-public texlive-kfupm-math-exam
  (package
    (name "texlive-kfupm-math-exam")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/kfupm-math-exam/"
                                     "source/latex/kfupm-math-exam/"
                                     "tex/latex/kfupm-math-exam/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hgyasjhqpb1b9xnffzcwhsi8rr6wx929awn0sadx6rsabiamb16"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/kfupm-math-exam")
    (synopsis
     "LaTeX document style to produce homework, quiz and exam papers")
    (description
     "The package provides commands and environments that simplify and
streamline the process of preparing homework, quiz and exam papers according
to a preferred style.  The default style is based on the guidelines set by the
department of mathematics at @acronym{KFUPM, King Fahd University of Petroleum
and Minerals}.  It can be easily customized to fit any style for any
institution.")
    (license license:expat)))

(define-public texlive-kixfont
  (package
    (name "texlive-kixfont")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/kixfont/"
                                     "fonts/source/public/kixfont/"
                                     "fonts/tfm/public/kixfont/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0w6fjsws26plm9p74c3qcvvgx5hhlabfbhpc046rb31183f7h0q5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/kixfont")
    (synopsis "Font for KIX codes")
    (description
     "The KIX code is a barcode-like format used by the Dutch PTT to encode
country codes, zip codes and street numbers in a machine-readable format.  If
printed below the address line on bulk mailings, a discount can be obtained.
The font is distributed in Metafont format, and covers the numbers and
upper-case letters.")
    (license license:public-domain)))

(define-public texlive-kluwer
  (package
    (name "texlive-kluwer")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/kluwer/" "doc/latex/kluwer/"
                                     "source/latex/kluwer/" "tex/latex/kluwer/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14y95srzggd8kaiyjq0sz5amvmppl3rilhj9fr0vcjsy2g1ms52z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          ;; The "kluwer.ins" file only generates "kluwer.cls".  To that
          ;; effect, it needs data from files located in
          ;; "tex/latex/kluwer/".  Bring them to build directory.
          (add-before 'build 'bring-data-files
            (lambda _
              (for-each (lambda (f) (install-file f "build/"))
                        (find-files "tex/latex/kluwer/" "\\.(clo|sty)$")))))))
    (home-page "https://ctan.org/pkg/kluwer")
    (synopsis "@emph{Kluwer} publication support")
    (description
     "This package provides a class file for @emph{Kluwer} journal
submissions, and bibliography style for named references.  It also includes
@file{klucite.sty}, which collapses bibliographic citations, and
@file{klups.sty}, which attempts to select Times for text and MathTime for
math instead of Computer Modern.  This package is most likely long obsolete,
unfortunately.")
    (license license:knuth)))

(define-public texlive-kotex-oblivoir
  (package
    (name "texlive-kotex-oblivoir")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/kotex-oblivoir/"
                                     "tex/latex/kotex-oblivoir/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rnwzbalirc1qdhwkn976w09r2q39vycn027m2cmk6wxcc2v67bs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-kotex-utf texlive-memoir))
    (home-page "https://ctan.org/pkg/kotex-oblivoir")
    (synopsis "LaTeX document class for typesetting Korean documents")
    (description
     "The class is based on @code{memoir}, and is adapted to typesetting
Korean documents.")
    (license license:lppl1.3c)))

(define-public texlive-kotex-plain
  (package
    (name "texlive-kotex-plain")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/kotex-plain/"
                                     "tex/plain/kotex-plain/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0r79cvm7iy1266yvrn60vwq9wjkgmzgfihbz9dqc84lif5q8kmnw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/kotex-plain")
    (synopsis "Macros for typesetting Korean under Plain TeX")
    (description
     "The package provides macros for typesetting Hangul, the native alphabet
of the Korean language, using Plain TeX.  Korean text should be encoded in
UTF-8.")
    (license license:lppl1.3c)))

(define-public texlive-kotex-utf
  (package
    (name "texlive-kotex-utf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/kotex-utf/"
                                     "tex/latex/kotex-utf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1l3hlav7fihws2ly49fn994sc7mjcdwk3zp4xhkgvm0mqjbxzxzz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-cjk-ko))
    (home-page "https://ctan.org/pkg/kotex-utf")
    (synopsis "Typeset Hangul, coded in UTF-8")
    (description
     "The package typesets Hangul, which is the native alphabet of the Korean
language; input Korean text should be encoded in UTF-8.")
    (license license:lppl1.3c)))

(define-public texlive-kotex-utils
  (package
    (name "texlive-kotex-utils")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/kotex-utils/"
                                     "makeindex/kotex-utils/"
                                     "scripts/kotex-utils/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01qmr50fr3i2gzgjyj69jgj4czf62s22z58kja6hbqygczc1jba3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts
           #~(list "jamo-normalize.pl" "komkindex.pl" "ttf2kotexfont.pl")))
    (inputs (list perl))
    (propagated-inputs (list texlive-kotex-utf))
    (home-page "https://ctan.org/pkg/kotex-utils")
    (synopsis "Utility scripts and support files for typesetting Korean")
    (description
     "The bundle provides scripts and support files for index generation in
Korean language typesetting.")
    (license license:lppl)))

(define-public texlive-knuth-errata
  (package
    (name "texlive-knuth-errata")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/knuth-errata/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rcyw7dqcwlnf9q421k017hrx5c0d9rra6rcr3n6wqmhxmdy5mn9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/knuth-errata")
    (synopsis "Knuth's published errata")
    (description
     "These files record details of problems reported in Knuth's Computers and
Typesetting series of books, for the Computer Modern fonts, and for TeX,
Metafont and related programs.")
    (license license:knuth)))

(define-public texlive-knuth-hint
  (package
    (name "texlive-knuth-hint")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/knuth-hint/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fl3nyzsf9jifccw75grhdgyh5qhj4akkkyaa7mp6kpfznipqbmc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/knuth-hint")
    (synopsis "HINT collection of typeset C/WEB sources in TeX Live")
    (description
     "The @code{knuth-hint} package contains the large collection of HINT
documents for many of the CWEB amd WEB sources of programs in the TeX Live
distribution (and, for technical reasons, PDF documents for CTWILL and XeTeX).
Each program is presented in its original form as written by the respective
authors, and in the changed form as used in TeX Live.  Care has been taken to
keep the section numbering intact, so that you can study the codes and the
changes in parallel.

Also included are the errata for Donald Knuth's @emph{Computers &
Typesetting}.  HINT is the dynamic document format created by Martin Ruckert's
HiTeX engine.  The HINT files can be viewed with the @code{hintview}
application.  The @code{knuth-hint} package is a showcase of HiTeX's
capabilities.")
    (license (list license:public-domain license:knuth))))

(define-public texlive-knuth-pdf
  (package
    (name "texlive-knuth-pdf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/knuth-pdf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ig3ml88gqks5j9ly73qsx0kdii5m2i46f9d9bnh7nr9bjbpmd38"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/knuth-pdf")
    (synopsis "PDF collection of typeset C/WEB sources in TeX Live")
    (description
     "Here you find a large collection of PDF documents for many C/WEB
programs in TeX Live, both in their original form as written by their
respective authors, and in the changed form as they are actually used in the
TeX Live system.  Care has been taken to keep the section numbering intact, so
that you can study the sources and their changes in parallel.

Also included is the collection of errata for Donald Knuth's @emph{Computers &
Typesetting series}.  Although not all the texts here are written or
maintained by Donald Knuth, it is more convenient for everything to be
collected in one place for reading and searching.  They all stem from the
system that Knuth created.  The central entry point is the index file, with
links to the individual documents, either in HTML or in PDF format.")
    (license license:public-domain)))

(define-public texlive-ksfh-nat
  (package
    (name "texlive-ksfh-nat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/ksfh_nat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qzn0n19lslf2qg8fvm844xx5k7s8a275a77z2ynbb0vs1w4prpw"))))
    (properties '((upstream-name . "ksfh_nat")))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ksfh-nat")
    (synopsis "BibTeX style for KSFH Munich")
    (description
     "The package supports bibliographies as standard for
KSFH (@emph{Katholische Stiftungsfachhochschule}) Munich.  BibTeX entries in
@code{article}, @code{book}, @code{inbook}, @code{incollection} and
@code{misc} formats are supported.")
    (license license:lppl1.3+)))

(define-public texlive-ksp-thesis
  (package
    (name "texlive-ksp-thesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ksp-thesis/"
                                     "tex/latex/ksp-thesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03jklx2yym78b29y3s8fh91mfsn9p4w1cl7yisj3kyyawygzs6hp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ksp-thesis")
    (synopsis
     "LaTeX class for theses published with KIT Scientific Publishing")
    (description
     "This package provides a LaTeX class intended for authors who want to
publish their thesis or other scientific work with @acronym{KSP, KIT
Scientific Publishing}.  The class is based on the @code{scrbook} class of the
KOMA-script bundle in combination with the ClassicThesis and ArsClassica
packages.  It modifies some of the layout and style definitions of these
packages in order to provide a document layout that should be compatible with
the requirements by KSP.")
    (license license:lppl1.3+)))

(define-public texlive-ku-template
  (package
    (name "texlive-ku-template")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ku-template/"
                                     "tex/latex/ku-template/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1aa3rday97l1b7vca6sq1jwj81bqx6j7d0ijz0jr4vp3r27pxgs9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ku-template")
    (synopsis "Copenhagen University or faculty logo for front page")
    (description
     "This package provides a comprehensive package for adding University of
Copenhagen or faculty logo to your front page.  For use by student or staff at
University of Copenhagen (Kobenhavns Universitet).")
    (license license:expat)))

(define-public texlive-kvmap
  (package
    (name "texlive-kvmap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/kvmap/" "source/latex/kvmap/"
                                     "tex/latex/kvmap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04sjs8r2ijd0rdx5d13p6pwnwnwd0rgzx894j3cqfi29y860c7yr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-amsmath texlive-l3experimental
                             texlive-pgf))
    (home-page "https://ctan.org/pkg/kvmap")
    (synopsis "Create Karnaugh maps with LaTeX")
    (description
     "This LaTeX package allows the creation of (even large) Karnaugh maps.
It provides a tabular-like input syntax and support for drawing bundles
(implicants) around adjacent values.")
    (license license:lppl1.3c)))

(define-public texlive-langsci
  (package
    (name "texlive-langsci")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/langsci/"
                                     "tex/xelatex/langsci/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jqv69wbr9mwg019h4x8b7s717299dy6pvmdpqs1mrdnrpzvl1v6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/langsci")
    (synopsis "Typeset books for publication with Language Science Press")
    (description
     "This package allows you to typeset monographs and edited volumes for
publication with @url{https://www.langsci-press.org, Language Science Press}.
It includes all necessary files for title pages, frontmatter, main content,
list of references and indexes.")
    (license license:lppl1.3+)))

(define-public texlive-langsci-avm
  (package
    (name "texlive-langsci-avm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/langsci-avm/"
                                     "source/latex/langsci-avm/"
                                     "tex/latex/langsci-avm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n53syf2slndgjbndjhd3cl8y6bl9j3xgb86z9r1mwvdcdls5674"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/langsci-avm")
    (synopsis "Feature structures and attribute-value matrices (AVM)")
    (description
     "This package provides a package for typesetting feature structures,
also known as attribute-value matrices (AVMs), for use in linguistics.  The
package provides a minimal and easy to read syntax.  The package serves the
same purpose as @code{avm} package, but shares no code base with that
package.")
    (license license:lppl1.3c)))

(define-public texlive-lato
  (package
    (name "texlive-lato")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/lato/"
                                     "fonts/enc/dvips/lato/"
                                     "fonts/map/dvips/lato/"
                                     "fonts/tfm/typoland/lato/"
                                     "fonts/truetype/typoland/lato/"
                                     "fonts/type1/typoland/lato/"
                                     "fonts/vf/typoland/lato/"
                                     "tex/latex/lato/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ykwm108zh79dv96axl74izzhzvmbx74pcl46i99ix2qpicyvcf7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lato")
    (synopsis "Lato font family and LaTeX support")
    (description
     "Lato is a sanserif typeface family designed by Lukasz Dziedzic.  This
font, which includes five weights (hairline, light, regular, bold and black),
is available as TrueType files.  The package provides support for this font in
LaTeX.")
    (license (list license:silofl1.1 license:lppl1.3c))))

(define-public texlive-l2picfaq
  (package
    (name "texlive-l2picfaq")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/l2picfaq/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mk8d082gcqlxw2x7d2w85sm6i51928pijybzbsh9fy2rfcv99xz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/l2picfaq")
    (synopsis "LaTeX pictures how-to (German)")
    (description
     "The document (in German) is a collection of how-to notes about LaTeX and
pictures.  The aim of the document is to provide a solution, in the form of
some sample code, for every problem.")
    (license license:fdl1.3+)))

(define-public texlive-l2tabu
  (package
    (name "texlive-l2tabu")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/l2tabu/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jl0n43bqbys0c9v0xb4sjql0gvk4r14ldzp2rbwzjsk8a39q8v8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/l2tabu")
    (synopsis "Obsolete packages and commands")
    (description
     "This package provides a German translation of the @emph{l2tabu}
practical guide to LaTeX2e by Mark Trettin.  It focuses on obsolete packages
and commands.")
    (license license:gpl3+)))

(define-public texlive-l2tabu-english
  (package
    (name "texlive-l2tabu-english")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/l2tabu-english/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dqmdr3lffhiaq7pg5pn6ia46miwq4nh5vimhd0qbf936amiv1mm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/l2tabu-english")
    (synopsis "English translation of @emph{Obsolete packages and commands}")
    (description
     "This package provides an English translation of the @emph{l2tabu}
practical guide to LaTeX2e by Mark Trettin.  It focuses on obsolete packages
and commands.")
    (license license:fdl1.2+)))

(define-public texlive-l2tabu-french
  (package
    (name "texlive-l2tabu-french")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/l2tabu-french/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c6fbmgwv2adlxbhl1shvpa1w6xd36gmrwvkjgdp9xc3q999l4dj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/l2tabu-french")
    (synopsis "English translation of @emph{Obsolete packages and commands}")
    (description
     "This package provides a French translation of the @emph{l2tabu}
practical guide to LaTeX2e by Mark Trettin.  It focuses on obsolete packages
and commands.")
    (license license:fdl1.2+)))

(define-public texlive-l2tabu-italian
  (package
    (name "texlive-l2tabu-italian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/l2tabu-italian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bgfmn5v80rdhs9wmjj6mki29p28ip1d29rmgbw4jh4z6gd4sf22"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/l2tabu-italian")
    (synopsis "Italian translation of @emph{Obsolete packages and commands}")
    (description
     "This package provides an Italian translation of the @emph{l2tabu}
practical guide to LaTeX2e by Mark Trettin.  It focuses on obsolete packages
and commands.")
    (license license:fdl1.2+)))

(define-public texlive-l2tabu-spanish
  (package
    (name "texlive-l2tabu-spanish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/l2tabu-spanish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p83xflgv8x7nq9mylh468zn3hz5pv3zxprc63q51fwx0ylxfdbk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/l2tabu-spanish")
    (synopsis "Spanish translation of @emph{Obsolete packages and commands}")
    (description
     "This package provides a Spanish translation of the @emph{l2tabu}
practical guide to LaTeX2e by Mark Trettin.  It focuses on obsolete packages
and commands.")
    (license license:public-domain)))

(define-public texlive-labyrinth
  (package
    (name "texlive-labyrinth")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/labyrinth/"
                                     "tex/latex/labyrinth/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0i4w3dmfjq9vp6m82p4afplca0pdvk36g2h1yskmwbis07bykdgp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/labyrinth")
    (synopsis "Draw labyrinths and solution paths")
    (description
     "The @code{labyrinth} package provides code and an environment for
typesetting simple labyrinths with LaTeX, and generating an automatic or
manual solution path.")
    (license license:lppl)))

(define-public texlive-lambda
  (package
    (name "texlive-lambda")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/lambda/base/" "tex/lambda/config/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ajx5g5cd5s9jqr4b196689k7zmlxmhhksly88qps31s7lzaprvn"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lambda")
    (synopsis "LaTeX for Omega and Aleph")
    (description "This is LaTeX for Omega and Aleph.")
    (license license:lppl1.0+)))

(define-public texlive-langnames
  (package
    (name "texlive-langnames")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/langnames/"
                                     "source/latex/langnames/"
                                     "tex/latex/langnames/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cyhqvr2j2h6sbblg4dpqwnl5kxlr82s0fs5ppm7vpnmqbhzcsm7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/langnames")
    (synopsis "Name languages and their genetic affiliations consistently")
    (description
     "This package attempts to make the typing of language names, codes, and
families slightly easier by providing macros to access pre-defined
language --- code --- family combinations from two important databases, as
well as the possibility to create new combinations.  It may be particularly
useful for large, collaborative projects as well as typologically minded ones
with a variety of language examples.")
    (license license:lppl1.3+)))

(define-public texlive-latex-notes-zh-cn
  (package
    (name "texlive-latex-notes-zh-cn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/latex-notes-zh-cn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0w9rmd7b5fnfvix653n9vbnn1k8yxlaaak79ipvm8p53dx75xfxd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latex-notes-zh-cn")
    (synopsis "Chinese Introduction to TeX and LaTeX")
    (description
     "The document is an introduction to TeX and LaTeX, in Chinese.  It covers
basic text typesetting, mathematics, graphics, tables, Chinese language &
fonts, and some miscellaneous features (hyperlinks, long documents,
bibliographies, indexes and page layout).")
    (license license:lppl1.3+)))

(define-public texlive-latex2e-help-texinfo-fr
  (package
    (name "texlive-latex2e-help-texinfo-fr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/info/latex2e-fr.info"
                                     "doc/latex/latex2e-help-texinfo-fr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13s0zjwk3m95kbx4qrz2xwp8kifzc2zmasp1ks9l2acf1nqfac9p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latex2e-help-texinfo-fr")
    (synopsis "French translation of @code{latex2e-help-texinfo}")
    (description
     "This package provides a complete French translation of
@code{latex2e-help-texinfo}.")
    (license license:public-domain)))

(define-public texlive-latex2e-help-texinfo-spanish
  (package
    (name "texlive-latex2e-help-texinfo-spanish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/info/latex2e-es.info"
                                     "doc/latex/latex2e-help-texinfo-spanish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1v3wa99phdmsiajbq0ad4h939cpwjwzpq88h6s0796h5fr34hrvq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latex2e-help-texinfo")
    (synopsis "Spanish translation of @code{latex2e-help-texinfo}")
    (description
     "This package provides a complete Spanish translation of
@code{latex2e-help-texinfo}.")
    (license license:public-domain)))

(define-public texlive-latex4musicians
  (package
    (name "texlive-latex4musicians")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latex4musicians/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zvy2pa93kyn056d5n0irzdq5xmzki6d35zxacxfy19r0g9rwq6f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latex4musicians")
    (synopsis "Guide for combining LaTeX and music")
    (description
     "This guide, @emph{LaTeX for Musicians}, explains how to create LaTeX
documents that include several kinds of music elements: music symbols, song
lyrics, guitar chords diagrams, lead sheets, music excerpts, guitar
tablatures, multi-page scores.")
    (license license:fdl1.3+)))

(define-public texlive-latexcheat-de
  (package
    (name "texlive-latexcheat-de")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latexcheat-de/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cpqcvqkkyb2bf87yjvc2migxawnacx5mva8dapma7hmwx0z7rhm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latexcheat-de")
    (synopsis "LaTeX cheat sheet, in German")
    (description
     "This is a translation to German of Winston Chang's LaTeX cheat sheet (a
reference sheet for writing scientific papers).  It has been adapted to German
standards using the KOMA script document classes.")
    (license license:lppl)))

(define-public texlive-latexcheat-esmx
  (package
    (name "texlive-latexcheat-esmx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latexcheat-esmx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1d6nk9p9adlhgr28mnnizrxzzqlk20zw2clcddqlaa8pn73dqhcm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latexcheat-esmx")
    (synopsis "LaTeX cheat sheet, in Spanish")
    (description
     "This is a translation to Spanish (Castellano) of Winston Chang's LaTeX
cheat sheet (a reference sheet for writing scientific papers).")
    (license license:lppl)))

(define-public texlive-latino-sine-flexione
  (package
    (name "texlive-latino-sine-flexione")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latino-sine-flexione/"
                                     "tex/latex/latino-sine-flexione/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0py61xhgg73jlz6f9p7g9r06pn7m648d29068i4d97gqc20i2jvc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latino-sine-flexione")
    (synopsis "LaTeX support for documents written in Peano's Interlingua")
    (description
     "Latino sine Flexione (or Interlingua) is a language constructed by
Giuseppe Peano at the beginning of the last century.  This simplified Latin is
designed to be an instrument for international cooperation, especially in the
academic sphere.  This package provides the necessary translations to use the
language within a LaTeX document.  It also imports @code{fontenc} in order to
be able to use ligatures and quotation marks.  Finally, it offers a text in
Interlingua that can be used as a dummy text: @emph{Fundamento de
intelligentia}.")
    (license license:public-domain)))

(define-public texlive-leadsheets
  (package
    (name "texlive-leadsheets")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/leadsheets/"
                                     "tex/latex/leadsheets/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12aly170pf10dw82i6rykiaxl9r5mmva7kvkhlywir4s6gx07gjc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/leadsheets")
    (synopsis "Typesetting leadsheets and songbooks")
    (description
     "This LaTeX package offers support for typesetting simple leadsheets of
songs, i.e., song lyrics and the corresponding chords.")
    (license license:lppl1.3+)))

(define-public texlive-ledmac
  (package
    (name "texlive-ledmac")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ledmac/" "source/latex/ledmac/"
                                     "tex/latex/ledmac/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03b23rkhdhvr0rbmp687p76mlq68crsfyh67frxbnh11vccmfgnc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ledmac")
    (synopsis "Typeset scholarly editions")
    (description
     "This package provides a macro package for typesetting scholarly critical
editions.  The @code{ledmac} package is a LaTeX port of the Plain TeX EDMAC
macros.  It supports indexing by page and line number and simple
@code{tabular}- and @code{array}-style environments.  The package is
distributed with the related @code{ledpar} and @code{ledarab} packages.  The
package is now superseded by @code{reledmac}.")
    (license license:lppl1.3+)))

(define-public texlive-letgut
  (package
    (name "texlive-letgut")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/letgut/"
                                     "source/lualatex/letgut/"
                                     "tex/lualatex/letgut/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cylvg39cav72pg3h48awmj7fka5kyj805hv9ayzk9ybxyvkwayz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/letgut")
    (synopsis
     "Class for the newsletter @code{La Lettre GUTenberg} of the French TeX User
Group GUTenberg")
    (description
     "The French TeX User Group GUTenberg has been publishing @emph{The
GUTenberg Letter}, its irregular newsletter, since February 1993.  For this
purpose, a dedicated, in-house (La)TeX class was gradually created but,
depending on new needs and on the people who were publishing the Newsletter,
its development was somewhat erratic; in particular, it would not have been
possible to publish its code as it was.  In addition, its documentation was
non-existent.  The Board of Directors of the association, elected in November
2020, wished to provide a better structured, more perennial and documented
class, able to be published on the CTAN.  This is now done with the present
@code{letgut} class.")
    (license license:lppl1.3c)))

(define-public texlive-letterswitharrows
  (package
    (name "texlive-letterswitharrows")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/letterswitharrows/"
                                     "source/latex/letterswitharrows/"
                                     "tex/latex/letterswitharrows/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qws4in1qgj52z2d38lfyx3l3dxp01agfbipy5xdi1p4jyhw6b7c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/letterswitharrows")
    (synopsis "Draw arrows over math letters")
    (description
     "This package provides LaTeX math-mode commands for setting left and
right arrows over mathematical symbols so that the arrows dynamically scale
with the symbols.  While it is possible to set arrows over longer strings of
symbols, the focus lies on single characters.")
    (license license:lppl1.3+)))

(define-public texlive-lexend
  (package
    (name "texlive-lexend")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/lexend/"
                                     "fonts/truetype/public/lexend/"
                                     "tex/latex/lexend/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jk9m3zb3xik463nwsjh003ly3xrrph7kam519b9lyqybyxb16xs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lexend")
    (synopsis "Lexend fonts for XeLaTeX and LuaLaTeX")
    (description
     "The purpose of this package is pretty straightforward: the Lexend font
collection has been designed by Dr.@: Bonnie Shaver-Troup and Thomas Jockin to
make reading easier for everyone.")
    (license (list license:lppl1.3c license:silofl1.1))))

(define-public texlive-lexikon
  (package
    (name "texlive-lexikon")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lexikon/" "tex/latex/lexikon/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0x2h8w3cchzr2lvx5xqs1fn01y7b4lqkky85dard223w2r1dn22m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lexikon")
    (synopsis "Macros for a two language dictionary")
    (description "This package provides macros for a two language
dictionary.")
    (license license:lppl)))

(define-public texlive-lexref
  (package
    (name "texlive-lexref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lexref/" "tex/latex/lexref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0562vjn0vvjsqfi2jqy1yp6mqi8nrs25yc9nr1zc950q421w0vrb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lexref")
    (synopsis "Convenient and uniform references to legal provisions")
    (description
     "The package is aimed at continental lawyers (especially those in
Switzerland and Germany), allowing the user to make references to legal
provisions conveniently and uniformly.  The package also allows the user to
add cited Acts to a nomenclature list (automatically), and to build specific
indexes for each cited Act.")
    (license license:lppl1.3+)))

(define-public texlive-lfb
  (package
    (name "texlive-lfb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/lfb/" "fonts/source/public/lfb/"
                                     "fonts/tfm/public/lfb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n0cf7igvhqnmdk8hjj1lahzr3iaiaqsq01pxkphg6myab127x71"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/lfb")
    (synopsis "Greek font with normal and bold variants")
    (description
     "This is a Greek font written in Metafont, with inspiration from the
Bodoni typefaces in old books.  It is stylistically a little more exotic than
the standard textbook Greek fonts, particularly in glyphs like the lowercase
rho and kappa.  It aims for a rather calligraphic feel, but seems to blend
well with Computer Modern.  There is a ligature scheme which automatically
inserts the breathings required for ancient texts, making the input text more
readable than in some schemes.")
    (license license:lppl)))

(define-public texlive-libertinegc
  (package
    (name "texlive-libertinegc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/libertinegc/"
                                     "fonts/enc/dvips/libertinegc/"
                                     "fonts/map/dvips/libertinegc/"
                                     "fonts/tfm/public/libertinegc/"
                                     "tex/latex/libertinegc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17712j1gb38l4c5b2br7db8ix36kc8kwfpa7d6ass32wz5jck656"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/libertinegc")
    (synopsis "Libertine add-on to support Greek and Cyrillic")
    (description
     "The package provides LaTeX support files to access the Greek and
Cyrillic glyphs in Linux Libertine.  It functions as an add-on to the
@code{libertine} package, using filenames and macro names that are compatible
with that package.")
    (license license:lppl1.3+)))

(define-public texlive-libertinus
  (package
    (name "texlive-libertinus")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/libertinus/"
                                     "tex/latex/libertinus/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13m20jkrf0sp39f0ihc0fw7spzc3gys5xdc720r5gzdnbdqdvih4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/libertinus")
    (synopsis
     "Use the correct @code{libertinus} package according to current TeX
engine")
    (description
     "This package is only a wrapper for the two packages @code{libertinus-type1}
(pdfLaTeX) and @code{libertinus-otf} (LuaLaTeX and XeLaTeX).  The Libertinus
fonts are similar to Libertine and Biolinum, but come with math symbols.")
    (license license:lppl1.3+)))

(define-public texlive-libertinus-fonts
  (package
    (name "texlive-libertinus-fonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/libertinus-fonts/"
                                     "fonts/opentype/public/libertinus-fonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g4y3v7i8bs1677rj56v3kw5q3nkl9ksljmly4m7n42dlpggxiaj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/libertinus-fonts")
    (synopsis "Libertinus font family")
    (description
     "This is a fork of the Linux Libertine and Linux Biolinum fonts that
started as an OpenType math companion of the Libertine font family, but grown
as a full fork.  The family consists of Libertinus Serif, Libertinus Sans,
Libertinus Mono, and Libertinus Math, an OpenType math font for use in
OpenType math-capable applications.")
    (license license:silofl1.1)))

(define-public texlive-libertinus-otf
  (package
    (name "texlive-libertinus-otf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/libertinus-otf/"
                                     "tex/latex/libertinus-otf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0j6p4q251jk3im3ghw9klp7m5psyz0vmkz2ivynml389sd466zgj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/libertinus-otf")
    (synopsis "Support for Libertinus OpenType")
    (description
     "This package offers LuaLaTeX and XeLaTeX support for the Libertinus
OpenType fonts.  Missing fonts are defined via several font feature settings.
The Libertinus fonts are similar to Libertine and Biolinum, but come with
math symbols.")
    (license license:lppl1.3+)))

(define-public texlive-libertinus-type1
  (package
    (name "texlive-libertinus-type1")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/libertinus-type1/"
                                     "fonts/enc/dvips/libertinus-type1/"
                                     "fonts/map/dvips/libertinus-type1/"
                                     "fonts/tfm/public/libertinus-type1/"
                                     "fonts/type1/public/libertinus-type1/"
                                     "fonts/vf/public/libertinus-type1/"
                                     "tex/latex/libertinus-type1/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04maqnzdwk3c0pkjhslyrxdprr581vc078bqzqapr03jxx9x1rlx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/libertinus-type1")
    (synopsis "Support for using Libertinus fonts with LaTeX")
    (description
     "This package provides support for use of Libertinus fonts with
traditional processing engines (LaTeX with Dvips or Dvipdfmx, or pdfLaTeX).")
    (license (list license:gpl2 license:silofl1.1 license:lppl))))

(define-public texlive-libertinust1math
  (package
    (name "texlive-libertinust1math")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/libertinust1math/"
                                     "fonts/afm/public/libertinust1math/"
                                     "fonts/enc/dvips/libertinust1math/"
                                     "fonts/map/dvips/libertinust1math/"
                                     "fonts/tfm/public/libertinust1math/"
                                     "fonts/type1/public/libertinust1math/"
                                     "fonts/vf/public/libertinust1math/"
                                     "tex/latex/libertinust1math/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0v9hj90lqv4rx9ivqj53n3f4cnnmjmk7bw396w4xryrpwvk2hssx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/libertinust1math")
    (synopsis "Type 1 font and LaTeX support for Libertinus Math")
    (description
     "The package provides a Type 1 version of Libertinus Math, with a number
of additions and changes, plus LaTeX support files that allow it to serve as
a math accompaniment to Libertine under LaTeX.  In addition, with option
@code{sansmath}, it can function as a standalone math font with sans serif
Roman and Greek letters.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-librebaskerville
  (package
    (name "texlive-librebaskerville")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/librebaskerville/"
                                     "fonts/enc/dvips/librebaskerville/"
                                     "fonts/map/dvips/librebaskerville/"
                                     "fonts/tfm/impallari/librebaskerville/"
                                     "fonts/truetype/impallari/librebaskerville/"
                                     "fonts/type1/impallari/librebaskerville/"
                                     "fonts/vf/impallari/librebaskerville/"
                                     "tex/latex/librebaskerville/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rjac2w8q0m4a6qcdjphv3rgws19vbg65wv6gk1frl0d14bijqdy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/librebaskerville")
    (synopsis "Libre Baskerville family of fonts with LaTeX support")
    (description
     "This package provides the Libre Baskerville family of fonts, designed by
Pablo Impallari, for use with LaTeX, pdfLaTeX, XeLaTeX or LuaLaTeX.  It is
primarily intended to be a web font but is also attractive as a text font.
A BoldItalic variant has been artificially generated.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-librebodoni
  (package
    (name "texlive-librebodoni")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/librebodoni/"
                                     "fonts/enc/dvips/librebodoni/"
                                     "fonts/map/dvips/librebodoni/"
                                     "fonts/opentype/impallari/librebodoni/"
                                     "fonts/tfm/impallari/librebodoni/"
                                     "fonts/type1/impallari/librebodoni/"
                                     "fonts/vf/impallari/librebodoni/"
                                     "tex/latex/librebodoni/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1skyjmb0drrs6z8bhmdyx7q9wqz9vbyi6nkif5rj95kqxxwznkyz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/librebodoni")
    (synopsis "Libre Bodoni fonts with LaTeX support")
    (description
     "The Libre Bodoni fonts are designed by Pablo Impallari and Rodrigo
Fuenzalida, based on the 19th century Morris Fuller Benton's.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-librecaslon
  (package
    (name "texlive-librecaslon")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/librecaslon/"
                                     "fonts/enc/dvips/librecaslon/"
                                     "fonts/map/dvips/librecaslon/"
                                     "fonts/opentype/impallari/librecaslon/"
                                     "fonts/tfm/impallari/librecaslon/"
                                     "fonts/type1/impallari/librecaslon/"
                                     "fonts/vf/impallari/librecaslon/"
                                     "tex/latex/librecaslon/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16lmaa0rsrgrib00r8rsj9librkybq2zf1as11l3hiw5zcq3wj0w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/librecaslon")
    (synopsis "Libre Caslon fonts, with LaTeX support")
    (description
     "The Libre Caslon fonts are designed by Pablo Impallari.  Although they
have been designed for use as web fonts, they work well as conventional text
fonts.  An artificially generated BoldItalic variant has been added.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-librefranklin
  (package
    (name "texlive-librefranklin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/librefranklin/"
                                     "fonts/enc/dvips/librefranklin/"
                                     "fonts/map/dvips/librefranklin/"
                                     "fonts/opentype/impallari/librefranklin/"
                                     "fonts/tfm/impallari/librefranklin/"
                                     "fonts/type1/impallari/librefranklin/"
                                     "fonts/vf/impallari/librefranklin/"
                                     "tex/latex/librefranklin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vkc2sj7689zn2rxc03q2spvs10865jrnv37s9dgw35hifb69m5s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/librefranklin")
    (synopsis "LaTeX support for the Libre-Franklin family of fonts")
    (description
     "Libre Franklin is an interpretation and expansion based on the 1912
Morris Fuller Benton's classic, designed by Pablo Impallari, Rodrigo
Fuenzalida and Nhung Nguyen.")
    (license (list license:lppl license:silofl1.1))))

(define-public texlive-libris
  (package
    (name "texlive-libris")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/libris/"
                                     "fonts/afm/arkandis/libris/"
                                     "fonts/enc/dvips/libris/"
                                     "fonts/map/dvips/libris/"
                                     "fonts/tfm/arkandis/libris/"
                                     "fonts/type1/arkandis/libris/"
                                     "fonts/vf/arkandis/libris/"
                                     "source/fonts/libris/"
                                     "tex/latex/libris/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ky2b4knhfd51yz6ycsly6q5rz2fk4h3rhnxmcx3qnhnai6cf9fc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/libris")
    (synopsis "Libris ADF fonts, with LaTeX support")
    (description
     "LibrisADF is a sans-serif family designed to mimic Lydian.  The bundle
includes: fonts, in Adobe Type 1, TrueType and OpenType formats, and LaTeX
support macros, for use with the Type 1 versions of the fonts.")
    (license license:gpl3+)))

(define-public texlive-lie-hasse
  (package
    (name "texlive-lie-hasse")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lie-hasse/"
                                     "tex/latex/lie-hasse/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p4ln326spkzcp42p0bjk8cma4cj4ks8xs6ps5mq1b9q1r3vknaa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lie-hasse")
    (synopsis "Draw Hasse diagrams")
    (description
     "This package draws Hasse diagrams of the partially ordered sets of the
simple roots of any complex simple Lie algebra.  It uses the Dynkin diagrams
package @code{dynkin-diagrams}.")
    (license license:lppl1.3c)))

(define-public texlive-lilyglyphs
  (package
    (name "texlive-lilyglyphs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lilyglyphs/"
                                     "fonts/opentype/public/lilyglyphs/"
                                     "scripts/lilyglyphs/"
                                     "source/latex/lilyglyphs/fonts/"
                                     "source/latex/lilyglyphs/glyphimages/definitions/"
                                     "source/latex/lilyglyphs/glyphimages/generated_src/"
                                     "tex/latex/lilyglyphs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g5v2bq7ml9pnh2xlkzf6k9zh3azw7i96iapp8yajyxk8akj0ki2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts
           #~(list "lily-glyph-commands.py"
                   "lily-image-commands.py"
                   "lily-rebuild-pdfs.py")))
    (inputs (list python))
    (home-page "https://ctan.org/pkg/lilyglyphs")
    (synopsis "Access Lilypond fragments and glyphs, in LaTeX")
    (description
     "The package provides the means to include arbitrary elements of LilyPond
notation, including symbols from Lilypond's Emmentaler font, in a LaTeX
document.  The package uses OpenType fonts, and as a result must be compiled
with LuaLaTeX or XeLaTeX.")
    (license license:lppl1.3c)))

(define-public texlive-limecv
  (package
    (name "texlive-limecv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/limecv/" "source/latex/limecv/"
                                     "tex/latex/limecv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bqqkbxzayb8wwlkj1vkf01lx78i7pq2kb9clrir0paxjm8xa6ja"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/limecv")
    (synopsis "(Xe/Lua)LaTeX document class for curriculum vitae")
    (description
     "@code{limecv} is a LaTeX document class to write curriculum vitae.  It
is designed with the following design rules: simple, elegant and clean.  To
this end, it offers several environments and macros for convenience.")
    (license license:lppl1.3c)))

(define-public texlive-lineara
  (package
    (name "texlive-lineara")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/lineara/"
                                     "fonts/afm/public/lineara/"
                                     "fonts/map/dvips/lineara/"
                                     "fonts/tfm/public/lineara/"
                                     "fonts/type1/public/lineara/"
                                     "source/fonts/lineara/"
                                     "tex/latex/lineara/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1k3frdshsc2cj1y61bcpz9fcs1rw1rkzh8fk3fzbaqyqmyka3yl7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lineara")
    (synopsis "Linear A script fonts")
    (description
     "The @code{lineara} package provides a simple interface to two fonts
which include all known symbols, simple and complex, of the Linear A script.
This way one can easily replicate Linear A texts using modern typographic
technology.")
    (license license:lppl)))

(define-public texlive-ling-macros
  (package
    (name "texlive-ling-macros")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ling-macros/"
                                     "tex/latex/ling-macros/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q5l9h5xkd9gkpx2g5inzkcsssqvdicv05r8xvlmmx41mf1ikc88"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ling-macros")
    (synopsis "Macros for typesetting formal linguistics")
    (description
     "This package contains macros for typesetting glosses and formal
expressions.  It covers a range of subfields in formal linguistics.")
    (license license:lppl1.3+)))

(define-public texlive-linguex
  (package
    (name "texlive-linguex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/linguex/" "tex/latex/linguex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0w2rxvjljrl4b7s1dr7k2vk5nifq0zgmjlx68ajpsihjnzal7k8g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/linguex")
    (synopsis "Format linguists' examples")
    (description
     "This bundle comprises two packages: the @code{linguex} package
facilitates the formatting of linguist examples, automatically taking care of
example numbering, indentations, indexed brackets, and the @samp{*} in
grammaticality judgments.  The @code{ps-trees} package provides linguistic
trees.")
    (license license:lppl)))

(define-public texlive-linguisticspro
  (package
    (name "texlive-linguisticspro")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/linguisticspro/"
                                     "fonts/enc/dvips/linguisticspro/"
                                     "fonts/map/dvips/linguisticspro/"
                                     "fonts/opentype/public/linguisticspro/"
                                     "fonts/tfm/public/linguisticspro/"
                                     "fonts/type1/public/linguisticspro/"
                                     "fonts/vf/public/linguisticspro/"
                                     "tex/latex/linguisticspro/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yyclkwsa4ibsdc60mw22f2skq2wify9ic4lzvkjsaigvq28zj3y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/linguisticspro")
    (synopsis "LinguisticsPro fonts with LaTeX support")
    (description
     "The package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the LinguisticsPro family of fonts.  This family is derived from the Utopia
Nova font family, by Andreas Nolda.")
    (license (list license:lppl license:silofl1.1))))

(define-public texlive-lion-msc
  (package
    (name "texlive-lion-msc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/lion-msc/" "doc/latex/lion-msc/"
                                     "tex/latex/lion-msc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yj3xwbd4lb5vjkfqhwhy82pc9p59vffah6zmiqbgjaj10q1ihb5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lion-msc")
    (synopsis
     "LaTeX class for B.Sc.@: and M.Sc.@: reports at Leiden Institute of
Physics (LION)")
    (description
     "This is a LaTeX class for B.Sc.@: and M.Sc.@: reports at Leiden
Institute of Physics (LION).  The purpose of this class is twofold.  It
creates a uniform layout of the student theses from our department.  More
importantly, it contains several fields on the front-page that the user needs
to fill that are used in the university administration (name, student number
and name of supervisor).  Students are free to change the layout of the text
but should leave the title page as it is.")
    (license license:lppl1.3+)))

(define-public texlive-listbib
  (package
    (name "texlive-listbib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/listbib/" "doc/latex/listbib/"
                                     "scripts/listbib/" "source/latex/listbib/"
                                     "tex/latex/listbib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1k4xwmv6lh1vaggimzmiqib8aai9dm0j586m0hds04485pvhv5ky"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "listbib")))
    (home-page "https://ctan.org/pkg/listbib")
    (synopsis "Lists contents of BibTeX files")
    (description
     "This package generates listings of bibliographic data bases in BibTeX
format.  Included is a @file{listbib.bst}, which is better suited for this
purpose than the standard styles.")
    (license license:gpl3+)))

(define-public texlive-lithuanian
  (package
    (name "texlive-lithuanian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lithuanian/"
                                     "fonts/enc/dvips/lithuanian/"
                                     "fonts/map/dvips/lithuanian/"
                                     "fonts/tfm/public/lithuanian/"
                                     "tex/latex/lithuanian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1iq06vlryl4fj2mzkmmphw9ihm0y7wmi5k8wxniaciw5mm5vrw7x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lithuanian")
    (synopsis "Lithuanian language support")
    (description
     "This language support package provides:

@itemize
@item extra 8-bit encoding L7x used by @code{fontenc}: @file{l7xenc.def},
@file{l7xenc.dfu}, @file{l7xenc.sty};
@item Lithuanian TeX support for URW family Type1 fonts: map, fd, tfm with L7x
encoding;
@item extra code page definitions used by @code{inputenc}: @file{cp775.def}
and @file{latin7.def}.
@end itemize")
    (license license:lppl1.3c)))

(define-public texlive-liturg
  (package
    (name "texlive-liturg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/liturg/" "source/latex/liturg/"
                                     "tex/latex/liturg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nmcz7zg27aasczdv3p6ilsmy66cbfjg9yri45d0pml7m7c56din"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    ;; The "liturg.ins" provided by the package does not generate anything.
    ;; As a consequence, there's nothing to build.
    (arguments (list #:build-targets #~'()))
    (home-page "https://ctan.org/pkg/liturg")
    (synopsis "Support for typesetting Catholic liturgical texts")
    (description
     "The packages offers simple macros for typesetting Catholic liturgical
texts, particularly @code{Missal} and @code{Breviary} texts.  The package
assumes availability of Latin typesetting packages.")
    (license license:lppl)))

(define-public texlive-llncs
  (package
    (name "texlive-llncs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/llncs/" "doc/latex/llncs/"
                                     "tex/latex/llncs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ix21bqh7wjlcwpljy3wvbir76n270n8phxrls3pwq3dhd2aqz51"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/llncs")
    (synopsis
     "Document class and bibliography style for @acronym{LNCS, Lecture Notes
in Computer Science}")
    (description
     "This is Springer's official macro package for typesetting contributions
to be published in Springer's @acronym{LNCS, Lecture Notes in Computer
Science} and its related proceedings series CCIS, LNBIP, LNICST, and IFIP
AICT.")
    (license license:cc-by4.0)))

(define-public texlive-llncsconf
  (package
    (name "texlive-llncsconf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/llncsconf/"
                                     "tex/latex/llncsconf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18z94lh90pzvbzfgxj27n2l12mfbcjd20vga16h8d2bln56lrfpm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/llncsconf")
    (synopsis "LaTeX package extending Springer's @code{llncs} class")
    (description
     "The package extends Springer's @code{llncs} class for adding additional
notes describing the status of the paper (submitted, accepted) as well as for
creating author-archived versions that include the references to the official
version hosted by Springer (as requested by the copyright transfer agreement
for Springer's LNCS series).")
    (license license:lppl1.3c)))

(define-public texlive-lni
  (package
    (name "texlive-lni")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/lni/" "doc/latex/lni/"
                                     "source/latex/lni/" "tex/latex/lni/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q4z7rkijx4gafsvz8rj3j1bvsd84cx323rz1hr44d3g8ra7hkj9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lni")
    (synopsis "Official class for the @emph{Lecture Notes in Informatics}")
    (description
     "This is the official version of the class @code{lni} for submissions to
the @emph{Lecture Notes in Informatics} published by the Gesellschaft fur
Informatik.")
    (license license:lppl1.3c)))

(define-public texlive-lobster2
  (package
    (name "texlive-lobster2")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/lobster2/"
                                     "fonts/enc/dvips/lobster2/"
                                     "fonts/map/dvips/lobster2/"
                                     "fonts/opentype/impallari/lobster2/"
                                     "fonts/tfm/impallari/lobster2/"
                                     "fonts/type1/impallari/lobster2/"
                                     "fonts/vf/impallari/lobster2/"
                                     "tex/latex/lobster2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jq6287n0c0qzcx6jch0d9k7axg119z2p2mw6i3s40jdyg67m3a4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lobster2")
    (synopsis "Lobster Two fonts, with support for all LaTeX engines")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the Lobster Two family of fonts, designed by Pablo Impallari.  This is
a family of script fonts with many ligatures and terminal forms; for the best
results, use XeLaTeX or LuaLaTeX.  There are two weights and italic variants
for both.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-logicproof
  (package
    (name "texlive-logicproof")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/logicproof/"
                                     "source/latex/logicproof/"
                                     "tex/latex/logicproof/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02iif9rvp8njp7zc4ab4jgksf0hrbg6z5cp7066y245bjwi99fi3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/logicproof")
    (synopsis "Box proofs for propositional and predicate logic")
    (description
     "This package provides a common style of proof used in propositional and
predicate logic is Fitch proofs, in which each line of the proof has
a statement and a justification, and subproofs within a larger proof have
boxes around them.  The package provides environments for typesetting such
proofs and boxes.  It creates proofs in a style similar to that used in
@emph{Logic in Computer Science} by Huth and Ryan.")
    (license license:lppl1.3+)))

(define-public texlive-logicpuzzle
  (package
    (name "texlive-logicpuzzle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/logicpuzzle/"
                                     "scripts/logicpuzzle/"
                                     "tex/latex/logicpuzzle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m2yrizdj76gywxkcfz90by2qwx8pq8akacj5qmsin095hnyskfh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/logicpuzzle")
    (synopsis "Typeset (grid-based) logic puzzles")
    (description
     "The package allows the user to typeset various logic puzzles.  At the
moment the following puzzles are supported:

@itemize

@item 2D-Sudoku (aka Magiequadrat, Diagon, ...),

@item Battleship (aka Bimaru, Marinespiel, Batalla Naval, ...),

@item Bokkusu (aka Kakurasu, Feldersummenratsel, ...),

@item Bridges (akak Bruckenbau, Hashi, ...),

@item Chaos Sudoku,

@item Four Winds (aka Eminent Domain, Lichtstrahl, ...),

@item Hakyuu (aka Seismic, Ripple Effect, ...),

@item Hitori,

@item Kakuro,

@item Kendoku (aka Mathdoku, Calcudoku, Basic, MiniPlu, Ken Ken, Square
Wisdom, Sukendo, Caldoku, ...),

@item Killer Sudoku (aka Samunapure, Sum Number Place, Sumdoku, Gebietssummen,
...),

@item Laser Beam (aka Laserstrahl, ...),

@item Magic Labyrinth (aka Magic Spiral, Magisches Labyrinth, ...),

@item Magnets (aka Magnetplatte, Magnetfeld, ...),

@item Masyu (aka Mashi, White or Black Pearls, ...),

@item Minesweeper (aka Minensuche, ...),

@item Nonogram (aka Griddlers, Hanjie, Tsunami, Logic Art, Logimage, ...),

@item Number Link (aka Alphabet Link, Arukone, Buchstabenbund, ...),

@item Resuko,

@item Schatzsuche,

@item Skyline (aka Skycrapers, Wolkenkratzer, Hochhauser, ...), including
Skyline Sudoku and Skyline Sudou (N*N) variants,

@item Slitherlink (aka Fences, Number Line, Dotty Dilemma, Sli-Lin, Takegaki,
Great Wall of China, Loop the Loop, Rundweg, Gartenzaun, ...),

@item Star Battle (aka Sternenschlacht, ...),

@item Stars and Arrows (aka Sternenhimmel, ...),

@item Sudoku,

@item Sun and Moon (aka Sternenhaufen, Munraito, ...),

@item Tents and Trees (aka Zeltlager, Zeltplatz, Camping, ...),

@item and Tunnel.

@end itemize")
    (license license:lppl1.3+)))

(define-public texlive-logix
  (package
    (name "texlive-logix")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/logix/"
                                     "fonts/opentype/public/logix/"
                                     "fonts/truetype/public/logix/"
                                     "tex/latex/logix/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19ak3zfqnx04rb5wcmzc5z3g8sp2wphi83lx9i58y41y3lp2z4kq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/logix")
    (synopsis "Supplement to the Unicode math symbols")
    (description
     "The package provides a Unicode font with over 4,000 symbols to
supplement the Unicode math symbols.  It is compatible with and
complements the AMS STIX2 math fonts, but focuses on new symbols and
symbol variants more suited to work in logic.")
    (license (list license:silofl1.1 license:lppl1.3c))))

(define-public texlive-lollipop
  (package
    (name "texlive-lollipop")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/otherformats/lollipop/" "tex/lollipop/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xdldlnhsr2n8544j9vd6gllin8bfkpcbhlpmxlhrvjl5bdg0rjp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:create-formats #~(list "lollipop")
           #:phases
           #~(modify-phases %standard-phases
               (add-after 'install 'symlink-binaries
                 (lambda* (#:key inputs #:allow-other-keys)
                   (let ((tex (search-input-file inputs "bin/tex"))
                         (bin (string-append #$output "/bin")))
                     (mkdir-p bin)
                     (with-directory-excursion bin
                       (symlink tex "lollipop"))))))))
    (propagated-inputs (list texlive-cm texlive-hyphen-base texlive-tex))
    (home-page "https://ctan.org/pkg/lollipop")
    (synopsis "TeX made easy")
    (description
     "Lollipop is a macro package that functions as a toolbox for writing TeX
macros.  Its main aim is to make macro writing so easy that implementing
a fully new layout in TeX would become a matter of less than an hour for an
average document.  The aim is that such a task could be accomplished by
someone with only a very basic training in TeX programming.")
    (license license:gpl3)))

(define-public texlive-longdivision
  (package
    (name "texlive-longdivision")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/longdivision/"
                                     "tex/latex/longdivision/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16pg9b4jxjfb0ik93i3pwfim0nz3c3b8cklarvpsngavzyx9mr2h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/longdivision")
    (synopsis "Typesets long division")
    (description
     "This package executes the long division algorithm and typesets the solutions.
The dividend must be a positive decimal number and the divisor must be
a positive integer.  Repeating decimals is handled correctly, putting a bar
over the repeated part of the decimal.

The package defines two macros, @code{\\longdivision} and
@code{\\intlongdivision}.  Each takes two arguments, a dividend and
a divisor. @code{\\longdivision} keeps dividing until the remainder is zero,
or it encounters a repeated remainder. @code{\\intlongdivision} stops when the
dividend stops (though the dividend doesn't have to be an integer).")
    (license license:lppl)))

(define-public texlive-lpform
  (package
    (name "texlive-lpform")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/lpform/" "tex/generic/lpform/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13pg4wb3z8xhmf9wry4rvdzhg0ydhpbdp6vxjk7g91p6s3lvqa51"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lpform")
    (synopsis
     "Typesetting linear programming formulations and sets of equations")
    (description
     "The package is designed to aid the author writing linear programming
formulations, one restriction at a time.  With the package, one can easily
label equations, formulations can span multiple pages and several elements of
the layout (such as spacing, texts and equation tags) are also customizable.
Besides linear programming formulations, this package can also be used to
display any series of aligned equations with easy labeling/referencing and
other customization options.")
    (license license:lppl)))

(define-public texlive-lplfitch
  (package
    (name "texlive-lplfitch")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lplfitch/"
                                     "source/latex/lplfitch/"
                                     "tex/latex/lplfitch/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x396k71r8sb04pby3h6snjzmyzmai9s11icgxf1vi9dswh191cz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lplfitch")
    (synopsis "Fitch-style natural deduction proofs")
    (description
     "The package provides macros for typesetting natural deduction proofs in
Fitch style, with subproofs indented and offset by scope lines.  The proofs
from use of the package are in the format used in the textbook @emph{Language,
Proof, and Logic} by Dave Barker-Plummer, Jon Barwise, and John Etchemendy.")
    (license license:lppl1.3+)))

(define-public texlive-lps
  (package
    (name "texlive-lps")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lps/" "source/latex/lps/"
                                     "tex/latex/lps/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11jd8k1w2mk0xmwaxb1ps8pabxlzvs24z5hl74dwcim2xad7ahvj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lps")
    (synopsis "Class for @emph{Logic and Philosophy of Science}")
    (description
     "The @emph{Logic and Philosophy of Science} journal is an online
publication of the University of Trieste (Italy).  The class builds on the
standard article class to offer a format that LaTeX authors may use when
submitting to the journal.")
    (license license:lppl)))

(define-public texlive-lshort-bulgarian
  (package
    (name "texlive-lshort-bulgarian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-bulgarian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qg23asq2i5mqhp9xblv5hm3qxmd5886d5x0gq1fkdbyy9gsawi3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-bulgarian")
    (synopsis
     "Bulgarian translation of the @emph{Short Introduction to LaTeX2e}")
    (description
     "This package includes the source files, PostScript and PDF files of the
Bulgarian translation of the @emph{Short Introduction to LaTeX2e}.")
    (license license:public-domain)))

(define-public texlive-lshort-chinese
  (package
    (name "texlive-lshort-chinese")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-chinese/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05b9fq4jhh9xifn2lj58fs17fc0prx915gwfz47s92spvv9fwbi6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-zh-cn")
    (synopsis "Introduction to LaTeX, in Chinese")
    (description
     "This package provides a Chinese edition of the @emph{(Not so) short
introduction to LaTeX2e}, with additional information of typesetting Chinese
language.")
    (license license:fdl1.3+)))

(define-public texlive-lshort-czech
  (package
    (name "texlive-lshort-czech")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-czech/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ar9qa0cg0mjv6ydgx1phaa1qpiy25s3jciznbylgi5xprvnnfa9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-czech")
    (synopsis "Czech translation to LaTeX")
    (description
     "This is the Czech translation of a @emph{(Not So) Short Introduction to
LaTeX2e}.}")
    (license license:gpl3+)))

(define-public texlive-lshort-dutch
  (package
    (name "texlive-lshort-dutch")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-dutch/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "160r060gmw6f6lgbnyvfxafjpqvyr4jwd56ddkjfm3ir2bfl973d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-dutch")
    (synopsis "Introduction to LaTeX in Dutch")
    (description
     "This is the Dutch (Nederlands) translation of the @emph{(No So) Short
Introduction to LaTeX2e}.")
    (license license:gpl3+)))

(define-public texlive-lshort-estonian
  (package
    (name "texlive-lshort-estonian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-estonian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dfwp7kkynpskb345i3yz7h5pvc8iljqg3q6l546vrwla0bmb95c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-estonian")
    (synopsis "Estonian introduction to LaTeX")
    (description
     "This is the Estonian translation of @emph{(No So) Short Introduction to
LaTeX2e}.")
    (license license:gpl2)))

(define-public texlive-lshort-english
  (package
    (name "texlive-lshort-english")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-english/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pzqdbzynlwvpamd69cmfpa8jdcvq96qjr9k1fy3dxpzi2mapvhd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-english")
    (synopsis "(Not So) short introduction to LaTeX2e")
    (description
     "@emph{The Not So Short Introduction to LaTeX2e} derives from a German
introduction (@emph{lkurz}), which was translated and updated; it continues to
be updated.  This translation has, in its turn, been translated into several
other languages; see the @code{lshort} catalogue entry for the current list.")
    (license license:gpl2)))

(define-public texlive-lshort-finnish
  (package
    (name "texlive-lshort-finnish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-finnish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06madlm869kmwxprmy2c78ma4s8zk8mclzmd4xdl0r4mlhk4vdsl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-finnish")
    (synopsis "Finnish introduction to LaTeX")
    (description
     "This is the Finnish translation of @emph{(No So) Short Introduction to
LaTeX2e}, with added coverage of Finnish typesetting rules.")
    (license license:public-domain)))

(define-public texlive-lshort-french
  (package
    (name "texlive-lshort-french")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-french/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hdl0w7b1ablx7qfcvgniz7dcbgazb49b8wfw7c08hlb38gxfqh7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-french")
    (synopsis "Short introduction to LaTeX, French translation")
    (description
     "This package contains a French version of a @emph{(Not so) short
introduction to LaTeX2e}.")
    (license license:gpl3+)))

(define-public texlive-lshort-german
  (package
    (name "texlive-lshort-german")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-german/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "073v7zvk8xri0f05mr0ad770p81akl9b9cnia1q4hcma9fk89k10"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-german")
    (synopsis
     "German version of @emph{A Short Introduction to LaTeX2e:
LaTeX2e-Kurzbeschreibung}")
    (description
     "This package provides the German version of @emph{A Short Introduction
to LaTeX2e: LaTeX2e-Kurzbeschreibung}.")
    (license license:opl1.0+)))

(define-public texlive-lshort-italian
  (package
    (name "texlive-lshort-italian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-italian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "085ydria5q7s648r7frl54sa1y4kyr569zvqjjkancfd83h873cg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-italian")
    (synopsis "Introduction to LaTeX in Italian")
    (description
     "This is the Italian translation of the @emph{(Not so) Short Introduction
to LaTeX2e.}")
    (license license:gpl3+)))

(define-public texlive-lshort-japanese
  (package
    (name "texlive-lshort-japanese")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-japanese/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mfxig980jyzhay1i83d69p294hgbr92v3kk2a4z8ca3fwzy8w74"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-japanese")
    (synopsis "Japanese version of the @emph{Short Introduction to LaTeX2e}")
    (description "This is the Japanese version of the @emph{(Not so) Short
Introduction to LaTeX2e}.")
    (license license:gpl3+)))

(define-public texlive-lshort-korean
  (package
    (name "texlive-lshort-korean")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-korean/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07660lrss97hswmis7rgc419h05mgrvsfrrwmnrwk5yn97flhhqd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-korean")
    (synopsis "Korean introduction to LaTeX")
    (description
     "This package provides a translation of Oetiker's original @emph{(Not so)
short introduction to LaTeX2e}.")
    (license license:fdl1.3+)))

(define-public texlive-lshort-mongol
  (package
    (name "texlive-lshort-mongol")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-mongol/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "153k4dzia30fpx847wli7i5p407a808gmj3p7jifq5bpx479qg1g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-mongol")
    (synopsis "Short introduction to LaTeX, in Mongolian")
    (description
     "This package provides a translation of Oetiker's @emph{(Not so) short
introduction to LaTeX2e}.")
    (license license:lppl)))

(define-public texlive-lshort-persian
  (package
    (name "texlive-lshort-persian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-persian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b1b45nh2d3d3zv735dymgyllj6m8i57icbihjkl1im0nghrzklk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-persian")
    (synopsis "Persian (Farsi) introduction to LaTeX")
    (description
     "This package provides a Persian (Farsi) translation of Oetiker's
@emph{(Not so) short introduction to LaTeX2e}.")
    (license license:public-domain)))

(define-public texlive-lshort-polish
  (package
    (name "texlive-lshort-polish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-polish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "121y638k4f4pbjpa4q0n9qj2w57624q2d1v4jz09qh399fl5yk81"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-polish")
    (synopsis "Introduction to LaTeX in Polish")
    (description
     "This is the Polish translation of the @emph{(Not so) Short Introduction
to LaTeX2e}.")
    (license license:gpl2+)))

(define-public texlive-lshort-portuguese
  (package
    (name "texlive-lshort-portuguese")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-portuguese/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wg51rjcayiizkz0vvjkirrx19q8fbnfrwilgh13prlbpams1hsh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-portuguese")
    (synopsis "Introduction to LaTeX in Portuguese")
    (description
     "This is the Portuguese translation of a @emph{(Not So) Short
Introduction to LaTeX2e}.")
    (license license:public-domain)))

(define-public texlive-lshort-russian
  (package
    (name "texlive-lshort-russian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-russian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02abh69xl43p56fcciyan4j0z4mqq2j7ynwazq1nywhz37d6zn7y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-russian")
    (synopsis "Russian introduction to LaTeX")
    (description "This package provides the Russian version of the @emph{Short
Introduction to LaTeX2e}.")
    (license license:gpl3+)))

(define-public texlive-lshort-slovak
  (package
    (name "texlive-lshort-slovak")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-slovak/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b5gn95i32dyn8r7v2cdcz759fllp3b0zwx17adjs282n06vfymq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-slovak")
    (synopsis "Slovak introduction to LaTeX")
    (description
     "This package provides a Slovak translation of Oetiker's @emph{(Not So)
Short Introduction to LaTeX2e}.")
    (license license:lppl)))

(define-public texlive-lshort-slovenian
  (package
    (name "texlive-lshort-slovenian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-slovenian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cwjg0z5vr4x93bz1khwl27rk8k7kpjm978iyzn6w7gx3wi87zr0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-slovenian")
    (synopsis "Slovenian introduction to LaTeX")
    (description
     "This package provides a Slovenian translation of the @emph{(Not So)
Short Introduction to LaTeX2e}.")
    (license license:gpl3+)))

(define-public texlive-lshort-spanish
  (package
    (name "texlive-lshort-spanish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-spanish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ls50syrg3dl5dl5a3fi33cr9j990l2xr6pribn1vqglsqrh191l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-spanish")
    (synopsis "Short introduction to LaTeX, in Spanish")
    (description
     "This package provides a Spanish translation of the @emph{(Not So) Short
Introduction to LaTeX2e}.")
    (license license:gpl3+)))

(define-public texlive-lshort-thai
  (package
    (name "texlive-lshort-thai")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-thai/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16r9gx902a342q2mj570y269yw97yaj6hrbqrk4h49ihm695z30i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-thai")
    (synopsis "Introduction to LaTeX in Thai")
    (description
     "This is the Thai translation of the @emph{Short Introduction to LaTeX2e}.")
    (license license:public-domain)))

(define-public texlive-lshort-turkish
  (package
    (name "texlive-lshort-turkish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-turkish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00r6pv4z4933jw072djdasd2wp5j05wghln62ga4g6y6jblf6zks"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-turkish")
    (synopsis "Turkish introduction to LaTeX")
    (description
     "This package provides a Turkish translation of Oetiker's @emph{(Not so)
short introduction to LaTeX2e}.")
    (license license:public-domain)))

(define-public texlive-lshort-ukr
  (package
    (name "texlive-lshort-ukr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-ukr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nsah1h3z3sy96a9x0mfdwby7pvvjwq7zxfv2s8nvsbvnn1al17s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-ukr")
    (synopsis "Ukrainian version of the LaTeX introduction")
    (description
     "This package provides the Ukrainian version of the @emph{Short
Introduction to LaTeX2e}.")
    (license license:gpl2+)))

(define-public texlive-lshort-vietnamese
  (package
    (name "texlive-lshort-vietnamese")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lshort-vietnamese/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "094lfry6cqvpk02c3acss6581mgb7j30fnja1b3qwzxmyxjdblwa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lshort-vietnamese")
    (synopsis "Vietnamese version of the LaTeX introduction")
    (description
     "This is the Vietnamese version of the @emph{Short Introduction to
LaTeX2e}.")
    (license license:lppl)))

(define-public texlive-lstbayes
  (package
    (name "texlive-lstbayes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lstbayes/"
                                     "source/latex/lstbayes/"
                                     "tex/latex/lstbayes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gd3zyq1z1n0ksmazky9dbal0qaiss2lgh7dh3021ckj7c3mwkmd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lstbayes")
    (synopsis "Listings language driver for Bayesian modeling languages")
    (description
     "The package provides language drivers for the listings package for
several languages not included in that package: BUGS, JAGS, and Stan.")
    (license license:lppl1.3+)))

(define-public texlive-ltb2bib
  (package
    (name "texlive-ltb2bib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ltb2bib/" "source/latex/ltb2bib/"
                                     "tex/latex/ltb2bib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wrm89bynjm4g4a1zpx38v6yd2l3b1gh13h4m5hknvla2lydljfg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ltb2bib")
    (synopsis "Converts @code{amsrefs} bibliographical databases to BibTeX
format")
    (description
     "This package implements a LaTeX command that converts an @code{amsrefs}
bibliographical database (@file{.ltb}) to a BibTeX bibliographical database
(@file{.bib}).  @code{ltb2bib} is the reverse of the @samp{amsxport} option in
@code{amsrefs}.")
    (license license:lppl1.3+)))

(define-public texlive-ltxdockit
  (package
    (name "texlive-ltxdockit")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ltxdockit/"
                                     "tex/latex/ltxdockit/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0n1c8g8kaaazg7kahfkckh86s29bi1p3sw9h8v7hl5zgg6mb3415"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ltxdockit")
    (synopsis "Documentation support")
    (description
     "This bundle, consisting of a simple wrapper class and some packages,
forms a small LaTeX and BibTeX documentation kit; the author uses it for some
of his own packages.")
    (license license:lppl)))

(define-public texlive-luabibentry
  (package
    (name "texlive-luabibentry")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luabibentry/"
                                     "source/lualatex/luabibentry/"
                                     "tex/lualatex/luabibentry/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00f6sxkzmfznjbisicacxd546v8zizm1fz36s05iiyra04cawnw4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luabibentry")
    (synopsis "Repeat BibTeX entries in a LuaLaTeX document body")
    (description
     "The package reimplements @code{bibentry}, for use in LuaLaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-lxfonts
  (package
    (name "texlive-lxfonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/lxfonts/"
                                     "fonts/map/dvips/lxfonts/"
                                     "fonts/source/public/lxfonts/"
                                     "fonts/tfm/public/lxfonts/"
                                     "fonts/type1/public/lxfonts/"
                                     "source/fonts/lxfonts/"
                                     "tex/latex/lxfonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n7bznkcc1ma2k977306rjg1mlpcspc46xg14abnc2d4k2970bfg"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ec")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ec texlive-metafont))
    (home-page "https://ctan.org/pkg/lxfonts")
    (synopsis "Set of slide fonts based on CM")
    (description
     "The bundle contains the traditional slides fonts revised to be
completely usable both as text fonts and mathematics fonts; they are fully
integrate with the new operators, letters, symbols and extensible delimiter
fonts, as well as with the AMS fonts, all redone with the same stylistic
parameters.")
    (license license:lppl)))

(define-public texlive-lyluatex
  (package
    (name "texlive-lyluatex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/lyluatex/" "scripts/lyluatex/"
                                     "tex/luatex/lyluatex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1d6yiyfbhlaljz80znjdzy9prhsxrzq0yhmylqc4yx9ajbjyp989"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lyluatex")
    (synopsis
     "Commands to include LilyPond scores within a (Lua)LaTeX document")
    (description
     "This package provides macros for the inclusion of LilyPond scores within
LuaLaTeX.  It calls LilyPond to compile scores, then includes the produced
files.")
    (license license:expat)))

(define-public texlive-m-tx
  (package
    (name "texlive-m-tx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/m-tx/"
                                     "doc/man/man1/prepmx.1"
                                     "doc/man/man1/prepmx.man1.pdf"
                                     "scripts/m-tx/"
                                     "tex/generic/m-tx/"
                                     "tex/latex/m-tx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sakzv7r6mybx0k7k0fi1qb789nf7lvbl0ns8s0hhc9fz37b0br5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "m-tx.lua")))
    (propagated-inputs (list texlive-m-tx-bin))
    (home-page "https://ctan.org/pkg/m-tx")
    (synopsis "Preprocessor for @command{pmx}")
    (description
     "M-Tx is a preprocessor to @command{pmx}, which is itself a preprocessor
to MusixTeX, a music typesetting system.  The prime motivation to the
development of M-Tx was to provide lyrics for music to be typeset.  In fact,
@command{pmx} now provides a lyrics interface, but M-Tx continues in use by
those who prefer its language.")
    (license license:expat)))

(define-public texlive-m-tx-bin
  (package
    (inherit texlive-bin)
    (name "texlive-m-tx-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '("m-tx"))
            (delete-other-directories "texk" '())))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-m-tx" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "utils/m-tx"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "utils/m-tx"
                  (invoke "make" "install"))))))))
    (native-inputs '())
    (inputs '())
    (propagated-inputs '())
    (home-page (package-home-page texlive-m-tx))
    (synopsis "Binary for @code{texlive-m-tx}")
    (description
     "This package provides the binary for @code{texlive-m-tx}.")
    (license (package-license texlive-m-tx))))

(define-public texlive-macros2e
  (package
    (name "texlive-macros2e")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/macros2e/" "tex/latex/macros2e/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vdw389gvwmpqs7ykm3vlyqbpwm45mgqasmqyxm7q9jgay3dn2iz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/macros2e")
    (synopsis "List of internal LaTeX2e macros")
    (description
     "This document lists the internal macros defined by the LaTeX2e base files,
which can also be useful to package authors.  The macros are hyper-linked to
their description in @code{source2e}.  For this to work both PDFs must be
inside the same directory.  This document is not yet complete in content and
format and may miss some macros.")
    (license license:lppl1.3c)))

(define-public texlive-mafr
  (package
    (name "texlive-mafr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mafr/" "tex/latex/mafr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bzmf36xy2ppd2bkc5lkcw43jangwn0w4scgr9il06d14lbw68yn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mafr")
    (synopsis "Mathematics in accord with French usage")
    (description
     "The package provides settings and macros for typesetting mathematics
with LaTeX in compliance with French usage.  It comes with two document
classes, @code{fiche} and @code{cours}, useful to create short high school
documents such as tests or lessons.  The documentation is in French.")
    (license license:gpl3+)))

(define-public texlive-magra
  (package
    (name "texlive-magra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/magra/"
                                     "fonts/enc/dvips/magra/"
                                     "fonts/map/dvips/magra/"
                                     "fonts/tfm/public/magra/"
                                     "fonts/type1/public/magra/"
                                     "fonts/vf/public/magra/"
                                     "tex/latex/magra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bbybiv6v05886qydj1c7l2ja520j15jgz6jz4g8qa58ycrls4kl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/magra")
    (synopsis "Magra font face with support for LaTeX and pdfLaTeX")
    (description
     "This package provides the Magra family of fonts designed by FontFuror,
with support for LaTeX and pdfLaTeX.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-mahjong
  (package
    (name "texlive-mahjong")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mahjong/" "source/latex/mahjong/"
                                     "tex/latex/mahjong/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nkj6kri9dpk3gkms4raldzkj3dhsf54vggivb6nh169s7a16m7q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mahjong")
    (synopsis "Typeset mahjong tiles using MPSZ Notation")
    (description
     "The @code{mahjong} package provides a LaTeX interface for typesetting
mahjong tiles using an extended version of MPSZ algebraic notation.  Its
features include spaces, rotated, blank, and concealed tiles, as well as red
fives.  The size of the mahjong tiles can be controlled using a package option
and an optional argument of @code{\\mahjong}.  It is primarily aimed at
Riichi (aka Japanese) Mahjong but can be used to typeset any style of
mahjong.")
    (license (list license:expat license:cc-by4.0))))

(define-public texlive-marcellus
  (package
    (name "texlive-marcellus")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/marcellus/"
                                     "fonts/enc/dvips/marcellus/"
                                     "fonts/map/dvips/marcellus/"
                                     "fonts/tfm/public/marcellus/"
                                     "fonts/truetype/public/marcellus/"
                                     "fonts/type1/public/marcellus/"
                                     "fonts/vf/public/marcellus/"
                                     "tex/latex/marcellus/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nnc0v15sjwzivy504lvrrfyzjhha7p42nwp0qqy7pwspb7cqsm5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/marcellus")
    (synopsis "Marcellus fonts with LaTeX support")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the Marcellus family of fonts, designed by Brian J. Bonislawsky.  Marcellus is
a flared-serif family, inspired by classic Roman inscription letterforms.
There is currently just a regular weight and small-caps.  The regular weight
will be silently substituted for bold.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-margbib
  (package
    (name "texlive-margbib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/margbib/" "source/latex/margbib/"
                                     "tex/latex/margbib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04aa9nfdxc475nyj4cl8gkj2grn7v3rkb3hwhbhff5nr88nx4aqq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/margbib")
    (synopsis "Display bibitem tags in the margins")
    (description
     "The package redefines the @code{thebibliography} environment to place
the citation key into the margin.")
    (license license:gpl3+)))

(define-public texlive-matapli
  (package
    (name "texlive-matapli")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/matapli/" "tex/latex/matapli/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0khkgc80hbydnlciqr02ay88gazr4nxdq099pjgf1xcjlnlmnwcp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/matapli")
    (synopsis "Class for the French journal @emph{MATAPLI}")
    (description
     "This is a class for the French journal @emph{MATAPLI} of the Société de
Mathématiques Appliquées et Industrielles (SMAI).")
    (license license:lppl1.3c)))

(define-public texlive-matc3
  (package
    (name "texlive-matc3")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/matc3/" "source/latex/matc3/"
                                     "tex/latex/matc3/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rmrkdcda87pjl1lvyvzky0vdhghx0j6z1vdi9fdz2122f2drmpm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/matc3")
    (synopsis "Commands for Matematica C3 textbooks")
    (description
     "The package provides support for the Matematica C3 project to produce
mathematical textbooks for use in Italian high schools.")
    (license license:lppl1.3+)))

(define-public texlive-matc3mem
  (package
    (name "texlive-matc3mem")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/matc3mem/"
                                     "source/latex/matc3mem/"
                                     "tex/latex/matc3mem/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10igcyqzddl25gxasa9dxj2j49gqs9vi2g1ay0z6jyd5nfsp8ic0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/matc3mem")
    (synopsis "Class for MatematicaC3 textbooks")
    (description
     "The class is a development of @code{memoir}, with
additions (specifically, mathematical extensions) that provide support for
writing the books for the Matematica C3 project to produce mathematical
textbooks for use in Italian high schools.")
    (license license:lppl1.3+)))

(define-public texlive-math-into-latex-4
  (package
    (name "texlive-math-into-latex-4")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/math-into-latex-4/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k11j92h9hpxnyciczknhl83b05avc0rqdnwn82ssqi1k3qixibd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/math-into-latex-4")
    (synopsis "Samples from @emph{(More) Math into LaTeX}, 4th Edition")
    (description
     "This package contains samples for the book @emph{(More) Math into LaTeX},
4th edition.")
    (license license:public-domain)))

(define-public texlive-mathabx
  (package
    (name "texlive-mathabx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/mathabx/"
                                     "fonts/source/public/mathabx/"
                                     "fonts/tfm/public/mathabx/"
                                     "tex/generic/mathabx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kj95jl89wh43b9mfqp05hpa5jqyxca7hp9pfk21js2dhysr7x18"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/mathabx")
    (synopsis "Three series of mathematical symbols")
    (description
     "Mathabx is a set of three mathematical symbols font series.
They are defined by Metafont code.  The package includes Plain TeX and LaTeX
support macros.  A version of the fonts, in Adobe Type 1 format, is also
available.")
    (license license:lppl)))

(define-public texlive-mathabx-type1
  (package
    (name "texlive-mathabx-type1")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/mathabx-type1/"
                                     "fonts/map/dvips/mathabx-type1/"
                                     "fonts/type1/public/mathabx-type1/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1j9aiwxq512bnwjvah06rygd8m6b68dpfkynagad627sfyrblcaa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-mathabx))
    (home-page "https://ctan.org/pkg/mathabx-type1")
    (synopsis "Outline version of the @code{mathabx} fonts")
    (description
     "This is an Adobe Type 1 outline version of the @code{mathabx} fonts.")
    (license license:lppl)))

(define-public texlive-mathalpha
  (package
    (name "texlive-mathalpha")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mathalpha/"
                                     "tex/latex/mathalpha/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19wniyaba8cz4vk279ashg68bxq9178cvvz53cng2cn6i6rw32rv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mathalpha")
    (synopsis "General package for loading maths alphabets in LaTeX")
    (description
     "Package @code{mathalfa} was renamed to @code{mathalpha}.  For backward
compatibility the old name will continue to be recognized in LaTeX documents.
The package provides means of loading maths alphabets (such as are normally
addressed via macros @code{\\mathcal}, @code{\\mathbb}, @code{\\mathfrak} and
@code{\\mathscr}).")
    (license license:lppl1.3c)))

(define-public texlive-mathastext
  (package
    (name "texlive-mathastext")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mathastext/"
                                     "source/latex/mathastext/"
                                     "tex/latex/mathastext/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02zx7v3vffz4wag24pd29dgw2l6vbs30vhrrkylsi26rwsr839zc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mathastext")
    (synopsis "Use the text font in maths mode")
    (description
     "The package uses a text font (usually the document's text font) for the
letters of the Latin alphabet needed when typesetting
mathematics. (Optionally, other characters in the font may also be used).
This facility makes possible (for a document with simple mathematics) a far
wider choice of text font, with little worry that no specially designed
accompanying maths fonts are available.  The package also offers a simple
mechanism for using many different choices of (text hence, now, maths) font in
the same document.  Of course, using one font for two purposes helps produce
smaller PDF files.")
    (license license:lppl1.3+)))

(define-public texlive-mathcommand
  (package
    (name "texlive-mathcommand")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mathcommand/"
                                     "source/latex/mathcommand/"
                                     "tex/latex/mathcommand/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vm7k1p5d74vkqmpxdza4127qj7622w0vfr2bh51wb612dpps2a5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mathcommand")
    (synopsis "@code{\\newcommand}-like commands for defining math macros")
    (description
     "This package provides functionalities for defining macros that have
different behaviors depending on whether in math or text mode, that absorb
Primes, Indices and Exponents (PIE) as extra parameters usable in the code;
and it offers some iteration facilities for defining macros with similar code.
The primary objective of this package is to be used together with the
knowledge package for a proper handling of mathematical notations.")
    (license license:lppl1.3+)))

(define-public texlive-mathcomp
  (package
    (name "texlive-mathcomp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mathcomp/"
                                     "source/latex/mathcomp/"
                                     "tex/latex/mathcomp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a7y6r9ikasr9v48671ij40z31j0mxiliy1k3yg3ldbiggrjh07i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mathcomp")
    (synopsis "Text symbols in maths mode")
    (description
     "This package provides a package which provides access to some
interesting characters of the Text Companion fonts (TS1 encoding) in maths
mode.")
    (license license:lppl)))

(define-public texlive-mathfixs
  (package
    (name "texlive-mathfixs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mathfixs/"
                                     "source/latex/mathfixs/"
                                     "tex/latex/mathfixs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "069gcdc6mhf045cpg5dbd81ng8v7bhqjxwpg9dvz4qdpf508jvq0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mathfixs")
    (synopsis "Fix various layout issues in math mode")
    (description
     "This is a LaTeX2e package to fix some odd behaviour in math mode such as
spacing around fractions and roots, math symbols within bold text as well as
capital Greek letters.  It also adds some related macros.")
    (license license:lppl1.3+)))

(define-public texlive-mathlig
  (package
    (name "texlive-mathlig")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/generic/mathlig/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pyaqwr2h9knxf1axi55vm6wr9xj15d5j5pagb2011k3b830f91b"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mathlig")
    (synopsis "Define maths ligatures")
    (description
     "The package defines character sequences that behave like ligatures, in
maths mode.")
    ;; The license is basically CC-BY.
    (license (license:fsf-free "file://tex/generic/mathlig/mathlig.tex"))))

(define-public texlive-mathpartir
  (package
    (name "texlive-mathpartir")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mathpartir/"
                                     "source/latex/mathpartir/"
                                     "tex/latex/mathpartir/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1baadhdxs4rp1qijkwiki2f4w1faarsq3dqy62q7rxs4640mxqa1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mathpartir")
    (synopsis
     "Typesetting sequences of math formulas, e.g., type inference rules")
    (description
     "The package provides macros for typesetting math formulas in mixed
horizontal and vertical mode, automatically as best fit.  It provides an
environment @code{mathpar} that behaves much as a loose centered paragraph
where words are math formulas, and spaces between them are larger and
adjustable.  It also provides a macro @code{\\inferrule} for typesetting
fractions where both the numerator and denominator may be sequences of
formulas that will be also typeset in a similar way.  It can typically be used
for typeseting sets of type inference rules or typing derivations.")
    (license license:gpl2)))

(define-public texlive-mathpunctspace
  (package
    (name "texlive-mathpunctspace")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mathpunctspace/"
                                     "tex/latex/mathpunctspace/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kbsdbnhiwgxa1yznsknni7gvv7x96x02ir2vxmlmhph1j3wqx28"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mathpunctspace")
    (synopsis "Control the space after punctuation in math expressions")
    (description
     "This package provides a mechanism to control the space after commas and
semicolons in mathematical expressions.")
    (license license:bsd-2)))

(define-public texlive-mathsemantics
  (package
    (name "texlive-mathsemantics")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mathsemantics/"
                                     "tex/latex/mathsemantics/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06p4i9nx8sh3dv2nzq3vk1m36nshxgalr8c6660ns9kbhraprkbp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mathsemantics")
    (synopsis "Semantic math commands in LaTeX")
    (description
     "This LaTeX package provides both syntactic and semantic helpers to
typeset mathematics in LaTeX.  The syntactic layer eases typesetting of
formulae in general, while the semantic layer provides commands like
@code{\\inner@{x@}@{y@}} to unify typesetting of inner products.  These not
only unify typesetting of math formulae but also allow easily adapting
notation if a user prefers to.  The semantic layer is split into topics.")
    (license license:expat)))

(define-public texlive-maths-symbols
  (package
    (name "texlive-maths-symbols")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/maths-symbols/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0z83qf1rz84cr0b1zvwlacf24pc5r8dn1cxiiyl0xrqncl3279ka"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/maths-symbols")
    (synopsis "Summary of mathematical symbols available in LaTeX")
    (description
     "This package provides a predecessor of the comprehensive symbols list,
covering mathematical symbols available in standard @code{LaTeX} (including
the AMS symbols, if available at compile time).")
    (license license:lppl1.2+)))

(define-public texlive-matlab-prettifier
  (package
    (name "texlive-matlab-prettifier")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/matlab-prettifier/"
                                     "source/latex/matlab-prettifier/"
                                     "tex/latex/matlab-prettifier/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mr3h2pwz5ghhy3k9c35c6q9k946qzmg7clldmlzlrq3cm685lsh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/matlab-prettifier")
    (synopsis "Pretty-print Matlab source code")
    (description
     "The package extends the facilities of the listings package, to
pretty-print Matlab and Octave source code. (Note that support of Octave
syntax is not complete.)")
    (license license:lppl1.3+)))

(define-public texlive-matrix-skeleton
  (package
    (name "texlive-matrix-skeleton")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/matrix-skeleton/"
                                     "tex/latex/matrix-skeleton/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07mqmc0kli0azp2vlzm8q3lp1b70lyggm2hqnq0v9c0jlfhvj9j7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/matrix-skeleton")
    (synopsis
     "PGF/TikZ library that simplifies working with multiple matrix nodes")
    (description
     "The package provides a PGF/TikZ library that simplifies working with
multiple matrix nodes.  To do so, it correctly aligns groups of nodes with the
content of the whole matrix.  Furthermore, @code{matrix-skeleton} provides
rows and columns for easy styling.")
    (license license:isc)))

(define-public texlive-mattens
  (package
    (name "texlive-mattens")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mattens/" "source/latex/mattens/"
                                     "tex/latex/mattens/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18v2hypd9vkxk3anixvgf16rmsjzq3apm6s7qxrkk4vyrgrahsnj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mattens")
    (synopsis "Matrices and tensor typesetting")
    (description
     "The @code{mattens} package contains the definitions to typeset matrices,
vectors and tensors as used in the engineering community for the
representation of common vectors and tensors such as forces, velocities,
moments of inertia, etc.")
    (license license:lppl1.3c)))

(define-public texlive-maze
  (package
    (name "texlive-maze")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/maze/" "tex/latex/maze/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dwsv62rpyll1cfh1qpz6msmypc1a61b1pb0a7lm89ks1cj42zmg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/maze")
    (synopsis "Generate random mazes")
    (description
     "This package can generate random square mazes of a specified size.
The mazes generated by this package are natural and their solution is not too
obvious.  The output it based on the @code{picture} environment.")
    (license license:lppl1.3c)))

(define-public texlive-mcmthesis
  (package
    (name "texlive-mcmthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mcmthesis/"
                                     "source/latex/mcmthesis/"
                                     "tex/latex/mcmthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15v7dkf3ssjvxkxnwvmsz7h8cjcansf7cfc653j78504pvhj4jqr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mcmthesis")
    (synopsis "Template designed for MCM and ICM")
    (description
     "The package offers a template for @acronym{MCM, The Mathematical Contest
in Modeling} and @acronym{ICM, The Interdisciplinary Contest in Modeling} for
typesetting the submitted paper.")
    (license license:lppl1.3c)))

(define-public texlive-mdputu
  (package
    (name "texlive-mdputu")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mdputu/"
                                     "fonts/tfm/public/mdputu/"
                                     "fonts/vf/public/mdputu/"
                                     "tex/latex/mdputu/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01baplnisdakypsrzcvz1hibqw2gq70hyk2dwgljhwcb14rcxylw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mdputu")
    (synopsis "Upright digits in Adobe Utopia Italic")
    (description
     "The @emph{Annals of Mathematics} uses italics for theorems.  However,
slanted digits and parentheses look disturbing when surrounded by (upright)
mathematics.  This package provides virtual fonts with italics and upright
digits and punctuation, as an extension to Mathdesign's Utopia bundle.")
    (license license:bsd-3)))

(define-public texlive-mdsymbol
  (package
    (name "texlive-mdsymbol")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/mdsymbol/"
                                     "doc/latex/mdsymbol/"
                                     "fonts/enc/dvips/mdsymbol/"
                                     "fonts/map/dvips/mdsymbol/"
                                     "fonts/opentype/public/mdsymbol/"
                                     "fonts/source/public/mdsymbol/"
                                     "fonts/tfm/public/mdsymbol/"
                                     "fonts/type1/public/mdsymbol/"
                                     "source/latex/mdsymbol/"
                                     "tex/latex/mdsymbol/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ssvyqyh3k8q2snj8wk0xdbxgnafacsyj4iyh14hrxybknxxqh22"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/mdsymbol")
    (synopsis "Symbol fonts to match Adobe Myriad Pro")
    (description
     "The package provides a font of mathematical symbols, MyriadPro.  The
font is designed as a companion to Adobe Myriad Pro, but it might also fit
well with other contemporary typefaces.")
    (license license:silofl1.1)))

(define-public texlive-mecaso
  (package
    (name "texlive-mecaso")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mecaso/" "tex/latex/mecaso/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11h10mxjdmknvi8r4dnkhv5q2bzgckwaq7p3dziyxkibq1ciq622"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mecaso")
    (synopsis "Formulas frequently used in rigid body mechanics")
    (description
     "This package provides a number of formulas frequently used in rigid body
mechanics.  Since most of these formulas are long and tedious to write, this
package wraps them up in short commands.")
    (license license:gpl3+)))

(define-public texlive-membranecomputing
  (package
    (name "texlive-membranecomputing")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/membranecomputing/"
                                     "tex/latex/membranecomputing/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r5k8ipf435vvffr7da8nl2j14myfp102i5qf0yy0jczziddbq6z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/membranecomputing")
    (synopsis "Membrane Computing notation")
    (description
     "This is a LaTeX package for the Membrane Computing community.  It
comprises the definition of @samp{P} systems, rules and some concepts related
to languages and computational complexity usually needed for Membrane
Computing research.")
    (license license:lppl1.3+)))

(define-public texlive-memdesign
  (package
    (name "texlive-memdesign")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/memdesign/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0aij1b7l1kb2x44qn33m39k0kbhdrclmr25nmvzfn6yw42lh9fz7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/memdesign")
    (synopsis "Notes on book design")
    (description
     "@emph{A Few Notes on Book Design} provides an introduction to the
business of book design.  It is an extended version of what used to be the
first part of the @code{memoir} users manual.")
    (license license:lppl1.3+)))

(define-public texlive-memoirchapterstyles
  (package
    (name "texlive-memoirchapterstyles")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/memoirchapterstyles/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jxd7sbh5vc3j5d5jd3zmyg58kwhy550l5z8q14b4msm00fp6z0a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/memoirchapterstyles")
    (synopsis "Chapter styles in @code{memoir} class")
    (description
     "This package provides a showcase of chapter styles available to users of
@code{memoir}: the six provided in the class itself, plus many from
elsewhere (by the present author and others).  The package's resources apply
only to @code{memoir}, but the package draws from a number of sources relating
to standard classes, including the @code{fncychap} package, and Vincent
Zoonekynd's tutorial on headings.")
    (license license:lppl)))

(define-public texlive-memorygraphs
  (package
    (name "texlive-memorygraphs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/memorygraphs/"
                                     "tex/latex/memorygraphs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03wsql3aq6327k905fz902il1acxcz2ik4adxfkl4vm1f1g045xn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/memorygraphs")
    (synopsis "TikZ styles to typeset graphs of program memory")
    (description
     "This package defines some TikZ styles and adds anchors to existing
styles that ease the declaration of memory graphs.  It is intended for graphs
that represent the memory of a computer program during its execution.")
    (license license:lppl1.3+)))

(define-public texlive-mendex-doc
  (package
    (name "texlive-mendex-doc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/mendex-doc/"
                                     "makeindex/mendex-doc/"
                                     "source/latex/mendex-doc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "096b1v9zzl3qm189paaxz16z4a1xgcj7l2bhdgvl2wqshsz9lx4p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mendex-doc")
    (synopsis "Documentation for Mendex index processor")
    (description
     "This package provides documentation for Mendex (Japanese index
processor).")
    (license license:bsd-3)))

(define-public texlive-mentis
  (package
    (name "texlive-mentis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mentis/" "source/latex/mentis/"
                                     "tex/latex/mentis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0js6gp93jzj6kzvwqycilp42zbwslxk6z77g2198gip2i4m1li0i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mentis")
    (synopsis "Basis for books to be published by Mentis publishers")
    (description
     "This LaTeX class loads @code{scrbook} and provides changes necessary for
publishing at Mentis publishers in Paderborn, Germany.  It is not an official
Mentis class, but developed in close co-operation with Mentis.")
    (license license:lppl)))

(define-public texlive-merriweather
  (package
    (name "texlive-merriweather")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/merriweather/"
                                     "fonts/enc/dvips/merriweather/"
                                     "fonts/map/dvips/merriweather/"
                                     "fonts/opentype/sorkin/merriweather/"
                                     "fonts/tfm/sorkin/merriweather/"
                                     "fonts/type1/sorkin/merriweather/"
                                     "fonts/vf/sorkin/merriweather/"
                                     "tex/latex/merriweather/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dgjw3ld1srv2irnhn6b592y9q9917y6w1x1kcqb4a7dv8s7wpzj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/merriweather")
    (synopsis "Merriweather and MerriweatherSans fonts, with LaTeX support")
    (description
     "This package provides the Merriweather and MerriweatherSans families of
fonts, designed by Eben Sorkin, with support for LaTeX, pdfLaTeX, XeLaTeX, and
LuaLaTeX.  Merriweather features a very large x-height, slightly condensed
letterforms, a mild diagonal stress, sturdy serifs and open forms.  The Sans
family closely harmonizes with the weights and styles of the serif family.
There are four weights and italics for each.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-messagepassing
  (package
    (name "texlive-messagepassing")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/messagepassing/"
                                     "source/latex/messagepassing/"
                                     "tex/latex/messagepassing/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y73kc0jfk7mbcqa0z8g3rdqrw9yhz0z23j94wsks3g2lfl31l0j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/messagepassing")
    (synopsis "Draw diagrams to represent communication protocols")
    (description
     "This package provides an environment to easily draw diagrams to
represent communication protocols using message passing among processes.
Processes are represented as horizontal or vertical lines, and communications
as arrows between lines.  The package also provides multiple macros to
decorate those diagrams, for instance to annotate the diagram, to add crashes
to the processes, checkpoints, ...")
    (license license:lppl1.3+)))

(define-public texlive-metafont-beginners
  (package
    (name "texlive-metafont-beginners")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/metafont-beginners/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12hhvlnvh8dj1396242m6yi0341cina7sxrv7pwzqxzzahwdvmgm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/metafont-beginners")
    (synopsis "Introductory tutorial for Metafont")
    (description
     "This package provides an old introduction to the use of Metafont, that
has stood the test of time.  It focuses on using the program, rather than
designing fonts, but does offer advice about understanding errors in other
people's fonts.")
    (license license:public-domain)))

(define-public texlive-metapost-examples
  (package
    (name "texlive-metapost-examples")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/metapost-examples/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rslyjnw27b5br17cbf6mjjkcgyr49yav4kw12spm3vdwyzb7gxr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/metapost-examples")
    (synopsis "Example drawings using MetaPost")
    (description
     "This package provides a few (hundred) example pictures drawn with MetaPost,
ranging from very simple (lines and circles) to rather intricate (uncommon
geometric transformations, fractals, bitmap, etc).")
    (license license:gpl1+)))

(define-public texlive-metrix
  (package
    (name "texlive-metrix")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/metrix/" "source/latex/metrix/"
                                     "tex/latex/metrix/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "185w7pgil8zix0czvd69l5pv6pcjc0n4nfbllm5v5mzr31sc0k5j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/metrix")
    (synopsis "Typeset metric marks for Latin text")
    (description
     "The package may be used to type the prosodics/metrics of (Latin) verse;
it provides macros to typeset the symbols standing alone, and in combination
with symbols, giving automatic alignment.")
    (license license:lppl1.3c)))

(define-public texlive-mex
  (package
    (name "texlive-mex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/mex/base/" "source/mex/base/"
                                     "tex/mex/base/" "tex/mex/config/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kc766cvvbcqrj60ncz4a105nrn454y5c2330y7s7jzh45dx8qsi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:create-formats #~(list "mex" "pdfmex" "utf8mex")
           #:phases
           #~(modify-phases %standard-phases
               (add-after 'install 'symlink-binaries
                 (lambda* (#:key inputs #:allow-other-keys)
                   (let ((pdftex (search-input-file inputs "bin/pdftex"))
                         (bin (string-append #$output "/bin")))
                     (mkdir-p bin)
                     (with-directory-excursion bin
                       (symlink pdftex "mex")
                       (symlink pdftex "pdfmex")
                       (symlink pdftex "utf8mex"))))))))
    (propagated-inputs
     (list texlive-enctex
           texlive-hyphen-complete
           texlive-knuth-lib
           texlive-pdftex
           texlive-pl
           texlive-plain
           texlive-tex
           texlive-tex-ini-files
           texlive-utf8mex))
    (home-page "https://ctan.org/pkg/mex")
    (synopsis "Polish formats for TeX")
    (description
     "MeX is an adaptation of Plain TeX (MeX) and LaTeX209 (LaMeX) formats to
the Polish language and to Polish printing customs.  It contains a complete
set of Metafont sources of Polish fonts, hyphenation rules for the Polish
language and sources of formats.")
    (license license:knuth)))

(define-public texlive-mgltex
  (package
    (name "texlive-mgltex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mgltex/" "source/latex/mgltex/"
                                     "tex/latex/mgltex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lv18k5z59ayxm9z02pnfibhdblvl802nhmpxd7wg0fbl1sk886x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mgltex")
    (synopsis
     "High-quality graphics from MGL scripts embedded in LaTeX documents")
    (description
     "This package allows you to create high-quality publication-ready
graphics directly from MGL scripts embedded into your LaTeX document, using
the MathGL library.

MathGL is a fast and efficient library by Alexey Balakin for the creation of
high-quality publication-ready scientific graphics.  Although it defines
interfaces for many programming languages, it also implements its own
scripting language, called MGL, which can be used independently.")
    (license (list license:gpl3 license:cc-by-sa3.0))))

(define-public texlive-mhchem
  (package
    (name "texlive-mhchem")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mhchem/" "tex/latex/mhchem/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lnvca8f4xyc756mq2nj9skzjmm5m66ahzxf70yh4gpixc5ijq2r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-amsmath
           texlive-chemgreek
           texlive-graphics
           texlive-l3kernel
           texlive-l3packages
           texlive-tools))
    (home-page "https://ctan.org/pkg/mhchem")
    (synopsis
     "Typeset chemical formulae/equations and H and P statements")
    (description
     "The bundle provides three packages: The @code{mhchem} package provides
commands for typesetting chemical molecular formulae and equations.  The
@code{hpstatement} package provides commands for the official hazard
statements and precautionary statements (H and P statements) that are used to
label chemicals.  The @code{rsphrase} package provides commands for the
official Risk and Safety (R and S) Phrases that are used to label chemicals.")
    (license license:lppl1.3c)))

(define-public texlive-mhequ
  (package
    (name "texlive-mhequ")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mhequ/" "tex/latex/mhequ/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08k45mklj8ag5z3rmn9c15f6pgixz6pxlip4wp07q4l6xdzkk8fq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mhequ")
    (synopsis "Multicolumn equations, tags, labels, sub-numbering")
    (description
     "The @code{mhequ} style file simplifies creating multi-column equation
environments and tagging equations therein.  It supports sub-numbering of
blocks of equations, such as @samp{(1.2a)} and @samp{(1.2b)}, references to
each equation individually @samp{(1.2a)} or to the whole block @samp{(1.2)}.
The labels can be shown in draft mode.  The default behaviour is to show an
equation number if and only if the equation actually has a label, which
reduces visual clutter.")
    (license license:public-domain)))

(define-public texlive-miama
  (package
    (name "texlive-miama")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/miama/"
                                     "fonts/afm/public/miama/"
                                     "fonts/enc/dvips/miama/"
                                     "fonts/map/dvips/miama/"
                                     "fonts/opentype/public/miama/"
                                     "fonts/tfm/public/miama/"
                                     "fonts/type1/public/miama/"
                                     "source/fonts/miama/"
                                     "tex/latex/miama/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07a2i250himdjnphq39kq08ycl7mgi9v1w3cnsg1q2c7qwwizrkw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/miama")
    (synopsis "Miama Nueva handwriting font with LaTeX support")
    (description
     "Miama Nueva is a handwriting and script font with over 1300 glyphs that
supports Latin, Cyrillic, and Greek.  It comes complete with LaTeX support.")
    (license (list license:silofl1.1 license:lppl1.3+))))

(define-public texlive-miller
  (package
    (name "texlive-miller")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/miller/" "source/latex/miller/"
                                     "tex/latex/miller/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "062pzzzi72hrhvxqg8ay9bacqq1rcjry3ms3j9amzmz6zma3jrgw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/miller")
    (synopsis "Typeset Miller indices")
    (description
     "This package typesets Miller indices that are used in material science
with an easy syntax.  Minus signs are printed as bar above the corresponding
number.")
    (license license:lppl)))

(define-public texlive-minimalist
  (package
    (name "texlive-minimalist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/minimalist/"
                                     "tex/latex/minimalist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rcplrng5ib61pwzi32rjxjprk8b5y087xbcyz5jrmkhsyawy575"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-projlib))
    (home-page "https://ctan.org/pkg/minimalist")
    (synopsis "Write your articles or books in a simple and clear way")
    (description
     "This package offers you a LaTeX style file and two classes to typeset
articles or books in a simple and clear way.  These classes currently have
native support for English, French, German, Italian, Portuguese (European and
Brazilian), and Spanish typesetting.  They compile with any major TeX engine.
You may also wish to consider the packages @code{einfart} and
@code{simplivre}, which are enhanced versions of the classes provided here.")
    (license license:lppl1.3c)))

(define-public texlive-mintspirit
  (package
    (name "texlive-mintspirit")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/mintspirit/"
                                     "fonts/enc/dvips/mintspirit/"
                                     "fonts/map/dvips/mintspirit/"
                                     "fonts/opentype/arkandis/mintspirit/"
                                     "fonts/tfm/arkandis/mintspirit/"
                                     "fonts/type1/arkandis/mintspirit/"
                                     "fonts/vf/arkandis/mintspirit/"
                                     "tex/latex/mintspirit/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rh8xjrxm996k2qkd42r27fz8ir8cg8bpy1fgbdbbjyd3a6xpic3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mintspirit")
    (synopsis "LaTeX support for MintSpirit font families")
    (description
     "The package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the MintSpirit and MintSpiritNo2 families of fonts, designed by Hirwen
Harendal.  MintSpirit was originally designed for use as a system font on
a Linux Mint system.  The No.@: 2 variant provides more conventional shapes
for some glyphs.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-mismath
  (package
    (name "texlive-mismath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mismath/" "source/latex/mismath/"
                                     "tex/latex/mismath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1400jh0lnrz24zdwn9hai222haz9fqr0rxld9lnf42drlmb0nlxz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mismath")
    (synopsis "Miscellaneous mathematical macros")
    (description
     "The package provides some mathematical macros to typeset: mathematical
constants @samp{e}, @samp{i}, @samp{p} in upright shape (automatically) as
recommended by ISO 80000-2, vectors with beautiful arrows and adjusted norm,
some standard operator names, improved spacings in mathematical formulas,
systems of equations and small matrices, @code{displaymath} in double columns
for long calculations.")
    (license license:lppl1.3+)))

(define-public texlive-missaali
  (package
    (name "texlive-missaali")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/missaali/"
                                     "fonts/opentype/public/missaali/"
                                     "tex/latex/missaali/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wa6knx1s82q86rl2icd9nqlh5ppa3636f28ns6g1l5fag6wd283"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/missaali")
    (synopsis "Late medieval OpenType Textura font")
    (description
     "This package contains the OpenType Textura font Missaali and a style
file for using it with XeLaTeX.  Textura is a typeface based on the
@emph{textus quadratus} form of the @emph{textualis formata} that late
medieval scribes used for the most valuable manuscripts.  The font Missaali is
based on Textura that German printer Bartholomew Ghotan used for printing
missals and psalters in the 1480s.

This font has two intended use cases: as a Gothic display font; and for
emulating late-medieval manuscripts.  In addition to the basic Textura
letters, the font contains a large number of abbreviation sigla as well as
a set of Lombardic initials.  As modern typesetting algorithms are not
intended for creating 15th century style layout, the package contains
a XeLaTeX style file that makes it easier to achieve the classic incunabula
look.")
    (license (list license:silofl1.1 license:lppl1.3+))))

(define-public texlive-mlacls
  (package
    (name "texlive-mlacls")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mlacls/" "source/latex/mlacls/"
                                     "tex/latex/mlacls/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g6kqsrvcvf8xmygb7rh18a1amqc83fp7fghvd17klsaslal83cd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mlacls")
    (synopsis "LaTeX class for MLA papers")
    (description
     "In the United States, secondary and undergraduate students are generally
expected to adhere to the format prescribed by the @acronym{MLA, Modern
Language Association} for typewritten essays, research papers and writings.
This package provides a simple, straightforward LaTeX class for composing
papers almost perfectly adherent to the MLA style guide.")
    (license license:lppl1.3c)))

(define-public texlive-mlmodern
  (package
    (name "texlive-mlmodern")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/mlmodern/"
                                     "fonts/map/dvips/mlmodern/"
                                     "fonts/tfm/public/mlmodern/"
                                     "fonts/type1/public/mlmodern/"
                                     "tex/latex/mlmodern/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cw802x67yqh6zlkf89pdjlx0r5lmwdca5vcqxmv24c5gx2bc666"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mlmodern")
    (synopsis
     "Blacker Type 1 version of Computer Modern, with multilingual support")
    (description
     "MLModern is a text and math font family with (La)TeX support, based on
the design of Donald Knuth's Computer Modern and the Latin Modern project.  It
avoids the spindliness of most other Type 1 versions of Computer Modern.")
    (license license:lppl1.3c)))

(define-public texlive-mltex
  (package
    (name "texlive-mltex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mltex/" "tex/latex/mltex/"
                                     "tex/mltex/config/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ip0q5kqj6bg4jkginzljknbrd74ss4iky2gvlmf8nnrq06n89my"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:create-formats #~(list "mllatex" "mltex")
           #:phases
           #~(modify-phases %standard-phases
               (add-after 'install 'symlink-binaries
                 (lambda* (#:key inputs #:allow-other-keys)
                   (let ((pdftex (search-input-file inputs "bin/pdftex"))
                         (bin (string-append #$output "/bin")))
                     (mkdir-p bin)
                     (with-directory-excursion bin
                       (symlink pdftex "mllatex")
                       (symlink pdftex "mltex"))))))))
    (propagated-inputs
     (list texlive-babel
           texlive-cm
           texlive-firstaid
           texlive-hyphen-complete
           texlive-knuth-lib
           texlive-l3backend
           texlive-l3kernel
           texlive-latex
           texlive-latex-fonts
           texlive-latexconfig
           texlive-plain
           texlive-tex-ini-files
           texlive-unicode-data))
    (home-page "https://ctan.org/pkg/mltex")
    (synopsis "The MLTeX system")
    (description
     "MLTeX is a modification of TeX that allows the hyphenation of words with
accented letters using ordinary Computer Modern (CM) fonts.  The system is
distributed as a TeX change file.")
    (license license:knuth)))

(define-public texlive-mluexercise
  (package
    (name "texlive-mluexercise")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mluexercise/"
                                     "source/latex/mluexercise/"
                                     "tex/latex/mluexercise/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zvnz3rm9dq8h00hlbzll5cvw4zlcy8xr8l6cfjg0winfnyznky8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:build-targets #~(list "mluexercice.dtx")))
    (home-page "https://ctan.org/pkg/mluexercise")
    (synopsis
     "Exercises and homework at the Martin Luther University Halle-Wittenberg")
    (description
     "This package provides a template class for solving weekly exercises at
the Institute for Computer Science of Martin Luther University
Halle-Wittenberg.  The class can be used by all students --- especially first
semesters --- to typeset their exercises with low effort in beautiful LaTeX.
A bunch of handy macros are included that are used throughout many lectures
during the bachelor's degree program.")
    (license license:expat)))

(define-public texlive-mnras
  (package
    (name "texlive-mnras")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/mnras/" "doc/latex/mnras/"
                                     "tex/latex/mnras/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fzdd0r49g7wbdwhin93b8m4z8zx3n9ipl3gmpypncsmwr096crg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mnras")
    (synopsis "Monthly Notices of the Royal Astronomical Society")
    (description
     "This package is used for preparing papers in the journal @emph{Monthly
Notices of the Royal Astronomical Society}.")
    (license license:lppl1.3+)))

(define-public texlive-mnsymbol
  (package
    (name "texlive-mnsymbol")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mnsymbol/"
                                     "fonts/enc/dvips/mnsymbol/"
                                     "fonts/map/dvips/mnsymbol/"
                                     "fonts/map/vtex/mnsymbol/"
                                     "fonts/opentype/public/mnsymbol/"
                                     "fonts/source/public/mnsymbol/"
                                     "fonts/tfm/public/mnsymbol/"
                                     "fonts/type1/public/mnsymbol/"
                                     "source/latex/mnsymbol/"
                                     "tex/latex/mnsymbol/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "164zspl0wcpmba9j0kl6wy8k46xaafjvwjp0dn82dzh73r85jdk2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/mnsymbol")
    (synopsis "Mathematical symbol font for Adobe MinionPro")
    (description
     "MnSymbol is a symbol font family, designed to be used in conjunction
with Adobe Minion Pro (via the MinionPro package).  Almost all of LaTeX and
AMS mathematical symbols are provided; remaining coverage is available from
the MinionPro font with the MinionPro package.  The fonts are available both
as Metafont source and as Adobe Type 1 format, and a comprehensive support
package is provided.")
    (license license:public-domain)))

(define-public texlive-modeles-factures-belges-assocs
  (package
    (name "texlive-modeles-factures-belges-assocs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/modeles-factures-belges-assocs/"
                                     "tex/latex/modeles-factures-belges-assocs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rj4r3qa5khgc54f1gz73zywrh61rdw76hlrk9jb6b08gz56wzdz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/modeles-factures-belges-assocs")
    (synopsis "Generate invoices for Belgian non-profit organizations")
    (description
     "This package provides templates and a @file{.sty} file for generating
invoices for Belgian non-profit organizations.")
    (license license:lppl1.3c)))

(define-public texlive-montserrat
  (package
    (name "texlive-montserrat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/montserrat/"
                                     "fonts/enc/dvips/montserrat/"
                                     "fonts/map/dvips/montserrat/"
                                     "fonts/opentype/public/montserrat/"
                                     "fonts/tfm/public/montserrat/"
                                     "fonts/type1/public/montserrat/"
                                     "fonts/vf/public/montserrat/"
                                     "tex/latex/montserrat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08aaypw8l30sb0rvv2s9jcw15k3909xam98z2c6vj2x5jyi9wzn7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/montserrat")
    (synopsis "Montserrat sans serif, with LaTeX support files")
    (description
     "Montserrat is a geometric sans-serif typeface designed by Julieta
Ulanovsky.  It is rather close in spirit to Gotham and Proxima Nova, but has
its own individual appearance --- more informal, less extended, and more
idiosyncratic.  It is provided in a total of nine different weights, each
having eight figure styles and small caps in both upright and italic shapes.
There are two quite different versions that don't fit into the usual LaTeX
classifications.  The version having the appellation Alternates has letter
shapes that are much more rounded than the default version, reflecting the
signage in the neighborhood of Montserrat.")
    (license (list license:silofl1.1 license:lppl1.3+))))

(define-public texlive-mparhack
  (package
    (name "texlive-mparhack")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mparhack/"
                                     "source/latex/mparhack/"
                                     "tex/latex/mparhack/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ajlpri5bi62k9wsmic3j2xjkz1wzjc3n4fr04c5d667jsibpfmg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mparhack")
    (synopsis "Work around a LaTeX bug in marginpars")
    (description
     "This package works around the LaTeX bug that marginpars will sometimes
come out at the wrong margin.")
    (license license:gpl2+)))

(define-public texlive-mpfonts
  (package
    (name "texlive-mpfonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/mpfonts/"
                                     "fonts/map/dvips/mpfonts/"
                                     "fonts/type3/mpfonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z6pdjwi14fq6y1s39gxyqlpg6p5j09psjv1cyp7xjwjffdikgaf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mpfonts")
    (synopsis "Computer Modern Type 3 fonts converted using MetaPost")
    (description
     "The Computer Modern fonts are available in Type 1 format, but these
renditions are somewhat thin and spindly, and produce much lighter results
than the originals.  These fonts are conversions to Type 3 fonts, done
entirely in MetaPost; they are vector fonts which are a direct conversion from
the original Metafont files, so they are the design most authentic to the
originals.  However, these fonts, because they are PostScript Type 3 fonts,
are not suitable for on-screen reading, and should probably only be used for
printing.")
    (license (list license:knuth
                   license:lppl1.2+
                   license:silofl1.1
                   license:public-domain))))

(define-public texlive-mucproc
  (package
    (name "texlive-mucproc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mucproc/" "source/latex/mucproc/"
                                     "tex/latex/mucproc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l6xycas6asggpd4hd1b7x5x867nsx8aw2fkdd1ib8g98i5a8vhk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mucproc")
    (synopsis "Conference proceedings for the German MuC-conference")
    (description
     "The @file{mucproc.cls} is a document class to support the formatting
guidelines for submissions to the German Mensch und Computer conference.")
    (license license:lppl1.3+)))

(define-public texlive-mugsthesis
  (package
    (name "texlive-mugsthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mugsthesis/"
                                     "source/latex/mugsthesis/"
                                     "tex/latex/mugsthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xf3zjwx6k2dg1hrz4nw6shn6xk3lvmjprg3psfrh3z38r1sp9nh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mugsthesis")
    (synopsis
     "Thesis class complying with Marquette University Graduate School
requirements")
    (description
     "The bundle offers a thesis class, based on @code{memoir}, that complies
with Marquette University Graduate School requirements.")
    (license license:lppl1.3+)))

(define-public texlive-muling
  (package
    (name "texlive-muling")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/muling/" "source/latex/muling/"
                                     "tex/latex/muling/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lz19h237xkijcxlmbv982bs8niscya9m4l9w5ai01vlvh1hg9z6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/muling")
    (synopsis
     "MA thesis class for the Department of Linguistics, University of
Mumbai")
    (description
     "This is a class file for writing MA thesis as required by the
Department of Linguistics at the University of Mumbai.")
    (license license:lppl1.3c)))

(define-public texlive-multibib
  (package
    (name "texlive-multibib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/multibib/" "doc/latex/multibib/"
                                     "makeindex/multibib/"
                                     "source/latex/multibib/"
                                     "tex/latex/multibib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m16vi9fj2yc49a6iqcccd7yay26i8zpyzzsgxywlrp4ijrx4hqc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/multibib")
    (synopsis "Multiple bibliographies within one document")
    (description
     "The package the creation of references to multiple bibliographies within
one document.  It thus provides complementary functionality to packages like
@code{bibunits} and @code{chapterbib}, which allow the creation of one
bibliography for multiple, but different parts of the document.  Multibib is
compatible with @code{inlinebib}, @code{natbib}, and @code{koma-script}.")
    (license license:lppl)))

(define-public texlive-multibibliography
  (package
    (name "texlive-multibibliography")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/multibibliography/"
                                     "doc/latex/multibibliography/"
                                     "scripts/multibibliography/"
                                     "source/latex/multibibliography/"
                                     "tex/latex/multibibliography/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10281fv7xfqmdc08pyk9l9280crklsfqwf5cwd5ysbhdz1r0grcm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "multibibliography.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/multibibliography")
    (synopsis
     "Multiple versions of a bibliography, with different sort orders")
    (description
     "Conventional standards for bibliography styles impose a forced choice
between index and name/year citations, and corresponding references.  The
package avoids this choice, by providing alphabetic, sequenced, and even
chronological orderings of references.  Inline citations, that integrate these
heterogeneous styles, are also supported (and work with other bibliography
packages).")
    (license license:lppl1.3+)))

(define-public texlive-multiobjective
  (package
    (name "texlive-multiobjective")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/multiobjective/"
                                     "source/latex/multiobjective/"
                                     "tex/latex/multiobjective/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0f5l6pg8877a7777vzlh91yxv2rliijgdhkm71fim5n66q0ym9y4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/multiobjective")
    (synopsis "Symbols for multiobjective optimisation etc")
    (description
     "The package provides a series of operators commonly used in papers
related to multiobjective optimisation, multiobjective evolutionary
algorithms, multicriteria decision making and similar fields.")
    (license license:lppl)))

(define-public texlive-munich
  (package
    (name "texlive-munich")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/munich/" "doc/latex/munich/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1w464hiivzccfk0i4hz60x3q14h38y2yzycldckx144q0z6i4c5r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/munich")
    (synopsis "Alternative author-date bibliography style")
    (description
     "The Munich BibTeX style is produced with @code{custom-bib}, as a German
(and, more generally, Continental European) alternative to such author-date
styles as @code{harvard} and @code{oxford}.")
    (license license:lppl)))

(define-public texlive-musical
  (package
    (name "texlive-musical")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/musical/" "tex/latex/musical/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qdrd622vs5dkr5w6pvf04hvni1jqcgxfvhf0ak7gjaxjczisb9h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/musical")
    (synopsis "Typeset (musical) theatre scripts")
    (description
     "This package is designed to simplify the development and distribution of
scripts for theatrical musicals, especially ones under development.  The
output is formatted to follow generally accepted script style while also
maintaining a high level of typographic integrity, and includes commands for
dialog, lyrics, stage directions, music and dance cues, rehearsal marks, and
more.  It gracefully handles dialog that crosses page breaks, and can generate
lists of songs and lists of dances in the show.")
    (license license:lppl1.3+)))

(define-public texlive-musicography
  (package
    (name "texlive-musicography")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/musicography/"
                                     "tex/latex/musicography/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ppzxx875vzisdmmjkkgn6jcsnr0zvz06h0j1pkq2khl4mp59jik"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/musicography")
    (synopsis "Accessing symbols for music writing with pdfLaTeX")
    (description
     "This package makes available the most commonly used symbols in writing
about music in a way that can be used with pdfLaTeX and looks consistent and
attractive.  It includes accidentals, meters, and notes of different rhythmic
values.  The package builds on the approach used in the @code{harmony}
package, where the symbols are taken from the MusiXTeX fonts.  But it provides
a larger range of symbols and a more flexible, user-friendly interface.")
    (license license:lppl1.3+)))

(define-public texlive-musikui
  (package
    (name "texlive-musikui")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/musikui/" "tex/latex/musikui/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r5ygiavq51sj0l2jcn8jzc1jafach05a3pz2xvzxmxsxdjgzf02"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/musikui")
    (synopsis "Easy creation of ``arithmetical restoration'' puzzles")
    (description
     "This package permits easily typesetting arithmetical restorations using
LaTeX.")
    (license license:lppl)))

(define-public texlive-musixguit
  (package
    (name "texlive-musixguit")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/musixguit/"
                                     "tex/latex/musixguit/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ck8li0wdn22x0g4f57c9r57ans4rj7ggrm3rsp7xnqgc78as065"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/musixguit")
    (synopsis "Easy notation for guitar music, in MusixTeX")
    (description
     "The package provides commands for typesetting notes for guitar,
especially for simplifying guitar notation with MusixTeX.")
    (license license:lppl1.3+)))

(define-public texlive-musixtex
  (package
    (name "texlive-musixtex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/musixtex/"
                                     "doc/man/man1/musixflx.1"
                                     "doc/man/man1/musixflx.man1.pdf"
                                     "doc/man/man1/musixtex.1"
                                     "doc/man/man1/musixtex.man1.pdf"
                                     "dvips/musixtex/"
                                     "scripts/musixtex/"
                                     "source/generic/musixtex/musixcrd/"
                                     "tex/generic/musixtex/"
                                     "tex/latex/musixtex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jjsciwgibw3zqng9ix51ykxjr9kvljsqpamrk7d62s2lkvxx4xn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:build-targets #~(list "strip.tex")
           #:link-scripts #~(list "musixflx.lua" "musixtex.lua")))
    (home-page "https://ctan.org/pkg/musixtex")
    (synopsis "Sophisticated music typesetting")
    (description
     "MusiXTeX provides a set of macros, based on the earlier MusicTeX,
for typesetting music with TeX.  To produce optimal spacing, MusiXTeX
is a three-pass system: @command{etex}, @command{musixflx}, and
@command{etex} again.  (Musixflx is a Lua script that is provided in
the bundle.) The three-pass process, optionally followed by processing
for printed output, is automated by the @command{musixtex} wrapper
script.

The package uses its own specialised fonts, which must be available on the
system for @command{musixtex} to run.  The MusiXTeX macros are universally
acknowledged to be challenging to use directly: the @command{pmx} preprocessor
compiles a simpler input language to MusiXTeX macros.")
    (license license:gpl2+)))

(define-public texlive-musixtex-fonts
  (package
    (name "texlive-musixtex-fonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/musixtex-fonts/"
                                     "fonts/map/dvips/musixtex-fonts/"
                                     "fonts/opentype/public/musixtex-fonts/"
                                     "fonts/source/public/musixtex-fonts/"
                                     "fonts/tfm/public/musixtex-fonts/"
                                     "fonts/type1/public/musixtex-fonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ychs959d1yvxkhwayf73iwvl4qg0a6v5fk7lnw8w3hk8n7zvp86"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/musixtex-fonts")
    (synopsis "Fonts used by MusixTeX")
    (description
     "These are fonts for use with MusixTeX; they are provided both as
original Metafont source, and as converted Adobe Type 1.  The bundle renders
the older (Type 1 fonts only) bundle @code{musixtex-t1fonts} obsolete.")
    (license license:gpl3+)))

(define-public texlive-musixtnt
  (package
    (name "texlive-musixtnt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/musixtnt/"
                                     "doc/man/man1/msxlint.1"
                                     "doc/man/man1/msxlint.man1.pdf"
                                     "tex/generic/musixtnt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0z1rfscla1hiibd0gs3lgf8x5yx19pmwdsbzvx2vvz0ikwgjglm9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-musixtex texlive-musixtnt-bin))
    (home-page "https://ctan.org/pkg/musixtnt")
    (synopsis
     "MusiXTeX extension library enabling transformations of the effect of
notes commands")
    (description
     "This archive contains a MusiXTeX extension library @file{musixtnt.tex}
and a program, @command{msxlint}.

@file{musixtnt.tex} provides a macro @code{\\TransformNotes} that enables
transformations of the effect of notes commands such as @code{\\notes}.  In
general, the effect of @code{\\TransformNotes@{input@}@{output@}} is that
notes commands in the source will expect their arguments to match the input
pattern, but the notes will be typeset according to the output pattern.  An
example is extracting single-instrument parts from a multi-instrument score.

@command{msxlint} detects incorrectly formatted notes lines in a MusiXTeX
source file.  This should be used before using @code{\\TransformNotes}.")
    (license license:gpl2)))

(define-public texlive-musixtnt-bin
  (package
    (inherit texlive-bin)
    (name "texlive-musixtnt-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root keep)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir
                       "."
                       (lambda (file)
                         (and (not (member file (append keep '("." ".."))))
                              (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("musixtnt"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-musixtnt" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/musixtnt"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/musixtnt"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list texlive-libkpathsea))
    (propagated-inputs '())
    (home-page (package-home-page texlive-musixtnt))
    (synopsis "Binary for @code{texlive-musixtnt}")
    (description
     "This package provides the binary for @code{texlive-musixtnt}.")
    (license (package-license texlive-musixtnt))))

(define-public texlive-musuos
  (package
    (name "texlive-musuos")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/musuos/" "source/latex/musuos/"
                                     "tex/latex/musuos/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a7cyjfgch6fvwdv2wi78sx2fdgmjbpb85gp2clhvgf15nkw0h94"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/musuos")
    (synopsis "Typeset papers for the department of music, Osnabruck")
    (description
     "The package provides a LaTeX class for typesetting term papers at the
institute of music and musicology of the University of Osnabruck, Germany,
according to the specifications of Prof.@: Stefan Hahnheide.  A BibLaTeX style
is provided.")
    (license license:lppl)))

(define-public texlive-muthesis
  (package
    (name "texlive-muthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/muthesis/" "tex/latex/muthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yydkhxpa9c5w8bpdx09w3mjggff0q2zsq8gkkbjjg29mg5x559j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/muthesis")
    (synopsis "Classes for University of Manchester Dept.@: of Computer
Science")
    (description
     "The bundle provides thesis and project report document classes from the
University of Manchester's Department of Computer Science.")
    (license license:lppl)))

(define-public texlive-msu-thesis
  (package
    (name "texlive-msu-thesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/msu-thesis/"
                                     "tex/latex/msu-thesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h84kk88mn1vvakcvxxfwpw1fhc9i8ypmz3y12frzvm6n9h2dyy2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/msu-thesis")
    (synopsis "Class for Michigan State University Master's and PhD theses")
    (description
     "This is a class file for producing dissertations and theses according to
the Michigan State University Graduate School Guidelines for Electronic
Submission of master's theses and dissertations.  The class should meet all
current requirements and is updated whenever the university guidelines change.
The class is based on the @code{memoir} document class, and inherits the
functionality of that class.")
    (license license:lppl1.3+)))

(define-public texlive-mwcls
  (package
    (name "texlive-mwcls")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mwcls/" "source/latex/mwcls/"
                                     "tex/latex/mwcls/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pj1m08gh5zsahvzan6wq9v0lnir9zb4qvgkadsl6jm9ia8990yn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mwcls")
    (synopsis "Polish-oriented document classes")
    (description
     "@code{mwcls} is a set of document classes for LaTeX designed with Polish
typographical tradition in mind.  The classes include: @code{mwart} (which is
a replacement for @code{article}), @code{mwrep} (replacing @code{report}), and
@code{mwbk} (replacing @code{book}).

Most features present in standard classes work with @code{mwcls} classes.
Some extensions/exceptions include: sectioning commands allow for second
optional argument (it is possible to state different texts for running head
and for TOC), new environments @code{itemize*} and @code{enumerate*} for lists
with long items, page styles have variants for normal, opening, closing, and
blank pages.")
    (license license:lppl1.2+)))

(define-public texlive-mxedruli
  (package
    (name "texlive-mxedruli")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/mxedruli/"
                                     "fonts/afm/public/mxedruli/"
                                     "fonts/map/dvips/mxedruli/"
                                     "fonts/source/public/mxedruli/"
                                     "fonts/tfm/public/mxedruli/"
                                     "fonts/type1/public/mxedruli/"
                                     "tex/latex/mxedruli/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "070lfw12mfimcwhkgb1hh092p8npmhpmba28rzzwfl1kmsmk99q5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/mxedruli")
    (synopsis "Pair of fonts for different Georgian alphabets")
    (description
     "This package provides two Georgian fonts, in both Metafont and Type
1 formats, which cover the Mxedruli and the Xucuri alphabets.")
    (license license:lppl)))

(define-public texlive-mynsfc
  (package
    (name "texlive-mynsfc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/mynsfc/"
                                     "source/xelatex/mynsfc/"
                                     "tex/xelatex/mynsfc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15vbgqmqsjqz068gn5ql5ca3wbw7gdq1vnaazpwmc71jdybxxv14"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:phases
           #~(modify-phases %standard-phases
               ;; "mynsfc.ins" writes files to "./examples".  Create this
               ;; directory first to prevent an error.
               (add-before 'build 'prepare-build
                 (lambda _ (mkdir-p "build/examples"))))))
    (home-page "https://ctan.org/pkg/mynsfc")
    (synopsis "XeLaTeX template for writing the main body of NSFC proposals")
    (description
     "The package provides a XeLaTeX template for writing the main body of
@acronym{NSFC, National Natural Science Foundation of China} proposals, which
are allowed to apply online.  The package defines styles of the outlines and
uses BibLaTeX and Biber for the management of references.")
    (license license:lppl1.3c)))

(define-public texlive-na-box
  (package
    (name "texlive-na-box")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/na-box/" "tex/xelatex/na-box/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1j02k0d4m23yackb1vn8pajxwkimkkrx9h512xs3hkxdi6qdwb73"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/na-box")
    (synopsis "Arabic-aware version of @code{pas-cours} package")
    (description
     "This is a modified version of the @code{pas-cours} package made
compatible with XeLaTeX and Polyglossia to write Arabic documents with fancy
boxed @code{theorem}-alike environments.")
    (license license:lppl)))

(define-public texlive-naive-ebnf
  (package
    (name "texlive-naive-ebnf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/naive-ebnf/"
                                     "source/latex/naive-ebnf/"
                                     "tex/latex/naive-ebnf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0z32jdxnw9lzc49ar6h8wb7rzh52pbkh88jha7zgz6nywpr7dwk1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-filecontentsdef
           texlive-l3kernel
           texlive-pgfopts))
    (home-page "https://ctan.org/pkg/naive-ebnf")
    (synopsis "EBNF in Plain Text")
    (description
     "With the help of this LaTeX package, a context-free grammar (CFG) may be
rendered in a plain-text mode using a simplified Extended Backus-Naur
Form (EBNF) notation.")
    (license license:expat)))

(define-public texlive-namedtensor
  (package
    (name "texlive-namedtensor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/namedtensor/"
                                     "tex/latex/namedtensor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bsphfy1k9kplfmhn8qcb2y90l5ga1281r5xds4jn73m319n0iq5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/namedtensor")
    (synopsis "Macros for named tensor notation")
    (description "This style file provides macros for named tensor notation.")
    (license license:expat)))

(define-public texlive-nanicolle
  (package
    (name "texlive-nanicolle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/nanicolle/"
                                     "tex/xelatex/nanicolle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lzcsmy4iw0ch3w1g3h5b23hkzspi5q2gs406l4cihfmf30yiadk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nanicolle")
    (synopsis "Typesetting herbarium specimen labels")
    (description
     "This package provides a LaTeX class @file{nanicolle.cls} for typesetting
collection labels and identification labels in Chinese style or in western
style for plant herbarium specimens.  So far, documents using this class can
only be compiled with XeLaTeX.")
    (license license:lppl1.3c)))

(define-public texlive-nanumtype1
  (package
    (name "texlive-nanumtype1")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/nanumtype1/"
                                     "fonts/afm/public/nanumtype1/"
                                     "fonts/map/dvips/nanumtype1/"
                                     "fonts/tfm/public/nanumtype1/"
                                     "fonts/type1/public/nanumtype1/"
                                     "fonts/vf/public/nanumtype1/"
                                     "tex/latex/nanumtype1/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0n7dbhxa186x7f2ql8kjr2bn425vlhswl2m5n2n3iklfam9bmf6k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nanumtype1")
    (synopsis "Type1 subfonts of Nanum Korean fonts")
    (description
     "Nanum is a unicode font designed especially for Korean-language script.
The font was designed by Sandoll Communication and Fontrix; it includes the
sans serif (gothic), serif (myeongjo), pen script and brush script typefaces.
The package provides Type1 subfonts converted from Nanum Myeongjo (Regular and
@code{ExtraBold)} and Nanum Gothic (Regular and Bold) OTFs.  C70, LUC, T1, and
TS1 font definition files are also provided.")
    (license license:silofl1.1)))

(define-public texlive-nar
  (package
    (name "texlive-nar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/nar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nwk71qirapkg3h6jwlv53fm6zwb2vq0fvmc4xcanf19sm3331mk"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nar")
    (synopsis "BibTeX style for @emph{Nucleic Acid Research}")
    (description
     "This BibTeX bibliography style is for the journal @emph{Nucleic Acid Research}.
It was adapted from the standard @file{unsrt.bst} style file.")
    (license license:knuth)))

(define-public texlive-natded
  (package
    (name "texlive-natded")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/natded/" "tex/latex/natded/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01zfxh4ryjjv5qyvbs1pgwpcnq19rdrg3drd2gfx3c4ppqvwbxp4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/natded")
    (synopsis "Typeset natural deduction proofs")
    (description
     "The package provides commands to typeset proofs in the style used by Jaskowski,
or that of Kalish and Montague.")
    (license license:lppl1.3+)))

(define-public texlive-nath
  (package
    (name "texlive-nath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nath/" "tex/latex/nath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dq9hb3gbqak6406x8av9zig4pc7kxasa3ak0fr50hx4fvfa6v8q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nath")
    (synopsis "Natural mathematics notation")
    (description
     "Nath is a LaTeX style to separate presentation and content in
mathematical typography.  The style delivers a particular context-dependent
presentation on the basis of a rather coarse context-independent notation.
Highlighted features: depending on the context, the command @code{\\frac}
produces either built-up or case or solidus fractions, with parentheses added
whenever required for preservation of the mathematical meaning; delimiters
adapt their size to the material enclosed, rendering @code{\\left} and
@code{\\right} almost obsolete.")
    (license license:gpl3+)))

(define-public texlive-nature
  (package
    (name "texlive-nature")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/nature/" "doc/latex/nature/"
                                     "tex/latex/nature/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04jxf6i83qnhy6i3rpqzm4nzqvc7r56ygx37741ii8yckz58xiah"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nature")
    (synopsis "Prepare papers for the journal @emph{Nature}")
    (description
     "@emph{Nature} does not accept papers in LaTeX, but it does accept PDF.
This class and BibTeX style provide what seems to be necessary to produce
papers in a format acceptable to the publisher.")
    (license license:lppl)))

(define-public texlive-navydocs
  (package
    (name "texlive-navydocs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/navydocs/"
                                     "source/latex/navydocs/"
                                     "tex/latex/navydocs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qisck3lr1nhjnqs195agvmiw93yld801nahr3bb7yyhzgn2f443"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/navydocs")
    (synopsis "Support for technical reports by US Navy organizations")
    (description
     "The @code{navydocs} package provides an easy means for creating title
pages and the following supplementary material pages used in technical reports
by United States Navy organizations.  These pages are generated by specifying
the page content via a set of commands and then calling a macro to create the
page at its occurrence in the document.")
    (license license:lppl1.3+)))

(define-public texlive-nchairx
  (package
    (name "texlive-nchairx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nchairx/" "source/latex/nchairx/"
                                     "tex/latex/nchairx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cgp22c26afdpb5pfk5ljp1fr0wvlkf04viw9zbc4gss8hi3gqi5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nchairx")
    (synopsis "Maths macros from chair X of Wurzburg University")
    (description
     "This package was developed by members of the chair for mathematical
physics at the University of Wurzburg as a collection of macros and predefined
environments for quickly creating nice mathematical documents.")
    (license license:lppl1.3+)))

(define-public texlive-nddiss
  (package
    (name "texlive-nddiss")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/nddiss/" "doc/latex/nddiss/"
                                     "source/latex/nddiss/" "tex/latex/nddiss/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "131gzskjqhh5v677rxf2pap87jvi6jdznimqmql468y3pwc2zja0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nddiss")
    (synopsis "Notre Dame Dissertation format class")
    (description
     "This class file conforms to the requirements of the Graduate School of
the University of Notre Dame; with it a user can format a thesis or
dissertation in LaTeX.")
    (license license:lppl1.2+)))

(define-public texlive-nevelok
  (package
    (name "texlive-nevelok")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nevelok/" "source/latex/nevelok/"
                                     "tex/latex/nevelok/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02g60npy2hp181vnzpna7h2544y7bnbi9y6srpm7kjmd6immm7qn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nevelok")
    (synopsis "LaTeX package for automatic definite articles for Hungarian")
    (description
     "This LaTeX package provides automatic definite articles for Hungarian.")
    (license license:lppl1.3+)))

(define-public texlive-newcastle-bst
  (package
    (name "texlive-newcastle-bst")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/newcastle-bst/"
                                     "doc/bibtex/newcastle-bst/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q5mwwiwf6pvlk6xbvrc6rfm87qrkpp7nba4qgdagjkdrn0hs4jz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/newcastle-bst")
    (synopsis
     "BibTeX style following Harvard at Newcastle style recommendations")
    (description
     "This package provides a BibTeX style to format reference lists in the
Harvard at Newcastle style recommended by Newcastle University.  It should be
used alongside @code{natbib} for citations.")
    (license license:lppl1.3c)))

(define-public texlive-newcomputermodern
  (package
    (name "texlive-newcomputermodern")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/newcomputermodern/"
                                     "fonts/opentype/public/newcomputermodern/"
                                     "tex/latex/newcomputermodern/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qqw6src414v9f418xc9pjwzij67rh874rwz8vnrz9fczvpbiq8f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/newcomputermodern")
    (synopsis "Computer Modern fonts including matching non-Latin alphabets")
    (description
     "This is a new assembly of Computer Modern fonts including extensions in
many directions for both Latin based languages, non-Latin based languages and
Mathematics, all compatible in style to CM fonts.  In addition to the Regular
weight of Computer Modern, it provides a Book weight for heavier printing.")
    (license license:gfl1.0)))

(define-public texlive-newpx
  (package
    (name "texlive-newpx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/newpx/"
                                     "fonts/afm/public/newpx/"
                                     "fonts/enc/dvips/newpx/"
                                     "fonts/map/dvips/newpx/"
                                     "fonts/opentype/public/newpx/"
                                     "fonts/tfm/public/newpx/"
                                     "fonts/type1/public/newpx/"
                                     "fonts/vf/public/newpx/"
                                     "source/fonts/newpx/"
                                     "tex/latex/newpx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ijy6hgdgyscp8jl2hf1g115k8w41z7mjjh010avgbjjrj7i8zky"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/newpx")
    (synopsis "Alternative uses of the PX fonts, with improved metrics")
    (description
     "This package, initially based on @code{pxfonts}, provides many fixes and
enhancements to that package, and splits it in two parts (@code{newpxtext} and
@code{newpxmath}) which may be run independently of one another.  It provides
scaling, improved metrics, and other options.")
    (license (list license:lppl license:silofl1.1))))

(define-public texlive-newtxsf
  (package
    (name "texlive-newtxsf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/newtxsf/"
                                     "fonts/map/dvips/newtxsf/"
                                     "fonts/tfm/public/newtxsf/"
                                     "fonts/type1/public/newtxsf/"
                                     "fonts/vf/public/newtxsf/"
                                     "tex/latex/newtxsf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "042n07d46ps1ciqnkqf7hf21nbgmsmlsrswq3q3v6vcqsxvyrc7d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/newtxsf")
    (synopsis "Sans-math fonts for use with @code{newtx}")
    (description
     "The package provides a maths support that amounts to modifications of
the STIX sans serif Roman and Greek letters with most symbols taken from
@code{newtxmath}.")
    (license license:silofl1.1)))

(define-public texlive-newtxtt
  (package
    (name "texlive-newtxtt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/newtxtt/"
                                     "fonts/enc/dvips/newtxtt/"
                                     "fonts/map/dvips/newtxtt/"
                                     "fonts/tfm/public/newtxtt/"
                                     "fonts/type1/public/newtxtt/"
                                     "tex/latex/newtxtt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yhlk13nmzaprkw3vp8gbrdripf9xix1b2wmb48ci2ja4j9fpm46"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/newtxtt")
    (synopsis "Enhancement of typewriter fonts from @code{newtx}")
    (description
     "The package provides enhanced fonts with LaTeX support files providing
access to the typewriter fonts from @code{newtx}.  Regular and bold weights,
slanted variants and a choice of four different styles for zero.")
    (license (list license:gpl3 license:lppl))))

(define-public texlive-niceframe-type1
  (package
    (name "texlive-niceframe-type1")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/niceframe-type1/"
                                     "fonts/afm/public/niceframe-type1/"
                                     "fonts/map/dvips/niceframe-type1/"
                                     "fonts/type1/public/niceframe-type1/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vqdy0k94qn72mbz2kqccx2zlmzrh14qfwgqb16n017wlnynzvd7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/niceframe-type1")
    (synopsis "Type 1 versions of the fonts recommended in @code{niceframe}")
    (description
     "The bundle provides Adobe Type 1 versions of the fonts @code{bbding10},
@code{dingbat}, @code{karta15}, @code{umranda} and @code{umrandb}.")
    (license license:lppl)))

(define-public texlive-nicematrix
  (package
    (name "texlive-nicematrix")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nicematrix/"
                                     "source/latex/nicematrix/"
                                     "tex/latex/nicematrix/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15jlm41gi2573l1bsqh1ldw49g5gk2bcgcaxm959388xzyky53gy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nicematrix")
    (synopsis "Improve the typesetting of mathematical matrices with PGF")
    (description
     "This package is based on the package @code{array}.  It creates PGF/TikZ
nodes under the cells of the array and uses these nodes to provide
functionalities to construct tabulars, arrays and matrices.  Among the
features, it provides: continuous dotted lines for the mathematical matrices;
exterior rows and columns (so-called border matrices); control of the width of
the columns; tools to color rows and columns with a good PDF result; blocks of
cells; etc.")
    (license license:lppl1.3+)))

(define-public texlive-nimbus15
  (package
    (name "texlive-nimbus15")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/nimbus15/"
                                     "fonts/afm/public/nimbus15/"
                                     "fonts/enc/dvips/nimbus15/"
                                     "fonts/map/dvips/nimbus15/"
                                     "fonts/opentype/public/nimbus15/"
                                     "fonts/tfm/public/nimbus15/"
                                     "fonts/type1/public/nimbus15/"
                                     "fonts/vf/public/nimbus15/"
                                     "tex/latex/nimbus15/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x5y8jcwg3ns4jdz3rqzmd1xsfsdjbab70dnlm3n7lgs64ljlzyk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-fontools))
    (home-page "https://ctan.org/pkg/nimbus15")
    (synopsis "Support files for Nimbus 2015 Core fonts")
    (description
     "The Nimbus 2015 Core fonts added Greek and Cyrillic glyphs.  This
package may be best suited as an add-on to the comprehensive Times package,
providing support for Greek and Cyrillic.  A new intermediate weight of
NimbusMono (AKA Courier) is provided, along with a narrower version which may
be useful for rendering code.")
    (license (list license:agpl3 license:lppl1.3+))))

(define-public texlive-nimsticks
  (package
    (name "texlive-nimsticks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nimsticks/"
                                     "source/latex/nimsticks/"
                                     "tex/latex/nimsticks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y7v01a02lz6mj1fdyrqzgz7kf7y4m3jarkr3sdyid25k0zx9dbj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nimsticks")
    (synopsis "Draws sticks for games of multi-pile nim")
    (description
     "This LaTeX package provides commands @code{\\drawnimstick} to draw
a single nim stick and @code{\\nimgame} which represents games of multi-pile
Nim.  Nim sticks are drawn with a little random wobble so they look thrown
together and not too regular.  The package also provides options to customise
the size and colour of the sticks, and flexibility to draw heaps of different
objects.")
    (license license:expat)))

(define-public texlive-nkarta
  (package
    (name "texlive-nkarta")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/nkarta/"
                                     "fonts/source/public/nkarta/"
                                     "fonts/tfm/public/nkarta/"
                                     "metapost/nkarta/" "source/latex/nkarta/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0x5rdacf3d2jm4rgcvmpz76icga4gis4ykmsmp745xb7kh99npjv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/nkarta")
    (synopsis "New version of the Karta cartographic fonts")
    (description
     "This package provides a development of the Karta font, offering more
mathematical stability in Metafont.  A version that will produce the glyphs as
Encapsulated PostScript is also provided.")
    (license license:public-domain)))

(define-public texlive-nmbib
  (package
    (name "texlive-nmbib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/nmbib/" "doc/latex/nmbib/"
                                     "source/latex/nmbib/" "tex/latex/nmbib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17snspchv0yafz062h59gs9px4dwjk99pwfyxcraw9243k2gd79g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nmbib")
    (synopsis "Multiple versions of a bibliography, with different sort orders")
    (description
     "This package is a rewrite of the @code{multibibliography} package
providing multiple bibliographies with different sorting.  The new version
offers a number of citation commands, streamlines the creation of
bibliographies, ensures compatibility with the @code{natbib} package, and
provides other improvements.")
    (license license:lppl1.3+)))

(define-public texlive-nnext
  (package
    (name "texlive-nnext")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nnext/" "source/latex/nnext/"
                                     "tex/latex/nnext/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hh2kn4ghnxv9l0xfkh0c0bkflmq5qwnc24y0jm1djjwrnyg1y2r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nnext")
    (synopsis "Extension for the @code{gb4e} package")
    (description
     "This is an add-on for the @code{gb4e} package used in linguistics.  It
implements the @code{\\Next}, @code{\\NNext}, @code{\\Last}, and
@code{\\LLast} commands from the @code{linguex} package or the @code{\\nextx},
@code{\\anextx}, @code{\\lastx}, @code{\\blastx}, and @code{\\bblastx}
commands from the @code{expex} package.")
    (license license:lppl1.3+)))

(define-public texlive-notes2bib
  (package
    (name "texlive-notes2bib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/notes2bib/"
                                     "source/latex/notes2bib/"
                                     "tex/latex/notes2bib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d51xy7hlwdl752yl1sfr7f6r77j41nkpj1mf1l7pycn5nlnii79"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/notes2bib")
    (synopsis "Integrating notes into the bibliography")
    (description
     "The package defines a new type of note, @code{bibnote}, which will
always be added to the bibliography.  The package allows footnotes and
endnotes to be moved into the bibliography in the same way.  The package can
be used with @code{natbib} and BibLaTeX as well as plain LaTeX citations.
Both sorted and unsorted bibliography styles are supported.")
    (license license:lppl1.3c)))

(define-public texlive-notex-bst
  (package
    (name "texlive-notex-bst")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/notex-bst/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14r3q4z35k5n0rl2igjs4lj5ic4yd14xksg1qam5klb6raaf1jkh"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/notex-bst")
    (synopsis "BibTeX style that outputs HTML")
    (description
     "@file{noTeX.bst} produces a number of beautifully formatted HTML
@samp{P} elements instead of TeX code.  It can be used to automatically
generate bibliographies to be served on the web starting from BibTeX files.")
    (license license:public-domain)))

(define-public texlive-noto-emoji
  (package
    (name "texlive-noto-emoji")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/noto-emoji/"
                                     "fonts/truetype/google/noto-emoji/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "117mj4w0gvbndhm7mcxbxzxscd73np5s35467jr2sq2pwbv87i8r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/noto-emoji")
    (synopsis "Noto Emoji fonts")
    (description
     "Noto Color Emoji supports all emoji defined in the latest Unicode
version.")
    (license license:silofl1.1)))

(define-public texlive-notomath
  (package
    (name "texlive-notomath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/notomath/"
                                     "fonts/map/dvips/notomath/"
                                     "fonts/tfm/public/notomath/"
                                     "fonts/type1/public/notomath/"
                                     "fonts/vf/public/notomath/"
                                     "tex/latex/notomath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yb7gs2ks0n714n9isbrh4rdrr96b10v58f29907kjixjhf52cd5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/notomath")
    (synopsis "Math support for Noto fonts")
    (description
     "This package provides math support via @code{newtxmath} for NotoSerif
and NotoSans.  (Regular and Bold weights only.)")
    (license (list license:silofl1.1 license:lppl1.3+))))

(define-public texlive-nuc
  (package
    (name "texlive-nuc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nuc/" "tex/latex/nuc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "006c9k3nix0y8nys3sf6r1sjzswhc0kwxhm01q0sk2pzih981w37"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nuc")
    (synopsis "Notation for nuclear isotopes")
    (description
     "This package provides a simple package providing nuclear sub- and
superscripts as commonly used in radiochemistry, radiation science, and
nuclear physics and engineering applications.  Isotopes which have Z with more
digits than A require special spacing to appear properly; this spacing is
supported in the package.")
    (license license:lppl)))

(define-public texlive-njurepo
  (package
    (name "texlive-njurepo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/njurepo/" "source/latex/njurepo/"
                                     "tex/latex/njurepo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03dli7kk1h8kycbj83h2gy434zl6wvj4xz0lli91b1h8k59i8fv4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/njurepo")
    (synopsis "Reports for Nanjing University")
    (description
     "This LaTeX document class provides a thesis template for Nanjing
University in order to make it easy to write experiment reports and homework
for the bachelor's curriculum.")
    (license license:lppl1.3c)))

(define-public texlive-ndsu-thesis
  (package
    (name "texlive-ndsu-thesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ndsu-thesis/"
                                     "tex/latex/ndsu-thesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nwn17993jqiwgjjfi2jqj6m1qq8b1cbgxvq7shqvk48a0zh6y6h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ndsu-thesis")
    (synopsis "North Dakota State University disquisition class")
    (description
     "This package provides a class for generating disquisitions, intended to
be in compliance with North Dakota State University requirements.")
    (license license:lppl1.3+)))

(define-public texlive-ndsu-thesis-2022
  (package
    (name "texlive-ndsu-thesis-2022")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ndsu-thesis-2022/"
                                     "tex/latex/ndsu-thesis-2022/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dpkqwl7w2rqv0k0a3s72incfp9qg04m1ql3mc1hsjnn8f9dysq2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ndsu-thesis-2022")
    (synopsis "North Dakota State University disquisition class 2022")
    (description
     "This package provides a class for generating disquisitions intended to
be in compliance with North Dakota State University requirements.
Updated (2022) North Dakota State University LaTeX thesis class features
several functionalities, including not limited to, numbered and non-numbered
versions, overall justification, document point sizes, fonts options, SI
units, show frames, URL breaking, long tables, subfigures, multi-page figures,
chapter styles, sub-files, algorithm listing, BibTeX and BibLaTeX support,
individual chapter and whole document bibliography, @code{natbib} citations,
and clever references.")
    (license license:lppl1.3c)))

(define-public texlive-nih
  (package
    (name "texlive-nih")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nih/" "tex/latex/nih/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fa4z598i5hvlc4g9zjvqfn34pmmpab37ghi5miklvji5r2a1835"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nih")
    (synopsis "Class for NIH grant applications")
    (description
     "The @code{nih} class offers support for grant applications to @acronym{NIH,
National Institutes of Health}, a US government agency.")
    (license license:lppl)))

(define-public texlive-nihbiosketch
  (package
    (name "texlive-nihbiosketch")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nihbiosketch/"
                                     "tex/latex/nihbiosketch/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15d22va4bxwy6h0dwahpakiqry0pq0j4mpc0rbm10lgm3z7hz25c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nihbiosketch")
    (synopsis "Class for NIH biosketches based on the 2015 updated format")
    (description
     "This LaTeX document class tries to adhere to the Biographical Sketch
formatting requirements outlined in NIH Notice NOT-OD-15-032..  This new
format is required for applications submitted for due dates on or after May
25, 2015.")
    (license license:lppl1.3+)))

(define-public texlive-njustthesis
  (package
    (name "texlive-njustthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/njustthesis/"
                                     "source/latex/njustthesis/"
                                     "tex/latex/njustthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11xbxz3vvq15v5nr32ww6llq08v7r0x52zmq13dp90nmh0xyj7y6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/njustthesis")
    (synopsis
     "Thesis template for the Nanjing University of Science and Technology")
    (description
     "This is a thesis template for the Nanjing University of Science and
Technology.")
    (license license:gpl3+)))

(define-public texlive-njuthesis
  (package
    (name "texlive-njuthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/njuthesis/"
                                     "source/latex/njuthesis/"
                                     "tex/latex/njuthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0s8vf63yhkmyzz3x72cmch4i69q5py0nr9n83rxxjs5rlv3aid9l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/njuthesis")
    (synopsis "LaTeX thesis template for Nanjing University")
    (description
     "The @code{njuthesis} class is intended for typesetting Nanjing
University dissertations with LaTeX, providing support for bachelor, master,
and doctoral theses as well as postdoctoral reports.  Compilation of this
class requires either XeLaTeX or LuaLaTeX.")
    (license license:lppl1.3c)))

(define-public texlive-njuvisual
  (package
    (name "texlive-njuvisual")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/njuvisual/"
                                     "source/latex/njuvisual/"
                                     "tex/latex/njuvisual/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1v5iv44wi0hh77j56jjccgyrh9kyyfvzbl305vqryphq0r73bk36"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/njuvisual")
    (synopsis "Display logos related to Nanjing University")
    (description
     "The njuvisual package collects standard colors and logos related to
Nanjing University, saves the vector logos as TikZ pictures and provides
a user-friendly interface to display them in documents and beamers.")
    (license license:lppl1.3c)))

(define-public texlive-nostarch
  (package
    (name "texlive-nostarch")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/nostarch/" "doc/latex/nostarch/"
                                     "makeindex/nostarch/"
                                     "source/latex/nostarch/"
                                     "tex/latex/nostarch/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18c43p8mygfcjxl1swrn5i9snydxp4s9d0mcb4k5qng6b7saavf1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nostarch")
    (synopsis "LaTeX class for No Starch Press")
    (description
     "The package provides the official LaTeX style for No Starch Press.
Provided are a class, a package for interfacing to @code{hyperref} and an
index style file.  The style serves both for printed and for electronic
books.")
    (license license:lppl)))

(define-public texlive-nrc
  (package
    (name "texlive-nrc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nrc/" "source/latex/nrc/"
                                     "tex/latex/nrc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10h5adzwj8558rwgwipjsbq4j5h674v8nrqfp6hvs3wbn8gdd9hj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nrc")
    (synopsis "Class for the NRC technical journals")
    (description
     "This package provides macros, and some documentation, for typesetting
papers for submission to journals published by the National Research Council
Research Press.  At present, only @file{nrc2.cls} (for two-column layout)
should be used.")
    (license license:lppl)))

(define-public texlive-nucleardata
  (package
    (name "texlive-nucleardata")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nucleardata/"
                                     "source/latex/nucleardata/"
                                     "tex/latex/nucleardata/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sdqgb38yyk3bhjgfxy3gxvfmpc0y9s60hhig5rry7kydm2w5jfc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nucleardata")
    (synopsis "Provides data about atomic nuclides for documents")
    (description
     "The package provides data and commands for including nuclear and atomic
mass and energy data in LaTeX documents.  It uses the PythonTeX package and
requires @command{pythontex} to be called with the TeX file as the argument.")
    (license license:lppl1.3+)))

(define-public texlive-numberpt
  (package
    (name "texlive-numberpt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/numberpt/"
                                     "source/latex/numberpt/"
                                     "tex/latex/numberpt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14515d1l9d9pxs333f8m99mclaf8mklrs14h2w3bdk5m37m7pv8i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/numberpt")
    (synopsis "Counters spelled out in Portuguese")
    (description
     "This package defines commands to display counters spelled out in Portuguese.
Options are offered to select variations in the spelling of @samp{14}, or
Brazilian vs. European Portuguese forms in the spelling of @samp{16},
@samp{17}, and @samp{19}.")
    (license license:lppl1.3c)))

(define-public texlive-numerica
  (package
    (name "texlive-numerica")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/numerica/" "tex/latex/numerica/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wgfc68v9n16kj5qc0x4l134jx5xc6gbara5wrci309gmxrylpj6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/numerica")
    (synopsis "Numerically evaluate mathematical expressions in LaTeX form")
    (description
     "This package defines a command to wrap around a mathematical expression
in its LaTeX form and, once values are assigned to variables, numerically
evaluate it.  The intent is to avoid the need to modify the LaTeX form of the
expression being evaluated.  For programs with a preview facility like LyX, or
compile-as-you-go systems, interactive back-of-envelope calculations and
numerical exploration are possible within the document being worked on.")
    (license license:lppl1.3c)))

(define-public texlive-numerica-plus
  (package
    (name "texlive-numerica-plus")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/numerica-plus/"
                                     "tex/latex/numerica-plus/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "098l5jfkwkkwlja5d0hizn4awd9gfgbr9m3f2cxi062fkjyk7rrv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/numerica-plus")
    (synopsis "Iteration and recurrence relations")
    (description
     "The package defines commands to iterate functions of a single variable,
find fixed points, zeros and extrema of such functions, and calculate the
terms of recurrence relations.")
    (license license:lppl1.3c)))

(define-public texlive-numerica-tables
  (package
    (name "texlive-numerica-tables")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/numerica-tables/"
                                     "tex/latex/numerica-tables/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1q39rlmi1f9xaf627vdqnnhl0b36ppk5hrql64incf3i8vvqziyw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/numerica-tables")
    (synopsis "Create multi-column tables of mathematical functions")
    (description
     "The package defines a command to create possibly multi-column tables of
mathematical function values.")
    (license license:lppl1.3c)))

(define-public texlive-nunito
  (package
    (name "texlive-nunito")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/nunito/"
                                     "fonts/enc/dvips/nunito/"
                                     "fonts/map/dvips/nunito/"
                                     "fonts/opentype/public/nunito/"
                                     "fonts/tfm/public/nunito/"
                                     "fonts/type1/public/nunito/"
                                     "fonts/vf/public/nunito/"
                                     "tex/latex/nunito/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0arx54h5hw50rlikw3sdxgqwhn1sr2jss30103cjip9wff606pa7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nunito")
    (synopsis "The Nunito font face with support for LaTeX and pdfLaTeX")
    (description
     "This package provides LaTeX and pdfLaTeX support for the Nunito family
of fonts, designed by Vernon Adams.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-nwafuthesis
  (package
    (name "texlive-nwafuthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nwafuthesis/"
                                     "source/latex/nwafuthesis/"
                                     "tex/latex/nwafuthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fmq2cf7687bwczwlh0br67smvwnkv7agxrqbcd2bqzijq0r8ks0"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-xetex")))
    (build-system texlive-build-system)
    (arguments
     (list #:tex-format "xetex" #:build-targets #~(list "nwafuthesis.dtx")))
    (native-inputs (list texlive-xetex))
    (home-page "https://ctan.org/pkg/nwafuthesis")
    (synopsis "Thesis template package for Northwest A&F University, China")
    (description
     "This template supports doctoral and master dissertations and
undergraduate theses in Chinese.  It aims to create a simple interface,
a normative format, as well as a hackable class for the users.  At present, it
only supports XeTeX and LuaTeX engines.")
    (license license:lppl1.3c)))

(define-public texlive-nwejm
  (package
    (name "texlive-nwejm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nwejm/" "source/latex/nwejm/"
                                     "tex/latex/nwejm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16lcn84hp3l5ibdiz9wpfdghlva4m9lq2xhppv4rcpixkxnm9g60"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list  #:build-targets #~(list "nwejm.dtx")))
    (home-page "https://ctan.org/pkg/nwejm")
    (synopsis
     "Support for the journal @emph{North-Western European Journal of
Mathematics}")
    (description
     "The bundle includes LaTeX classes and BibLaTeX styles files dedicated to
the new journal @emph{North-Western European Journal of Mathematics}:
@code{nwejm} for the complete issues of the journal, aimed at the NWEJM's
team, @code{nwejmart}, intended for the authors who wish to publish an article
in the NWEJM.")
    (license license:lppl1.3c)))

(define-public texlive-objectz
  (package
    (name "texlive-objectz")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/objectz/" "source/latex/objectz/"
                                     "tex/latex/objectz/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a10ajlpmx6gfg4h9rvwf0q7zkb843pl5xfcsd9pzfg33245wbrz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/objectz")
    (synopsis "Macros for typesetting Object Z")
    (description
     "The package will typeset both Z and Object-Z specifications.")
    (license license:lppl)))

(define-public texlive-obnov
  (package
    (name "texlive-obnov")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/obnov/"
                                     "fonts/source/public/obnov/"
                                     "fonts/tfm/public/obnov/" "tex/latex/obnov/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hjc381fw38qr7rkj137d5rp2jjv002g29bx5g3jjaxl9civvplq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/obnov")
    (synopsis "Obyknovennaya Novaya fonts")
    (description
     "The Obyknovennaya Novaya (Ordinary New Face) typeface was widely used in
the USSR for scientific and technical publications, as well as textbooks.  The
fonts are encoded to KOI8-R (which is a long-established Russian font
encoding, rather than a TeX/LaTeX encoding).  To use the fonts, the user needs
Cyrillic font support.")
    (license license:lppl)))

(define-public texlive-ocherokee
  (package
    (name "texlive-ocherokee")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/omega/ocherokee/"
                                     "fonts/afm/public/ocherokee/"
                                     "fonts/map/dvips/ocherokee/"
                                     "fonts/ofm/public/ocherokee/"
                                     "fonts/ovf/public/ocherokee/"
                                     "fonts/ovp/public/ocherokee/"
                                     "fonts/tfm/public/ocherokee/"
                                     "fonts/type1/public/ocherokee/"
                                     "omega/ocp/ocherokee/"
                                     "omega/otp/ocherokee/"
                                     "tex/lambda/ocherokee/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1j2giz3rjr8hdzca5hny31zklnl721mhsgxm575fhh82qrpvdx26"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ocherokee")
    (synopsis "LaTeX Support for the Cherokee language")
    (description
     "This package provides macros and Type 1 fonts for Typesetting the
Cherokee language with the Omega version of LaTeX (known as Lambda).")
    (license license:lppl)))

(define-public texlive-octave
  (package
    (name "texlive-octave")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/octave/" "tex/latex/octave/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1avikh00n92lxk7p7h0kvsv2dk2z411fv85fagj7bg6azb3fch8g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/octave")
    (synopsis "Typeset musical pitches with octave designations")
    (description
     "This package package typesets musical pitch names with designation for
the octave in either the Helmholtz system (with octave numbers), or the
traditional system (with prime symbols).  The system can also be changed
mid-document.")
    (license license:lppl1.3+)))

(define-public texlive-ocr-b
  (package
    (name "texlive-ocr-b")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/ocr-b/"
                                     "fonts/source/public/ocr-b/"
                                     "fonts/tfm/public/ocr-b/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "089y4hihxdln1rvn87lmmiamcy8xc0niiv4gqxivahwkdjl8w0zw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/ocr-b")
    (synopsis "Fonts for OCR-B")
    (description
     "This package includes Metafont source for OCR-B at several sizes.")
    ;; "you may freely use, modify, and/or distribute any of these files or
    ;; the resulting fonts, without limitation."
    (license (license:fsf-free "file://doc/fonts/ocr-b-outline/README"))))

(define-public texlive-ocr-b-outline
  (package
    (name "texlive-ocr-b-outline")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/ocr-b-outline/"
                                     "fonts/map/dvips/ocr-b-outline/"
                                     "fonts/opentype/public/ocr-b-outline/"
                                     "fonts/type1/public/ocr-b-outline/"
                                     "source/fonts/ocr-b-outline/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wlgwz91iv3ck8qmwgqda1kmijs3076hccfvbk6v7dkrcy726014"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ocr-b-outline")
    (synopsis "OCR-B fonts in Type 1 and OpenType")
    (description
     "The package contains OCR-B fonts in Type1 and OpenType formats.")
    ;; "You may freely use, modify, and/or distribute any of these files,
    ;; without limitation."
    (license (license:fsf-free "file://doc/fonts/ocr-b-outline/README"))))

(define-public texlive-ogham
  (package
    (name "texlive-ogham")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/ogham/"
                                     "fonts/source/public/ogham/"
                                     "fonts/tfm/public/ogham/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lk419jbg3ahgcrmffl7snbgv521fccjpsx5i0nq55cs9vrsnav1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/ogham")
    (synopsis "Fonts for typesetting Ogham script")
    (description
     "The font provides the Ogham alphabet, which is found on a number of
Irish and Pictish carvings dating from the 4th century AD.  The font is
distributed as Metafont source.")
    (license license:public-domain)))

(define-public texlive-oinuit
  (package
    (name "texlive-oinuit")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/oinuit/"
                                     "fonts/map/dvips/oinuit/"
                                     "fonts/ofm/public/oinuit/"
                                     "fonts/ovf/public/oinuit/"
                                     "fonts/tfm/public/oinuit/"
                                     "fonts/type1/public/oinuit/"
                                     "omega/ocp/oinuit/"
                                     "omega/otp/oinuit/"
                                     "source/lambda/oinuit/"
                                     "tex/lambda/oinuit/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1f5rlqgdz4r93z5prxjq7z7591frqz89gplj3y0dscjnlc98wxy4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/oinuit")
    (synopsis "LaTeX Support for the Inuktitut Language")
    (description
     "The package provides a set of Lambda (Omega LaTeX) typesetting tools for
the Inuktitut language.  Five different input methods are supported and with
the necessary fonts are also provided.")
    (license license:lppl)))

(define-public texlive-old-arrows
  (package
    (name "texlive-old-arrows")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/old-arrows/"
                                     "fonts/afm/public/old-arrows/"
                                     "fonts/enc/dvips/old-arrows/"
                                     "fonts/map/dvips/old-arrows/"
                                     "fonts/tfm/public/old-arrows/"
                                     "fonts/type1/public/old-arrows/"
                                     "tex/latex/old-arrows/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lrw3r982646pdp5nf9y9s8w85c2zw7cvbq3lqa3d3lsnykvn3y7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/old-arrows")
    (synopsis "Computer Modern old-style arrows with smaller arrowheads")
    (description
     "This package provides Computer Modern old-style arrows with smaller
arrowheads, associated with the usual LaTeX commands.  It can be used in
documents that contain other amssymb arrow characters that also have small
arrowheads.  It is also possible to use the usual new-style Computer Modern
arrows together with the old-style ones.")
    (license license:lppl1.3+)))

(define-public texlive-oldlatin
  (package
    (name "texlive-oldlatin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/oldlatin/"
                                     "fonts/source/public/oldlatin/"
                                     "fonts/tfm/public/oldlatin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fvy8myxxa3a5g2s8b5m57a9ijg1qanwcrf701s9lix5yxaqn474"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/oldlatin")
    (synopsis "Compute Modern-like font with long @emph{s}")
    (description
     "This package provides Metafont sources modified from Computer Modern in
order to generate long @emph{s}, which was used in old text.")
    (license license:lppl)))

(define-public texlive-oldstandard
  (package
    (name "texlive-oldstandard")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/oldstandard/"
                                     "fonts/enc/dvips/oldstandard/"
                                     "fonts/map/dvips/oldstandard/"
                                     "fonts/opentype/public/oldstandard/"
                                     "fonts/tfm/public/oldstandard/"
                                     "fonts/type1/public/oldstandard/"
                                     "fonts/vf/public/oldstandard/"
                                     "tex/latex/oldstandard/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1siw4zjyx40whsi7gsd05nhbhii2mf91vn837srhai2v7nll4fa8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/oldstandard")
    (synopsis "OldStandard fonts with LaTeX support")
    (description
     "Old Standard is designed to reproduce the actual printing style of the
early 20th century, reviving a specific type of Modern (classicist) style of
serif typefaces, very commonly used in various editions of the late 19th and
early 20th century.

The font supports typesetting of Old and Middle English, Old Icelandic,
Cyrillic (with historical characters, extensions for Old Slavonic and
localised forms), Gothic transliterations, critical editions of Classical
Greek and Latin, and many more.")
    (license (list license:silofl1.1 license:lppl license:gpl3+))))

(define-public texlive-omega
  (package
    (name "texlive-omega")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/omega/base/"
                                     "dvips/omega/"
                                     "fonts/afm/public/omega/"
                                     "fonts/map/dvips/omega/"
                                     "fonts/ofm/public/omega/"
                                     "fonts/ovf/public/omega/"
                                     "fonts/ovp/public/omega/"
                                     "fonts/tfm/public/omega/"
                                     "fonts/type1/public/omega/"
                                     "omega/ocp/char2uni/"
                                     "omega/ocp/misc/"
                                     "omega/ocp/omega/"
                                     "omega/ocp/uni2char/"
                                     "omega/otp/char2uni/"
                                     "omega/otp/misc/"
                                     "omega/otp/omega/"
                                     "omega/otp/uni2char/"
                                     "tex/generic/encodings/"
                                     "tex/generic/omegahyph/"
                                     "tex/plain/omega/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gma5angnq5wdxianz0ml7y9jh04lsq9ksspykan06p0cp1bnmjc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/omega")
    (synopsis "Wide-character-set extension of TeX")
    (description
     "This package provides a development of TeX, which deals in multi-octet
Unicode characters, to enable native treatment of a wide range of languages
without changing character-set.  Work on Omega has ceased; its compatible
successor is Aleph, which is itself also in major maintenance mode only.
Ongoing projects developing Omega (and Aleph) ideas include Omega-2 and
LuaTeX.")
    (license license:gpl3+)))

(define-public texlive-omegaware
  (package
    (name "texlive-omegaware")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/odvicopy.1"
                                     "doc/man/man1/odvicopy.man1.pdf"
                                     "doc/man/man1/odvitype.1"
                                     "doc/man/man1/odvitype.man1.pdf"
                                     "doc/man/man1/ofm2opl.1"
                                     "doc/man/man1/ofm2opl.man1.pdf"
                                     "doc/man/man1/opl2ofm.1"
                                     "doc/man/man1/opl2ofm.man1.pdf"
                                     "doc/man/man1/otangle.1"
                                     "doc/man/man1/otangle.man1.pdf"
                                     "doc/man/man1/otp2ocp.1"
                                     "doc/man/man1/otp2ocp.man1.pdf"
                                     "doc/man/man1/outocp.1"
                                     "doc/man/man1/outocp.man1.pdf"
                                     "doc/man/man1/ovf2ovp.1"
                                     "doc/man/man1/ovf2ovp.man1.pdf"
                                     "doc/man/man1/ovp2ovf.1"
                                     "doc/man/man1/ovp2ovf.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04fchy1n6ppi2l2c99mz1x64m8zl741d0z8fkjxapqn266z4bc7k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-omegaware-bin))
    (home-page "https://ctan.org/pkg/omega")
    (synopsis "Wide-character-set extension of TeX")
    (description
     "This package provides a development of TeX, which deals in multi-octet
Unicode characters, to enable native treatment of a wide range of languages
without changing character-set.  Work on Omega has ceased (the TeX Live
package contains only support files); its compatible successor is Aleph, which
is itself also in major maintenance mode only.  Ongoing projects developing
Omega (and Aleph) ideas include Omega-2 and LuaTeX.")
    (license license:gpl3+)))

(define-public texlive-omegaware-bin
  (package
    (inherit texlive-bin)
    (name "texlive-omegaware-bin")
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(delete "--enable-web2c" #$flags))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'install
              (lambda _
                (let ((bin (string-append #$output "/bin")))
                  (with-directory-excursion "texk/web2c"
                    (let ((files '("odvicopy" "odvitype""otangle" "wofm2opl"
                                   "wopl2ofm" "wovf2ovp")))
                      (for-each (lambda (t) (invoke "make" t)) files)
                      (for-each (lambda (f) (install-file f bin)) files))
                    (with-directory-excursion "omegafonts"
                      (invoke "make" "omfonts")
                      (install-file "omfonts" bin))
                    (with-directory-excursion "otps"
                      (for-each (lambda (t)
                                  (invoke "make" t)
                                  (install-file t bin))
                                '("otp2ocp" "outocp"))))
                  (with-directory-excursion bin
                    (for-each (lambda (l) (symlink "omfonts" l))
                              '("ofm2opl" "opl2ofm" "ovf2ovp" "ovp2ovf"))))))))))
    (native-inputs (list pkg-config))
    (home-page (package-home-page texlive-omegaware))
    (synopsis "Binaries for @code{texlive-omegaware}")
    (description
     "This package provides the binaries for @code{texlive-omegaware}.")
    (license (package-license texlive-omegaware))))

(define-public texlive-onrannual
  (package
    (name "texlive-onrannual")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/onrannual/"
                                     "tex/latex/onrannual/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m701gqf0my947jh4lsgwryn3h9m6w4b6rimm8wmzsxlvnag9ag7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/onrannual")
    (synopsis
     "Class for Office of Naval Research Ocean Battlespace Sensing annual
report")
    (description
     "This is an unofficial document class for writing @acronym{ONR, Office of
Naval Research} annual reports using LaTeX; as ONR has had numerous problems
with LaTeX-generated PDF submissions in the past.")
    (license license:lppl1.3+)))

(define-public texlive-opensans
  (package
    (name "texlive-opensans")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/opensans/"
                                     "fonts/enc/dvips/opensans/"
                                     "fonts/map/dvips/opensans/"
                                     "fonts/tfm/ascender/opensans/"
                                     "fonts/truetype/ascender/opensans/"
                                     "fonts/type1/ascender/opensans/"
                                     "fonts/vf/ascender/opensans/"
                                     "tex/latex/opensans/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1l81y548cslwsy7m06pckf5w33gq53ly3a35zkd9jzfz6yg6w4bq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/opensans")
    (synopsis "Open Sans font family, and LaTeX support")
    (description
     "Open Sans is a humanist sans serif typeface designed by Steve Matteson.
The package provides support for this font family in LaTeX. It includes the
original TrueType fonts, as well as Type 1 versions.")
    (license (list license:asl2.0 license:lppl1.3c))))

(define-public texlive-oplotsymbl
  (package
    (name "texlive-oplotsymbl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/oplotsymbl/"
                                     "tex/latex/oplotsymbl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kbkxy18yq7990rbbm8b8ky9dyvxknzhczkfa9ki93jap8hwac2r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/oplotsymbl")
    (synopsis "Some symbols which are not easily available")
    (description
     "This package is named oPlotSymbl and it includes symbols, which are not
easily available.  Especially, these symbols are used in scientific plots, but
the potential user is allowed to use them in other ways.")
    (license license:lppl1.3+)))

(define-public texlive-opteng
  (package
    (name "texlive-opteng")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/opteng/" "tex/latex/opteng/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1svis9n0ssrc6pnvlshwprfjimdfrbisb0jjnlhhys343dv95jqs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/opteng")
    (synopsis "SPIE Optical Engineering and OE Letters manuscript template")
    (description
     "With this template, and associated style and LaTeX packages, it is
possible to estimate the page length of manuscripts for submission to the SPIE
journals @emph{Optical Engineering} and @emph{Optical Engineering Letters}.
With a strict three-page limit, this is particularly important for the latter.
The template gives simple instructions on how to prepare the manuscript.")
    (license license:lppl)))

(define-public texlive-ordinalpt
  (package
    (name "texlive-ordinalpt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ordinalpt/"
                                     "source/latex/ordinalpt/"
                                     "tex/latex/ordinalpt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02hsl021gd23qrfm3myazg606lmp149dmpss3vyx93dyqcg8axbr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ordinalpt")
    (synopsis "Counters as ordinal numbers in Portuguese")
    (description
     "The package provides a counter style (like @code{\\arabic},
@code{\\alph} and others) which produces output strings like
@samp{primeiro} (``first'' in Portuguese), @samp{segundo}, (``second''), and
so on up to 1999th.  Separate counter commands are provided for different
letter case variants, and for masculine and feminine gender inflections.")
    (license license:lppl)))

(define-public texlive-orkhun
  (package
    (name "texlive-orkhun")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/orkhun/"
                                     "fonts/source/public/orkhun/"
                                     "fonts/tfm/public/orkhun/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18p78sprnig93iq74y1vb1ai3ixqqj1pssrqczr1fiy0rnxsjdig"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/orkhun")
    (synopsis "Font for Orkhun script")
    (description
     "The Orkhun font covers an old Turkic script.  It is provided as Metafont
source.")
    (license license:lppl)))

(define-public texlive-oscola
  (package
    (name "texlive-oscola")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/oscola/" "makeindex/oscola/"
                                     "tex/latex/oscola/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lx883rqq9p3f0vfv6i5xp35qpi79jf1jxycyi5j86i1fvk0jz08"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/oscola")
    (synopsis
     "BibLaTeX style for the Oxford Standard for the Citation of Legal
Authorities")
    (description
     "The package provides a set of style files for use with BibLaTeX and
Biber to produce citations and bibliographies in accordance with the
widely-used Oxford Standard for the Citation of Legal Authorities.  It also
includes facilities for constructing tables of cases and legislation from
citations (in conjunction with appropriate indexing packages).")
    (license license:lppl1.3+)))

(define-public texlive-oswald
  (package
    (name "texlive-oswald")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/oswald/"
                                     "fonts/enc/dvips/oswald/"
                                     "fonts/map/dvips/oswald/"
                                     "fonts/tfm/public/oswald/"
                                     "fonts/type1/public/oswald/"
                                     "fonts/vf/public/oswald/"
                                     "tex/latex/oswald/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ib7k3vgzmsjaxhfb3zcpy3m0yx8p5yyc2hr8x7b8ik7n1ik5sgm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/oswald")
    (synopsis "Oswald family of fonts with support for LaTeX and pdfLaTeX")
    (description
     "This package provides the Oswald family of fonts, designed by Vernon Adams,
Kalapi Gajjar, Cyreal, with support for LaTeX and pdfLaTeX.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-ot-tableau
  (package
    (name "texlive-ot-tableau")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ot-tableau/"
                                     "tex/latex/ot-tableau/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nbadc2c3973y7b28ddklpmhmms8f1nxc48ln5fxv68jmsmd4wb2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ot-tableau")
    (synopsis "Optimality Theory tableaux in LaTeX")
    (description
     "The package makes it easy to create beautiful optimality-theoretic tableaux.
The LaTeX source is visually very similar to a formatted tableau, which makes
working with the source code painless (well, less painful).  A variety of
stylistic variants are available to suit personal taste.")
    (license license:lppl1.3+)))

(define-public texlive-othello
  (package
    (name "texlive-othello")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/othello/"
                                     "fonts/source/public/othello/"
                                     "fonts/tfm/public/othello/"
                                     "tex/latex/othello/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ijb2giry6bjvx6ll51n9c8fqy1kmwgrwvrg21mxnj9xc4gkdjrh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/othello")
    (synopsis "Create othello boards")
    (description
     "This package can be used to create othello boards.  It includes also
fonts, as Metafont source.")
    (license license:gpl3+)))

(define-public texlive-othelloboard
  (package
    (name "texlive-othelloboard")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/othelloboard/"
                                     "tex/latex/othelloboard/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kaj01bn4828261n8s761qcv7hg6a5aqi577rqglbkjg9grdh1s6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/othelloboard")
    (synopsis
     "Typeset othello (Reversi) diagrams of any size, with annotations")
    (description
     "The package enables the user to generate high-quality othello (also
known as Reversi) board diagrams of any size.  The diagrams support
annotations, including full game transcripts.  Automated board or transcript
creation, from plain text formats standard to WZebra (and other programs) is
also supported.")
    (license license:lppl1.3+)))

(define-public texlive-otibet
  (package
    (name "texlive-otibet")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/otibet/"
                                     "fonts/ofm/public/otibet/"
                                     "fonts/ovf/public/otibet/"
                                     "fonts/ovp/public/otibet/"
                                     "fonts/source/public/otibet/"
                                     "fonts/tfm/public/otibet/"
                                     "omega/ocp/otibet/"
                                     "omega/otp/otibet/"
                                     "source/latex/otibet/"
                                     "tex/latex/otibet/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cman22brlm8qklb60mzq8f6c9kmdspv3zfg4s5p0lj9sf03bb6c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/otibet")
    (synopsis "Support for Tibetan using Omega")
    (description "This package provides support for Tibetan using Omega.")
    ;; Per "unidoc.tex": "this package is freely distributable under the GPL
    ;; Version~?.? or any later one."
    (license license:gpl1+)))

(define-public texlive-oubraces
  (package
    (name "texlive-oubraces")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/oubraces/" "tex/latex/oubraces/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kh2acj4420cxd5x5y3dnfkdfqp5m70d16kiwz5b0f095af42v1g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/oubraces")
    (synopsis "Braces over and under a formula")
    (description
     "This package provides a means to interleave @code{\\overbrace} and
@code{\\underbrace} in the same formula.")
    ;; Library states: "Redistribution and use, with or without modification,
    ;; are permitted provided that the above copyright notice and this
    ;; condition for use are retained".
    (license (license:fsf-free "file://tex/latex/oubraces/oubraces.sty"))))

(define-public texlive-oup-authoring-template
  (package
    (name "texlive-oup-authoring-template")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/oup-authoring-template/"
                                     "tex/latex/oup-authoring-template/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fbkrka650pv2k5n0fcdcgmzlfpj2kzlg9d72d145b24zza79qh0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/oup-authoring-template")
    (synopsis
     "General template for journals published by Oxford University
Press (OUP)")
    (description
     "This package provides a general LaTeX template for journals published by
@acronym{OUP, Oxford University Press}.  The template outputs to the three
official page designs (traditional, contemporary, modern) used by many
journals published by OUP, with large, medium and small page options.")
    (license license:lppl1.2+)))

(define-public texlive-overarrows
  (package
    (name "texlive-overarrows")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/overarrows/"
                                     "source/latex/overarrows/"
                                     "tex/latex/overarrows/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zr1qq6g3zfabz4x37bc2ajlbrkdlskk99144kqwkvmrwr9nxpww"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/overarrows")
    (synopsis "Custom extensible arrows over math expressions")
    (description
     "This package provides a LaTeX package to create custom arrows over math
expressions, mainly for vectors (but arrows can as well be drawn below).
Arrows stretch with content, scale with math styles, and have a correct
kerning when a subscript follows.  Some predefined commands are also
provided.")
    (license license:lppl1.3c)))

(define-public texlive-overlock
  (package
    (name "texlive-overlock")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/overlock/"
                                     "fonts/enc/dvips/overlock/"
                                     "fonts/map/dvips/overlock/"
                                     "fonts/opentype/tipo/overlock/"
                                     "fonts/tfm/tipo/overlock/"
                                     "fonts/type1/tipo/overlock/"
                                     "fonts/vf/tipo/overlock/"
                                     "tex/latex/overlock/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rpqpd5ja32i44lf8szr2hn0dz5dh2p238iid0dnkpylf006wni2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/overlock")
    (synopsis "Overlock sans fonts with LaTeX support")
    (description
     "The package provides the Overlock and OverlockSC families of fonts,
designed by Dario Manuel Muhafara, rounded sans-serif fonts in three
weights (Regular, Bold, Black) with italic variants for each of them.  There
are also small-caps and old-style figures in the Regular weight.")
    (license license:silofl1.1)))

(define-public texlive-pacioli
  (package
    (name "texlive-pacioli")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/pacioli/"
                                     "fonts/source/public/pacioli/"
                                     "fonts/tfm/public/pacioli/"
                                     "source/fonts/pacioli/" "tex/latex/pacioli/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "100fs89b2nfybnjdg8b4v3z8q982b6x0azn0sc31533pkkkp19i3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/pacioli")
    (synopsis "Fonts designed by Fra Luca de Pacioli in 1497")
    (description
     "Pacioli was a 15th century mathematician, and his font was designed
according to the divine proportion.  The font consists of uppercase letters
together with punctuation and some analphabetics; no lowercase or digits.  The
package provides Metafont source for the font together with LaTeX support.")
    (license license:lppl)))

(define-public texlive-padauk
  (package
    (name "texlive-padauk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/padauk/"
                                     "fonts/truetype/public/padauk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yn5w8bkcf9ihqy4v2zq4yc74d2d3dc1c6dcissaa6pcdj4z9r9l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/padauk")
    (synopsis
     "High-quality TrueType font for languages using the Myanmar script")
    (description
     "Padauk is a Unicode-based font family with broad support for writing
systems that use the Myanmar script.")
    (license license:silofl1.1)))

(define-public texlive-pagella-otf
  (package
    (name "texlive-pagella-otf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/pagella-otf/"
                                     "tex/latex/pagella-otf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yi5d5wffqcrlslk9gxifnx4imhpi1hqya6x7k1qq9znvlf97inl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pagella-otf")
    (synopsis "Using the OpenType fonts TeX Gyre Pagella")
    (description
     "This package can only be used with LuaLaTeX or XeLaTeX.  It does the
font setting for the OpenType font TeX Gyre Pagella for text and math.  The
missing typefaces like bold math and slanted text are also defined.")
    (license license:lppl1.3+)))

(define-public texlive-parallel
  (package
    (name "texlive-parallel")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/parallel/"
                                     "source/latex/parallel/"
                                     "tex/latex/parallel/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14gca28ph90vhsliy5g8jc6fd87igni1wkiy41jrp33qhjiz94qa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/parallel")
    (synopsis "Typeset parallel texts")
    (description
     "This package provides a @code{parallel} environment which allows two
potentially different texts to be typeset in two columns, while maintaining
alignment.  The two columns may be on the same page, or on facing pages.  This
arrangement of text is commonly used when typesetting translations, but it can
have value when comparing any two texts.")
    (license license:lppl)))

(define-public texlive-paratype
  (package
    (name "texlive-paratype")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/paratype/"
                                     "fonts/afm/paratype/ptmono/"
                                     "fonts/afm/paratype/ptsans/"
                                     "fonts/afm/paratype/ptserif/"
                                     "fonts/enc/dvips/paratype/"
                                     "fonts/map/dvips/paratype/"
                                     "fonts/tfm/paratype/ptmono/"
                                     "fonts/tfm/paratype/ptsans/"
                                     "fonts/tfm/paratype/ptserif/"
                                     "fonts/truetype/paratype/ptmono/"
                                     "fonts/truetype/paratype/ptsans/"
                                     "fonts/truetype/paratype/ptserif/"
                                     "fonts/type1/paratype/ptmono/"
                                     "fonts/type1/paratype/ptsans/"
                                     "fonts/type1/paratype/ptserif/"
                                     "fonts/vf/paratype/ptmono/"
                                     "fonts/vf/paratype/ptsans/"
                                     "fonts/vf/paratype/ptserif/"
                                     "tex/latex/paratype/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k93y4xlng9b9cwa9mk7bdxj2zzbyigv02z358lm0vpr7nw8vxig"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/paratype")
    (synopsis "LaTeX support for ParaType fonts")
    (description
     "The package offers LaTeX support for the fonts PT Sans, PT Serif and PT
Mono developed by ParaType for the project @emph{Public Types of Russian
Federation}.  The fonts themselves are provided in both the TrueType and Type
1 formats.  The fonts provide encodings OT1, T1, IL2, TS1, T2* and X2.  The
package provides a convenient replacement of the two packages @code{ptsans}
and @code{ptserif}.")
    (license license:lppl)))

(define-public texlive-parrun
  (package
    (name "texlive-parrun")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/parrun/" "source/latex/parrun/"
                                     "tex/latex/parrun/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cfqvsda505pxwyjv6k197lg464y4njr2j65sghvzk7qp3i6vq11"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/parrun")
    (synopsis "Typesets (two) streams of text running parallel")
    (description
     "This package can be used for typesetting translated text and the
original source, parallel on the same page, one above the other.")
    (license license:lppl)))

(define-public texlive-pas-crosswords
  (package
    (name "texlive-pas-crosswords")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pas-crosswords/"
                                     "tex/latex/pas-crosswords/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1masrs2ywyxa9rfw7vz9j9jw0b1hhkd5fin2rg7rd2x1qb305q5w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pas-crosswords")
    (synopsis "Creating crossword grids, using TikZ")
    (description
     "The package produces crossword grids, using a wide variety of colours
and decorations of the grids and the text in them.  The package uses TikZ for
its graphical output.")
    (license license:lppl)))

(define-public texlive-pascaltriangle
  (package
    (name "texlive-pascaltriangle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pascaltriangle/"
                                     "tex/latex/pascaltriangle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g5y02gcgwhdq168n7d33plfhfp83zq97vjrfyz8ldlc7vncdnlh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pascaltriangle")
    (synopsis "Draw beautiful Pascal (Yanghui) triangles")
    (description
     "This LaTeX3 package based on TikZ helps to generate beautiful
Pascal (Yanghui) triangles.  It provides a unique drawing macro
@code{\\pascal} which can generate isosceles or right-angle triangles
customized by means of different @code{\\pascal} macro options or the
@code{\\pascalset} macro.")
    (license license:lppl1.3c)))

(define-public texlive-patgen2-tutorial
  (package
    (name "texlive-patgen2-tutorial")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/patgen2-tutorial/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "016bx1rp8kpvlywg0yafhbbhlzw4zxdcbdrd5525vffn6fyp9fi3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/patgen2-tutorial")
    (synopsis "Tutorial on the use of Patgen 2")
    (description
     "This document describes the use of Patgen 2 to create hyphenation
patterns for wide ranges of languages.")
    (license license:lppl1.3c)))

(define-public texlive-perception
  (package
    (name "texlive-perception")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/perception/"
                                     "doc/bibtex/perception/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0958g65hv8fpyhhbkvkd2ybdbp6aiblnc5izbr5z5w8b0v5n0ixx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/perception")
    (synopsis "BibTeX style for the journal @emph{Perception}")
    (description
     "This package provides a BibTeX style for the journal
@emph{Perception}.")
    (license license:lppl)))

(define-public texlive-perfectcut
  (package
    (name "texlive-perfectcut")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/perfectcut/"
                                     "tex/latex/perfectcut/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13lclcf5aynbivhlsgnssi36dgacmyjl3rmr0i8s3az5941bsyfh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/perfectcut")
    (synopsis
     "Nested delimiters that consistently grow regardless of the contents")
    (description
     "This package defines the command @code{\\perfectcut#1#2} which displays
a bracket @samp{<#1||#2>}.  Various other delimiters are similarly
defined (parentheses, square brackets ...).  The effect of these commands is
to let the delimiters grow according to the number of nested
@code{\\perfectcommands} (regardless of the size of the contents).

The package was originally intended for solving a notational issue for
direct-style continuation calculi in proof theory.  For general use, the
package also defines commands for defining other sorts of delimiters which
will behave in the same way.  The package also offers a robust
reimplementation of @code{\\big}, @code{\\bigg}, etc.")
    (license license:lppl1.3+)))

(define-public texlive-persian-bib
  (package
    (name "texlive-persian-bib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/persian-bib/"
                                     "bibtex/csf/persian-bib/"
                                     "doc/xelatex/persian-bib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18x592g8y1i8kw724an65q84jj91cam5qvwp9mgnhqpwh3gjflpw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/persian-bib")
    (synopsis "Persian translations of classic BibTeX styles")
    (description
     "This package provides BibTeX styles modified for Persian documents
prepared with XePersian (which the present package depends on).  The Persian
@file{.bst} files can simultaneously handle both Latin and Persian references.
A file @file{p1256fa.csf} is provided for correct sorting of Persian
references and three fields LANGUAGE, TRANSLATOR and AUTHORFA are defined.")
    (license license:lppl1.3+)))

(define-public texlive-pfdicons
  (package
    (name "texlive-pfdicons")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pfdicons/" "tex/latex/pfdicons/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16xdy0ah7za1gr63w1pdfvbq8x4fkin7q0yfpml7y4wv7m1qxqgc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pfdicons")
    (synopsis "Draw process flow diagrams in chemical engineering")
    (description
     "This package provides TikZ shapes to represent commonly encountered unit
operations for depiction in process flow diagrams (PFDs) and, to a lesser
extent, process and instrumentation diagrams (PIDs).  The package was designed
with undergraduate chemical engineering students and faculty in mind, and the
number of units provided should cover--in Turton's estimate--about 90 percent
of all fluid processing operations.")
    (license license:lppl1.3c)))

(define-public texlive-phaistos
  (package
    (name "texlive-phaistos")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/phaistos/"
                                     "fonts/afm/public/phaistos/"
                                     "fonts/map/dvips/phaistos/"
                                     "fonts/opentype/public/phaistos/"
                                     "fonts/tfm/public/phaistos/"
                                     "fonts/type1/public/phaistos/"
                                     "source/fonts/phaistos/"
                                     "tex/latex/phaistos/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b5mjfzmhr6dw6i90mjym2hwi4cm2jfwfagl41dm6grnznwcn8bb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/phaistos")
    (synopsis "Disk of Phaistos font")
    (description
     "This package provides a font that contains all the symbols of the famous
Disc of Phaistos, together with a LaTeX package.  The disc was printed by
stamping the wet clay with some sort of punches, probably around 1700 BCE.
The font is available in Adobe Type 1 and OpenType formats (the latter using
the Unicode positions for the symbols).")
    (license license:lppl)))

(define-public texlive-philosophersimprint
  (package
    (name "texlive-philosophersimprint")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/philosophersimprint/"
                                     "source/latex/philosophersimprint/"
                                     "tex/latex/philosophersimprint/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12rflr3w8lxk9yg1fx3kpyz52002571lh4g3m6hcp73mb393fq1w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/philosophersimprint")
    (synopsis "Typesetting articles for @emph{Philosophers' Imprint}")
    (description
     "The @emph{Philosophers' Imprint} is a series of original papers in
philosophy, edited by philosophy faculty at the University of Michigan, and
published on the World Wide Web by the University of Michigan Digital Library.
The class helps authors to typeset their own articles in Web-ready format.")
    (license license:lppl1.3+)))

(define-public texlive-phonetic
  (package
    (name "texlive-phonetic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/phonetic/"
                                     "fonts/source/public/phonetic/"
                                     "fonts/tfm/public/phonetic/"
                                     "tex/latex/phonetic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0f1z1kzfyxap4hbmpjfhy417n3jcg3rv0m8f5ab1wlil64jn0rgb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/phonetic")
    (synopsis "Metafont Phonetic fonts, based on Computer Modern")
    (description
     "The Phonetic fonts are based on Computer Modern, and specified in
Metafont.  Macros for the fonts use are provided for LaTeX.")
    (license license:lppl)))

(define-public texlive-physconst
  (package
    (name "texlive-physconst")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/physconst/"
                                     "source/latex/physconst/"
                                     "tex/latex/physconst/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jrhsycm9fp4crhy4g9i4hn7wll85fczwmvxvlzgkzi249zcssm9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/physconst")
    (synopsis "Macros for commonly used physical constants")
    (description
     "This package consists of several macros that are shorthand for a variety
of physical constants, e.g. the speed of light.  The constants can be used in
two forms, the most accurate available values, or versions that are rounded to
3 significant digits for use in typical classroom settings, homework
assignments, etc.  Most constants are taken from CODATA 2018, with the
exception of the astronomical objects, whose values are taken from
International Astronomical Union specified values.  Constants that are derived
from true constants, e.g. the fine structure constant, have been calculated
using the accepted values of the fundamental constants.")
    (license license:lppl1.3c)))

(define-public texlive-phonrule
  (package
    (name "texlive-phonrule")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/phonrule/" "tex/latex/phonrule/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09nhlhqgq2af2p6rn5r0q8ccn9a2qq35znn5j4z2kjq744wbzjih"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/phonrule")
    (synopsis "Typeset linear phonological rules")
    (description
     "The package provides macros for typesetting phonological rules like
those in @emph{Sound Pattern of English} (Chomsky and Halle 1968).")
    (license license:lppl1.0+)))

(define-public texlive-physics2
  (package
    (name "texlive-physics2")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/physics2/"
                                     "source/latex/physics2/"
                                     "tex/latex/physics2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m4wv8kcmy3jrhsnfl5dx4aqzgrq51w8h32l3k378lfg5zdh0axa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/physics2")
    (synopsis "Macros for typesetting math faster and more simply")
    (description
     "The @code{physics2} package defines commands for typesetting math
formulae faster andmore simply.  @code{physics2} is a modularized package,
each module provides its own function.  You can load modules separately after
loading @code{physics2}.

Modules of physics provide the following supports:
@itemize
@item automatic braces,
@item Dirac bracket notation,
@item easy way to typeset diagonal matrices and matrices with similar entries,
@item double cross and double dot (binary) operators for tensors.
@end itemize")
    (license license:lppl1.3c)))

(define-public texlive-physunits
  (package
    (name "texlive-physunits")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/physunits/"
                                     "source/latex/physunits/"
                                     "tex/latex/physunits/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "139qcg10879q17l84kqh8x1rzp8bgdcyd4iaxwgl4qlnrkg5rbl5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/physunits")
    (synopsis "Macros for commonly used physical units")
    (description
     "This package provides a collection of macros to simplify using physical units
(e.g., @samp{m} for meters, @samp{J} for joules, etc.), especially in math
mode.  All major SI units are included, as well as some @acronym{CGS,
Centimetre–Gram–Second} units used in astronomy.")
    (license license:lppl1.3c)))

(define-public texlive-piano
  (package
    (name "texlive-piano")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/piano/" "tex/latex/piano/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nbax18dgg2a9l6bihqhwx0va7829324lk29ibq29wjissmhjqww"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/piano")
    (synopsis "Typeset a basic 2-octave piano diagram")
    (description
     "This package adds the @code{\\keyboard[1][2]..[7]} command to your
project.  When used, it draws a small 2 octaves piano keyboard on your
document, with up to 7 keys highlighted.")
    (license license:lppl)))

(define-public texlive-pigpen
  (package
    (name "texlive-pigpen")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/pigpen/"
                                     "fonts/map/dvips/pigpen/"
                                     "fonts/source/public/pigpen/"
                                     "fonts/tfm/public/pigpen/"
                                     "fonts/type1/public/pigpen/"
                                     "tex/latex/pigpen/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17jgzzjyi6skpqgjmrbvd4mm3gggs5dls0jfj6qd8ccf7qdrxiaz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/pigpen")
    (synopsis "Font for the Pigpen (or masonic) cipher")
    (description
     "The Pigpen cipher package provides the font and the necessary
wrappers (style file, etc.) in order to write Pigpen ciphers, a simple
substitution cipher.  The package provides a font (available both as Metafont
source, and as an Adobe Type 1 file), and macros for its use.")
    (license license:lppl)))

(define-public texlive-pinoutikz
  (package
    (name "texlive-pinoutikz")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pinoutikz/"
                                     "tex/latex/pinoutikz/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kqdvldrr7r0jsi2sd8rzqcgwfdy0p9ixqcrwg2k94dcs6ad9mhy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pinoutikz")
    (synopsis "Draw chip pinouts with TikZ")
    (description
     "The package provides a set of macros for typesetting electronic chip pinouts.
It is designed as a tool that is easy to use, with a lean syntax, native to
LaTeX, and directly supporting PDF output format.")
    (license license:lppl1.3c)))

(define-public texlive-pittetd
  (package
    (name "texlive-pittetd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pittetd/" "source/latex/pittetd/"
                                     "tex/latex/pittetd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1q8ikj4qqlzw3kimywdmbvkvwyvyjn8q6gr68kc0wpypqd1a91as"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pittetd")
    (synopsis
     "Electronic theses and dissertations at the University of Pittsburgh")
    (description
     "This package provides a document class for theses and dissertations at
the University of Pittsburgh.")
    (license license:lppl)))

(define-public texlive-pkuthss
  (package
    (name "texlive-pkuthss")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pkuthss/" "tex/latex/pkuthss/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0chc8ikl3xkcrdcgj7mrlam5f8x39mafj2w1yyydq917i7xi129b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pkuthss")
    (synopsis "LaTeX template for dissertations in Peking University")
    (description
     "The package provides a simple, clear and flexible LaTeX template for
dissertations in Peking University.")
    (license
     (list license:lppl1.3+
           license:bsd-3
           license:public-domain))))

(define-public texlive-plainyr
  (package
    (name "texlive-plainyr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/plainyr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09py8psdqqnxmq2nkczxz092668zscvf9hbr6fcvrnj0blvz3wxy"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/plainyr")
    (synopsis "Plain bibliography style, sorted by year first")
    (description
     "This is a version of the standard plain BibTeX style, modified to sort
chronologically (by year) first, then by author, title, etc.")
    (license license:knuth)))

(define-public texlive-plari
  (package
    (name "texlive-plari")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/plari/" "source/latex/plari/"
                                     "tex/latex/plari/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07g4rn4nn5wvwqd39s0xnn35ijkamhzxi12icnha8vb0b564jwq8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/plari")
    (synopsis "Typesetting stageplay scripts")
    (description
     "Plari is a @code{report}-alike class, without section headings, and with
paragraphs vertically separated rather than indented.")
    (license license:gpl3+)))

(define-public texlive-play
  (package
    (name "texlive-play")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/play/" "source/latex/play/"
                                     "tex/latex/play/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1v1d8hfng6s8x8spzrzhhkgg36zay9jvfna9md1mh4ijlipnzyma"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/play")
    (synopsis "Typeset drama using LaTeX")
    (description
     "This package provides a class and style file that supports the
typesetting of plays, including options for line numbering.")
    (license license:lppl)))

(define-public texlive-playfair
  (package
    (name "texlive-playfair")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/playfair/"
                                     "fonts/enc/dvips/playfair/"
                                     "fonts/map/dvips/playfair/"
                                     "fonts/opentype/public/playfair/"
                                     "fonts/tfm/public/playfair/"
                                     "fonts/type1/public/playfair/"
                                     "fonts/vf/public/playfair/"
                                     "tex/latex/playfair/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "060l6q6m410nn31mn09v3gy5nvbimplraifqcqlp3h8pzcrc3akf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/playfair")
    (synopsis "Playfair Display fonts with LaTeX support")
    (description
     "This package provides the PlayFairDisplay family of fonts, designed by
Claus Eggers Sorensen, for use with LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX.
PlayFairDisplay is well suited for titling and headlines.  It has an extra
large x-height and short descenders.  It can be set with no leading if space
is tight, for instance in news headlines, or for stylistic effect in titles.
Capitals are extra short, and only very slightly heavier than the lowercase
characters.  This helps achieve a more even typographical colour when
typesetting proper nouns and initialisms.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-plex
  (package
    (name "texlive-plex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/plex/"
                                     "fonts/enc/dvips/plex/"
                                     "fonts/map/dvips/plex/"
                                     "fonts/opentype/ibm/plex/"
                                     "fonts/tfm/ibm/plex/"
                                     "fonts/type1/ibm/plex/"
                                     "fonts/vf/ibm/plex/"
                                     "tex/latex/plex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1h05ln5c74r85mpj0psf0zcv22mz5psbhqq10vap7x32pc7bhb48"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/plex")
    (synopsis "Support for IBM Plex fonts")
    (description
     "The package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the IBM Plex families of fonts.  Serif, Sans and Mono families are available
in eight weights: Regular, Light, ExtraLight, Thin, Bold, Text, Medium and
SemiBold (with corresponding italics).")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-plex-otf
  (package
    (name "texlive-plex-otf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/plex-otf/" "tex/latex/plex-otf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zkzr7mrmvfgnfd554vb0g6bka7976p93hqfmzapf17js2mfxfsz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/plex-otf")
    (synopsis "Support for the OpenType font IBM Plex")
    (description
     "This package supports the OTF fonts from the IBM Plex project.  This
package supports only XeLaTeX or LuaLaTeX; for pdfLaTeX use
@code{}plex-mono.sty}, @code{}plex-sans.sty}, and @code{plex-serif.sty} from
the @code{plex} package.  IBM Plex has no math symbols.  You will have to use
one of the existing math fonts if you need them.")
    (license license:lppl1.3+)))

(define-public texlive-plimsoll
  (package
    (name "texlive-plimsoll")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/plimsoll/"
                                     "fonts/afm/public/plimsoll/"
                                     "fonts/enc/dvips/plimsoll/"
                                     "fonts/map/dvips/plimsoll/"
                                     "fonts/tfm/public/plimsoll/"
                                     "fonts/type1/public/plimsoll/"
                                     "source/fonts/plimsoll/"
                                     "tex/latex/plimsoll/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cxvlpb7z83ajyqh5nw1596i7ak582pp2mmqmfjqk2bffv6jqay1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/plimsoll")
    (synopsis "Fonts with the Plimsoll symbol and LaTeX support")
    (description
     "This package provides access to the Plimsoll symbol for use with LaTeX.
The Plimsoll symbol is sometimes used in chemistry for denoting standard
states and values.  The LaTeX package provides access to this notation as
well.")
    (license license:gpl3+)))

(define-public texlive-pm-isomath
  (package
    (name "texlive-pm-isomath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pm-isomath/"
                                     "source/latex/pm-isomath/"
                                     "tex/latex/pm-isomath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a3qsv8x1pj2fd8hdbds6skvda9hpaph0a3hakf61xngc7q4ymxn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pm-isomath")
    (synopsis "Poor man ISO math for pdfLaTeX users")
    (description
     "This small package realizes a poor man approximation of the ISO
regulations for physical sciences and technology.  Contrary to other more
elegant solutions, it does not load any math alphabet, since pdfLaTeX can use
only a maximum of such alphabets.  The necessary user macros are defined for
typsetting common math symbols that require special ISO treatment.")
    (license license:lppl1.3c)))

(define-public texlive-pmhanguljamo
  (package
    (name "texlive-pmhanguljamo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pmhanguljamo/"
                                     "tex/latex/pmhanguljamo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1k8cvzmrrpb6hkkjczfq4mad71450pappf68jdlf1vmg3qb0f9z3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pmhanguljamo")
    (synopsis "Poor man's Hangul Jamo input method")
    (description
     "This package provides a Hangul transliteration input method that allows
to typeset Korean letters (Hangul) using the proper fonts.  The use of XeLaTeX
is recommended.")
    (license license:lppl1.3+)))

(define-public texlive-pmx
  (package
    (name "texlive-pmx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pmx/"
                                     "doc/man/man1/pmxab.1"
                                     "doc/man/man1/pmxab.man1.pdf"
                                     "doc/man/man1/scor2prt.1"
                                     "doc/man/man1/scor2prt.man1.pdf"
                                     "tex/generic/pmx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p9js9izv50vg7qqqmyg5jz4am4phhscqdfnn4nszlyfv3zkg7p3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-pmx-bin))
    (home-page "https://ctan.org/pkg/pmx")
    (synopsis "Preprocessor for MusiXTeX")
    (description
     "PMX provides a preprocessor for MusiXTeX.  @command{pmxab} builds a TeX
input file based on a @file{.pmx} input file in a much simpler language,
making most of the layout decisions by itself.  It has most of MusiXTeX's
functionality, but it also permits in-line TeX to give access to virtually all
of MusiXTeX.  For proof-listening, @command{pmxab} will make a MIDI file of
your score.  @command{scor2prt} is an auxiliary program that makes parts from
a score.")
    (license license:gpl2)))

(define-public texlive-pmx-bin
  (package
    (inherit texlive-bin)
    (name "texlive-pmx-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '("pmx"))
            (delete-other-directories "texk" '())))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-pmx" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "utils/pmx"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "utils/pmx"
                  (invoke "make" "install"))))))))
    (native-inputs '())
    (inputs '())
    (propagated-inputs '())
    (home-page (package-home-page texlive-pmx))
    (synopsis "Binaries for @code{texlive-pmx}")
    (description
     "This package provides the binaries for @code{texlive-pmx}.")
    (license (package-license texlive-pmx))))

(define-public texlive-pmxchords
  (package
    (name "texlive-pmxchords")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/pmxchords.1"
                                     "doc/man/man1/pmxchords.man1.pdf"
                                     "doc/pmxchords/" "scripts/pmxchords/"
                                     "tex/generic/pmxchords/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01dlic0b0fdm41982mqj3xpin0wksmsyz4h53vdckkz2ayyagagk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "pmxchords.lua")))
    (home-page "https://ctan.org/pkg/pmxchords")
    (synopsis "Produce chord information to go with @command{pmx} output")
    (description
     "The bundle supplements @command{pmx}, providing the means of typesetting
chords above the notes of a score.  The bundle contains: macros for typing the
chords; a Lua script to transpose chord macros to the required key signature;
and support scripts for common requirements.")
    (license license:gpl2)))

(define-public texlive-pnas2009
  (package
    (name "texlive-pnas2009")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/pnas2009/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yl475rlfhlnd9d0pyzm1gj2gixrdzyn6858j1ndvkhr8vc055ns"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pnas2009")
    (synopsis "BibTeX style for PNAS (newer version)")
    (description
     "This style produces bibliographies in the format of @emph{Proceedings of
the National Academy of Sciences, USA}.  The style was derived from the
standard @file{unsrt.bst} and adapted to the new (2009) formatting rules.")
    (license license:knuth)))

(define-public texlive-poemscol
  (package
    (name "texlive-poemscol")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/poemscol/"
                                     "source/latex/poemscol/"
                                     "tex/latex/poemscol/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hz6zsqcvlzcccxywwzwlpp9gsv41g4hc88481vmj313bys77spd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/poemscol")
    (synopsis "Typesetting critical editions of poetry")
    (description
     "The package offers LaTeX macros for typesetting critical editions of
poetry.  Its features include automatic linenumbering, generation of separate
endnotes sections for emendations, textual collations, and explanatory notes,
special marking for cases in which page breaks occur during stanza breaks,
running headers of the form @samp{Notes to pp.@: xx-yy} for the notes
sections, index of titles and first lines, and automatic generation of a table
of contents.")
    (license license:lppl1.3c)))

(define-public texlive-poetry
  (package
    (name "texlive-poetry")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/poetry/" "source/latex/poetry/"
                                     "tex/latex/poetry/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z262am0qh6h1qqf36hxj2lc7d5pr4r65yx8ysrydh0sijccgild"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/poetry")
    (synopsis "Facilities for typesetting poetry and poetical structure")
    (description
     "This package provides some macros and general doodads for typesetting poetry.
There is, of course, already the excellent @code{verse} package, and the
@code{poetrytex} package provides some extra functionality on top of it.  But
@code{poetry} provides much of the same functionality in a bit of a different
way, and with a few additional abilities, such as facilities for a list of
poems, an index of first lines, and some structural commands.")
    (license license:lppl1.3c)))

(define-public texlive-poetrytex
  (package
    (name "texlive-poetrytex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/poetrytex/"
                                     "source/latex/poetrytex/"
                                     "tex/latex/poetrytex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1y78zd1hd3z1901x6mc6q0mw4rgj3qcqhnjn34zix11r0gn4b2jr"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments
     (list #:tex-format "latex"
           #:phases
           #~(modify-phases %standard-phases
               ;; Replace "\code{...}" with "\texttt{...}" (which is the alias
               ;; chosen in the documentation) in order to prevent a "Command
               ;; \code already defined" error.
               (add-after 'unpack 'fix-documentation-source
                 (lambda _
                   (substitute* "source/latex/poetrytex/poetrytex.dtx"
                     (("\\\\newcommand\\*\\\\code\\[1\\].*") "")
                     (("\\\\code\\{") "\\texttt{")))))))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-etoolbox
                  texlive-fancyvrb
                  texlive-framed
                  texlive-hologo
                  texlive-hypdoc
                  texlive-parskip
                  texlive-tipa
                  texlive-tocloft))))
    (home-page "https://ctan.org/pkg/poetrytex")
    (synopsis "Typeset anthologies of poetry")
    (description
     "The package is designed to aid in the management and formatting of
anthologies of poetry and other writings; it does not concern itself with
actually typesetting the verse itself.")
    (license license:lppl1.3+)))

(define-public texlive-poiretone
  (package
    (name "texlive-poiretone")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/poiretone/"
                                     "fonts/enc/dvips/poiretone/"
                                     "fonts/map/dvips/poiretone/"
                                     "fonts/tfm/public/poiretone/"
                                     "fonts/truetype/public/poiretone/"
                                     "fonts/type1/public/poiretone/"
                                     "fonts/vf/public/poiretone/"
                                     "tex/latex/poiretone/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zdncw8pj0x8nwgk7b5lgqldiifqjnsci57jnkf5vyhzsxx1c8kr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/poiretone")
    (synopsis "PoiretOne family of fonts with LaTeX support")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the PoiretOne family of fonts, designed by Denis Masharov.  PoiretOne is
a decorative geometric grotesque with a hint of Art Deco and constructivism.
There is currently just a regular weight and an artificially emboldened
bold.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-polexpr
  (package
    (name "texlive-polexpr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/polexpr/"
                                     "tex/generic/polexpr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09lryzizy59aaq92m2rzryxf0q0b9wqhrm258q1kqgm0sd2z6pn3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/polexpr")
    (synopsis "Parser for polynomial expressions")
    (description
     "The package provides a parser @code{\\poldef} of algebraic polynomial
expressions.  Once defined, a polynomial is usable by its name either as
a numerical function in @code{\\xintexpr} or @code{\\xinteval}, or for
additional polynomial definitions, or as argument to the package macros.  The
localization of real roots to arbitrary precision as well as the determination
of all rational roots is implemented via such macros.")
    (license license:lppl1.3c)))

(define-public texlive-powerdot-fuberlin
  (package
    (name "texlive-powerdot-fuberlin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/powerdot-fuberlin/"
                                     "tex/latex/powerdot-fuberlin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q49f7sbywfgdgn24ayg7ybfnqdnaqiwn463hiahib0vznwv1fn6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/powerdot-fuberlin")
    (synopsis "Powerdot, using the style of FU Berlin")
    (description
     "The bundle provides a Powerdot-derived class and a package for use with
Powerdot to provide the corporate design of the Free University in Berlin.
Users may use the class itself (FUpowerdot) or use the package in the usual
way with @code{\\style=BerlinFU} as a class option.")
    (license license:lppl)))

(define-public texlive-powerdot-tuliplab
  (package
    (name "texlive-powerdot-tuliplab")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/powerdot-tuliplab/"
                                     "tex/latex/powerdot-tuliplab/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wwml3n7lrfm4m9xw3a14ksa8mcrrp2gbwi9y4m5pgz1r92jmph3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/powerdot-tuliplab")
    (synopsis "Style package for Powerdot to provide the design of TULIP Lab")
    (description
     "@code{powerdot-tuliplab} is the LaTeX package used in TULIP Lab for
presentation drafting.")
    (license license:lppl1.3+)))

(define-public texlive-pracjourn
  (package
    (name "texlive-pracjourn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pracjourn/"
                                     "source/latex/pracjourn/"
                                     "tex/latex/pracjourn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pavlcxv7jqni6rl2hdqfmmns566151rvsaa1p5xhgfb6qa4l1b1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pracjourn")
    (synopsis "Typeset articles for PracTeX")
    (description
     "The @code{pracjourn} class is used for typesetting articles in the
@emph{PracTeX Journal}.  It is based on the @code{article} class with
modifications to allow for more flexible front-matter and revision control,
among other small changes.")
    (license license:gpl3+)))

(define-public texlive-prftree
  (package
    (name "texlive-prftree")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/prftree/" "tex/latex/prftree/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1h5cgk0jsdngmhzr90910fqyvnvabbpicwskan6yay7h8iqqmxvf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/prftree")
    (synopsis "Macros for building proof trees")
    (description
     "This package provides a package to typeset proof trees for natural
deduction calculi, sequent-like calculi, and similar.")
    (license license:gpl3+)))

(define-public texlive-principia
  (package
    (name "texlive-principia")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/principia/"
                                     "tex/latex/principia/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0i429lcyblqx6g6nf6s6bbbfnb62wxgglgkg28hmip81xxbx4vbg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/principia")
    (synopsis "Notations for typesetting the @emph{Principia Mathematica}")
    (description
     "This package supports typesetting the Peanese notation in Volume I of
Whitehead and Russell's 1910 @emph{Principia Mathematica}.")
    (license license:lppl1.3c)))

(define-public texlive-proba
  (package
    (name "texlive-proba")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/proba/" "source/latex/proba/"
                                     "tex/latex/proba/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ym6szixg2dl17l07kdqmyah6pi6hn68ckr95xmimqhv8ib124kj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/proba")
    (synopsis "Shortcuts commands to symbols used in probability texts")
    (description
     "This package includes some of the most often used commands in
probability texts, e.g., probability, expectation, variance, etc.  It also
includes some short commands for set (blackboard) or
filtrations (calligraphic).")
    (license license:lppl)))

(define-public texlive-prociagssymp
  (package
    (name "texlive-prociagssymp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/prociagssymp/"
                                     "tex/latex/prociagssymp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c8fa2d0rsq5drrrckvm1b9mfdfn3p0b9wwwzr263lw7qdqhnlwj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/prociagssymp")
    (synopsis "Macros for IAG symposium papers")
    (description
     "This package provides (re-)definitions of some LaTeX commands that can
be useful for the preparation of papers with the style of the proceedings of
symposia sponsored by the @acronym{IAG, International Association of Geodesy}
published by Springer-Verlag.")
    (license license:lppl)))

(define-public texlive-prodint
  (package
    (name "texlive-prodint")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/prodint/"
                                     "fonts/afm/public/prodint/"
                                     "fonts/map/dvips/prodint/"
                                     "fonts/tfm/public/prodint/"
                                     "fonts/type1/public/prodint/"
                                     "tex/latex/prodint/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k354qidij22mwxafh2zbam7qb4jd5pb8jakw0c660xdxaxrdxx3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/prodint")
    (synopsis "Font that provides the product integral symbol")
    (description
     "Product integrals are to products, as integrals are to sums.  They have
been around for more than a hundred years, they have not become part of the
standard mathematician's toolbox, possibly because no-one invented the right
mathematical symbol for them.  The authors have remedied that situation by
proposing the symbol and providing this font.")
    (license license:silofl1.1)))

(define-public texlive-profcollege
  (package
    (name "texlive-profcollege")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/profcollege/"
                                     "metapost/profcollege/"
                                     "tex/latex/profcollege/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03cnyd4dwxmsl2z46878x7l1k3dshwjkwc7lclw1ivlakl6h4g1f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/profcollege")
    (synopsis "LaTeX package for French maths teachers in college")
    (description
     "This package provides some commands to help French mathematics teachers
for 11-16 years olds.")
    (license license:lppl1.3c)))

(define-public texlive-proflabo
  (package
    (name "texlive-proflabo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/proflabo/" "tex/latex/proflabo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0208sjybqgvd7xrrnc49d31cpvd0bfjyjamfsyzi6yb0fhsxd7x7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/proflabo")
    (synopsis "Draw laboratory equipment")
    (description
     "This package was developed to help French chemistry teachers to create
drawings (using TikZ) for laboratory stuff.")
    (license license:lppl)))

(define-public texlive-proflycee
  (package
    (name "texlive-proflycee")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/proflycee/"
                                     "metapost/proflycee/"
                                     "tex/latex/proflycee/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cmda7dqydvrg327sz5z635kzjs4p2r31z5pc1bj8zq7jc9c5f6h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/proflycee")
    (synopsis "LaTeX package for French maths teachers in high school")
    (description
     "This package provides some commands to help French mathematics teachers
for 15-18 years olds.")
    (license license:lppl1.3c)))

(define-public texlive-projlib
  (package
    (name "texlive-projlib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/projlib/" "source/latex/projlib/"
                                     "tex/latex/projlib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kp8khsr848lksnypj0n4j24pg5xi1lcplvfi8fksrmv0whzyi31"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-create-theorem))
    (home-page "https://ctan.org/pkg/projlib")
    (synopsis "Tools to simplify your workflow")
    (description
     "ProjLib is a collection of tools to help you write LaTeX documents.
With the main package ProjLib loaded, you no longer need to set up the
@code{theorem}-like environments, nor to manually configure the appropriate
multilingual settings.  In addition, a series of auxiliary functionalities are
introduced.")
    (license license:lppl1.3c)))

(define-public texlive-proof-at-the-end
  (package
    (name "texlive-proof-at-the-end")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/proof-at-the-end/"
                                     "source/latex/proof-at-the-end/"
                                     "tex/latex/proof-at-the-end/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1axgv5lln20iwhn07z8ar3blnqmaj4fm6g98948zzlmvysjw5vi9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/proof-at-the-end")
    (synopsis "Move proofs to appendix")
    (description
     "This package aims to provide a way to easily move proofs to the appendix.
You can (among other things) move proofs to different places/sections, create
links from theorems to proofs, restate theorems, add comments in appendix...")
    (license license:lppl1.3+)))

(define-public texlive-prooftrees
  (package
    (name "texlive-prooftrees")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/prooftrees/"
                                     "tex/latex/prooftrees/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0apfsvnappjfnnw3962fwd5wmax6a0hqq8kz29qy3x20n4l8akk3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/prooftrees")
    (synopsis "Forest-based proof trees (symbolic logic)")
    (description
     "The package supports drawing proof trees of the kind often used in
introductory logic classes, especially those aimed at students without strong
mathemtical backgrounds.  Hodges (1991) is one example of a text which uses
this system.  When teaching such a system it is especially useful to annotate
the tree with line numbers, justifications and explanations of branch
closures.  The package provides a single environment, @code{prooftree}, and
a variety of tools for annotating, customising and highlighting such trees.
A cross-referencing system is provided for trees which cite line numbers in
justifications for proof lines or branch closures.")
    (license license:lppl1.3+)))

(define-public texlive-proposal
  (package
    (name "texlive-proposal")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/proposal/base/"
                                     "doc/latex/proposal/dfg/"
                                     "doc/latex/proposal/eu/"
                                     "source/latex/proposal/base/"
                                     "source/latex/proposal/bin/"
                                     "source/latex/proposal/dfg/"
                                     "source/latex/proposal/eu/"
                                     "source/latex/proposal/lib/"
                                     "tex/latex/proposal/base/"
                                     "tex/latex/proposal/dfg/"
                                     "tex/latex/proposal/eu/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0km6i418hdcbl457dfwh1hl3q8qshp1gvqc1frqc84f9a6cr0kzc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/proposal")
    (synopsis
     "Set of LaTeX classes preparing proposals for collaborative projects")
    (description
     "The process of preparing a collaborative proposal, to a major funding body,
involves integration of contributions of a many people at many sites.  It is
therefore an ideal application for a text-based document preparation system
such as LaTeX, in concert with a distributed version control system such as
SVN.  The @code{proposal} class itself provides a basis for such an
enterprise.  The @code{dfgproposal} and @code{dfgproposal} classes provide two
specialisations of the base class for (respectively) German and European
research proposals.")
    (license license:lppl)))

(define-public texlive-prtec
  (package
    (name "texlive-prtec")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/prtec/" "doc/latex/prtec/"
                                     "tex/latex/prtec/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15l75a6blk1dpcj2q841i92cdvlfjxmmaqi5lk01rac8rxa5cghx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/prtec")
    (synopsis "Template for PRTEC conference papers")
    (description
     "This package provides a LaTeX class, a BibTeX style, and a LaTeX
template to format conference papers for the @acronym{PRTEC, Pacific Rim
Thermal Engineering Conference}.")
    (license license:expat)))

(define-public texlive-pseudo
  (package
    (name "texlive-pseudo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pseudo/" "tex/latex/pseudo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rdhgg8y224959qr5c6ph66bkm572147fab3mdp8rw7s4dqkmjli"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pseudo")
    (synopsis "Straightforward pseudocode")
    (description
     "The package permits writing pseudocode without much fuss and with quite
a bit of configurability.  Its main environment combines aspects of
enumeration, tabbing and tabular for nonintrusive line numbering, indentation
and highlighting, and there is functionality for typesetting common syntactic
elements such as keywords, identifiers, and comments.")
    (license license:expat)))

(define-public texlive-pseudocode
  (package
    (name "texlive-pseudocode")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pseudocode/"
                                     "tex/latex/pseudocode/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "180m5yja3wkdnpfz0qx9m031qmhqyjjjgxynm3v4y8fz9jz7vidq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pseudocode")
    (synopsis "LaTeX environment for specifying algorithms in a natural way")
    (description
     "This package provides the environment @code{pseudocode} for describing
algorithms in a natural manner.")
    (license license:lppl)))

(define-public texlive-psgo
  (package
    (name "texlive-psgo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/psgo/" "tex/latex/psgo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ki49zbdn0qvzsz7h53vqwpf4rmiiranq52lh344z7wypznddi28"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/psgo")
    (synopsis "Typeset go diagrams with PSTricks")
    (description
     "This package can be used to typeset go diagrams with PSTricks.")
    (license license:lppl)))

(define-public texlive-psizzl
  (package
    (name "texlive-psizzl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/otherformats/psizzl/base/"
                                     "source/psizzl/base/" "tex/psizzl/base/"
                                     "tex/psizzl/config/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07h8raq2k80ycvsaaaxaaczwwnhkxdbnvnr52mihr8dyih5s7jns"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/psizzl")
    (synopsis "TeX format for physics papers")
    (description
     "PSIZZL is a TeX format for physics papers written at SLAC and used at
several other places.  It dates from rather early in the development of TeX82;
as a result, some of the descriptions of limitations look rather quaint to
modern eyes.")
    (license license:lppl)))

(define-public texlive-ptptex
  (package
    (name "texlive-ptptex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ptptex/" "tex/latex/ptptex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1f040dv31g8bdn0awa40mvhzp095glsfsxcg28cbslckbdds5k6c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ptptex")
    (synopsis "Macros for @emph{Progress of Theoretical Physics}")
    (description
     "The distribution contains the class (which offers an option file for
preprints), a template, and macros for writing articles in @emph{Progress of
Theoretical Physics}.")
    (license license:lppl)))

(define-public texlive-punk
  (package
    (name "texlive-punk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/punk/"
                                     "fonts/source/public/punk/"
                                     "fonts/tfm/public/punk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ncarqjmwrsiw65p7mr44gjy0h90q5hw5n4jb5y2fxr1kgbzmz1p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/punk")
    (synopsis "Donald Knuth's Punk font")
    (description
     "This package provides a response to the assertion in a lecture that
``typography tends to lag behind other stylistic changes by about 10 years''.
Knuth felt it was (in 1988) time to design a replacement for his designs of
the 1970s, and came up with the Punk font!  The fonts are distributed as
Metafont source.  The package also offers LaTeX support for them, although
@code{punk-latex} is a better choice.")
    (license license:knuth)))

(define-public texlive-punk-latex
  (package
    (name "texlive-punk-latex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/punk-latex/"
                                     "tex/latex/punk-latex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gkbv3fwlfq8f3nn9zibhzwa5xw2scaf3xnkvlbxqcslmi129b2l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/punk-latex")
    (synopsis "LaTeX support for Punk fonts")
    (description
     "The package and @file{.fd} file provide support for Knuth's Punk fonts.
Although that bundle also offers support within LaTeX; the present package is
to be preferred.")
    (license license:gpl3+)))

(define-public texlive-punknova
  (package
    (name "texlive-punknova")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/punknova/"
                                     "fonts/opentype/public/punknova/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07g0j329bgyzn3f3ac8gf9m6jh6zpwirw5l72mzzm8n32sgajym0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/punknova")
    (synopsis "OpenType version of Knuth's Punk font")
    (description
     "Knuth's original Punk fonts generated different shapes at random.
This isn't actually possible in an OpenType font; rather, the font contains
several variants of each glyph, and uses the OpenType randomize function to
select a variant for each invocation.")
    (license license:knuth)))

(define-public texlive-pxtxalfa
  (package
    (name "texlive-pxtxalfa")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/pxtxalfa/"
                                     "fonts/tfm/public/pxtxalfa/"
                                     "fonts/vf/public/pxtxalfa/"
                                     "tex/latex/pxtxalfa/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zanrgazaffpby6jmfncyq2g4sgi23p27wi2dx18zp0350ai55ia"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pxtxalfa")
    (synopsis
     "Virtual maths alphabets based on @code{pxfonts} and @code{txfonts}")
    (description
     "The package provides virtual math alphabets based on @code{pxfonts} and
@code{txfonts}, with LaTeX support files and adjusted metrics.  The
@code{mathalpha} package offers support for this collection.")
    (license license:lppl)))

(define-public texlive-pythonhighlight
  (package
    (name "texlive-pythonhighlight")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pythonhighlight/"
                                     "tex/latex/pythonhighlight/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1grvq2sih8klkvzgyrc4fpalv7q670l9q00vs8293n698bhmn72g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pythonhighlight")
    (synopsis
     "Highlighting of Python code, based on the @code{listings} package")
    (description
     "This package allows highlighting of Python code, based on the
@code{listings} package.")
    (license license:bsd-3)))

(define-public texlive-qobitree
  (package
    (name "texlive-qobitree")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/qobitree/" "tex/latex/qobitree/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pzy5i8fi37zhkpsrh179qd4gp8ahwk8s2gw6261kjjiqf6p6znc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/qobitree")
    (synopsis "LaTeX macros for typesetting trees")
    (description
     "This package provides commands @code{\\branch} and @code{\\leaf} for
specifying the elements of the tree; you build up your tree with those
commands, and then issue the @code{\\tree} command to typeset the whole.")
    (license license:lppl)))

(define-public texlive-qrbill
  (package
    (name "texlive-qrbill")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/qrbill/" "scripts/qrbill/"
                                     "source/latex/qrbill/" "tex/latex/qrbill/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "162czrwklb4ybxga12zw5mm50i0zg9abm3aydlz1kk453n2rzynp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/qrbill")
    (synopsis "Create QR bills using LaTeX")
    (description
     "This LaTeX package provides support for creating QR-bills for the new
Swiss payment standards.  This implementation is intended to offer an option
to support these regulations and can be adapted for international use.")
    (license (list license:lppl1.3c license:bsd-3))))

(define-public texlive-qsharp
  (package
    (name "texlive-qsharp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/qsharp/" "source/latex/qsharp/"
                                     "tex/latex/qsharp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "104asd1z3n7yqpq2midca2sjjxbbr0c9ngaqncj8zzb0i7ky19v4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/qsharp")
    (synopsis "Syntax highlighting for the Q# language")
    (description
     "The package provides syntax highlighting for the Q# language,
a domain-specific language for quantum programming.")
    (license license:lppl1.3c)))

(define-public texlive-qtree
  (package
    (name "texlive-qtree")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/qtree/" "tex/latex/qtree/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gmwkm6400pcrjnq111bih7za0p45nx6gy4lksvgjhdcpnykbbla"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/qtree")
    (synopsis "Draw tree structures")
    (description
     "The package offers support for drawing tree diagrams, and is especially
suitable for linguistics use.  It allows trees to be specified in a simple
bracket notation, automatically calculates branch sizes, and supports both
DVI/PostScript and PDF output by use of @code{pict2e} facilities.  The package
is a development of the existing @code{qobitree} package, offering a new front
end.")
    (license license:lppl)))

(define-public texlive-qualitype
  (package
    (name "texlive-qualitype")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/qualitype/"
                                     "fonts/opentype/public/qualitype/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "027n3i9cy4p7wkbj1zrlsvagplxk74gz5cwv7mr4yl8gqzd41058"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/qualitype")
    (synopsis "QualiType font collection")
    (description
     "This is a collection of 45 fonts, created by QualiType.")
    (license (list license:silofl1.1 license:gpl2+))))

(define-public texlive-quantumarticle
  (package
    (name "texlive-quantumarticle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/quantumarticle/"
                                     "doc/latex/quantumarticle/"
                                     "tex/latex/quantumarticle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00v04n109mbi7w0xcmfdzs8f1fabwd2qhf53fqps99k3dj4z5f0a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/quantumarticle")
    (synopsis "Document class for submissions to the @emph{Quantum} journal")
    (description
     "This package provides the preferred document class for papers to be
submitted to @emph{Quantum --- the open journal of quantum science}.  It is
based on the @code{article} document class.

As a service to authors, the document class comes with a predefined
bibliography style @file{quantum.bst} that is optimized to be used with the
@code{quantumarticle} document class.  Additionally, the @code{quantumview}
document class is provided, which can be used as a proxy to typeset the
HTML-only editorial pieces in @emph{Quantum Views}.

The @code{quantumarticle} document class also offers an option to remove the
@emph{Quantum}-related branding.  In that way, users can use it for their
notes as well.")
    (license license:lppl1.3c)))

(define-public texlive-quattrocento
  (package
    (name "texlive-quattrocento")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/quattrocento/"
                                     "fonts/enc/dvips/quattrocento/"
                                     "fonts/map/dvips/quattrocento/"
                                     "fonts/tfm/impallari/quattrocento/"
                                     "fonts/truetype/impallari/quattrocento/"
                                     "fonts/type1/impallari/quattrocento/"
                                     "fonts/vf/impallari/quattrocento/"
                                     "tex/latex/quattrocento/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mgsyl3xc9274mdh3ssd9ifxb0d9rlv0y33nlw9pwnl9y9f9gd9a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/quattrocento")
    (synopsis "Quattrocento and Quattrocento Sans fonts with LaTeX support")
    (description
     "The package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the Quattrocento and Quattrocento Sans families of fonts, designed by Pablo
Impallari; the fonts themselves are also provided, in both TrueType and Type1
format.  Quattrocento is a classic typeface with wide and open letterforms,
and great x-height, which makes it very legible for body text at small sizes.
Tiny details that only show up at bigger sizes make it also great for display
use.  Quattrocento Sans is the perfect sans-serif companion for
Quattrocento.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-raleway
  (package
    (name "texlive-raleway")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/raleway/"
                                     "fonts/enc/dvips/raleway/"
                                     "fonts/map/dvips/raleway/"
                                     "fonts/opentype/impallari/raleway/"
                                     "fonts/tfm/impallari/raleway/"
                                     "fonts/type1/impallari/raleway/"
                                     "fonts/vf/impallari/raleway/"
                                     "tex/latex/raleway/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pp5m31rr4lww0z92q3vsaz1l01nb78ll5mn2l9w469hpghf2gd3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/raleway")
    (synopsis "Use Raleway with TeX(-alike) systems")
    (description
     "The package provides the Raleway family in an easy to use way.  For
XeLaTeX and LuaLaTeX users the original OpenType fonts are used.  The entire
font family is included.")
    (license license:silofl1.1)))

(define-public texlive-rank-2-roots
  (package
    (name "texlive-rank-2-roots")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rank-2-roots/"
                                     "tex/latex/rank-2-roots/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mjck9vcysgak245fl43vklzw0z1znmmz9jr5qxa2gdargnkvgxl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rank-2-roots")
    (synopsis "Draw (mathematical) rank 2 root systems")
    (description
     "This package concerns mathematical drawings arising in representation
theory.  The purpose of this package is to ease drawing of rank 2 root
systems, with Weyl chambers, weight lattices, and parabolic subgroups.")
    (license license:lppl1.3c)))

(define-public texlive-rbt-mathnotes
  (package
    (name "texlive-rbt-mathnotes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rbt-mathnotes/"
                                     "tex/latex/rbt-mathnotes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12zhnciww00z4rkxp2pr2l31nwgsp10h38pla5jqgicvvz77x67c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rbt-mathnotes")
    (synopsis
     "Rebecca Turner's personal macros and styles for typesetting mathematics notes")
    (description
     "This package includes styles for typesetting mathematics notes, classes
for typesetting homework assignments, and formula cheat sheets for exams.")
    (license license:lppl1.3c)))

(define-public texlive-realtranspose
  (package
    (name "texlive-realtranspose")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/realtranspose/"
                                     "source/latex/realtranspose/"
                                     "tex/latex/realtranspose/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ar1yisx6pq8qjhsvb406l5j06y9jkyxvvgq9s1sg15nk9sjzy1r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/realtranspose")
    (synopsis "The ``real'' way to transpose a matrix")
    (description
     "With @code{realtranspose} you can notate the transposition of a matrix
by rotating the symbols 90 degrees.")
    (license license:expat)))

(define-public texlive-rec-thy
  (package
    (name "texlive-rec-thy")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rec-thy/" "tex/latex/rec-thy/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hnh371kvp2m98gg01cnqqia8gp6m0rvblff53sq86ihcij8ifz9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rec-thy")
    (synopsis "Commands to typeset recursion theory papers")
    (description
     "This package is designed to help mathematicians publishing papers in the
area of recursion theory (aka Computability Theory) easily use standard
notation.  This includes easy commands to denote Turing reductions, Turing
functionals, c.e.@: sets, stagewise computations, forcing and syntactic
classes.")
    (license license:public-domain)))

(define-public texlive-recorder-fingering
  (package
    (name "texlive-recorder-fingering")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/recorder-fingering/"
                                     "tex/latex/recorder-fingering/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yq4fwh7pqkhh52f1zfdgf0a5f0kqfh167c4fnh2pvirkfwi7312"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/recorder-fingering")
    (synopsis "Package to display recorder fingering diagrams")
    (description
     "This package provides support for generating and displaying fingering
diagrams for baroque fingering recorders.  Standard fingerings are provided
for recorders in both C and F, along with methods to create and display
alternate fingerings for trills, etc.")
    (license license:lppl1.3+)))

(define-public texlive-recycle
  (package
    (name "texlive-recycle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/recycle/"
                                     "fonts/map/dvips/recycle/"
                                     "fonts/source/public/recycle/"
                                     "fonts/tfm/public/recycle/"
                                     "fonts/type1/public/recycle/"
                                     "tex/latex/recycle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16kmi7a75vrv3pfnxydxb21pafvi98q39jrdd10a94vxx6fdlx7s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    ;; FIXME: Font metrics generation fails with "! Inconsistent equation (off
    ;; by 0.00162)." errors.
    (arguments
     (list #:phases
           #~(modify-phases %standard-phases
               (delete 'generate-font-metrics))))
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/recycle")
    (synopsis "Font providing the ``recyclable'' logo")
    (description
     "This single-character font is provided as Metafont source, and in Adobe
Type 1 format.  It is accompanied by a trivial LaTeX package to use the logo
at various sizes.")
    (license license:gpl3+)))

(define-public texlive-reledmac
  (package
    (name "texlive-reledmac")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/reledmac/"
                                     "source/latex/reledmac/"
                                     "tex/latex/reledmac/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12ds4zbpv4zv6igg2pnqjxayxkrg06a69s4i10p408kwp9wwhs17"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/reledmac")
    (synopsis "Typeset scholarly editions")
    (description
     "This package provides a package for typesetting scholarly critical
editions, replacing the established @code{ledmac} and @code{eledmac} packages.
It supports indexing by page and by line numbers, and simple @code{tabular}-
and @code{array}-style environments.  The package is distributed with the
related @code{reledpar} package.")
    (license license:lppl1.3+)))

(define-public texlive-resolsysteme
  (package
    (name "texlive-resolsysteme")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/resolsysteme/"
                                     "tex/latex/resolsysteme/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0g51cmjd5gs0p198sb8v95l8jra6cv6smz2068b1pdpv1fqpmjfv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/resolsysteme")
    (synopsis "Work on linear systems using xint or pyluatex")
    (description
     "This package provides some commands (in French) to perform calculations
on small (2x2 or 3x3 or 4x4) linear systems, with @code{xint} or
@code{pyluatex}:

@itemize
@item @code{\\DetMatrice} or @code{\\DetMatricePY} to display the determinant
of a matrix;
@item @code{\\MatriceInverse} or @code{\\MatriceInversePY} to display the
inverse of a matrix;
@item @code{\\SolutionSysteme} or @code{\\SolutionSystemePY} to display the
solution of a linear system;
@item @dots{}
@end itemize")
    (license license:lppl1.3c)))

(define-public texlive-resphilosophica
  (package
    (name "texlive-resphilosophica")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/resphilosophica/"
                                     "doc/latex/resphilosophica/"
                                     "source/latex/resphilosophica/"
                                     "tex/latex/resphilosophica/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12a0pnksxh3b0w9iwhly9sb8j6jhhmk9r1957mb7m01h435n9yb4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/resphilosophica")
    (synopsis "Typeset articles for the journal @emph{Res Philosophica}")
    (description
     "The bundle provides a class for typesetting articles for the journal
@emph{Res Philosophica}.")
    (license license:lppl1.3+)))

(define-public texlive-rest-api
  (package
    (name "texlive-rest-api")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rest-api/"
                                     "source/latex/rest-api/"
                                     "tex/latex/rest-api/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yv81yisaqkxnq33803z7kx3rk6hsdnyza0dzgqmkf6x1jmsnlp9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rest-api")
    (synopsis "Describing a REST API")
    (description
     "This LaTeX package provides macros to describe REST APIs for
documentation purposes.  The endpoints can hold the following information:
method description path parameter request body and content type response body,
content type and status code.")
    (license license:lppl1.3c)))

(define-public texlive-resumecls
  (package
    (name "texlive-resumecls")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/resumecls/"
                                     "source/xelatex/resumecls/"
                                     "tex/xelatex/resumecls/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14za3bvvksq6xjvbppfm17cj8abspj7h7l7snyd2vciy0dc305yg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/resumecls")
    (synopsis "Typeset a resume both in English and Chinese")
    (description
     "This package provides a LaTeX document class to typeset a resume or CV
both in English and Chinese with more ease and flexibility.")
    (license license:lppl1.3+)))

(define-public texlive-reverxii
  (package
    (name "texlive-reverxii")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/reverxii/"
                                     "source/generic/reverxii/"
                                     "tex/generic/reverxii/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gg8qbc8ll3n6rfp3pjshbbjd30s4n3yk219y6qcmz1nv66fp1qq"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs (list (texlive-updmap.cfg)))
    (home-page "https://ctan.org/pkg/reverxii")
    (synopsis "Playing Reversi in TeX")
    (description
     "Following the lead of @file{xii.tex}, this little program plays
Reversi.")
    (license license:lppl1.3c)))

(define-public texlive-revquantum
  (package
    (name "texlive-revquantum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/revquantum/"
                                     "source/latex/revquantum/"
                                     "tex/latex/revquantum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00wac9xjzx9mw6vxd3wnjyb1f8c1661s2zwvd4d0r337ccs6jqbl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/revquantum")
    (synopsis
     "Hacks to make writing quantum papers for revtex4-1 less painful")
    (description
     "This package provides a number of useful hacks to solve common
annoyances with the @code{revtex4-1} package, and to define notation in common
use within quantum information.  In doing so, it imports and configures
a number of commonly-available and used packages, and where reasonable,
provides fallbacks.  It also warns when users try to load packages which are
known to be incompatible with @code{revtex4-1}.")
    (license license:lppl1.3+)))

(define-public texlive-revtex4
  (package
    (name "texlive-revtex4")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/revtex4/" "doc/latex/revtex4/"
                                     "source/latex/revtex4/" "tex/latex/revtex4/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mfjp8ycsvq63vk5348r7yfcskldx6ipcwflxz7pnf60xfla5646"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/revtex4-0")
    (synopsis "Styles for various physics journals (old version)")
    (description
     "This is an old version of @code{revtex}, and is kept as a courtesy to
users having difficulty with the incompatibility of that latest version.")
    (license license:lppl)))

(define-public texlive-revtex4-1
  (package
    (name "texlive-revtex4-1")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/revtex4-1/"
                                     "doc/latex/revtex4-1/"
                                     "source/latex/revtex4-1/"
                                     "tex/latex/revtex4-1/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "023pzbf8hgyk6038zz9g4g95pwqrsqy1ahzy6byxh28b2p8qyk9a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:modules '((ice-9 match)
                  (ice-9 regex)
                  (srfi srfi-1)
                  (guix build texlive-build-system)
                  (guix build utils))
      #:build-targets #~(list "revtex4-1.dtx")
      #:phases
      #~(modify-phases %standard-phases
          ;; In order to build revtex4-1, we need files from revtex source.
          ;; Add them to TEXINPUTS.
          (add-before 'build 'extend-texinputs
            (lambda* (#:key inputs native-inputs #:allow-other-keys)
              (let ((revtex-source
                     (any (match-lambda
                            ((_ . dir)
                             (and (string-match "texlive-revtex-[^-]+-checkout"
                                                dir)
                                  dir)))
                          (or native-inputs inputs))))
                (setenv "TEXINPUTS"
                        (string-append revtex-source
                                       "/source/latex/revtex/:"))))))))
    (native-inputs (list (package-source texlive-revtex)))
    (home-page "https://ctan.org/pkg/revtex4-1")
    (synopsis "Styles for various physics journals")
    (description
     "This is an old version of @code{revtex}, and is kept as a courtesy to
users having difficulty with the incompatibility of that latest version.")
    (license license:lppl1.3+)))

(define-public texlive-ribbonproofs
  (package
    (name "texlive-ribbonproofs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ribbonproofs/"
                                     "tex/latex/ribbonproofs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1590hcnmzffm1z2rqz0g3h5a7xpidjzw5am603pqvlsdxvjfm6my"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ribbonproofs")
    (synopsis "Drawing ribbon proofs")
    (description
     "The package provides a way to draw ribbon proofs in LaTeX, a graphical
proof system for the propositional fragment of the logic of bunched
implications.")
    (license license:lppl1.3+)))

(define-public texlive-rmathbr
  (package
    (name "texlive-rmathbr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rmathbr/" "source/latex/rmathbr/"
                                     "tex/latex/rmathbr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rgkl8fmq00w7yn445sfq3w2xf39d3waiphivvm6hx49nd6vacv0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rmathbr")
    (synopsis
     "Repeating of math operator at the broken line and the new line in inline equations")
    (description
     "Repeating of math operators at the broken line and the new line in
inline equations is used in Cyrillic mathematical typography (Russian for
example), but unfortunately LaTeX does not provide such an option.  This
package solves the problem by extending ideas described in M. I. Grinchuk
@emph{TeX and Russian Traditions of Typesetting}, and supports most of LaTeX
mathematical packages.")
    (license license:lppl1.3+)))

(define-public texlive-roboto
  (package
    (name "texlive-roboto")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/roboto/"
                                     "fonts/enc/dvips/roboto/"
                                     "fonts/map/dvips/roboto/"
                                     "fonts/opentype/google/roboto/"
                                     "fonts/tfm/google/roboto/"
                                     "fonts/type1/google/roboto/"
                                     "fonts/vf/google/roboto/"
                                     "tex/latex/roboto/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gbg9p9y6a2fis88qfcsscksrkkcnqvsrhdkak2jm2dfjnq6v2n8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/roboto")
    (synopsis "Support for the Roboto family of fonts")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the Roboto Sans, Roboto Condensed, Roboto Mono, Roboto Slab and Roboto Serif
families of fonts, designed by Christian Robertson and Greg Gazdowicz.")
    (license (list license:asl2.0 license:silofl1.1 license:lppl))))

(define-public texlive-romande
  (package
    (name "texlive-romande")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/romande/"
                                     "fonts/afm/arkandis/romande/"
                                     "fonts/enc/dvips/romande/"
                                     "fonts/map/dvips/romande/"
                                     "fonts/tfm/arkandis/romande/"
                                     "fonts/type1/arkandis/romande/"
                                     "fonts/vf/arkandis/romande/"
                                     "source/fonts/romande/"
                                     "tex/latex/romande/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xvahacjs8g5bl7yy89wi50m894r2402d5203ai79fk9d7rbc116"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/romandeadf")
    (synopsis "Romande ADF fonts and LaTeX support")
    (description
     "Romande ADF is a serif font family with oldstyle figures, designed as
a substitute for Times, Tiffany or Caslon.  The family currently includes
upright, italic and small-caps shapes in each of regular and demi-bold weights
and an italic script in regular.  The support package renames the fonts
according to the Karl Berry fontname scheme and defines four families.  Two of
these primarily provide access to the standard, or default, characters while
the alternate families support alternate characters, additional ligatures and
the long @emph{s}.  The included package files provide access to these
features in LaTeX.")
    (license license:lppl)))

(define-public texlive-rosario
  (package
    (name "texlive-rosario")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/rosario/"
                                     "fonts/enc/dvips/rosario/"
                                     "fonts/map/dvips/rosario/"
                                     "fonts/opentype/public/rosario/"
                                     "fonts/tfm/public/rosario/"
                                     "fonts/type1/public/rosario/"
                                     "fonts/vf/public/rosario/"
                                     "source/fonts/rosario/"
                                     "tex/latex/rosario/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bmz2xzx1xi3vn9s4wqij65nq54k9bc0kbxgnzd0p6q030g5yqby"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rosario")
    (synopsis "Using the Rosario fonts with LaTeX")
    (description
     "The package provides the files required to use the Rosario fonts with
LaTeX.  Rosario is a set of four fonts provided by Hector Gatti.")
    (license license:lppl1.3c)))

(define-public texlive-rsfso
  (package
    (name "texlive-rsfso")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/rsfso/" "fonts/map/dvips/rsfso/"
                                     "fonts/tfm/public/rsfso/"
                                     "fonts/vf/public/rsfso/" "tex/latex/rsfso/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fm65p7k0kfiksap2f2g8lqmgdykmhq80ff5qgma4cnqa4sa3jza"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rsfso")
    (synopsis "Mathematical calligraphic font based on @code{rsfs}")
    (description
     "The package provides virtual fonts and LaTeX support files for
mathematical calligraphic fonts based on the @code{rsfs} Adobe Type 1 fonts,
with the slant substantially reduced.  The output is quite similar to that
from the Adobe Mathematical Pi script font.")
    (license license:lppl)))

(define-public texlive-rrgtrees
  (package
    (name "texlive-rrgtrees")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rrgtrees/"
                                     "source/latex/rrgtrees/"
                                     "tex/latex/rrgtrees/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h33q32pb1s8zv598aacdzfhpk2psrzxgxnav6am16cxfri60hpi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rrgtrees")
    (synopsis
     "Linguistic tree diagrams for Role and Reference Grammar (RRG) with LaTeX")
    (description
     "This package provides a set of LaTeX macros that makes it easy to
produce linguistic tree diagrams suitable for Role and Reference
Grammar (RRG).  This package allows the construction of trees with crossing
lines, as is required by this theory for many languages.")
    (license license:lppl)))

(define-public texlive-rsc
  (package
    (name "texlive-rsc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/rsc/" "doc/latex/rsc/"
                                     "source/latex/rsc/" "tex/latex/rsc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fgc54fyikrgx81gfhv7mab6sqj4xjz6pyrkxk8jnlwwqrsk0yxb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rsc")
    (synopsis "BibTeX style for use with RSC journals")
    (description
     "The @code{rsc} package provides a BibTeX style in accordance with the
requirements of the Royal Society of Chemistry.  It was originally based on
the file @file{pccp.bst}, but also implements a number of styles from the
@code{achemso} package.  The package is now a stub for the @code{chemstyle}.")
    (license license:lppl1.3+)))

(define-public texlive-rtklage
  (package
    (name "texlive-rtklage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rtklage/" "tex/latex/rtklage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0p9z4dgh572n7j6b8vf8aqag8ybqw3xzsh5kab1czks2774gm7cq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ratex")
    (synopsis "Package for German lawyers")
    (description
     "RATeX is a newly developed bundle of packages and classes provided for
German lawyers.  Now in the early beginning it only contains @code{rtklage},
a class to make lawsuits.")
    (license license:lppl)))

(define-public texlive-rubik
  (package
    (name "texlive-rubik")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rubik/"
                                     "doc/man/man1/rubikrotation.1"
                                     "doc/man/man1/rubikrotation.man1.pdf"
                                     "scripts/rubik/"
                                     "source/latex/rubik/"
                                     "tex/latex/rubik/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0v7j88d72acgrj24x8g859k7q6qd47pjy3wdqfvrqq3y39x48011"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "rubikrotation.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/rubik")
    (synopsis "Document Rubik cube configurations and rotation sequences")
    (description
     "The bundle provides four packages:
@itemize

@item @code{rubikcube} provides commands for typesetting Rubik cubes
and their transformations,

@item @code{rubiktwocube} provides commands for typesetting Rubik
twocubes and their transformations,

@item @code{rubikrotation} can process a sequence of Rubik rotation
moves, with the help of a Perl package executed via
@code{\\write18} (shell escape) commands,

@item @code{rubikpatterns} is a collection of well known patterns and
their associated rotation sequences.

@end itemize")
    (license license:lppl1.3+)))

(define-public texlive-rutitlepage
  (package
    (name "texlive-rutitlepage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rutitlepage/"
                                     "source/latex/rutitlepage/"
                                     "tex/latex/rutitlepage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pcd6cqlm3r7wq9k96ignvars436hg9j5la4aaq35ldm01sqy268"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rutitlepage")
    (synopsis "Radboud University titlepage package")
    (description
     "This is an unofficial LaTeX package to generate titlepages for the
Radboud University, Nijmegen.  It uses official vector logos from the
university.")
    (license license:lppl1.3+)))

(define-public texlive-ryersonsgsthesis
  (package
    (name "texlive-ryersonsgsthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ryersonsgsthesis/"
                                     "tex/latex/ryersonsgsthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "170z5xqxwbx999dxlxhwf7mbml6j4pak6a8lgi4vbj8ii4njlygb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ryersonsgsthesis")
    (synopsis "Ryerson School of Graduate Studies thesis template")
    (description
     "This package provides a LaTeX class and template files for Ryerson
School of Graduate Studies (SGS) theses.")
    (license license:asl2.0)))

(define-public texlive-ryethesis
  (package
    (name "texlive-ryethesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ryethesis/"
                                     "source/latex/ryethesis/"
                                     "tex/latex/ryethesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xjzl1ng0nbcakiasi6sfbkannfipcfv96crq6y6cb7p7l707wg7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ryethesis")
    (synopsis "Class for Ryerson Unversity Graduate School requirements")
    (description
     "The class offers support for formatting a thesis, dissertation or
project according to Ryerson University's School of Graduate Studies thesis
formatting regulations.")
    (license license:lppl1.3+)))

(define-public texlive-sageep
  (package
    (name "texlive-sageep")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/sageep/" "doc/latex/sageep/"
                                     "source/latex/sageep/" "tex/latex/sageep/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xmfqqsabc7vv3rh74qlry5jkvp0ddyi8m4yynriv5vzyqigfw5y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sageep")
    (synopsis "Format papers for the annual meeting of EEGS")
    (description
     "The class provides formatting for papers for the annual meeting of the
@acronym{EEGS, Environmental and Engineering Geophysical Society}: Application
of Geophysics to Engineering and Environmental Problems, known as SAGEEP.")
    (license license:lppl)))

(define-public texlive-sankey
  (package
    (name "texlive-sankey")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sankey/" "source/latex/sankey/"
                                     "tex/latex/sankey/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "020in4r4pim07nya119767zjs90yqpkcyr6h6l5v7ig21n4q7d8s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sankey")
    (synopsis "Draw Sankey diagrams with TikZ")
    (description
     "This package provides macros and an environment for creating Sankey
diagrams, i.e., flow diagrams in which the width of the arrows is proportional
to the flow rate.")
    (license (list license:lppl1.3+ license:gpl3+))))

(define-public texlive-sansmathaccent
  (package
    (name "texlive-sansmathaccent")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/sansmathaccent/"
                                     "fonts/map/dvips/sansmathaccent/"
                                     "fonts/tfm/public/sansmathaccent/"
                                     "fonts/vf/public/sansmathaccent/"
                                     "tex/latex/sansmathaccent/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03xd3wpmzrggpmjrff4ka56v2zycbznlcdfyvz74xxjnngxz81qm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sansmathaccent")
    (synopsis "Correct placement of accents in sans-serif maths")
    (description
     "Sans serif maths (produced by the @code{beamer} class or the
@code{sfmath} package) often has accents positioned incorrectly.  This package
fixes the positioning of such accents when the default font (@code{cmssi}) is
used for sans serif maths.")
    (license license:lppl1.3+)))

(define-public texlive-sapthesis
  (package
    (name "texlive-sapthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/sapthesis/"
                                     "doc/latex/sapthesis/"
                                     "tex/latex/sapthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15livlw0xbc6ys408pqqvh3qvzphigar9cr57dd0is4zrh4c2y36"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sapthesis")
    (synopsis "Typeset theses for Sapienza-University, Rome")
    (description
     "The class will typeset PhD, master, and bachelor theses that adhere to
the publishing guidelines of the Sapienza University of Rome.")
    (license license:lppl1.3+)))

(define-public texlive-sasnrdisplay
  (package
    (name "texlive-sasnrdisplay")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sasnrdisplay/"
                                     "tex/latex/sasnrdisplay/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0siifxzkvgryixypgw7dywr5g7qqqrnbq622qhhyfd4xlgix43in"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sasnrdisplay")
    (synopsis "Typeset SAS or R code or output")
    (description
     "The SASnRdisplay package serves as a front-end to listings, which
permits statisticians and others to import source code and the results of
their calculations or simulations into LaTeX projects.  The package is also
capable of overloading the Sweave User Manual and SASweave packages.")
    (license license:lppl1.3+)))

(define-public texlive-sauterfonts
  (package
    (name "texlive-sauterfonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sauterfonts/"
                                     "source/latex/sauterfonts/"
                                     "tex/latex/sauterfonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h34vp94i16al0z8zw5xn3igk2hg4nnb507kiv87qxrr3gl11zy4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sauterfonts")
    (synopsis "Use Sauter's fonts in LaTeX")
    (description
     "The package provides font definition files (plus a replacement for the
package @code{exscale}) to access many of the fonts in Sauter's collection.
These fonts are available in all point sizes and look nicer for such
intermediate document sizes as 11pt.  Also included is the package
@code{sbbm}, an alternative to access the BBM fonts.")
    (license license:gpl3+)))

(define-public texlive-schola-otf
  (package
    (name "texlive-schola-otf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/schola-otf/"
                                     "tex/latex/schola-otf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ygc9bhdc9qgp20r17am8k7zmc1c1rdra0a56davw5y93zjvyzji"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/schola-otf")
    (synopsis "Using the OpenType fonts TeX Gyre Schola")
    (description
     "This package can only be used with LuaLaTeX or XeLaTeX.  It does the
font setting for the OpenType font TeX Gyre Schola for text and math.  The
missing typefaces like bold math and slanted text are also defined.")
    (license license:lppl1.3+)))

(define-public texlive-scholax
  (package
    (name "texlive-scholax")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/scholax/"
                                     "fonts/afm/public/scholax/"
                                     "fonts/enc/dvips/scholax/"
                                     "fonts/map/dvips/scholax/"
                                     "fonts/opentype/public/scholax/"
                                     "fonts/tfm/public/scholax/"
                                     "fonts/type1/public/scholax/"
                                     "fonts/vf/public/scholax/"
                                     "tex/latex/scholax/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jw09a75gw9favzpfkp4kmwf6wz9kp4jsk8f838rk1x76q213rrw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/scholax")
    (synopsis
     "Extension of TeXGyreSchola (New Century Schoolbook) with math support")
    (description
     "This package contains an extension of TeXGyreSchola with extensive
superiors, inferior figures, upright punctuation glyphs added to the Italic
face for a theorem font, plus slanted and bold slanted faces.  Math support is
provided by one of two options to @code{newtxmath}, one of which uses an
adaptation of the Fourier math Greek letters.")
    (license license:lppl)))

(define-public texlive-schule
  (package
    (name "texlive-schule")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/schule/" "tex/latex/schule/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0j1qpr8712zailnl6cal11wl27zq2vk456xgx9dza354imxpsjs9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/schule")
    (synopsis "Support for teachers at German schools")
    (description
     "The @code{schule} bundle was built to provide packages and commands that
could be useful for documents in German schools.  At the moment, its main
focus lies on documents for informatics as a school subject.  An extension for
physics is currently in progress.

For the time being, the whole package splits up into individual packages for
informatics (including syntax diagrams, Nassi-Shneiderman diagrams, sequence
diagrams, object diagrams, and class diagrams) as well as classes for written
exams (tests, quizzes, teaching observations, information sheets, worksheets,
and answer keys).")
    (license license:lppl1.3+)))

(define-public texlive-schulschriften
  (package
    (name "texlive-schulschriften")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/schulschriften/"
                                     "fonts/source/public/schulschriften/"
                                     "fonts/tfm/public/schulschriften/"
                                     "tex/latex/schulschriften/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14nbgqr213zfm1y50bh0ggs40zpi1lfjmc4yc5mprwf7q174zrbr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/schulschriften")
    (synopsis "German school scripts from Suetterlin to the present day")
    (description
     "This package provides the Metafont sources for the following school
fonts: Das Paket enthalt im wesentlichen die Metafont-Quellfiles fur die
folgenden Schulausgangsschriften: Suetterlinschrift, Deutsche Normalschrift,
Lateinische Ausgangsschrift, Schulausgangsschrift, and Vereinfachte
Ausgangsschrift.")
    (license license:lppl)))

(define-public texlive-scientific-thesis-cover
  (package
    (name "texlive-scientific-thesis-cover")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/scientific-thesis-cover/"
                                     "source/latex/scientific-thesis-cover/"
                                     "tex/latex/scientific-thesis-cover/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ny19pczzrrwb20sin1qn914hy1npwxkx573g3n5gm62kzl1vc4k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/scientific-thesis-cover")
    (synopsis "Provides cover page and affirmation at the end of a thesis")
    (description
     "Institutions require a cover page and an affirmation at the end of
a thesis.  This package provides both.")
    (license license:lppl1.3c)))

(define-public texlive-shobhika
  (package
    (name "texlive-shobhika")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/shobhika/"
                                     "fonts/opentype/public/shobhika/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a9l8gdn9ddz334dwfdn7vjgrq9jz6b41wph9sgchank4yj0sc64"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/shobhika")
    (synopsis "OpenType Devanagari font designed for scholars")
    (description
     "This package provides a Unicode compliant OpenType font with support for
Devanagari, Latin, and Cyrillic scripts.  It is available in two
weights--regular and bold.  The font is designed with over 1600 Devanagari
glyphs, including support for over 1100 conjunct consonants, as well as vedic
accents.  The Latin component of the font not only supports a wide range of
characters required for Roman transliteration of Sanskrit, but also provides
a subset of regularly used mathematical symbols for scholars working with
scientific and technical documents.")
    (license license:silofl1.1)))

(define-public texlive-schwalbe-chess
  (package
    (name "texlive-schwalbe-chess")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/schwalbe-chess/"
                                     "source/latex/schwalbe-chess/"
                                     "tex/latex/schwalbe-chess/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i68bl4hb7cagwwb4lyihvdnwgd0irgqp7344m5kmsdxy7z94fmr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/schwalbe-chess")
    (synopsis "Typeset the German chess magazine @emph{Die Schwalbe}")
    (description
     "The package is used to typeset the German chess magazine @emph{Die
Schwalbe}.  It is based on @code{chess-problem-diagrams}, which in its turn
has a dependency on the @code{bartel-chess-fonts}.")
    (license license:lppl1.2+)))

(define-public texlive-sciposter
  (package
    (name "texlive-sciposter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sciposter/"
                                     "tex/latex/sciposter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1d4bfzx08df0vx805rhmcsl9b79lqglqbzg0i8y4rk9z9qbaajrq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sciposter")
    (synopsis "Make posters of ISO A3 size and larger")
    (description
     "This collection of files contains LaTeX packages for posters of ISO A3
size and larger (ISO A0 is the default size).  American paper sizes and custom
paper are supported.  In particular, @file{sciposter.cls} defines a document
class which allows cutting and pasting most of an article to a poster without
any editing (save reducing the size).")
    (license license:lppl)))

(define-public texlive-sclang-prettifier
  (package
    (name "texlive-sclang-prettifier")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sclang-prettifier/"
                                     "source/latex/sclang-prettifier/"
                                     "tex/latex/sclang-prettifier/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pjqhwnz7lihl4yqxr0xgfdxnsj2p7k10vj5y7smjyv0p93lqvaw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sclang-prettifier")
    (synopsis "Pretty-printing SuperCollider source code")
    (description
     "Built on top of the @code{listings} package, the package allows
effortless pretty-printing of SuperCollider source code in documents typeset
with LaTeX and friends.")
    (license license:lppl1.3+)))

(define-public texlive-scrabble
  (package
    (name "texlive-scrabble")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/scrabble/" "tex/latex/scrabble/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zqqwxh4v7jmx7hamrhkix98b2my3j4kqfz5s1p5c5vq40dvfha3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/scrabble")
    (synopsis "Commands for Scrabble boards")
    (description
     "This package provides some commands (in English and in French) to work
with a Scrabble board.")
    (license license:lppl1.3c)))

(define-public texlive-scratchx
  (package
    (name "texlive-scratchx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/scratchx/" "tex/latex/scratchx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vy8599n8hxrvjc063p1dis0y7y221rlcwxxxryvibhz2kk7zwc2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/scratchx")
    (synopsis "Include Scratch programs in LaTeX documents")
    (description
     "This package can be used to include every kind of Scratch program in
LaTeX documents.  This may be particularly useful for Math Teachers and IT
specialists.")
    (license license:lppl1.3c)))

(define-public texlive-screenplay
  (package
    (name "texlive-screenplay")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/screenplay/"
                                     "source/latex/screenplay/"
                                     "tex/latex/screenplay/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16vw7ikxblzlmamz0d95d0zj6vzhdg75w0q645sfh75pj7v6b1v0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/screenplay")
    (synopsis "Class file to typeset screenplays")
    (description
     "The class implements the format recommended by the Academy of Motion
Picture Arts and Sciences.")
    (license license:gpl3+)))

(define-public texlive-screenplay-pkg
  (package
    (name "texlive-screenplay-pkg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/screenplay-pkg/"
                                     "tex/latex/screenplay-pkg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07xl6631yjjx56whl1vl4mzdcn8k63i624lspxiw18ppfrxdh3an"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/screenplay-pkg")
    (synopsis "Package version of the screenplay document class")
    (description
     "This package implements the tools of the @code{screenplay} document
class in the form of a package so that screenplay fragments can be included
within another document class.")
    (license license:lppl1.3+)))

(define-public texlive-scripture
  (package
    (name "texlive-scripture")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/scripture/"
                                     "source/latex/scripture/"
                                     "tex/latex/scripture/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d57w9av2ysji31sm8qafi29irhvz7ds22jjx6ckm00idqbxvn9i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/scripture")
    (synopsis "LaTeX style for typesetting @emph{Bible} quotations")
    (description
     "The @code{scripture} package provides a set of macros for typesetting
quotations from the @emph{Bible}.  It provides many features commonly seen in
bibles such as dropped text for chapter numbers, superscripts for verse
numbers, indented lines for poetry sections, narrow sections and hanging
paragraphs.  A reference for the quotation can optionally be added.")
    (license license:lppl1.3c)))

(define-public texlive-scrjrnl
  (package
    (name "texlive-scrjrnl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/scrjrnl/" "source/latex/scrjrnl/"
                                     "tex/latex/scrjrnl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10smy8cq2papzv63q5lsharxcn1l1ln97fhrd39wm2jf48967lbn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/scrjrnl")
    (synopsis "Typeset diaries or journals")
    (description
     "This package provides a class, based on @code{scrbook}, designed for
typesetting diaries, journals or devotionals.")
    (license license:lppl1.3+)))

(define-public texlive-sduthesis
  (package
    (name "texlive-sduthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sduthesis/"
                                     "source/latex/sduthesis/"
                                     "tex/latex/sduthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c9dmgjbxc0xyphi4hcb9yilmhh6hg0l2r4vkyjds3xgii7kwkn7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sduthesis")
    (synopsis "Thesis template of Shandong University")
    (description
     "This package provides a thesis template of Shandong University.")
    (license license:lppl1.3+)))

(define-public texlive-se2thesis
  (package
    (name "texlive-se2thesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/se2thesis/"
                                     "source/latex/se2thesis/"
                                     "tex/latex/se2thesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02hlq4pr0bn33x45azbajxyqp4bh3lb9bvr338pki04qdjja9ayg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/se2thesis")
    (synopsis
     "Thesis class for the Chair of Software Engineering II at the
University of Passau, Germany")
    (description
     "The @code{se2thesis} bundle provides a document class for writing
a theses with the Chair of Software Engineering II at the University of
Passau, Germany.  The class is based on KOMA-Script classes.  While the class
provides some basic settings, mostly regrading the type area, fonts, and the
title page, it still provides large degrees of freedom to its users.")
    (license license:lppl1.3c)))

(define-public texlive-serbian-apostrophe
  (package
    (name "texlive-serbian-apostrophe")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/serbian-apostrophe/"
                                     "tex/latex/serbian-apostrophe/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hkgm4q74kn172nr5whlwjq88sfqm66cvnsv7nidcqssybnn5891"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/serbian-apostrophe")
    (synopsis "Commands for Serbian words with apostrophes")
    (description
     "The package provides a collection of commands (whose names are Serbian
words) whose expansion is the Serbian word with appropriate apostrophes.")
    (license license:lppl1.3+)))

(define-public texlive-serbian-date-lat
  (package
    (name "texlive-serbian-date-lat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/serbian-date-lat/"
                                     "tex/latex/serbian-date-lat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m23r2i2dxw4xnxih94iyiwk4a5ggvn7wkqhp8ai5va5grp36kfk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/serbian-date-lat")
    (synopsis "Updated date typesetting for Serbian")
    (description
     "Babel defines dates for Serbian texts, in Latin script.  The style it
uses does not match current practices.  The present package defines
a @code{\\date} command that solves the problem.")
    (license license:gpl2)))

(define-public texlive-serbian-def-cyr
  (package
    (name "texlive-serbian-def-cyr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/serbian-def-cyr/"
                                     "tex/latex/serbian-def-cyr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "116sgzxvny1hbkfc5s8bxirk9zshyv8qdd2fdr8iwqjfd7lhx03i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/serbian-def-cyr")
    (synopsis "Serbian Cyrillic localization")
    (description
     "This package provides abstract, chapter, title, date etc, for Serbian
language in Cyrillic scripts in T2A encoding and CP1251 code pages.")
    (license license:lppl1.3+)))

(define-public texlive-serbian-lig
  (package
    (name "texlive-serbian-lig")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/serbian-lig/"
                                     "tex/latex/serbian-lig/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vq33mr8br7z7y5ayb5wmhy0ralgx6alb9kmhaahdx8a105dl81b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/serbian-lig")
    (synopsis "Control ligatures in Serbian")
    (description
     "The package suppresses @samp{fi} and @samp{fl} (and other ligatures) in
Serbian text written using Roman script.")
    (license license:lppl1.3+)))

(define-public texlive-sesamanuel
  (package
    (name "texlive-sesamanuel")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sesamanuel/"
                                     "source/latex/sesamanuel/"
                                     "tex/latex/sesamanuel/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jgr6syi26qbzdg37rq4d633klgb7s5bp1k3zvb3r538bawag8kc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sesamanuel")
    (synopsis "Class and package for sesamath books or paper")
    (description
     "The package contains a @code{sesamanuel} class which could be used to
compose a student's classroom book with LaTeX, and also
a @code{sesamanuelTIKZ} style to be used for TikZ pictures in the Sesamath
book.")
    (license license:lppl1.3+)))

(define-public texlive-seu-ml-assign
  (package
    (name "texlive-seu-ml-assign")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/seu-ml-assign/"
                                     "tex/latex/seu-ml-assign/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1w8dhp0kmgi9ywskq772ccj5n0kd7j55y15xwm3ss3jjdh4vzh8m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/seu-ml-assign")
    (synopsis "Southeast University Machine Learning Assignment template")
    (description
     "This is a template for the Southeast University Machine Learning
Assignment that can be easily adapted to other usages.  This template features
a colorful theme that makes it look elegant and attractive.")
    (license license:expat)))

(define-public texlive-seuthesis
  (package
    (name "texlive-seuthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/seuthesis/"
                                     "doc/latex/seuthesis/"
                                     "source/latex/seuthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gb1bql0llnms1c18xzp4g8j16zffinjjydiv4gsasyvxc0p8c5n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/seuthesis")
    (synopsis "LaTeX template for theses at Southeastern University")
    (description
     "This template is for theses at Southeastern University, Nanjing,
China.")
    (license license:gpl3)))

(define-public texlive-seuthesix
  (package
    (name "texlive-seuthesix")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/seuthesix/"
                                     "doc/latex/seuthesix/"
                                     "source/latex/seuthesix/"
                                     "tex/latex/seuthesix/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k87ib96pbihph399rc3kl1c3ncb4w4ljmwmvw880vvrxvz8mxjs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/seuthesix")
    (synopsis "LaTeX class for theses at Southeast University, Nanjing, China")
    (description
     "This project provides a LaTeX document class as well as a bibliography
style file for typesetting theses at the Southeast University, Nanjing, China.
It is based on the @code{seuthesis}.")
    (license license:gpl3)))

(define-public texlive-sfg
  (package
    (name "texlive-sfg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sfg/" "tex/latex/sfg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bckiy5ahbbv69fdam1k74n5f7ikhmc3d08hh9770w4aqs6k017b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sfg")
    (synopsis "Draw signal flow graphs")
    (description
     "This package defines some commands to draw signal flow graphs as used by
electrical and electronics engineers and graph theorists.")
    (license license:lppl)))

(define-public texlive-sgame
  (package
    (name "texlive-sgame")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sgame/" "tex/latex/sgame/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kzrimwmgwa3f61vawc1fq5vvgx4pxa2586wqhd4cf66ywdikn0v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sgame")
    (synopsis "LaTeX style for typesetting strategic games")
    (description
     "This package can be used to format strategic games.  For a 2x2 game,
for example, the input: @samp{\\begin@{game@}{2}{2} &$L$ &$M$\\\\ $T$ &$2,2$
&$2,0$\\\\ $B$ &$3,0$ &$0,9$ \\end@{game@}} produces output with (a) boxes
around the payoffs, (b) payoff columns of equal width, and (c) payoffs
vertically centered within the boxes.")
    (license license:lppl)))

(define-public texlive-shortmathj
  (package
    (name "texlive-shortmathj")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/shortmathj/"
                                     "tex/latex/shortmathj/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rkrskx2fay7h6naa995l46xjj8v3ffdd6kx6fq6fknr091yfp7q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/shortmathj")
    (synopsis "Automatically shortify titles of mathematical journals")
    (description
     "This small dummy package just contains a simple list of full and short
journal names as written in AMS standard:
@url{https://mathscinet.ams.org/msnhtml/serials.pdf}.")
    (license license:lppl1.3c)))

(define-public texlive-showtags
  (package
    (name "texlive-showtags")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/showtags/" "tex/latex/showtags/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0690p94mmlwhg06wzisa73w4445yg3ljy98haqf65acrcb09rl6j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/showtags")
    (synopsis "Print the tags of bibliography entries")
    (description
     "This package prints the tag right-aligned on each line of the
bibliography.")
    (license license:public-domain)))

(define-public texlive-shtthesis
  (package
    (name "texlive-shtthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/shtthesis/"
                                     "tex/latex/shtthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1l7vfqvfcgpndp5kmpdx4d9w89b83j5s2kwkr37hih9cp9l3n9vz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-alphalph
           texlive-biber
           texlive-biblatex
           texlive-biblatex-gb7714-2015
           texlive-booktabs
           texlive-caption
           texlive-colortbl
           texlive-ctex
           texlive-datetime
           texlive-enumitem
           texlive-fancyhdr
           texlive-fmtcount
           texlive-lastpage
           texlive-latexmk
           texlive-listings
           texlive-lua-alt-getopt
           texlive-lualatex-math
           texlive-mathtools
           texlive-ntheorem
           texlive-tex-gyre
           texlive-tocvsec2
           texlive-transparent
           texlive-undolabl
           texlive-unicode-math
           texlive-xits
           texlive-xstring))
    (home-page "https://ctan.org/pkg/shtthesis")
    (synopsis "Unofficial LaTeX thesis template for ShanghaiTech University")
    (description
     "This package, forked from @code{ucasthesis}, is an unofficial LaTeX
thesis template for ShanghaiTech University and satisfies all format
requirements of the school.")
    (license license:gpl3)))

(define-public texlive-shuffle
  (package
    (name "texlive-shuffle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/shuffle/"
                                     "fonts/source/public/shuffle/"
                                     "fonts/tfm/public/shuffle/"
                                     "source/latex/shuffle/" "tex/latex/shuffle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06ah481pi9bdbh1f9kpk66wa8yv9qbaif1b3l80415wcxijsxp24"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/shuffle")
    (synopsis "Symbol for the shuffle product")
    (description
     "The bundle provides a LaTeX package and a font (as Metafont source) for
the shuffle product which is used in some part of mathematics and physics.")
    (license license:public-domain)))

(define-public texlive-sides
  (package
    (name "texlive-sides")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sides/" "tex/latex/sides/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lffwhb6px6f09f8jk6r9kvfh49dl5n0461b261mk2sr6fgyxrfz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sides")
    (synopsis "LaTeX class for typesetting stage plays")
    (description
     "This is a LaTeX class for typesetting stage plays, based on the
@code{plari} class.  It has been updated and several formatting changes have
been made to it.")
    (license license:gpl3+)))

(define-public texlive-simplebnf
  (package
    (name "texlive-simplebnf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/simplebnf/"
                                     "tex/latex/simplebnf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0iwqhk0nk1bbc6sxx8ylywv8ag1g32ncck44cf7gan22nm1y3xb2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/simplebnf")
    (synopsis "Simple package to format Backus-Naur form (BNF)")
    (description
     "This package provides a simple way to format Backus-Naur form (BNF).
The included @code{bnfgrammar} environment parses BNF expressions (possibly
annotated), so users can write readable BNF expressions in their documents.")
    (license license:expat)))

(define-public texlive-simpleicons
  (package
    (name "texlive-simpleicons")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/simpleicons/"
                                     "fonts/enc/dvips/simpleicons/"
                                     "fonts/map/dvips/simpleicons/"
                                     "fonts/opentype/public/simpleicons/"
                                     "fonts/tfm/public/simpleicons/"
                                     "fonts/type1/public/simpleicons/"
                                     "tex/latex/simpleicons/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k4dlyh9fng6358sp4njy51rh0165qipwaj5vpjljv2i3xbi7rxk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/simpleicons")
    (synopsis "Simple Icons for LaTeX")
    (description
     "Similar to FontAwesome icons being provided on LaTeX by the
@code{fontawesome} package, this package aims to do the same with
@url{https://simpleicons.org/, Simple Icons}.")
    (license license:cc0)))

(define-public texlive-simpler-wick
  (package
    (name "texlive-simpler-wick")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/simpler-wick/"
                                     "tex/latex/simpler-wick/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0iicdx5n0ifjwifxk6i0242hkk388jz1mz01zpmznixjlhx780ni"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/simpler-wick")
    (synopsis "Simpler Wick contractions")
    (description
     "In every quantum field theory course, there will be a chapter about
Wick's theorem and how it can be used to convert a very large product of many
creation and annihilation operators into something more tractable and normal
ordered.  The contractions are denoted with a square bracket over the
operators which are being contracted, which used to be rather annoying to
typeset in LaTeX as the only other package available was simplewick, which is
rather unwieldy.  This package provides a simpler syntax for Wick
contractions.")
    (license license:lppl1.3+)))

(define-public texlive-simples-matrices
  (package
    (name "texlive-simples-matrices")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/simples-matrices/"
                                     "source/latex/simples-matrices/"
                                     "tex/latex/simples-matrices/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dvb989qf0ibgax0rjj49y827f9mzls0axdh28a6ar0r6dfvyjb3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/simples-matrices")
    (synopsis "Define matrices by given list of values")
    (description
     "This package provides macros to define and write matrices whose
coefficients are given row by row in a list of values separated by commas.")
    (license license:lppl1.3c)))

(define-public texlive-simplewick
  (package
    (name "texlive-simplewick")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/simplewick/"
                                     "source/latex/simplewick/"
                                     "tex/latex/simplewick/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13c5hk9f8cw48j08qb0i4vh649n9maq7kjs1cf0zfmkdiqi3b6iw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/simplewick")
    (synopsis "Simple Wick contractions")
    (description
     "The package provides a simple means of drawing Wick contractions above
and below expressions.")
    (license license:gpl3+)))

(define-public texlive-sistyle
  (package
    (name "texlive-sistyle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sistyle/" "source/latex/sistyle/"
                                     "tex/latex/sistyle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y53ijyzridia40a5wrpgff74n6shbdh7xbn1n56ciqfgjn4rdq4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sistyle")
    (synopsis "Package to typeset SI units, numbers and angles")
    (description
     "This package typesets SI units, numbers and angles according to the ISO
requirements.  Care is taken with font setup and requirements, and language
customisation is available.  Note that this package is (in principle)
superseded by @code{siunitx}; @code{sistyle} has maintenance-only support,
now.")
    (license license:lppl)))

(define-public texlive-siunits
  (package
    (name "texlive-siunits")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/siunits/" "source/latex/siunits/"
                                     "tex/latex/siunits/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lw9qjb1bnk357z20yri3lhcvxdnknb7yymb6hh5y8jb61pskns4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/siunits")
    (synopsis "International System of Units")
    (description
     "This package typesets physical units following the rules of the
International System of Units (SI).  Note that the package is now superseded
by @code{siunitx}; @code{siunits} has maintenance-only support, now.")
    (license license:lppl1.3+)))

(define-public texlive-skak
  (package
    (name "texlive-skak")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/skak/"
                                     "fonts/source/public/skak/"
                                     "fonts/tfm/public/skak/" "tex/latex/skak/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12fbzvyz40fnb9v5y80wkmv1fmvi7frbyv28k68lagdalm7mwp3b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/skak")
    (synopsis "Fonts and macros for typesetting chess games")
    (description
     "This package provides macros and fonts in Metafont format which can be
used to typeset chess games using PGN, and to show diagrams of the current
board in a document.  An Adobe Type 1 implementation of skak's fonts is
available as package @code{skaknew}; an alternative chess notational scheme is
available in package @code{texmate}, and a general mechanism for selecting
chess fonts is provided in @code{chessfss}.")
    (license license:lppl)))

(define-public texlive-skaknew
  (package
    (name "texlive-skaknew")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/skaknew/"
                                     "fonts/afm/public/skaknew/"
                                     "fonts/map/dvips/skaknew/"
                                     "fonts/opentype/public/skaknew/"
                                     "fonts/tfm/public/skaknew/"
                                     "fonts/type1/public/skaknew/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jpm36qb65jbsrhq1yqhwajqz3jg35wid0wlav9hk7q4hd58qi4r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/skaknew")
    (synopsis "The @code{skak} chess fonts redone in Adobe Type 1")
    (description
     "This package offers Adobe Type 1 versions of the fonts provided as
Metafont source by the @code{skak} bundle.")
    (license license:lppl)))

(define-public texlive-skmath
  (package
    (name "texlive-skmath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/skmath/" "source/latex/skmath/"
                                     "tex/latex/skmath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0si369hs7550v26mm3wcp69vnyr5ci2iqa6k2b8nv8wbjpcsb9jc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/skmath")
    (synopsis "Extensions to the maths command repertoire")
    (description
     "The package provides a selection of new maths commands and improved
re-definitions of existing commands.")
    (license license:lppl1.3+)))

(define-public texlive-skull
  (package
    (name "texlive-skull")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "fonts/source/public/skull/"
                                     "fonts/tfm/public/skull/"
                                     "source/fonts/skull/" "tex/latex/skull/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vnqi8c5f1a78naa9pvsl43748bm52i3qhjcv96bwcf59miih730"))))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/skull")
    (synopsis "Font to draw a skull")
    (description
     "The font (defined in Metafont) defines a single character, a black solid
skull.  A package is supplied to make this character available as a symbol in
maths mode.")
    (license license:gpl3+)))

(define-public texlive-smflatex
  (package
    (name "texlive-smflatex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/smflatex/" "doc/latex/smflatex/"
                                     "source/latex/smflatex/"
                                     "tex/latex/smflatex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "160bdav5rzx2hzaqxqcmlc841awr7ks1k0bmpj8kq3gzzz1pqnwj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/smflatex")
    (synopsis "Classes for @emph{Societe mathematique de France} publications")
    (description
     "The @emph{Societe mathematique de France} provides a set of classes,
packages and BibTeX styles that are used in its publications.  They are based
on AMS classes.  Besides a quite different design, their main features are:

@itemize

@item new environments for typesetting some information in two languages
@code{altabstract}, @code{alttitle}, @code{altkeywords});

@item if necessary, use of Babel (option @code{frenchb});

@item deactivation of some features of @code{frenchb}.

@end itemize")
    (license license:lppl1.3c)))

(define-public texlive-songbook
  (package
    (name "texlive-songbook")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/songbook/" "makeindex/songbook/"
                                     "source/latex/songbook/"
                                     "tex/latex/songbook/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ab4l130dyzaslqmy7vm71rszwszw11kqzkn0b5fb680kxvsyicf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/songbook")
    (synopsis "Package for typesetting song lyrics and chord books")
    (description
     "The package provides an all purpose songbook style.  Three types of
output may be created from a single input file: ``words and chords'' books for
the musicians to play from, ``words only'' songbooks for the congregation to
sing from, and overhead transparency masters for congregational use.

The package will also print a table of contents, an index sorted by title and
first line, and an index sorted by key, or by artist/composer.  The package
attempts to handle songs in multiple keys, as well as songs in multiple
languages.")
    (license license:lgpl2.1)))

(define-public texlive-songproj
  (package
    (name "texlive-songproj")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/songproj/"
                                     "source/latex/songproj/"
                                     "tex/latex/songproj/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h9v91fza4bj5fv157rdnbzy208a7l8j9w4mlj8gmvk4lxxkwzkk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/songproj")
    (synopsis "Generate Beamer slideshows with song lyrics")
    (description
     "This package, together with the Beamer class, is used to generate
slideshows with song lyrics.  This is typically used in religious services in
churches equipped with a projector, for which this package has been written,
but it can be useful for any type of singing assembly.  It provides
environments to describe a song in a natural way, and formatting it into
slides with overlays.  The package comes with an additional Python script that
can be used to convert plain-text song lyrics to the expected LaTeX markup.")
    (license license:bsd-3)))

(define-public texlive-songs
  (package
    (name "texlive-songs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/songs/" "source/latex/songs/"
                                     "tex/latex/songs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mgzkh6cvq3smwjlkvd1gnhb7m151fgiv7f4v3drjqlsjyg2qds6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/songs")
    (synopsis "Produce song books for church or fellowship")
    (description
     "The package provides a means of producing beautiful song books for
church or fellowship.  It offers:
@itemize
@item a very easy chord-entry syntax;
@item multiple modes (words-only; words+chords; slides; handouts);
@item measure bars;
@item guitar tablatures;
@item automatic transposition;
@item scripture quotations;
@item multiple indexes (sorted by title, author, important lyrics, or
scripture references);
@item and projector-style output generation, for interactive use.
@end itemize")
    (license license:gpl2)))

(define-public texlive-sort-by-letters
  (package
    (name "texlive-sort-by-letters")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/sort-by-letters/"
                                     "doc/bibtex/sort-by-letters/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19zsc6a97q5wjdgxcl7mjlbxzhj5xpfi4zi8ym1962l97dj4a96n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sort-by-letters")
    (synopsis "Bibliography styles for alphabetic sorting")
    (description
     "This bundle contains several bibliography styles for separating
a document's references by the first letter of the first author/editor in the
bibliography entry.  The styles are adapted from standard ones or from
@code{natbib} ones.")
    (license license:knuth)))

(define-public texlive-soton
  (package
    (name "texlive-soton")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/soton/" "tex/latex/soton/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ib4i98x14g5bl4l5bd9ciw6aay5n6fihkyzfls52l5y9vpyglix"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/soton")
    (synopsis "University of Southampton-compliant slides")
    (description
     "The bundle contains two packages: @code{soton-palette} which defines
colour-ways, and @code{soton-beamer}, which uses the colours to produce
compliant presentations.")
    (license license:lppl)))

(define-public texlive-soup
  (package
    (name "texlive-soup")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/soup/" "source/latex/soup/"
                                     "tex/latex/soup/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04lpc3nn45i66cwnjn0sycdpfaynzkb19djyfi8ca3ppb1sn79z6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/soup")
    (synopsis "Generate alphabet soup puzzles")
    (description
     "This package generates alphabet soup puzzles (aka word search puzzles),
and variations using numbers or other symbols.  It provides macros to generate
an alphabet soup style puzzle (also known as word search puzzles or
find-the-word puzzles).  It also allows creating number soup and soups with
custom symbol sets.")
    (license license:lppl1.3+)))

(define-public texlive-spalign
  (package
    (name "texlive-spalign")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/spalign/" "source/latex/spalign/"
                                     "tex/latex/spalign/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1paxgykj07y8l5gbcz2823bn80s6y81zabqx67k0j0513ag75grf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/spalign")
    (synopsis
     "Typeset matrices and arrays with spaces and semicolons as delimiters")
    (description
     "The purpose of this package is to decrease the number of keystrokes
needed to typeset small amounts of aligned material (matrices, arrays, etc.).
It provides a facility for typing alignment environments and macros with
spaces as the alignment delimiter and semicolons (by default) as the
end-of-row indicator.  This package also contains utility macros for
typesetting augmented matrices, vectors, arrays, systems of equations, and
more, and is easily extendable to other situations that use alignments.
People who have to typeset a large number of matrices (like linear algebra
teachers) should find this package to be a real time saver.")
    (license license:lppl1.3+)))

(define-public texlive-spbmark
  (package
    (name "texlive-spbmark")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/spbmark/" "tex/latex/spbmark/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yyrl3367zaibn20pcxry2pcmhjh46ny1qaf7nc2syqhsyv12hnd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/spbmark")
    (synopsis "Customize superscripts and subscripts")
    (description
     "This package provides three commands @code{\\super}, @code{\\sub} and
@code{\\supersub} to improve the layout of superscripts and subscripts which
can be adjusted with respect to relative position and format, and can be used
in text and math mode.")
    (license license:cc-by4.0)))

(define-public texlive-spectral
  (package
    (name "texlive-spectral")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/spectral/"
                                     "fonts/enc/dvips/spectral/"
                                     "fonts/map/dvips/spectral/"
                                     "fonts/tfm/production/spectral/"
                                     "fonts/truetype/production/spectral/"
                                     "fonts/type1/production/spectral/"
                                     "fonts/vf/production/spectral/"
                                     "tex/latex/spectral/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i5ijzzk18m65ibf8igll22992wgfxrgr4qpxki0dpynfm0wiwjj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/spectral")
    (synopsis "Spectral fonts with LaTeX support")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the Spectral family of fonts, designed by Jean-Baptiste Levee.  Spectral is
a new and versatile serif face available in seven weights of roman and italic,
with small caps.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-sphdthesis
  (package
    (name "texlive-sphdthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sphdthesis/"
                                     "tex/latex/sphdthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05ncll9vd2yh15vp6gqzidrp011d1i2hsmlzfrfz954f9449ydx4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sphdthesis")
    (synopsis "LaTeX template for writing PhD thesis")
    (description
     "The package provides a LaTeX document class for writing a PhD thesis.
By default, the class adheres to the @acronym{NUS, National University of
Singapore} Guidelines on Format of Research Thesis Submitted For Examination.
However, modifying the class for conformation to a different guideline should
not be difficult.")
    (license license:public-domain)))

(define-public texlive-spie
  (package
    (name "texlive-spie")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/spie/" "bibtex/bst/spie/"
                                     "doc/latex/spie/" "tex/latex/spie/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z4nbm2w96lvwfcj8ghnzarv5f5klriyr3b6jjnb34wd3kw52xg8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/spie")
    (synopsis "Support for formatting SPIE Proceedings manuscripts")
    (description
     "This package provides support for formatting SPIE Proceedings
manuscripts.  A class and a BibTeX style are provided.")
    (license license:lppl)))

(define-public texlive-splitbib
  (package
    (name "texlive-splitbib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/splitbib/"
                                     "source/latex/splitbib/"
                                     "tex/latex/splitbib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18jhdrj9zfnqr4wyazxsqng6a88fwgkw2ka03qskjps8s9pc2fw7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/splitbib")
    (synopsis "Split and reorder your bibliography")
    (description
     "This package enables you to split a bibliography into several categories
and subcategories.  It does not depend on BibTeX: any bibliography may be
split and reordered.")
    (license license:lppl)))

(define-public texlive-sr-vorl
  (package
    (name "texlive-sr-vorl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sr-vorl/" "source/latex/sr-vorl/"
                                     "tex/latex/sr-vorl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1izgzwg6a9i93zfxi0qvfrdgza3q8z5b4nhlhgq072glmdqzymf0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sr-vorl")
    (synopsis "Class for Springer books")
    (description
     "This package provides a LaTeX class and templates for books to be
published at Springer Gabler Research, Springer Vieweg Research, Springer
Spektrum Research, Springer VS Research, or Springer VS Forschung.  It may be
used to produce monographs in different formats and several-authors-books
fitting the conditions of the aforementioned publishers.")
    (license license:lppl1.3c)))

(define-public texlive-srbtiks
  (package
    (name "texlive-srbtiks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/srbtiks/"
                                     "fonts/enc/dvips/srbtiks/"
                                     "fonts/map/dvips/srbtiks/"
                                     "fonts/tfm/public/srbtiks/"
                                     "fonts/vf/public/srbtiks/"
                                     "tex/latex/srbtiks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12b4xigicn259ghi5kc6nyk0bqr81kdiqfg0hql9fpwrldvbj4k6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/srbtiks")
    (synopsis "Font STIX2 for Serbian and Macedonian")
    (description
     "The @code{srbtiks} package is the extension of the @code{stix2-type1}
package that enables usage of the STIX2 font in LaTeX for the Serbian and
Macedonian languages.")
    (license (list license:silofl1.1 license:lppl1.3+))))

(define-public texlive-srdp-mathematik
  (package
    (name "texlive-srdp-mathematik")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/srdp-mathematik/"
                                     "tex/latex/srdp-mathematik/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wxgjfb98qjbbp0l87ajly9b3wp3lp4caw9c3f3zw8798midar15"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/srdp-mathematik")
    (synopsis "Typeset Austrian SRDP in mathematics")
    (description
     "This package provides basic commands for the defined formats of the
Austrian @acronym{sRDP, Standardisierte Reife- und Diplomprufung} in
mathematics.  Furthermore, it includes ways to implement answers in the
@file{.tex} file which can optionally be displayed in the PDF file, and it
offers a way to vary the answers in order to create different groups (e.g.,
for tests) easily.")
    (license license:lppl1.3c)))

(define-public texlive-stage
  (package
    (name "texlive-stage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/stage/" "source/latex/stage/"
                                     "tex/latex/stage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0789mddzsadiw9fiasjzjdma0f9li8gddf8m9wy5jblnsl2asf5p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/stage")
    (synopsis "LaTeX class for stage plays")
    (description
     "@file{stage.cls} is a LaTeX class for creating plays of any length in
a standard manuscript format for production and submission.")
    (license license:lppl1.3+)))

(define-public texlive-stanli
  (package
    (name "texlive-stanli")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/stanli/" "tex/latex/stanli/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kspb85303z642qj3c9b2q3g41p612vshn37j7npf3if2gcyyxbq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/stanli")
    (synopsis "TikZ Library for Structural Analysis")
    (description
     "STANLI is a STructural ANalysis LIbrary based on PGF/TikZ.  Creating new
assignments and tests, at university, is usually a very time-consuming task,
especially when this includes drawing graphics.  In the field of structural
engineering, those small structures are a key part for teaching.  This package
permits creating such 2D and 3D structures in a very fast and simple way.")
    (license (list license:gpl3+ license:lppl1.3+))))

(define-public texlive-starfont
  (package
    (name "texlive-starfont")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/starfont/"
                                     "fonts/afm/public/starfont/"
                                     "fonts/map/dvips/starfont/"
                                     "fonts/tfm/public/starfont/"
                                     "fonts/type1/public/starfont/"
                                     "tex/latex/starfont/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c2vnd5mycr6mnhwxz9gkjvfxwq0l91h2lhvpf49fjlfc3hdnd3l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/starfont")
    (synopsis "StarFont Sans astrological font")
    (description
     "The package contains StarFontSans and StarFontSerif, two astrological
fonts designed by Anthony I.P. Owen, and the appropriate macros to use them
with TeX and LaTeX.  The fonts are supplied both in the original TrueType
Format and in Adobe Type 1 format.")
    (license license:public-domain)))

(define-public texlive-startex
  (package
    (name "texlive-startex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/otherformats/startex/"
                                     "makeindex/startex/"
                                     "source/startex/startex/" "tex/startex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06hyz1bwzvabavkl6j9588skjwx8hc5dmiv8z9n7gr1w9aa9zm7x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/startex")
    (synopsis "XML-inspired format for student use")
    (description
     "This package provides a TeX format designed to help students write short
reports and essays.  It provides the user with a suitable set of commands for
such a task.  It is also more robust than plain TeX and LaTeX.")
    (license license:public-domain)))

(define-public texlive-statex
  (package
    (name "texlive-statex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/statex/" "tex/latex/statex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02zd9877kryv749lyxlswdkdfbgc4i1d2vvbkaplxq81njxipxry"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/statex")
    (synopsis "Statistics style")
    (description
     "This package provides a package defining many macros for items of
significance in statistical presentations.  An updated, but incompatible,
version of the package is available: @code{statex2}.")
    (license license:lppl)))

(define-public texlive-statex2
  (package
    (name "texlive-statex2")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/statex2/" "tex/latex/statex2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g0ymd0l0cvqn61vjbncrg8cr8wkaw7bywnk85c82rsl0wsc89xk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/statex2")
    (synopsis "Statistics style")
    (description
     "The package defines many macros for items of significance in statistical
presentations.  It represents a syntax-incompatible upgrade of
@code{statex}.")
    (license license:lppl)))

(define-public texlive-statistics
  (package
    (name "texlive-statistics")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/statistics/"
                                     "source/latex/statistics/"
                                     "tex/latex/statistics/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cdajj4fclsqcjfc46n82vi8d276qxqklpvdn4gm36dgckrrxaxf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/statistics")
    (synopsis "Compute and typeset statistics tables and graphics")
    (description
     "The @code{statistics} package can compute and typeset statistics like frequency tables,
cumulative distribution functions (increasing or decreasing, in frequency or
absolute count domain), from the counts of individual values, or ranges, or
even the raw value list with repetitions.  It can also compute and draw a bar
diagram in case of individual values, or, when the data repartition is known
from ranges, an histogram or the continuous cumulative distribution function.
You can ask @code{statistics} to display no result, selective results or all
of them.  Similarly @code{statistics} can draw only some parts of the
graphs.")
    (license license:gpl3+)))

(define-public texlive-statistik
  (package
    (name "texlive-statistik")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/statistik/"
                                     "source/latex/statistik/"
                                     "tex/latex/statistik/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1j1g9hidkq02v3f4alafi53qny3diazpfxb1w936dcy4wi5l584x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/statistik")
    (synopsis "Store statistics of a document")
    (description
     "The package counts the numbers of pages per chapter, and stores the
results in a separate file; the format of the file is selectable.")
    (license license:gpl3+)))

(define-public texlive-statmath
  (package
    (name "texlive-statmath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/statmath/"
                                     "source/latex/statmath/"
                                     "tex/latex/statmath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zqln39cambscblrqck9lw4krpqbhlasz58zvx84h8pmapwsk13g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/statmath")
    (synopsis "Simple use of statistical notation")
    (description
     "The package offers a number of notational conventions to be used in
applied and theoretical papers in statistics which are currently lacking in
the popular @code{amsmath} package.")
    (license license:lppl1.3+)))

(define-public texlive-staves
  (package
    (name "texlive-staves")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/staves/"
                                     "fonts/map/dvips/staves/"
                                     "fonts/tfm/public/staves/"
                                     "fonts/type1/public/staves/"
                                     "source/latex/staves/"
                                     "tex/latex/staves/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wa4zx4c439q6ahs1fwa55dcxzrx382ksrj0bv1jnck6j3iw2dlc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/staves")
    (synopsis "Typeset Icelandic staves and runic letters")
    (description
     "This package contains all the necessary tools to typeset the magical
Icelandic staves plus the runic letters used in Iceland.  Included are a font
in Adobe Type 1 format and LaTeX support.")
    (license license:lppl)))

(define-public texlive-steinmetz
  (package
    (name "texlive-steinmetz")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/steinmetz/"
                                     "source/latex/steinmetz/"
                                     "tex/latex/steinmetz/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x7bs22q1p07njvsg7npm5wg25jx547nv7v98wvcfmlcr4zrvbh1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/steinmetz")
    (synopsis "Print Steinmetz notation")
    (description
     "The @code{steinmetz} package provides a command for typesetting complex
numbers in the Steinmetz notation used in electrotechnics.")
    (license license:lppl)))

(define-public texlive-stellenbosch
  (package
    (name "texlive-stellenbosch")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/stellenbosch/"
                                     "doc/latex/stellenbosch/"
                                     "source/latex/stellenbosch/"
                                     "tex/latex/stellenbosch/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yqlwlwlszrwg8bihkfxh77b3rkf8yx978vwb4a3xjmb5yyyx3q6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/stellenbosch")
    (synopsis "Stellenbosch thesis bundle")
    (description
     "The @code{usthesis} class and style files are provided to typeset
reports, theses and dissertations that conform to the requirements of the
Engineering Faculty of the University of Stellenbosch.  The class file
@file{usthesis.cls} is based on the standard LaTeX @code{book} class, while
@file{usthesis.sty} is a style file to be loaded on top of the very powerful
@code{memoir} class.

Usthesis is primarily concerned with the formatting of the front matter such
as the title page, abstract, etc., and a decent page layout on A4 paper.  It
also works together with the Babel package to provide language options to
typeset documents in Afrikaans or in English.  Additional packages are
provided for bibliographic matter, note title pages, lists of symbols, as well
as various graphic files for logos.")
    (license license:lppl)))

(define-public texlive-step
  (package
    (name "texlive-step")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/step/"
                                     "fonts/enc/dvips/step/"
                                     "fonts/map/dvips/step/"
                                     "fonts/opentype/public/step/"
                                     "fonts/tfm/public/step/"
                                     "fonts/type1/public/step/"
                                     "fonts/vf/public/step/"
                                     "tex/latex/step/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p2fzbsxrq98hlykw23j26xi936vnnd95qggjcn5a4jjwfrzbx1g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/step")
    (synopsis "Times-like font")
    (description
     "The STEP fonts are a Times-like (i.e., Times replacement) font family,
implementing a design first created for The Times of London in 1932.  These
fonts are meant to be compatible in design with Adobe's digitization of
Linotype Times, commonly used in publishing.  Type 1 support is provided for
legacy TeX engines.")
    (license license:silofl1.1)))

(define-public texlive-stepgreek
  (package
    (name "texlive-stepgreek")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/stepgreek/"
                                     "fonts/enc/dvips/stepgreek/"
                                     "fonts/map/dvips/stepgreek/"
                                     "fonts/tfm/public/stepgreek/"
                                     "fonts/type1/public/stepgreek/"
                                     "fonts/vf/public/stepgreek/"
                                     "tex/latex/stepgreek/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00yh96gdk854yg61hgl7n938lyw11v9kdmwl7klriyq7wjy0zcaw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/stepgreek")
    (synopsis "Times/Elsevier-style Greek font")
    (description
     "This is a beta version of the STEP Greek font.  Only a regular face is
available at present, though there are plans to add italic, bold and bold
italic in the future.  The font only supports LGR in TeX and is meant to serve
as a Greek complement to a Times-like font such as STEP.  The font supports
polytonic Greek.")
    (license license:silofl1.1)))

(define-public texlive-stickstoo
  (package
    (name "texlive-stickstoo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/stickstoo/"
                                     "fonts/afm/public/stickstoo/"
                                     "fonts/enc/dvips/stickstoo/"
                                     "fonts/map/dvips/stickstoo/"
                                     "fonts/tfm/public/stickstoo/"
                                     "fonts/type1/public/stickstoo/"
                                     "fonts/vf/public/stickstoo/"
                                     "tex/latex/stickstoo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15hmplphlg5vc3a966x379bkn74vb39pv73w0py65nd9zbb7z27i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/stickstoo")
    (synopsis "Reworking of STIX2")
    (description
     "SticksToo is a reworking of the STIX2 fonts with support files focussing
on enhancements of support for LaTeX users wishing to be able to access more
of its features.  A companion addition to the @code{newtxmath} package
provides a matching math package using STIX2 letters (Roman and Greek) with
@code{newtxmath} symbols.")
    (license (list license:silofl1.1 license:lppl1.3+))))

(define-public texlive-stix
  (package
    (name "texlive-stix")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/stix/"
                                     "fonts/enc/dvips/stix/"
                                     "fonts/map/dvips/stix/"
                                     "fonts/opentype/public/stix/"
                                     "fonts/tfm/public/stix/"
                                     "fonts/type1/public/stix/"
                                     "fonts/vf/public/stix/"
                                     "source/fonts/stix/"
                                     "tex/latex/stix/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ixxglx4azdnppiqhlkgyahj9a67zamljzv98n6hycp7y6jbd1x0"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments
     (list #:tex-format "latex"
           ;; FIXME: I cannot build this package from source.
           #:phases #~(modify-phases %standard-phases (delete 'build))))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-accents
                  texlive-caption
                  texlive-enumitem
                  texlive-fonttable
                  texlive-hypdoc))))
    (home-page "https://ctan.org/pkg/stix")
    (synopsis "OpenType Unicode maths fonts")
    (description
     "The STIX fonts are a suite of unicode OpenType fonts containing
a complete set of mathematical glyphs.  This package is considered obsolete.
See @code{stix2-otf} and @code{stix2-type1} instead.")
    (license (list license:silofl1.1 license:lppl1.3+))))

(define-public texlive-stix2-type1
  (package
    (name "texlive-stix2-type1")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/stix2-type1/"
                                     "fonts/enc/dvips/stix2-type1/"
                                     "fonts/map/dvips/stix2-type1/"
                                     "fonts/tfm/public/stix2-type1/"
                                     "fonts/type1/public/stix2-type1/"
                                     "source/fonts/stix2-type1/"
                                     "tex/latex/stix2-type1/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jsnyxbi5054fw0j5jw9cisj9xm8i8gf1f48m9l77bkybq0qviwp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/stix2-type1")
    (synopsis "Type1 versions of the STIX Two OpenType fonts")
    (description
     "The @code{stix2} package provides minimal support for using the STIX Two
fonts with versions of TeX that are limited to TFM files, Type 1 PostScript
fonts, and 8-bit font encodings.

Some glyphs that are traditionally available in TeX math fonts are not yet
available in the STIX Two OpenType fonts.  In such cases, we have chosen to
omit them from the @code{stix2} package rather than create incompatibilities
between the OpenType and Type 1 versions.")
    (license (list license:silofl1.1 license:lppl1.3+))))

(define-public texlive-structmech
  (package
    (name "texlive-structmech")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/structmech/"
                                     "tex/latex/structmech/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nglxb3qa0q22k598y8p16fzwpi4x9pkhlqs1bvbk3zp9nnvfvq4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/structmech")
    (synopsis "TikZ command set for structural mechanics drawings")
    (description
     "This package provides a collection of TikZ commands that allow users to
draw basic elements in material/structural mechanics.  It is thus possible to
draw member forces, nodal forces/displacements, various boundary conditions,
internal force distributions, etc.")
    (license license:gpl3+)))

(define-public texlive-struktex
  (package
    (name "texlive-struktex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/struktex/"
                                     "source/latex/struktex/"
                                     "tex/latex/struktex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05bvzxrqwiw9jcq1dvvwf6ss1207qygg3iqdlfd0yjv0y7rdjvvf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/struktex")
    (synopsis "Draw Nassi-Shneiderman charts")
    (description
     "Nassi-Shneiderman charts are a well known tool to describe an algorithm
in a graphical way.  The package offers some macros for generating those
charts in a LaTeX document.  The package provides the most important elements
of a Nassi-Shneiderman charts, including processing blocks, loops, mapping
conventions for alternatives, etc.  The charts are drawn using the
@code{picture} environment (using @code{pict2e} for preference).")
    (license license:lppl1.2+)))

(define-public texlive-subfiles
  (package
    (name "texlive-subfiles")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/subfiles/"
                                     "source/latex/subfiles/"
                                     "tex/latex/subfiles/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lwbpf852qi0gmibwgd3i63mlwi2p8zb1ps0fis21r69hnisym8j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-import))
    (home-page "https://ctan.org/pkg/subfiles")
    (synopsis "Individual typesetting of sub-files of a main document")
    (description
     "Using this package one can handle multi-file projects more comfortably,
making it possible to both process the subsidiary files by themselves and to
process the main file that includes them, without making any changes to
either.")
    (license license:lppl1.3+)))

(define-public texlive-substances
  (package
    (name "texlive-substances")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/substances/"
                                     "tex/latex/substances/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lqg0bx34f7f9sva1lvvqdb7nfdaaf6lh23j0nwdy70z2g3kgkxp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/substances")
    (synopsis "Database of chemicals")
    (description
     "The package provides the means to create a database-like file that
contains data of various chemicals.  These data may be retrieved in the
document; an index of the chemicals mentioned in the document can be
created.")
    (license license:lppl1.3+)))

(define-public texlive-subsupscripts
  (package
    (name "texlive-subsupscripts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/subsupscripts/"
                                     "tex/latex/subsupscripts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1f9yn6ic1yn4nl2s8ngbrrl1xflb4g2j0iw77563j5n7prgy1wrf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/subsupscripts")
    (synopsis "Range of sub- and superscript commands")
    (description
     "The package provides a comprehensive and flexible set of commands for
combinations of left and right sub- and superscripts.")
    (license license:lppl)))

(define-public texlive-subtext
  (package
    (name "texlive-subtext")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/subtext/" "tex/latex/subtext/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wpb4087acwsgnsc1zw6ivqaqgdsq90zm63bgmrk77ban54qsqv0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/subtext")
    (synopsis "Easy text-style subscripts in math mode")
    (description
     "This LaTeX package gives easy access to text-style subscripts in math
mode by providing an optional argument to @samp{_}.  This is implemented by
using the @code{\\text@{@}} command from the @code{amstext} package.")
    (license license:gpl3)))

(define-public texlive-sudoku
  (package
    (name "texlive-sudoku")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sudoku/" "source/latex/sudoku/"
                                     "tex/latex/sudoku/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14g1kkxinp9l57yvdpbdx4wclgka71gilcbxl1dc6sdj4cmw7mbz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sudoku")
    (synopsis "Create sudoku grids")
    (description
     "The @code{sudoku} package provides an environment for typesetting sudoku
grids.")
    (license license:lppl)))

(define-public texlive-sudokubundle
  (package
    (name "texlive-sudokubundle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sudokubundle/"
                                     "source/latex/sudokubundle/"
                                     "tex/latex/sudokubundle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1swsx8r0chgxv8h27syj4h5cf7lnj6mxvwhhzixbkjg6scrvd8kw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sudokubundle")
    (synopsis "Set of sudoku-related packages")
    (description
     "The bundle provides three packages: @code{printsudoku}, which provides
a command @code{\\sudoku} whose argument is the name of a file containing
a puzzle specification; @code{solvesudoku}, which attempts to find a solution
to the puzzle in the file named in the argument; and @code{createsudoku},
which uses the @code{random} package to generate a puzzle according to a bunch
of parameters that the user sets via macros.

The bundle comes with a set of ready-prepared puzzle files.")
    (license license:lppl)))

(define-public texlive-suftesi
  (package
    (name "texlive-suftesi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/suftesi/" "source/latex/suftesi/"
                                     "tex/latex/suftesi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07p2fv265g78zbfrq4j33ryz1z1b13g2rvln646w2g5md1zwm2hb"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments
     (list #:tex-format "lualatex"
           #:phases #~(modify-phases %standard-phases
                        (add-after 'unpack 'support-greek-input
                          (lambda _
                            (substitute* "source/latex/suftesi/suftesi.dtx"
                              (("\\\\usepackage\\[T1\\]\\{fontenc\\}")
                               "\\usepackage[LGR, T1]{fontenc}")))))))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-babel-greek
                  texlive-biblatex
                  texlive-biblatex-philosophy
                  texlive-booktabs
                  texlive-cbfonts
                  texlive-cbfonts-fd
                  texlive-cochineal
                  texlive-csquotes
                  texlive-etoolbox
                  texlive-fontaxes
                  texlive-fontsize
                  texlive-fontspec
                  texlive-greek-fontenc
                  texlive-guitlogo
                  texlive-hologo
                  texlive-hypdoc
                  texlive-inconsolata
                  texlive-libertine
                  texlive-listings
                  texlive-ltxdockit
                  texlive-manfnt
                  texlive-manfnt-font
                  texlive-mathalpha
                  texlive-mdframed
                  texlive-microtype
                  texlive-multirow
                  texlive-needspace
                  texlive-newtx
                  texlive-parskip
                  texlive-pgf
                  texlive-realscripts
                  texlive-sectsty
                  texlive-siunitx
                  texlive-txfonts
                  texlive-upquote
                  texlive-xcolor
                  texlive-xkeyval
                  texlive-xstring
                  texlive-zref))))
    (home-page "https://ctan.org/pkg/suftesi")
    (synopsis "Document class for typesetting theses, books and articles")
    (description
     "The class can be used to typeset any kind of book (originally designed
for use in the humanities).")
    (license license:lppl1.3+)))

(define-public texlive-sugconf
  (package
    (name "texlive-sugconf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sugconf/" "tex/latex/sugconf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1v9fp0dpbk4g9aab8jvwhfzh71w4276awi8lyf2pgk66d5qhfxsb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sugconf")
    (synopsis "SAS(R) user group conference proceedings document class")
    (description
     "The class may be used to typeset articles to be published in the
proceedings of SAS(R) User group conferences and workshops.  The layout
produced by the class is based on that published by SAS Institute (2021).")
    (license license:lppl)))

(define-public texlive-superiors
  (package
    (name "texlive-superiors")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/superiors/"
                                     "tex/latex/superiors/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sm3kk2j66lbr5amk4i4sp6i6yad5g1nwhg0yq1r3kxiy2mrl1vk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/superiors")
    (synopsis "Attach superior figures to a font family")
    (description
     "The package allows the attachment of an arbitrary superior figures font
to a font family that lacks one. (Superior figures are commonly used as
footnote markers.)  Two superior figures fonts are provided --- one matching
Times, the other matching Libertine.")
    (license license:lppl)))

(define-public texlive-susy
  (package
    (name "texlive-susy")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/susy/" "tex/latex/susy/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17v3cmkrpkdxssa50vzdasp885waf9jpg8sfjyw1dcj9z7xfz91g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/susy")
    (synopsis "Macros for SuperSymmetry-related work")
    (description "The package macros for SuperSymmetry-related work, such as
abbreviations of longer expressions.")
    (license license:lppl)))

(define-public texlive-svg
  (package
    (name "texlive-svg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/svg/" "source/latex/svg/"
                                     "tex/latex/svg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yizgrjn6l9j1cf8mvkjz0zni7bzmajszc1y8q80xc723nwnbq7q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/svg")
    (synopsis "Include and extract SVG pictures in LaTeX documents")
    (description
     "This bundle contains the two packages @code{svg} and @code{svg-extract}.

The @code{svg} package is intended for the automated integration of SVG
graphics into LaTeX documents.  Therefore the capabilities provided by
Inkscape --- or more precisely its command line tool --- are used to export
the text within an SVG graphic to a separate file, which is then rendered by
LaTeX.  For this purpose the two commands @code{\\includesvg} and
@code{\\includeinkscape} are provided which are very similar to the
@code{\\includegraphics} command of the @code{graphicx} package.

In addition, the package @code{svg-extract} allows the extraction of these
graphics into independent files in different graphic formats, exactly as it is
rendered within the LaTeX document, using either ImageMagick or Ghostscript.")
    (license license:lppl1.3c)))

(define-public texlive-svrsymbols
  (package
    (name "texlive-svrsymbols")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/svrsymbols/"
                                     "fonts/afm/public/svrsymbols/"
                                     "fonts/map/dvips/svrsymbols/"
                                     "fonts/opentype/public/svrsymbols/"
                                     "fonts/tfm/public/svrsymbols/"
                                     "fonts/type1/public/svrsymbols/"
                                     "source/fonts/svrsymbols/"
                                     "tex/latex/svrsymbols/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l1pj97pqlh9mq3m3zswnxm2vws916yjlx0pq1gr3bc23kwvhhl3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/svrsymbols")
    (synopsis "Font with symbols for use in physics texts")
    (description
     "The @code{svrsymbols} package is a LaTeX interface to the SVRsymbols
font.  The glyphs of this font are ideograms that have been designed for use
in physics texts.")
    (license license:lppl1.3c)))

(define-public texlive-syllogism
  (package
    (name "texlive-syllogism")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/syllogism/"
                                     "tex/latex/syllogism/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ns8bv5qyzvcq59x7cjkncc9wlalcdhhnxs0r4s897qrrbz4cq43"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/syllogism")
    (synopsis "Typeset syllogisms in LaTeX")
    (description
     "The package provides a simple, configurable, way for neatly typesetting
syllogisms and syllogistic-like arguments, composed of two premises and
a conclusion.")
    (license license:lppl)))

(define-public texlive-symbats3
  (package
    (name "texlive-symbats3")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/symbats3/" "tex/latex/symbats3/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xr5m2irkbv376im1m5vms6gcpq3asj03dpfck2x1ccrywn4k3w2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/symbats3")
    (synopsis "Macros to use the Symbats3 dingbats fonts")
    (description
     "This package makes available for LaTeX the glyphs in Feorag's OpenType
Symbats3 neopagan dingbats fonts.")
    (license license:lppl1.3c)))

(define-public texlive-sympytexpackage
  (package
    (name "texlive-sympytexpackage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sympytexpackage/"
                                     "scripts/sympytexpackage/"
                                     "source/latex/sympytexpackage/"
                                     "tex/latex/sympytexpackage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ph8pldk2f477dm79vf5vrismfy8w1p2m455qfjqm7p704jm1pr3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sympytex")
    (synopsis "Include symbolic computation (using @code{sympy}) in documents")
    (description
     "The bundle supports inclusion of symbolic-python (@code{sympy})
expressions, as well as graphical output from the @code{sympy} plotting
module (or from Matplotlib).")
    (license license:gpl2)))

(define-public texlive-synproof
  (package
    (name "texlive-synproof")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/synproof/" "tex/latex/synproof/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02r0ld3lcxvjhij4lffx9kljmbv6fvz10x59bjvinqfbmmfmm58m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/synproof")
    (synopsis "Easy drawing of syntactic proofs")
    (description
     "The package provides a set of macros based on PSTricks that will enable
you to draw syntactic proofs easily (inspired by the Gamut books).  Very few
commands are needed, however fine tuning of the various
parameters (dimensions) can still be achieved through key=value pairs.")
    (license license:lppl)))

(define-public texlive-t-angles
  (package
    (name "texlive-t-angles")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/t-angles/" "tex/latex/t-angles/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jp16zd64c5xdsxfycdyvlwwss4k46y7nfd2dn6ybshx34kcv0qa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/t-angles")
    (synopsis
     "Draw tangles, trees, Hopf algebra operations and other pictures")
    (description
     "This package provides a LaTeX2e package for drawing tangles, trees, Hopf
algebra operations and other pictures.  It is based on emTeX or TPIC
@code{\\specials}.  Therefore, it can be used with the most popular drivers,
including emTeX drivers, dviwin, xdvi and dvips, and (using some code from
ConTeXt) it may also be used with pdfLaTeX.")
    (license license:gpl3+)))

(define-public texlive-t2
  (package
    (name "texlive-t2")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/t2/" "fonts/enc/t2/"
                                     "tex/generic/t2/cyrfinst/" "tex/latex/t2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "058j3bpv03d9nb0nxal1vjpliqqibv6hsjl1qlbgnndm95xd5n1a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/t2")
    (synopsis "Support for using T2 encoding")
    (description
     "The T2 bundle provides a variety of separate support functions for using
Cyrillic characters in LaTeX:
@itemize
@item the @code{mathtext} package, for using Cyrillic letters
transparently in formulae;
@item the @code{citehack} package, for using Cyrillic (or indeed any
non-ASCII) characters in citation keys;
@item support for Cyrillic in BibTeX;
@item support for Cyrillic in Makeindex;
@item and various items of font support.
@end itemize")
    (license license:lppl)))

(define-public texlive-tablor
  (package
    (name "texlive-tablor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tablor/" "tex/latex/tablor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qacb25whzxwn85cxq1fa5rklq5fm06g6i5x88qymm8yaq1yxa71"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tablor")
    (synopsis "Create tables of signs and of variations")
    (description
     "The package allows the user to use the computer algebra system XCAS to
generate tables of signs and of variations (the actual plotting of the tables
uses the MetaPost macro package tableauVariations).  Tables with forbidden
regions may be developed using the package.  A configuration file permits some
configuration of the language to be used in the diagrams.  The @code{tablor}
package requires that shell escape be enabled.")
    (license license:lppl)))

(define-public texlive-tabriz-thesis
  (package
    (name "texlive-tabriz-thesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tabriz-thesis/"
                                     "doc/xelatex/tabriz-thesis/"
                                     "tex/latex/tabriz-thesis/"
                                     "tex/xelatex/tabriz-thesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13k6kmg1x143m1kfc3wcvyy6l60vpzz5ivmdpcqhjbdd3wz7b2ry"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tabriz-thesis")
    (synopsis "Template for the University of Tabriz")
    (description
     "The package offers a document class for typesetting theses and
dissertations at the University of Tabriz.  The class requires use of
XeLaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-tabvar
  (package
    (name "texlive-tabvar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tabvar/"
                                     "fonts/afm/public/tabvar/"
                                     "fonts/map/dvips/tabvar/"
                                     "fonts/tfm/public/tabvar/"
                                     "fonts/type1/public/tabvar/"
                                     "metapost/tabvar/"
                                     "source/latex/tabvar/"
                                     "tex/latex/tabvar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yjf0j3296a5csr6xrzziralfsy2iny21cyjf4dmlwp4l0h6kcpc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tabvar")
    (synopsis "Typesetting tables showing variations of functions")
    (description
     "This LaTeX package is meant to ease the typesetting of tables showing
variations of functions as they are used in France.")
    (license license:lppl1.3+)))

(define-public texlive-tangramtikz
  (package
    (name "texlive-tangramtikz")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tangramtikz/"
                                     "tex/latex/tangramtikz/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18n67k7ggqh3mvp8iqyp44d70gh3s8jfbwbp3ympv2ff5drjjb3l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tangramtikz")
    (synopsis "Tangram puzzles, with TikZ")
    (description
     "This package provides some commands (with English and French keys) to
work with tangram puzzles: @code{\\begin{EnvTangramTikz}} and
@code{\\PieceTangram} to position a piece, @code{\\TangramTikz} to display
a predefined tangram.")
    (license license:lppl1.3c)))

(define-public texlive-tapir
  (package
    (name "texlive-tapir")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/tapir/"
                                     "fonts/source/public/tapir/"
                                     "fonts/type1/public/tapir/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b1r2zg8m46zd2cb8l3vglncvixzhcfq75s0s86pyn9f88b17w57"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tapir")
    (synopsis "Simple geometrical font")
    (description
     "Tapir is a simple geometrical font mostly created of line and circular
segments with constant thickness.  The font is available as Metafont source
and in Adobe Type 1 format.  The character set contains all ASCII characters
in the range 0-127 (as in @code{cmr10}), accented characters used in the
Czech, Slovak and Polish languages.")
    (license license:gpl3+)))

(define-public texlive-tdsfrmath
  (package
    (name "texlive-tdsfrmath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tdsfrmath/"
                                     "source/latex/tdsfrmath/"
                                     "tex/latex/tdsfrmath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z1z3jy0mbn6dc75pnfsq9877y8yafvdhv5p8a54dbxxkzdcl3ll"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tdsfrmath")
    (synopsis "Macros for French teachers of mathematics")
    (description
     "This package provides a collection of macros for French maths teachers
in colleges and lycées (and perhaps elsewhere).  It is hoped that the package
will facilitate the everyday use of LaTeX by mathematics teachers.")
    (license license:lppl)))

(define-public texlive-technion-thesis-template
  (package
    (name "texlive-technion-thesis-template")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/technion-thesis-template/"
                                     "tex/xelatex/technion-thesis-template/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fnz3d3knflhm9349rn9xw3k698fn6dyxxh2a7zv8rx3z3y7kzwn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/technion-thesis-template")
    (synopsis "Template for theses on the Technion graduate school")
    (description
     "This is a template for writing a thesis according to the Technion
specifications.")
    (license license:cc-by4.0)))

(define-public texlive-tempora
  (package
    (name "texlive-tempora")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/tempora/"
                                     "fonts/afm/public/tempora/"
                                     "fonts/enc/dvips/tempora/"
                                     "fonts/map/dvips/tempora/"
                                     "fonts/opentype/public/tempora/"
                                     "fonts/tfm/public/tempora/"
                                     "fonts/type1/public/tempora/"
                                     "fonts/vf/public/tempora/"
                                     "tex/latex/tempora/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vcg6al4navxhaha78zxigpwaj631hgm47z3ic36335rb80p8b83"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tempora")
    (synopsis "Greek and Cyrillic to accompany Times")
    (description
     "This package, derived from TemporaLGCUni by Alexej Kryukov, is meant as
a companion to Times text font packages, providing Greek and Cyrillic in
matching weights and styles.  OpenType and Type1 fonts are provided, with
LaTeX support files giving essentially complete LGR coverage of monotonic,
polytonic and ancient Greek, and almost full T2A coverage of Cyrillic.")
    (license license:gpl2)))

(define-public texlive-tengwarscript
  (package
    (name "texlive-tengwarscript")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tengwarscript/"
                                     "fonts/enc/dvips/tengwarscript/"
                                     "fonts/map/dvips/tengwarscript/"
                                     "fonts/tfm/public/tengwarscript/"
                                     "fonts/vf/public/tengwarscript/"
                                     "source/latex/tengwarscript/"
                                     "tex/latex/tengwarscript/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1k3wgg8cj9n4ijj5qdbm74snwzdyabh1c93zm75p4x9pmawlpaa4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tengwarscript")
    (synopsis "LaTeX support for using Tengwar fonts")
    (description
     "The package provides mid-level access to Tengwar fonts, providing good
quality output.  Each tengwar sign is represented by a command, which will
place the sign nicely in relation to previous signs.  A transcription package
is available from the package's home page: writing all those tengwar commands
would quickly become untenable.  The package supports the use of a wide
variety of tengwar fonts that are available from the net; metric and map files
are provided for all the supported fonts.")
    (license license:lppl)))

(define-public texlive-tensind
  (package
    (name "texlive-tensind")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tensind/" "tex/latex/tensind/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i0iczq20ihx5y19j9ifpbm6sad6jv9cs8zwblgkddyhwxa7n764"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tensind")
    (synopsis "Typeset tensors")
    (description
     "This package typesets tensors with dots filling gaps and fine tuning of
index placement.")
    (license license:expat)))

(define-public texlive-tensor
  (package
    (name "texlive-tensor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tensor/" "source/latex/tensor/"
                                     "tex/latex/tensor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jnjx8zhzblg66m0ss7gsdwja87h0l07vzgyaqk332kgk457iz00"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tensor")
    (synopsis "Typeset tensors")
    (description
     "This allows the user to set tensor-style super- and subscripts with
offsets between successive indices.  It supports the typesetting of tensors
with mixed upper and lower indices with spacing, also typeset preposed
indices.")
    (license license:lppl)))

(define-public texlive-termes-otf
  (package
    (name "texlive-termes-otf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/termes-otf/"
                                     "tex/latex/termes-otf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z8a1d2k4170n14hf8faimwfd26cshsww1ypa8im937lna7c0j39"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/termes-otf")
    (synopsis "Using the OpenType fonts TeX Gyre Termes")
    (description
     "This package provides the OpenType version of the TeX Gyre Termes font,
including text and math fonts.  The package needs LuaLaTeX or XeLaTeX.  The
missing typefaces like bold math and slanted text are also defined.")
    (license license:lppl1.3+)))

(define-public texlive-tex-ewd
  (package
    (name "texlive-tex-ewd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/tex-ewd/"
                                     "tex/generic/tex-ewd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xlxbnn16mf7mzz57rjzqqv18mcy0immmlcsnksda03dh7hn8b69"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tex-ewd")
    (synopsis
     "Macros to typeset calculational proofs and programs in Dijkstra's style")
    (description
     "Edsger W. Dijkstra and others suggest a unique style to present
mathematical proofs and to construct programs.  This package provides macros
that support calculational proofs and Dijkstra's guarded command language.")
    (license license:bsd-1)))

(define-public texlive-tex-virtual-academy-pl
  (package
    (name "texlive-tex-virtual-academy-pl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/tex-virtual-academy-pl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kb86nn5vp1b0sy21aw9wlla1dwlaijppzq7728bmfs5nk1dnbjv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tex-virtual-academy-pl")
    (synopsis "TeX usage web pages, in Polish")
    (description
     "TeX Virtual Academy is a bundle of Polish documentation in HTML format
about TeX and Co.  It contains information for beginners, LaTeX packages,
descriptions, etc.")
    (license license:fdl1.3+)))

(define-public texlive-texilikechaps
  (package
    (name "texlive-texilikechaps")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/latex/texilikechaps/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z9nvv2y2nzpkpxyf18p426wcl0g6gbg7qppq70b285kdbczbijd"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/texilikechaps")
    (synopsis "Format chapters with a Texi-like format")
    (description
     "The package enables the user to reduce the size of the rather large
chapter headings in standard classes into a Texi-like smaller format.")
    (license license:lppl)))

(define-public texlive-texilikecover
  (package
    (name "texlive-texilikecover")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/latex/texilikecover/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04bljvhvmrxh1a4sfqw57yysaw03c5ldi1bq63mlqqvd9p3hmyck"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/texilikecover")
    (synopsis "Cover-page package, like TeXinfo")
    (description
     "The package creates document cover pages, like those that TeXinfo
produces.")
    (license license:lppl)))

(define-public texlive-texsis
  (package
    (name "texlive-texsis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/texsis/"
                                     "doc/man/man1/texsis.1"
                                     "doc/man/man1/texsis.man1.pdf"
                                     "doc/otherformats/texsis/base/"
                                     "tex/texsis/base/"
                                     "tex/texsis/config/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vdywyg03ab5w50370ml8hwiidim2sy7hhygmz917rnhsnm87lnv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:create-formats #~(list "texsis")
           #:phases
           #~(modify-phases %standard-phases
               (add-after 'install 'symlink-binaries
                 (lambda* (#:key inputs #:allow-other-keys)
                   (let ((pdftex (search-input-file inputs "bin/pdftex"))
                         (bin (string-append #$output "/bin")))
                     (mkdir-p bin)
                     (with-directory-excursion bin
                       (symlink pdftex "texsis"))))))))
    (propagated-inputs
     (list texlive-cm
           texlive-hyphen-base
           texlive-knuth-lib
           texlive-pdftex
           texlive-plain
           texlive-tex))
    (home-page "https://ctan.org/pkg/texsis")
    (synopsis "Plain TeX macros for Physicists")
    (description
     "TeXsis is a TeX macro package which provides useful features for
typesetting research papers and related documents.  For example, it includes
support specifically for:

@itemize
@item automatic numbering of equations, figures, tables and references;
@item simplified control of type sizes, line spacing, footnotes, running
headlines and footlines, and tables of contents, figures and tables;
@item specialized document formats for research papers, preprints and
e-prints, conference proceedings, theses, books, referee reports, letters, and
memoranda;
@item simplified means of constructing an index for a book or thesis;
@item easy to use double column formatting;
@item specialized environments for lists, theorems and proofs, centered or
non-justified text, and listing computer code;
@item specialized macros for easily constructing ruled tables.
@end itemize

TeXsis was originally developed for physicists, but others may also find it
useful.  It is completely compatible with Plain TeX.")
    (license license:lppl)))

(define-public texlive-textglos
  (package
    (name "texlive-textglos")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/textglos/"
                                     "source/latex/textglos/"
                                     "tex/latex/textglos/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jxx3wrwkmmm6ida3ih0yap57laflvsks8nv0395sv49xn7waxf0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/textglos")
    (synopsis "Typeset and index linguistic gloss abbreviations")
    (description
     "The package provides a set of macros for in-line linguistic examples (as
opposed to interlinear glossing, set apart from the main text).  It prevents
hyphenated examples from breaking across lines and consistently formats
phonemic examples, orthographic examples, and more.")
    (license license:lppl1.3+)))

(define-public texlive-textgreek
  (package
    (name "texlive-textgreek")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/textgreek/"
                                     "source/latex/textgreek/"
                                     "tex/latex/textgreek/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a0x07xyy1akqwya54k5bf3f8k4vcrv4hfmijmcp60ikw4v5gha1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-greek-fontenc))
    (home-page "https://ctan.org/pkg/textgreek")
    (synopsis "Upright greek letters in text")
    (description
     "This package provides macros to use upright greek letters as text
symbols.")
    (license license:lppl)))

(define-public texlive-textopo
  (package
    (name "texlive-textopo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/textopo/" "source/latex/textopo/"
                                     "tex/latex/textopo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rw41qg3l4jzvwsrhwazwxn85kgad8r7bxp9bfbq843b4zrlwnaz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/textopo")
    (synopsis "Annotated membrane protein topology plots")
    (description
     "This package provides a LaTeX package for setting shaded and annotated
membrane protein topology plots and helical wheels.")
    (license license:gpl3+)))

(define-public texlive-tfrupee
  (package
    (name "texlive-tfrupee")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/tfrupee/"
                                     "fonts/afm/public/tfrupee/"
                                     "fonts/map/dvips/tfrupee/"
                                     "fonts/tfm/public/tfrupee/"
                                     "fonts/type1/public/tfrupee/"
                                     "source/fonts/tfrupee/"
                                     "tex/latex/tfrupee/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qhgxn5g4wzhi81xgb30giw542nprlmf0ryyq6jy752jccl07b7j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tfrupee")
    (synopsis "Font offering the new (Indian) Rupee symbol")
    (description
     "The package provides LaTeX support for the (Indian) Rupee symbol font.
Simple LaTeX support written for its use.")
    (license license:gpl3)))

(define-public texlive-thaienum
  (package
    (name "texlive-thaienum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/thaienum/" "tex/latex/thaienum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g7sf5gjnrmhgq4qmdh3gphc0ixyfx4rpm7kmbwmjra3b8j2i46w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/thaienum")
    (synopsis "Thai labels in @code{enumerate} environments")
    (description
     "This LaTeX package provides a command to use Thai numerals or characters
as labels in enumerate environments.  Once the package is loaded with
@samp{\\usepackage@{thaienum@}} you can use labels such as @code{\\thainum*}
or @code{\\thaimultialph*} in conjunction with the package @code{enumitem}.
Concrete examples are given in the documentation.")
    (license license:lppl1.3+)))

(define-public texlive-thaispec
  (package
    (name "texlive-thaispec")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/thaispec/"
                                     "source/latex/thaispec/"
                                     "tex/latex/thaispec/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1d0mj98akv7bfq3msaplm2pffcwfayssn4i5an12zrw0wxicmp96"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/thaispec")
    (synopsis "Thai language typesetting in XeLaTeX")
    (description
     "This package allows you to input Thai characters directly to LaTeX
documents and choose any (system wide) Thai fonts for typesetting in XeLaTeX.
It also tries to appropriately justify paragraphs with no more external
tools.")
    (license license:lppl1.3+)))

(define-public texlive-thalie
  (package
    (name "texlive-thalie")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/thalie/" "tex/latex/thalie/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08dg91nr469s3x5c8njj0gpki1j89dji7ii9sw5l5ajd3pk8xbwv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/thalie")
    (synopsis "Typeset drama plays")
    (description
     "The package provides tools to typeset drama plays.  It defines commands
to introduce characters lines, to render stage directions, to divide a play
into acts and scenes and to build the dramatis personae automatically.")
    (license license:lppl1.3+)))

(define-public texlive-theanodidot
  (package
    (name "texlive-theanodidot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/theanodidot/"
                                     "fonts/enc/dvips/theanodidot/"
                                     "fonts/map/dvips/theanodidot/"
                                     "fonts/tfm/public/theanodidot/"
                                     "fonts/truetype/public/theanodidot/"
                                     "fonts/type1/public/theanodidot/"
                                     "fonts/vf/public/theanodidot/"
                                     "tex/latex/theanodidot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00qf03ssh7ncpl6l33zcmqkhbylv77w3d0jdvxv9pcbbsn3rzk7v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/theanodidot")
    (synopsis "TheanoDidot fonts with LaTeX support")
    (description
     "This package provides the TheanoDidot font designed by Alexey Kryukov,
in both TrueType and Type1 formats, with support for both traditional and
modern LaTeX processors.  An artificially-emboldened variant has been provided
but there are no italic variants.")
    (license (list license:lppl license:silofl1.1))))

(define-public texlive-theanomodern
  (package
    (name "texlive-theanomodern")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/theanomodern/"
                                     "fonts/enc/dvips/theanomodern/"
                                     "fonts/map/dvips/theanomodern/"
                                     "fonts/tfm/public/theanomodern/"
                                     "fonts/truetype/public/theanomodern/"
                                     "fonts/type1/public/theanomodern/"
                                     "fonts/vf/public/theanomodern/"
                                     "tex/latex/theanomodern/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17s04wcliqn5sgg5d6axc5ky3wg7xzh62c83hgrf3fq3pbykwm77"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/theanomodern")
    (synopsis "Theano Modern fonts with LaTeX support")
    (description
     "This package provides the TheanoModern font designed by Alexey Kryukov,
in both TrueType and Type1 formats, with support for both traditional and
modern LaTeX processors.  An artificially-emboldened variant has been provided
but there are no italic variants.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-theanooldstyle
  (package
    (name "texlive-theanooldstyle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/theanooldstyle/"
                                     "fonts/enc/dvips/theanooldstyle/"
                                     "fonts/map/dvips/theanooldstyle/"
                                     "fonts/tfm/public/theanooldstyle/"
                                     "fonts/truetype/public/theanooldstyle/"
                                     "fonts/type1/public/theanooldstyle/"
                                     "fonts/vf/public/theanooldstyle/"
                                     "tex/latex/theanooldstyle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jkfdfrpp6v12mw5khw51ib9dsjnc5bz3y6bazyabx8z7lgksig5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/theanooldstyle")
    (synopsis "Theano OldStyle fonts with LaTeX support")
    (description
     "This package provides the Theano OldStyle font designed by Alexey
Kryukov, in both TrueType and Type1 formats, with support for both traditional
and modern LaTeX processors.  An artificially-emboldened variant has been
provided but there are no italic variants.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-theatre
  (package
    (name "texlive-theatre")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/theatre/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nhm56spqvryhmhwmzly939mzv5yv3398lh2lyfhf40rr02mzgi5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/theatre")
    (synopsis "Sophisticated package for typesetting stage plays")
    (description
     "This package enables the user to typeset stage plays in a way that
permits creating highly customized printouts for each actor.")
    (license license:lppl1.2+)))

(define-public texlive-thermodynamics
  (package
    (name "texlive-thermodynamics")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/thermodynamics/"
                                     "source/latex/thermodynamics/"
                                     "tex/latex/thermodynamics/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15g6nbv44f6rpnabz905025s7kh2lqgy6mzsgjm9bc97p87d4n6v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/thermodynamics")
    (synopsis "Macros for multicomponent thermodynamics documents")
    (description
     "This package makes typesetting quantities found in thermodynamics texts
relatively simple.  The commands are flexible and intended to be relatively
intuitive.  It handles several sets of notation for total, specific, and molar
quantities; allows changes between symbols (e.g., @samp{A} vs. @samp{F} for
Helmholtz free energy); and greatly simplifies the typesetting of symbols and
partial derivatives commonly encountered in mixture thermodynamics.  Changes
of one's notes from one textbook to another can be achieved relatively easily
by changing package options.")
    (license license:lppl1.3+)))

(define-public texlive-thesis-ekf
  (package
    (name "texlive-thesis-ekf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/thesis-ekf/"
                                     "source/latex/thesis-ekf/"
                                     "tex/latex/thesis-ekf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06jc8h1195h6440yc2xblv7x8cyf6yhfh99x3p6hk97hcvq0ing4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/thesis-ekf")
    (synopsis "Thesis class for Eszterhazy Karoly Catholic University")
    (description
     "This is a class file for theses and dissertations at the Eszterhazy
Karoly Catholic University (Eger, Hungary).  The documentation is in
Hungarian.")
    (license license:lppl1.2+)))

(define-public texlive-thesis-gwu
  (package
    (name "texlive-thesis-gwu")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/thesis-gwu/"
                                     "tex/latex/thesis-gwu/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "120w3wfh5b7f6lmsf0l3wy6agxkds4rnpy5pzjnpa6rwk59plk8k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/thesis-gwu")
    (synopsis
     "Thesis class for George Washington University School of Engineering and
Applied Science")
    (description
     "This class is an attempt to create a standard format for @acronym{GWU
SEAS, George Washington University School of Engineering and Applied Science}
dissertations and theses.")
    (license license:gpl3)))

(define-public texlive-thesis-qom
  (package
    (name "texlive-thesis-qom")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/thesis-qom/"
                                     "tex/xelatex/thesis-qom/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cjx3yqnx6ijm664i747sxd19g7pmwpqsw24mh4bvdf0k1wqjj2a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/thesis-qom")
    (synopsis "Thesis style of the University of Qom, Iran")
    (description
     "This package provides a class file for writing theses and dissertations
according to the University of Qom Graduate Schools's guidelines for the
electronic submission of master theses and PhD dissertations.  The class
should meet all the current requirements and is updated whenever the
university guidelines change.  The class needs XeLaTeX in conjunction with the
following fonts: XB Niloofar, IranNastaliq, IRlotus, XB Zar, XB Titre, and
Yas.")
    (license license:lppl1.3c)))

(define-public texlive-thesis-titlepage-fhac
  (package
    (name "texlive-thesis-titlepage-fhac")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/thesis-titlepage-fhac/"
                                     "source/latex/thesis-titlepage-fhac/"
                                     "tex/latex/thesis-titlepage-fhac/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zs1k43q4br29vyxk007ld0rmiz8z803i6xhlc6rmhmb1nb594nj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/thesis-titlepage-fhac")
    (synopsis "Style to create a standard titlepage for diploma thesis")
    (description "This is yet another thesis titlepage style.")
    (license license:lppl)))

(define-public texlive-thmbox
  (package
    (name "texlive-thmbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/thmbox/" "source/latex/thmbox/"
                                     "tex/latex/thmbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ibs75aqla6z3lww0xpxd0biarla8hhx9zz245isy9ks8q231v1l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/thmbox")
    (synopsis "Decorate theorem statements")
    (description
     "The package defines an environment thmbox that presents theorems,
definitions and similar objects in boxes decorated with frames and various
aesthetic features.  The standard macro @code{\\newtheorem} may be redefined
to use the environment.")
    (license license:lppl)))

(define-public texlive-thuaslogos
  (package
    (name "texlive-thuaslogos")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/thuaslogos/"
                                     "tex/latex/thuaslogos/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ndqqc5rgxsdkanycgxi79czx6ri9fsfghh1lwyrx6ssjz2hfd7p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/thuaslogos")
    (synopsis
     "Logos for @acronym{THUAS, The Hague University of Applied Sciences}")
    (description
     "This package contains some logos of @acronym{THUAS, The Hague University
of Applied Sciences}.  These Logos are available in English and in Dutch.")
    (license license:lppl1.3+)))

(define-public texlive-thubeamer
  (package
    (name "texlive-thubeamer")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/thubeamer/"
                                     "doc/latex/thubeamer/"
                                     "source/latex/thubeamer/"
                                     "tex/latex/thubeamer/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07jha3pfklqas3f2mwpxqfi6h7dm4sl9jm4kl9kg68an4drzp4zj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/thubeamer")
    (synopsis "Beamer theme for Tsinghua University")
    (description
     "This package provides a Beamer theme designed for Tsinghua University.")
    (license license:lppl1.3c)))

(define-public texlive-thucoursework
  (package
    (name "texlive-thucoursework")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/thucoursework/"
                                     "source/latex/thucoursework/"
                                     "tex/latex/thucoursework/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cv2kadwzwwrw3q98wy7cjjl3084qqp55ki50v7m2ylrjxinwkv4"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:tex-format "xelatex"
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'skip-documentation-build
            ;; Only extract the ".sty" files.
            (lambda _
              (substitute* "source/latex/thucoursework/thucoursework.dtx"
                (("\\\\DocInput\\{\\\\jobname\\.dtx\\}") "")))))))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-booktabs
                  texlive-carlisle
                  texlive-ctex
                  texlive-enumitem
                  texlive-etoolbox
                  texlive-fancyhdr
                  texlive-hypdoc
                  texlive-kastrup
                  texlive-listings
                  texlive-metalogo
                  texlive-newpx
                  texlive-newtx
                  texlive-oberdiek
                  texlive-realscripts
                  texlive-xcolor
                  texlive-xpatch
                  texlive-xstring))))
    (home-page "https://ctan.org/pkg/thucoursework")
    (synopsis "Coursework template for Tsinghua University")
    (description
     "This package provides a LaTeX package for students of Tsinghua
University to write coursework more efficiently.  It can also be used by
students from other universities.")
    (license license:lppl1.3+)))

(define-public texlive-thuthesis
  (package
    (name "texlive-thuthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/thuthesis/"
                                     "doc/latex/thuthesis/"
                                     "source/latex/thuthesis/"
                                     "tex/latex/thuthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04nqrg6ak102fhpn4myg3rby29mz1081y2s3qf0gb4aqc1yifv2l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/thuthesis")
    (synopsis "Thesis template for Tsinghua University")
    (description
     "This package establishes a simple and easy-to-use LaTeX template for
Tsinghua dissertations, including general undergraduate research papers,
masters theses, doctoral dissertations, and postdoctoral reports.")
    (license license:lppl1.3c)))

(define-public texlive-tidyres
  (package
    (name "texlive-tidyres")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tidyres/" "tex/latex/tidyres/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d27430v529qhc0zg1yx6hx6858k5zsz2h5xjki0mihlmpjdrlhs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tidyres")
    (synopsis "Create formal resumes easily")
    (description
     "This LaTeX package aims to provide users with a simple interface to
create multi-column formal resumes.")
    (license license:cc-by4.0)))

(define-public texlive-timbreicmc
  (package
    (name "texlive-timbreicmc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/timbreicmc/"
                                     "source/latex/timbreicmc/"
                                     "tex/latex/timbreicmc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nd44car7vksfrz53h54r7cz1flgkgmyjri5ai1k7s9g2fn16x2n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/timbreicmc")
    (synopsis "Typeset documents with ICMC/USP watermarks")
    (description
     "With this package you can typeset documents with ICMC/USP Sao Carlos
watermarks.  ICMC is acronym for @emph{Instituto de Ciencias Matematicas e de
Computacao} of the @emph{Universidade de Sao Paulo} (USP), in the city of Sao
Carlos-SP, Brazil.")
    (license license:lppl1.3c)))

(define-public texlive-tinos
  (package
    (name "texlive-tinos")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/tinos/"
                                     "fonts/enc/dvips/tinos/"
                                     "fonts/map/dvips/tinos/"
                                     "fonts/tfm/google/tinos/"
                                     "fonts/truetype/google/tinos/"
                                     "fonts/type1/google/tinos/"
                                     "fonts/vf/google/tinos/"
                                     "tex/latex/tinos/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06cckhcjxrg1x2jb8w1y3k0sb5bb6nfs3k9qdjc9mywji4a20g18"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tinos")
    (synopsis "Tinos fonts with LaTeX support")
    (description
     "Tinos, designed by Steve Matteson, is an innovative serif design that is
metrically compatible with Times New Roman.")
    (license (list license:asl2.0 license:lppl))))

(define-public texlive-tiscreen
  (package
    (name "texlive-tiscreen")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tiscreen/" "tex/latex/tiscreen/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nrwai8qg26412jm8v3vgy7m4qk2kq6asc33j5a76z2ixnnhjlps"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tiscreen")
    (synopsis "Mimic the screen of older Texas Instruments calculators")
    (description
     "This package mimics the screen of older Texas Instruments dot matrix
display calculators, specifically the TI-82 STATS.")
    (license license:lppl1.3c)))

(define-public texlive-tlc-article
  (package
    (name "texlive-tlc-article")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tlc-article/"
                                     "tex/latex/tlc-article/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zxghkxg1yls97zrcfyjn8nk45mg5ygcjiprdwcs0ha1bl3pybxs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tlc-article")
    (synopsis "LaTeX document class for formal documents")
    (description
     "The package provides a LaTeX document class that orchestrates a logical
arrangement for document header, footer, author, abstract, table of contents,
and margins.  It standardizes a document layout intended for formal
documents.")
    (license license:bsd-3)))

(define-public texlive-tocbibind
  (package
    (name "texlive-tocbibind")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tocbibind/"
                                     "source/latex/tocbibind/"
                                     "tex/latex/tocbibind/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "086yi3d11pj5cnf0jfsmyy495y6kcind88569mig2yvq2adjmq3b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tocbibind")
    (synopsis "Add bibliography/index/contents to table of contents")
    (description
     "This package automatically adds the bibliography and/or the index and/or
the contents, etc., to the table of contents.")
    (license license:lppl)))

(define-public texlive-topletter
  (package
    (name "texlive-topletter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/topletter/"
                                     "source/latex/topletter/"
                                     "tex/latex/topletter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0s9yq65wwcw6mg09lk3x756iski1k55skik3n45l9wdbdz81w1p9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/topletter")
    (synopsis "Letter class for the @emph{Politecnico di Torino}")
    (description
     "This package provides a LaTeX class for typesetting letters conforming
to the official Corporate Image guidelines for the @emph{Politecnico di
Torino}.  The class can be used for letters written in Italian and in
English.")
    (license license:asl2.0)))

(define-public texlive-toptesi
  (package
    (name "texlive-toptesi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/toptesi/" "source/latex/toptesi/"
                                     "tex/latex/toptesi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mskk7swjgcy6lw1l81brcnw7n870mrz3la64ln0f3mxps98gik6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/toptesi")
    (synopsis "Bundle for typesetting multilanguage theses")
    (description
     "This bundle contains everything needed for typesetting a bachelor,
master, or PhD thesis in any language supported by LaTeX.  The infix strings
may be selected and specified at will by means of a configuration file, so as
to customize the layout of the front page to the requirements of a specific
university.  Thanks to its language management, the bundle is suited for
multi-language theses.  Toptesi is designed to save the PDF version of
a thesis in PDF/A-1b compliant mode and with all the necessary metadata.")
    (license license:lppl1.3c)))

(define-public texlive-tpslifonts
  (package
    (name "texlive-tpslifonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tpslifonts/"
                                     "source/latex/tpslifonts/"
                                     "tex/latex/tpslifonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i713qbhbv6yhax667igabfal1p2f8r6w0hgvs4y4pbpv4ffyqf6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tpslifonts")
    (synopsis "LaTeX package for configuring presentation fonts")
    (description
     "This package aims to improve of font readability in presentations,
especially with maths.  The standard CM maths fonts at large design sizes are
difficult to read from far away, especially at low resolutions and low
contrast color choice.  Using this package leads to much better overall
readability of some font combinations.  The package offers a couple of
harmonising combinations of text and maths fonts from the (distant) relatives
of Computer Modern fonts, with a couple of extras for optimising readability.
Text fonts from Computer Modern roman, Computer Modern sans serif, SliTeX
Computer Modern sans serif, Computer Modern Bright, or Concrete Roman are
available, in addition to maths fonts from Computer Modern maths, Computer
Modern Bright maths, or Euler fonts.")
    (license license:gpl3+)))

(define-public texlive-trajan
  (package
    (name "texlive-trajan")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/trajan/"
                                     "fonts/afm/public/trajan/"
                                     "fonts/map/dvips/trajan/"
                                     "fonts/tfm/public/trajan/"
                                     "fonts/type1/public/trajan/"
                                     "source/latex/trajan/"
                                     "tex/latex/trajan/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yjx252c6a3bf1k2646sqf3n3s09x2gxya3ypn1zz9scn5kkh1wa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/trajan")
    (synopsis "Fonts from the Trajan's Column in Rome")
    (description
     "This package provides fonts (both as Metafont source and in Adobe Type
1 format) based on the capitals carved on the Trajan's Column in Rome in 114
AD, together with macros to access the fonts.  The font is uppercase letters
together with some punctuation and analphabetics; no lowercase or digits.")
    (license license:lppl)))

(define-public texlive-translation-array-fr
  (package
    (name "texlive-translation-array-fr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/translation-array-fr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "128k8isyn4s0v496sykn22fqn0gfwyyk19kcrmxnc6clgxxfbdy6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/translation-array-fr")
    (synopsis "French translation of the documentation of @code{array}")
    (description
     "This package provides a French translation of the documentation of
@code{array}.")
    (license license:lppl)))

(define-public texlive-translation-dcolumn-fr
  (package
    (name "texlive-translation-dcolumn-fr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/translation-dcolumn-fr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xakssrkxb2wc6xyy1yvx4mm398x3yq032b7vapqxl82h992fjll"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/translation-dcolumn-fr")
    (synopsis "French translation of the documentation of @code{dcolumn}")
    (description
     "This package provides a French translation of the documentation of
@code{dcolumn}.")
    (license license:lppl)))

(define-public texlive-translation-natbib-fr
  (package
    (name "texlive-translation-natbib-fr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/translation-natbib-fr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0f0r1n8q3jkxsdcddabsgz9h9ndq4yffdpxdqxvqjmhfafhzwgkg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/translation-natbib-fr")
    (synopsis "French translation of the documentation of @code{natbib}")
    (description
     "This package provides a French translation of the documentation of
@code{natbib}.")
    (license license:lppl)))

(define-public texlive-translation-tabbing-fr
  (package
    (name "texlive-translation-tabbing-fr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/translation-tabbing-fr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cih442gp6zf8nwb2lbgjn7a64aglyrcw3aciqy5pkdw09pwn0an"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/translation-tabbing-fr")
    (synopsis "French translation of the documentation of @code{tabbing}")
    (description
     "This package provides a translation to French of the documentation of
the @code{tabbing} package.")
    (license license:lppl1.0+)))

(define-public texlive-tree-dvips
  (package
    (name "texlive-tree-dvips")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tree-dvips/" "dvips/tree-dvips/"
                                     "tex/latex/tree-dvips/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wk86z29aqfrsg947h5qbp98fngdx55v8xcx6dgniv5fv7d9ffrp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tree-dvips")
    (synopsis "Trees and other linguists' macros")
    (description
     "The package defines a mechanism for specifying connected trees that uses
a @code{tabular} environment to generate node positions.  The package uses
PostScript code, loaded by Dvips, so output can only be generated by use of
Dvips.

The package @code{lingmacros.sty} defines a few macros for linguists:
@code{\\enumsentence} for enumerating sentence examples, simple
@code{tabular}-based non-connected tree macros, and gloss macros.")
    (license license:lppl1.0+)))

(define-public texlive-tuda-ci
  (package
    (name "texlive-tuda-ci")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tuda-ci/" "tex/latex/tuda-ci/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vv80p8p8xqdqg35d7ix32dl8lw1rmzfzqdz5c785llr9k87470p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tuda-ci")
    (synopsis "LaTeX templates of Technische Universitat Darmstadt")
    (description
     "The TUDa-CI-Bundle provides a possibility to use the corporate design
of TU Darmstadt in LaTeX.  It contains document classes as well as
some helper packages and config files together with some templates for
user documentation, which currently are only available in German.")
    (license license:lppl1.3c)))

(define-public texlive-tudscr
  (package
    (name "texlive-tudscr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tudscr/" "source/latex/tudscr/"
                                     "tex/latex/tudscr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1whwmablazz41hy1p99ls8l4lk80h202ynzhabpwcmhk7mj60ikn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-cbfonts
           texlive-environ
           texlive-etoolbox
           texlive-geometry
           texlive-graphics
           texlive-greek-inputenc
           texlive-iwona
           texlive-koma-script
           texlive-mathastext
           texlive-mweights
           texlive-oberdiek
           texlive-opensans
           texlive-trimspaces
           texlive-xcolor
           texlive-xpatch))
    (home-page "https://ctan.org/pkg/tudscr")
    (synopsis "Corporate design of Technische Universitat Dresden")
    (description
     "The TUD-Script bundle provides both classes and packages in order to
create LaTeX documents in the corporate design of the Technische Universitat
Dresden.  It bases on the KOMA-Script bundle.

The bundle offers:

@itemize

@item the three document classes @code{tudscrartcl}, @code{tudscrreprt}, and
@code{tudscrbook};

@item the class @code{tudscrposter} for creating posters;

@item the package @code{tudscrsupervisor} providing environments and macros to
create tasks, evaluations and notices for scientific theses;

@item the package @code{tudscrfonts}, which makes the corporate design fonts
of the Technische Universitat Dresden available for LaTeX standard classes and
KOMA-Script classes;

@item the package @code{fix-tudscrfonts}, which provides the same fonts to
additional corporate design classes not related to TUD-Script;

@item the package @code{tudscrcomp}, which simplifies the switch to TUD-Script
from external corporate design classes,

@item the package @code{mathswap} for swapping math delimiters within
numbers (similar to @code{ionumbers}),

@item and the package @code{twocolfix} for fixing the positioning bug of
headings in @code{twocolumn} layout.

@end itemize")
    (license license:lppl1.3c)))

(define-public texlive-tugboat
  (package
    (name "texlive-tugboat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/tugboat/" "doc/latex/tugboat/"
                                     "source/latex/tugboat/" "tex/latex/tugboat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g6shnxmq9ak0lp73c41m3x4ifr4qrd0s0i7pypnxa6r4i1miqci"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tugboat")
    (synopsis "LaTeX macros for @emph{TUGboat} articles")
    (description
     "This package provides @file{ltugboat.cls} for both regular and
proceedings issues of the @emph{TUGboat} journal.  It also provides a BibTeX
style, @file{tugboat.bst}.")
    (license license:lppl1.3+)))

(define-public texlive-tugboat-plain
  (package
    (name "texlive-tugboat-plain")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/tugboat-plain/"
                                     "tex/plain/tugboat-plain/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kqm03x42m3fpgsg644wychgi42wgpwl51ljarbf5kqcrjwij25z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tugboat-plain")
    (synopsis "Plain TeX macros for @emph{TUGboat}")
    (description
     "The macros defined in this package are used in papers written in Plain
TeX for publication in @emph{TUGboat}.")
    (license license:knuth)))

(define-public texlive-tui
  (package
    (name "texlive-tui")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tui/" "tex/latex/tui/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14wl2n8wbc2p6nmrallwsxp4s6h73h97qm1w8algyv67bfl5i0hs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tui")
    (synopsis "Thesis style for the University of the Andes, Colombia")
    (description
     "The class is used for doctoral dissertations from the Faculty of
Engineering at the Universidad de los Andes, Bogota, Colombia.  It is
implemented as an extension of the @code{memoir} class.")
    (license license:lppl)))

(define-public texlive-turabian
  (package
    (name "texlive-turabian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/turabian/" "tex/latex/turabian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1waqdm6r4fpy602jfqjbfhm2x71llpg4wj4a9w61pkbca19xcnki"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/turabian")
    (synopsis "Create Turabian-formatted material using LaTeX")
    (description
     "The bundle provides a class file and a template for creating
Turabian-formatted projects.  The class file supports citation formatting
conforming to the Turabian 8th Edition style guide.")
    (license license:lppl)))

(define-public texlive-turabian-formatting
  (package
    (name "texlive-turabian-formatting")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/turabian-formatting/"
                                     "tex/latex/turabian-formatting/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1h42lrgq59900bhzgw114w1sxi432rbnpb2j5amwz64bsckvd2ry"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/turabian-formatting")
    (synopsis "Formatting based on @emph{Turabian's Manual}")
    (description
     "The @code{turabian-formatting} package provides Chicago-style formatting
based on Kate L. Turabian's @emph{A Manual for Writers of Research Papers,
Theses, and Dissertations: Chicago Style for Students and Researchers} (9th
edition).")
    (license license:lppl1.3+)))

(define-public texlive-turnstile
  (package
    (name "texlive-turnstile")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/turnstile/"
                                     "source/latex/turnstile/"
                                     "tex/latex/turnstile/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05ffizykplpisjy75s8zbaphpj5vk8r09ii5jzv929y54mi2qs06"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/turnstile")
    (synopsis "Typeset the (logic) turnstile notation")
    (description
     "This package typesets the turnstile sign.  Among other uses, this sign
is used by logicians for denoting a consequence relation, related to a given
logic, between a collection of formulas and a derived formula.")
    (license license:lppl)))

(define-public texlive-twemoji-colr
  (package
    (name "texlive-twemoji-colr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/twemoji-colr/"
                                     "fonts/truetype/public/twemoji-colr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qadwv7malbji28pxjpz3r53kb94grp435yk8h7i93x143vd8p9n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/twemoji-colr")
    (synopsis "Twemoji font in COLR/CPAL layered format")
    (description
     "This is a COLR/CPAL-based color OpenType font from the Twemoji
collection of emoji images.")
    (license (list license:cc-by-sa4.0 license:asl2.0))))

(define-public texlive-txfontsb
  (package
    (name "texlive-txfontsb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/txfontsb/"
                                     "fonts/afm/public/txfontsb/"
                                     "fonts/enc/dvips/txfontsb/"
                                     "fonts/map/dvips/txfontsb/"
                                     "fonts/opentype/public/txfontsb/"
                                     "fonts/tfm/public/txfontsb/"
                                     "fonts/type1/public/txfontsb/"
                                     "fonts/vf/public/txfontsb/"
                                     "source/fonts/txfontsb/"
                                     "tex/latex/txfontsb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y7af1n1dymi6723jvn01rcjfwr6p47wr5y4c33wa4cgaa9m39hn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/txfontsb")
    (synopsis "Extensions to @code{txfonts}, using GNU Freefont")
    (description
     "This package provides a set of fonts that extend the @code{txfonts}
bundle with small caps and old style numbers, together with Greek support.
The extensions are made with modifications of the GNU Freefont.")
    (license (list license:gpl3+ license:lppl1.0+))))

(define-public texlive-txuprcal
  (package
    (name "texlive-txuprcal")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/txuprcal/"
                                     "fonts/map/dvips/txuprcal/"
                                     "fonts/tfm/public/txuprcal/"
                                     "fonts/type1/public/txuprcal/"
                                     "tex/latex/txuprcal/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "033h3rqj7kf0rx0kdy9s1kwhk1hkrc6z70ga6ky7xy79mc3k2vgp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/txuprcal")
    (synopsis "Upright calligraphic font based on TX calligraphic")
    (description
     "This small package provides a means of loading as @code{\\mathcal} an
uprighted version of the calligraphic fonts from the TX font package.
A scaled option is provided to allow arbitrary scaling.")
    (license license:gpl3)))

(define-public texlive-typicons
  (package
    (name "texlive-typicons")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/typicons/"
                                     "fonts/truetype/public/typicons/"
                                     "tex/latex/typicons/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p82gq8jy0brvps6y6qdw8bldfsck9fw1qy84vrzfjz65435dzvh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/typicons")
    (synopsis "Font containing a set of web-related icons")
    (description
     "This package grants access to 336 web-related icons provided by the
included Typicons font, designed by Stephen Hutchings.")
    (license license:lppl1.3+)))

(define-public texlive-uaclasses
  (package
    (name "texlive-uaclasses")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uaclasses/"
                                     "source/latex/uaclasses/"
                                     "tex/latex/uaclasses/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0n0bz3cq9zgl5ppwq02izjgiw6gpza05ymc6x0gsc8v13wfcgvz0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uaclasses")
    (synopsis "University of Arizona thesis and dissertation format")
    (description
     "This package provides a LaTeX2e document class named @code{ua-thesis}
for typesetting theses and dissertations in the official format required by
the University of Arizona.  Moreover, there is a fully compatible alternative
document class @code{my-thesis} for private nice copies of the dissertation,
and the respective title pages are available as separate packages to work with
any document class.")
    (license license:public-domain)))

(define-public texlive-uafthesis
  (package
    (name "texlive-uafthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uafthesis/"
                                     "tex/latex/uafthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vxd9vk4dzpxcpn4l20r5hm3cz04mwqvd8kw1yg7vvjlnpshi4i6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uafthesis")
    (synopsis "Document class for theses at University of Alaska Fairbanks")
    (description
     "This is document class for theses at University of Alaska Fairbanks.")
    (license license:lppl)))

(define-public texlive-uantwerpendocs
  (package
    (name "texlive-uantwerpendocs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uantwerpendocs/"
                                     "source/latex/uantwerpendocs/"
                                     "tex/latex/uantwerpendocs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kc8c2hb1lni19hi313y18n48ik37ba5bkqc431hfpgj18fl5jrq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uantwerpendocs")
    (synopsis
     "Course texts, master theses, and exams in University of Antwerp style")
    (description
     "These class files implement the house style of the University of
Antwerp.  Using these class files will make it easy for you to make and keep
your documents compliant to this version and future versions of the house
style of the University of Antwerp.")
    (license license:lppl1.3+)))

(define-public texlive-ucalgmthesis
  (package
    (name "texlive-ucalgmthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ucalgmthesis/"
                                     "tex/latex/ucalgmthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10y0663xcggbykia38q85v429033m5p8k02v7vp4k9lrn10zixbn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ucalgmthesis")
    (synopsis
     "LaTeX thesis class for University of Calgary Faculty of Graduate Studies")
    (description
     "@file{ucalgmthesis.cls} is a LaTeX class file that produces documents
according to the thesis guidelines of the University of Calgary Faculty of
Graduate Studies.  It uses the @code{memoir} class.")
    (license license:expat)))

(define-public texlive-ucbthesis
  (package
    (name "texlive-ucbthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ucbthesis/"
                                     "tex/latex/ucbthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kwy84r7vz5nvq8nrar1ykik4ycpvgl1kwiyi0da6wjn4cazxxh9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ucbthesis")
    (synopsis "Thesis and dissertation class supporting UCB requirements")
    (description
     "The class provides the necessary framework for electronic submission
of masters theses and PhD dissertations at the University of
California, Berkeley.  It is based on the @code{memoir} class.")
    (license license:lppl1.3+)))

(define-public texlive-ucdavisthesis
  (package
    (name "texlive-ucdavisthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ucdavisthesis/"
                                     "source/latex/ucdavisthesis/"
                                     "tex/latex/ucdavisthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ymgnb2q77j5gfhcb4w4hvsafvs3vyygvzbq7zl9zgzzb02ml35j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ucdavisthesis")
    (synopsis
     "Thesis and dissertation class for University of California at Davis")
    (description
     "The @code{ucdavisthesis} class is a LaTeX class that allows you to
create a dissertation or thesis conforming to UC Davis formatting
requirements as of April 2016.")
    (license license:lppl1.2+)))

(define-public texlive-ucsmonograph
  (package
    (name "texlive-ucsmonograph")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ucsmonograph/"
                                     "source/latex/ucsmonograph/"
                                     "tex/latex/ucsmonograph/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13yf91i1c4bin9vbvsjpl5s7fkina5ai5zw868wdk5fiqvmqvgx7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ucsmonograph")
    (synopsis
     "Typesetting academic documents from the University of Caxias do Sul")
    (description
     "This is a LaTeX class for typesetting academic documents according to
the @acronym{ABNT, Brazilian Technical Standards Association} standards and
the @acronym{UCS, University of Caxias do Sul} specifications.")
    (license license:lppl1.3c)))

(define-public texlive-ucthesis
  (package
    (name "texlive-ucthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ucthesis/" "tex/latex/ucthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19s6s4wxq494shi2pgrdyaz9qx52zma62czd92mrkjp2diim1197"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ucthesis")
    (synopsis "University of California thesis format")
    (description
     "This package provides a modified version of the standard LaTeX report
style that is accepted for use with University of California PhD dissertations
and masters theses.")
    (license license:lppl1.3+)))

(define-public texlive-udes-genie-these
  (package
    (name "texlive-udes-genie-these")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/udes-genie-these/"
                                     "source/latex/udes-genie-these/"
                                     "tex/latex/udes-genie-these/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00gc36hjc1mr3qgna2sr2hadr8673lvl1fw46anbskyj6509xx13"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/udes-genie-these")
    (synopsis
     "Thesis class for the @emph{Faculte de genie} at the Universite de
Sherbrooke")
    (description
     "The @code{udes-genie-these} class can be used for PhD theses,
master's theses and project definitions at the @emph{Faculte de genie} of the
Universite de Sherbrooke (Quebec, Canada).  The class file is coherent with
the latest version of the @emph{Protocole de redaction aux etudes superieures}
which is available on the faculte's intranet.  The class file documentation is
in French, the language of the typical user at the Universite de Sherbrooke.")
    (license license:lppl1.3c)))

(define-public texlive-uestcthesis
  (package
    (name "texlive-uestcthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/uestcthesis/"
                                     "doc/latex/uestcthesis/"
                                     "tex/latex/uestcthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gqa6yyj3nq75vfjxrcn0pxc9gmgdaf7mdhp5sf3hy3br9ix8qgw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uestcthesis")
    (synopsis "Thesis class for UESTC")
    (description
     "The class is for typesetting a thesis at the University of Electronic
Science and Technology of China.")
    (license license:lppl1.3+)))

(define-public texlive-ufrgscca
  (package
    (name "texlive-ufrgscca")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ufrgscca/" "tex/latex/ufrgscca/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l54a3bdrwr0dfi2nf5pq6jb3yd9pv5bgpkkgbq7j6g9fv00i6hz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ufrgscca")
    (synopsis
     "Bundle for undergraduate students final work or report (TCC) at
UFRGS/EE")
    (description
     "This bundled is aimed at producing undergraduate students final work or
report at UFRGS/EE (Engineering School at the Federal University of Rio Grande
do Sul), closely following ABNT rules (Brazilian Association for Technical
Norms).  It is composed of a main class, @code{ufrgscca}, and a set of
auxiliary packages, some of which can be used independently.")
    (license (list license:lppl1.3c license:gpl3+))))

(define-public texlive-uhhassignment
  (package
    (name "texlive-uhhassignment")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uhhassignment/"
                                     "source/latex/uhhassignment/"
                                     "tex/latex/uhhassignment/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15yvq00xsikb8c78gkyyqjdgcz2yw8dnp586mjcrk1p4kvlpwyam"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uhhassignment")
    (synopsis "Document class for typesetting homework assignments")
    (description
     "This document class was created for typesetting solutions to homework
assignments at the university of Hamburg (Universitat Hamburg).")
    (license license:lppl1.3c)))

(define-public texlive-uiucredborder
  (package
    (name "texlive-uiucredborder")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uiucredborder/"
                                     "source/latex/uiucredborder/"
                                     "tex/latex/uiucredborder/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wsf3cfmpfmsv3afm78gc91fsiba415ir4p5fa0ivfny3dh34qnq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uiucredborder")
    (synopsis "Class for UIUC thesis red-bordered forms")
    (description
     "The class offers a means of filling out the ``red-bordered form''
that gets signed by the department head, your advisor, and --- for
doctoral dissertations --- your thesis committee members.")
    (license license:lppl1.2+)))

(define-public texlive-uiucthesis
  (package
    (name "texlive-uiucthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uiucthesis/"
                                     "source/latex/uiucthesis/"
                                     "tex/latex/uiucthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kzp2p03p1v7qij2kz82xis88vh1g477vs2aa0sqfa24w9y28h5i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uiucthesis")
    (synopsis "UIUC thesis class")
    (description
     "The class produces a document that conforms to the format described in
the University's Handbook for Graduate Students Preparing to Deposit.")
    (license license:lppl)))

(define-public texlive-ukbill
  (package
    (name "texlive-ukbill")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ukbill/" "tex/latex/ukbill/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ba4j50qmhvncdb2nnmyczpwb6cy86jj96n6bj9azik755mzmh70"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ukbill")
    (synopsis "Class for typesetting UK legislation")
    (description
     "This package provides formatting to easily typeset draft UK legislation.
The font Palatine Parliamentary is required to use this package.")
    (license license:lppl1.3c)))

(define-public texlive-ulqda
  (package
    (name "texlive-ulqda")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ulqda/" "scripts/ulqda/"
                                     "source/latex/ulqda/" "tex/latex/ulqda/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07jzmk0p4l28dxxqqpma4px9riykg0zynnjycyripg2m76a9ah2g"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts #~(list "ulqda.pl")
           #:tex-format "latex"))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-dot2texi
                  texlive-etoolbox
                  texlive-hypdoc
                  texlive-moreverb
                  texlive-pgf
                  texlive-soul
                  texlive-subfigure
                  texlive-xkeyval))))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/ulqda")
    (synopsis "Support of Qualitative Data Analysis")
    (description
     "The package is for use in Qualitative Data Analysis research.  It
supports the integration of Qualitative Data Analysis (QDA) research tasks,
specifically for Grounded Theory, into the LaTeX work flow.  It assists in the
analysis of textual data such as interview transcripts and field notes by
providing the LaTeX user with macros which are used to markup textual
information.")
    (license license:lppl)))

(define-public texlive-ulthese
  (package
    (name "texlive-ulthese")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ulthese/" "source/latex/ulthese/"
                                     "tex/latex/ulthese/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kcw1zsgj0dr00h555qcld9dn58i8iipnka9s10fn9q0x46sq05q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ulthese")
    (synopsis "Thesis class and templates for Universite Laval")
    (description
     "The package provides a class based on @code{memoir} to prepare theses
and memoirs compliant with the presentation rules set forth by the Faculty of
Graduate Studies of Universite Laval, Quebec, Canada.  The class also comes
with an extensive set of templates for the various types of theses and memoirs
offered at Laval.

Please note that the documentation for the class and the comments in the
templates are all written in French, the language of the target audience.")
    (license license:lppl1.3c)))

(define-public texlive-umbclegislation
  (package
    (name "texlive-umbclegislation")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/umbclegislation/"
                                     "tex/latex/umbclegislation/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0znzm0ymvz43f4kgvww79mnr7nl78xcmi7yw2vlwx332kq8hcw2v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/umbclegislation")
    (synopsis
     "LaTeX class for legislation files for UMBC Student Government
Association Bills")
    (description
     "This is a LaTeX class for building legislation files for UMBC Student
Government Association Bills.")
    (license license:gpl3)))

(define-public texlive-umich-thesis
  (package
    (name "texlive-umich-thesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/umich-thesis/"
                                     "tex/latex/umich-thesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15y25n9j2zh7hmgpq9fir6y0ydjwqhvyy6cx59jm8i0swkgw33vz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/umich-thesis")
    (synopsis "University of Michigan thesis LaTeX class")
    (description
     "This package provides a LaTeX2e class to create a University of
Michigan dissertation according to the Rackham dissertation handbook.")
    (license license:lppl)))

(define-public texlive-umthesis
  (package
    (name "texlive-umthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/umthesis/" "tex/latex/umthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1y2ba0k9d2sab9mkfhpsm92v4wx6rhapj887jbvcl7871b4idbps"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/umthesis")
    (synopsis "Dissertations at the University of Michigan")
    (description
     "This is a class for dissertations at the University of Michigan. it
loads @code{book} class, and makes minimal changes to it.")
    (license license:lppl)))

(define-public texlive-umtypewriter
  (package
    (name "texlive-umtypewriter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/umtypewriter/"
                                     "fonts/opentype/public/umtypewriter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19skqmchglac4lrk4qhvb4rabi73qmypdi20sbjxnvb8abw0pf3i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/umtypewriter")
    (synopsis "Fonts to typeset with the @code{xgreek} package")
    (description
     "The UMTypewriter font family is a monospaced font family that was built
from glyphs from the CB Greek fonts, the CyrTUG Cyrillic alphabet fonts (LH),
and the standard Computer Modern font family.  It contains four OpenType fonts
which are required for use of the @code{xgreek} package for XeLaTeX.")
    (license license:silofl1.1)))

(define-public texlive-unam-thesis
  (package
    (name "texlive-unam-thesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/unam-thesis/"
                                     "tex/latex/unam-thesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cn4qd3rvh9z8sp7g94fh11khij2vykv89inbmy7g52hxgxzkdhh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/unam-thesis")
    (synopsis "Create documents according to the UNAM guidelines")
    (description
     "This is a class for creating dissertation documents according to the
National Autonomous University of Mexico (UNAM) guidelines.")
    (license license:gpl3+)))

(define-public texlive-unamth-template
  (package
    (name "texlive-unamth-template")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/unamth-template/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ydaxzcwxq1rjkawlapnfipjzlyzvbvijrx98pi9yd4zk2nnqjfv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/unamth-template")
    (synopsis "UNAM thesis LaTeX Template")
    (description
     "The bundle provides a template for UNAM's College of Engineering
Theses.")
    (license license:gpl3)))

(define-public texlive-unamthesis
  (package
    (name "texlive-unamthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/unamthesis/"
                                     "doc/latex/unamthesis/"
                                     "tex/latex/unamthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jdppibm49491ddgx6ny6hqsfs9qan948614bfcy67f5syjzx2jh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/unamthesis")
    (synopsis "Style for Universidad Nacional Autonoma de Mexico theses")
    (description
     "The package provides a customisable format to typeset Theses according
to the Universidad Nacional Autonoma de Mexico guidelines.  The bundle also
includes an appropriate bibliographic style which enables the use of
author-year schemes using the @code{natbib} package.")
    (license license:lppl1.3+)))

(define-public texlive-unbtex
  (package
    (name "texlive-unbtex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/unbtex/" "tex/latex/unbtex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a1lfv1ls6n1q5rxi7cdsvyfwhk4xf1qmwi17hv8g4sh1lwi0cyq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/unbtex")
    (synopsis "Class for theses at @acronym{UnB, University of Brasilia}")
    (description
     "This package provides a class based on abnTeX and compatible with
pdfLaTex and Biber to prepare bachelor, master, and doctoral theses for the
@acronym{UnB, University of Brasilia}, Brazil.  The class also comes with
a template for the various types of theses for undergraduate and graduate
programs at UnB.  The documentation for the class and the comments in the
templates are all written in Portuguese, the language of the target
audience.")
    (license license:lppl1.3+)))

(define-public texlive-unfonts-core
  (package
    (name "texlive-unfonts-core")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/unfonts-core/"
                                     "fonts/truetype/public/unfonts-core/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12q7h1akmgc3vdvyb4i8x51a716451kwi90vh9i57xw76hmg5f4x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/unfonts-core")
    (synopsis "TrueType version of Un-fonts")
    (description
     "This is TrueType version of Un-fonts core bundle.  It includes the
following font families (12 fonts):
@itemize
@item UnBatang, UnBatangBold: serif;
@item UnDotum, UnDotumBold: sans-serif;
@item UnGraphic, UnGraphicBold: sans-serif style;
@item UnDinaru, UnDinaruBold, UnDinaruLight;
@item UnPilgi, UnPilgiBold: script;
@item UnGungseo: cursive, brush-stroke.
@end itemize")
    (license license:gpl2)))

(define-public texlive-unfonts-extra
  (package
    (name "texlive-unfonts-extra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/unfonts-extra/"
                                     "fonts/truetype/public/unfonts-extra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1krs93dsi50278qxgm24ij9w9r7gdcxqsdfk6ai5klvkmlka8gkf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/unfonts-extra")
    (synopsis "TrueType version of Un-fonts")
    (description
     "This is TrueType version of Un-fonts extra bundle.  It includes the
following Korean font families (11 fonts):
@itemize
@item UnPen, UnPenheulim: script;
@item UnTaza: typewriter style;
@item UnShinmun;
@item UnYetgul: old Korean printing style;
@item UnJamoSora, UnJamoNovel, UnJamoDotum, UnJamoBatang;
@item UnPilgia;
@item UnVada.
@end itemize")
    (license license:gpl2)))

(define-public texlive-uni-wtal-ger
  (package
    (name "texlive-uni-wtal-ger")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uni-wtal-ger/"
                                     "tex/latex/uni-wtal-ger/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bxrvl10ccdqarffdf3xzcihnid8h84sv1hcbncjmwq249kf3f96"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uni-wtal-ger")
    (synopsis
     "Citation style for literary studies at the University of Wuppertal")
    (description
     "The package defines a BibLaTeX citation style based on the author-title
style of @code{biblatex-dw}.  The citations are optimised for literary studies
in faculty of humanities at the Bergische Universitat Wuppertal.")
    (license license:lppl1.3+)))

(define-public texlive-uni-wtal-lin
  (package
    (name "texlive-uni-wtal-lin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uni-wtal-lin/"
                                     "tex/latex/uni-wtal-lin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07ndzpby3m8ccw3r4sp9plrzmnnpiksvi8plnqyssklalmm406hj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uni-wtal-lin")
    (synopsis
     "Citation style for linguistic studies at the University of Wuppertal")
    (description
     "The package defines a BibLaTeX citation style based on the standard
author-year style.  The citations are optimised for linguistic studies at the
Institute of Linguistics at the Bergische Universitat Wuppertal.")
    (license license:lppl1.3+)))

(define-public texlive-unicode-alphabets
  (package
    (name "texlive-unicode-alphabets")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/unicode-alphabets/"
                                     "tex/latex/unicode-alphabets/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xvzmx0xa8mmi39a8c89byi6c6y7vbl5k3plp63k5mif19ncyq3s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/unicode-alphabets")
    (synopsis "Macros for using characters from Unicode's Private Use Area")
    (description
     "While Unicode supports the vast majority of use cases, there are certain
specialized niches which require characters and glyphs not (yet) represented
in the standard.  Thus the Private Use Area (PUA) at code points E000-F8FF,
which enables third parties to define arbitrary character sets.  This package
allows configuring a number of macros for using various PUA character sets in
LaTeX (AGL, CYFI, MUFI, SIL, TITUS, UCSUR, UNZ), to enable transcription and
display of medieval and other documents.")
    (license license:cc-by-sa4.0)))

(define-public texlive-unifith
  (package
    (name "texlive-unifith")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/unifith/" "doc/latex/unifith/"
                                     "tex/latex/unifith/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06y9hkxv8y9p06pcyy2nv0nqma6bnh0n9i9pwpdadks9zs9sqn8r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/unifith")
    (synopsis "Typeset theses for University of Florence (Italy)")
    (description
     "The package provides a class to typeset PhD, master, and bachelor theses
that adhere to the publishing guidelines of the University of
Florence (Italy).")
    (license license:lppl1.3c)))

(define-public texlive-unigrazpub
  (package
    (name "texlive-unigrazpub")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/unigrazpub/"
                                     "source/latex/unigrazpub/"
                                     "tex/latex/unigrazpub/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02xnlp7p1ap0wvkn4skskh6av4rj8fh28gqk27x97yp0c255w3qv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/unigrazpub")
    (synopsis
     "LaTeX templates for University of Graz Library Publishing Services")
    (description
     "This package provides a LaTeX class matching the preparation guidelines
of the Library Publishing Services of University of Graz.")
    (license license:lppl1.3c)))

(define-public texlive-unitn-bimrep
  (package
    (name "texlive-unitn-bimrep")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/unitn-bimrep/"
                                     "tex/latex/unitn-bimrep/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0id55sfi9bzj7vp7dm9wxy355ca6k6dmxq488r4dwmndy2z4v8hl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/unitn-bimrep")
    (synopsis
     "Bimonthly report class for the PhD School of Materials,
Mechatronics and System Engineering")
    (description
     "This package allows rapidly writing the bimonthly report for The PhD
School in Materials, Mechatronics and System Engineering.  It allows defining
the research activities, the participation to school and congress, and the
publication performed by a student.")
    (license license:expat)))

(define-public texlive-unitsdef
  (package
    (name "texlive-unitsdef")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/unitsdef/"
                                     "source/latex/unitsdef/"
                                     "tex/latex/unitsdef/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0r3d8af9543sfby3v39gq8vys0m0y3dvni7cly02q0cw6xxw784m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/unitsdef")
    (synopsis "Typesetting units in LaTeX")
    (description
     "This package predefines common units, defines an easy to use interface
to define new units and changes the output concerning to the surrounding font
settings.")
    (license license:lppl)))

(define-public texlive-universa
  (package
    (name "texlive-universa")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/universa/"
                                     "fonts/source/public/universa/"
                                     "fonts/tfm/public/universa/"
                                     "source/fonts/universa/"
                                     "tex/latex/universa/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1w1cw2236aj37iggxck1drsfbwsiap8mc3lrkqrimmz2rgixycdp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/universa")
    (synopsis "Herbert Bayer's Universal font")
    (description
     "This package provides an implementation of the Universal by Herbert
Bayer.  The Metafont sources of the fonts, and their LaTeX support, are
supplied.")
    (license license:gpl3+)))

(define-public texlive-universalis
  (package
    (name "texlive-universalis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/universalis/"
                                     "fonts/enc/dvips/universalis/"
                                     "fonts/map/dvips/universalis/"
                                     "fonts/opentype/arkandis/universalis/"
                                     "fonts/tfm/arkandis/universalis/"
                                     "fonts/type1/arkandis/universalis/"
                                     "fonts/vf/arkandis/universalis/"
                                     "tex/latex/universalis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hqlpyh3g682vwdxbgyp7jrswvf16ds8i4mqb6yyv00h3rv11cxk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/universalis")
    (synopsis "Universalis font, with support")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the UniversalisADFStd family of fonts, designed by Hirwin Harendal.  The font
is suitable as an alternative to fonts such as Adrian Frutiger's Univers and
Frutiger.")
    (license (list license:gpl2+ license:lppl))))

(define-public texlive-univie-ling
  (package
    (name "texlive-univie-ling")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/univie-ling/"
                                     "tex/latex/univie-ling/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lxxqddsssacsn9q75jfg6mxvb9drz9swi3h2xjbaakg7bf5y2g2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/univie-ling")
    (synopsis
     "Papers, theses and research proposals in (Applied) Linguistics at Vienna
University")
    (description
     "This bundle provides LaTeX2e classes, BibLaTeX files, and templates
suitable for student papers, PhD research proposals (Exposes), and theses
in (Applied) Linguistics at the University of Vienna.  The classes implement
some standards for these types of text, such as suitable title pages.  They
are particularly suited for the field of (Applied) Linguistics and pre-load
some packages that are considered useful in this context.  The classes can
also be used for General and Historical Linguistics as well as for other
fields of study at Vienna University.  In this case, however, some settings
may have to be adjusted.")
    (license license:lppl1.3+)))

(define-public texlive-unizgklasa
  (package
    (name "texlive-unizgklasa")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/unizgklasa/"
                                     "tex/latex/unizgklasa/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lrw0j34r9p2ydsajkvg2k7n8kirpi6lqj2iwhvfqh0pg230y82q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/unizgklasa")
    (synopsis
     "LaTeX class for theses at the Faculty Of Graphic Arts in Zagreb")
    (description
     "This class is intended for generating graduate and final theses
according to the instructions of the Faculty of Graphic Arts, University of
Zagreb.  It does not necessarily correspond to the requirements of each
component of the University, but is designed as an idea for linking and
uniformizing the look of all graduate papers.")
    (license license:lppl1.3+)))

(define-public texlive-unswcover
  (package
    (name "texlive-unswcover")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/unswcover/"
                                     "tex/latex/unswcover/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vdi90i07s8914sm7axn1pzks9d0w3qrsijynx5hxr7a36byafhp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/unswcover")
    (synopsis "Typeset a dissertation cover page following UNSW guidelines")
    (description
     "The package an UNSW cover sheet following the 2011 GRS guidelines.  It
may also (optionally) provide other required sheets such as Originality,
Copyright and Authenticity statements.")
    (license license:lppl1.3+)))

(define-public texlive-uol-physics-report
  (package
    (name "texlive-uol-physics-report")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uol-physics-report/"
                                     "source/latex/uol-physics-report/"
                                     "tex/latex/uol-physics-report/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00rvqmrc1k67136748vq4j5c90iqa2ry65jkaqarazvlv8x77m4d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uol-physics-report")
    (synopsis "LaTeX document class for writing lab reports")
    (description
     "The package provides physics students at the University of Oldenburg
with a prepared document class for writing laboratory reports for the
laboratory courses conducted by the Institute of Physics.  The document class
consists of predefinded margins and heading formats.  Furthermore, it presets
the headers of the pages and excludes the titlepage and table of contents from
the page numbering.")
    (license license:lppl1.3c)))

(define-public texlive-uothesis
  (package
    (name "texlive-uothesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uothesis/"
                                     "source/latex/uothesis/"
                                     "tex/latex/uothesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04md5wkh11hpczvl7gpi2a5k2j5yalssjw5azpbr2g9q8fc99zp3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uothesis")
    (synopsis "Class for dissertations and theses at the University of Oregon")
    (description
     "The class generates documents that are suitable for submission to the
Graduate School and conform with the style requirements for dissertations and
theses as laid out in the Fall 2010 UO graduate school student manual.")
    (license license:lppl1.3+)))

(define-public texlive-uowthesis
  (package
    (name "texlive-uowthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uowthesis/"
                                     "tex/latex/uowthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "196w8ics6r9n4x05ydpr0hprpmcwqwfqa92h200kxgflp595xm43"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uowthesis")
    (synopsis
     "Document class for dissertations at the University of Wollongong")
    (description
     "This package provides a document class for higher degree research theses
in compliance with the specifications of @acronym{UoW, University of
Wollongong} theses in the @emph{Guidelines for Preparation and Submission of
Higher Degree Research Theses} (March 2006), by the Research Student Centre,
Research & Innovation Division, UoW.")
    (license license:lppl1.3+)))

(define-public texlive-uowthesistitlepage
  (package
    (name "texlive-uowthesistitlepage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uowthesistitlepage/"
                                     "tex/latex/uowthesistitlepage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mspjj6wvcb9cdbp3qp2cqd3mmmf3kyd77pmk1kji0wspg0jra6y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uowthesistitlepage")
    (synopsis "Title page for dissertations at the University of Wollongong")
    (description
     "The package redefines @code{\\maketitle} to generate a title page for
a @acronym{UoW, University of Wollongong} thesis, in accordance with the UoW
branding guidelines.  The package should be used with the @code{book} class to
typeset a thesis.  The package also defines a @code{\\declaration} command
that typesets the declaration that this thesis is your own work, etc., which
is required in the front of each PhD thesis.")
    (license (list license:lppl1.3c license:cc-by-sa4.0))))

(define-public texlive-uppunctlm
  (package
    (name "texlive-uppunctlm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/uppunctlm/"
                                     "fonts/tfm/public/uppunctlm/"
                                     "fonts/vf/public/uppunctlm/"
                                     "tex/latex/uppunctlm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d9x56rlxjavamx361582khj5idhy692hxm5wwwcc5y5i3xsc4pp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uppunctlm")
    (synopsis
     "Always keep upright shape for some punctuation marks and Arabic numerals")
    (description
     "The package provides a mechanism to keep punctuation always in upright
shape even if italic was specified.  It is directed to Latin Modern fonts, and
provides @file{.tfm}, @file{.vf}, @file{.fd}, and @file{.sty} files.  Here
a list of punctuation characters always presented in upright shapes: comma,
period, semicolon, colon, parentheses, square brackets, and Arabic numerals.")
    (license license:gfl1.0)))

(define-public texlive-urlbst
  (package
    (name "texlive-urlbst")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/urlbst/" "doc/bibtex/urlbst/"
                                     "scripts/urlbst/" "source/bibtex/urlbst/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sfs2ybkfcqy8w0wdni3aakpnmk60zkmnlc55xskyzzh4yc69qi7"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "urlbst")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/urlbst")
    (synopsis "Web support for BibTeX")
    (description
     "This package supports a new BibTeX @code{webpage} entry type and @code{url},
@code{lastchecked}, and @code{eprint} and @code{DOI} fields.  The Perl script
@command{urlbst} can be used to add this support to an arbitrary @file{.bst}
file which has a reasonably conventional structure.  The result is meant to be
robust rather than pretty.")
    (license (list license:gpl2 license:lppl))))

(define-public texlive-urcls
  (package
    (name "texlive-urcls")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/urcls/" "tex/latex/urcls/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fkz3jqrfay9kzaq1iyyz95n1m7xg6cw8rar878dlgb1rmkds1fb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/urcls")
    (synopsis
     "Beamer and @code{scrlttr2} classes and styles for the University of
Regensburg")
    (description
     "The bundle provides a Beamer-derived class and a theme style file for
the corporate design of the @acronym{UR, University of Regensburg}.  It also
contains a @code{scrlttr2}-derived class for letters using the corporate
design of the UR.  Users may use the class itself (URbeamer) or use the theme
in the usual way with @code{\\usetheme@{UR@}}.")
    (license license:lppl)))

(define-public texlive-urwchancal
  (package
    (name "texlive-urwchancal")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/urwchancal/"
                                     "fonts/tfm/urw/urwchancal/"
                                     "fonts/vf/urw/urwchancal/"
                                     "tex/latex/urwchancal/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05mwicyb46hjlqpq432z4b3f0q566xplzp1fjiw1ijmns5xhvig9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/urwchancal")
    (synopsis "Use URW's clone of Zapf Chancery as a maths alphabet")
    (description
     "The package allows (the URW clone of) Zapf Chancery to function as
a maths alphabet, the target of @code{\\mathcal} or @code{\\mathscr}, with
accents appearing where they should, and other spacing parameters set to
reasonable (not very tight) values.  The font itself may be found in the URW
basic fonts collection.  This package supersedes the @code{pzccal} package.")
    (license license:lppl)))

(define-public texlive-usebib
  (package
    (name "texlive-usebib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/usebib/" "source/latex/usebib/"
                                     "tex/latex/usebib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qymf8hnp7ilzm030ypbagmw6nicdfy8lhry20viws1v7dibk9l0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/usebib")
    (synopsis "Simple bibliography processor")
    (description
     "The package is described by its author as @emph{a poor person's
replacement for the more powerful methods provided by BibLaTeX to access data
from a @file{.bib} file}.  Its principle commands are @code{\\bibinput}, which
specifies a database to use, and @code{\\usebibdata}, which typesets a single
field from a specified entry in that database.")
    (license license:lppl1.3+)))

(define-public texlive-uspatent
  (package
    (name "texlive-uspatent")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uspatent/" "tex/latex/uspatent/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0f2w7zczl6zmxysdwyksbq3zniyw6mfr9zhdz55j5l84fgkwcd3n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uspatent")
    (synopsis "U.S. Patent Application Tools for LaTeX and LyX")
    (description
     "The package provides a class and other tools for developing
a beautifully formatted, consistent U.S. Patent Application using LaTeX and/or
LyX.")
    (license license:lppl1.3+)))

(define-public texlive-ut-thesis
  (package
    (name "texlive-ut-thesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ut-thesis/"
                                     "source/latex/ut-thesis/"
                                     "tex/latex/ut-thesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0z1rvgy4d2zdagb7x5ymdid02fwnpv2x4dd4jxxkhg9mgq0lscyn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ut-thesis")
    (synopsis "University of Toronto thesis style")
    (description
     "This LaTeX document class implements the formatting requirements of the
University of Toronto School of Graduate Studies (SGS), as of Fall 2020.")
    (license license:lppl1.3c)))

(define-public texlive-utexasthesis
  (package
    (name "texlive-utexasthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/utexasthesis/"
                                     "tex/latex/utexasthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12qgidbdyjj9mdjp6lzidw0ifkdh7hskxdmpmsk5wybjicvf24w4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/utexasthesis")
    (synopsis "University of Texas at Austin graduate thesis style")
    (description
     "This class file complies with the Digital Submission Requirement for
masters and PhD thesis submissions of the University of Texas at Austin.")
    (license license:cc0)))

(define-public texlive-uvaletter
  (package
    (name "texlive-uvaletter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uvaletter/"
                                     "tex/latex/uvaletter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qqrlv7f4mdldf9gyllnaszvfv82ds8p0h63q802q8llviishjbm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uvaletter")
    (synopsis "Unofficial letterhead template for the University of Amsterdam")
    (description
     "This is an unofficial LaTeX package that provides a letterhead template
for the University of Amsterdam.")
    (license license:expat)))

(define-public texlive-uwa-colours
  (package
    (name "texlive-uwa-colours")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uwa-colours/"
                                     "source/latex/uwa-colours/"
                                     "tex/latex/uwa-colours/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lryscsnwayp0s74rcdlr36bi2n45fbdq9f2h3av2n1nj57259a9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uwa-colours")
    (synopsis "Colour palette of the University of Western Australia")
    (description
     "This package uses the @code{xcolor} package to define macros for the
colour palette of the University of Western Australia.")
    (license license:lppl1.3+)))

(define-public texlive-uwa-letterhead
  (package
    (name "texlive-uwa-letterhead")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uwa-letterhead/"
                                     "source/latex/uwa-letterhead/"
                                     "tex/latex/uwa-letterhead/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06p4c6m8dizq4y3pd95bzf81y296r1gg134jnx5h0qzh4l5ywpyx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uwa-letterhead")
    (synopsis "Letterhead of the University of Western Australia")
    (description
     "This package generates the letterhead of the @acronym{UWA, University of
Western Australia}.  It requires the UWA logo in PDF format, which is
available in SVG format at
@url{https://static-listing.weboffice.uwa.edu.au/visualid/core-rebrand/img/uwacrest/},
and uses the Arial and UWA Slab fonts by default.  The package works with
XeLaTeX and LuaLaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-uwa-pcf
  (package
    (name "texlive-uwa-pcf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uwa-pcf/" "source/latex/uwa-pcf/"
                                     "tex/latex/uwa-pcf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b41nfrrqmcq3abcwb13hb9anhb5c12c5ha60ni1yz2xqvimr1im"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uwa-pcf")
    (synopsis
     "@acronym{PCF, Participant Consent Form} for a human research protocol
at the University of Western Australia")
    (description
     "This LaTeX class generates a @acronym{PCF, Participant Consent Form} for
a human research protocol at the @acronym{UWA, University of Western
Australia}.  It requires the UWA logo in PDF format, which is available in SVG
format at
@url{https://static-listing.weboffice.uwa.edu.au/visualid/core-rebrand/img/uwacrest/},
and uses the Arial and UWA Slab fonts by default.  The class works with
XeLaTeX and LuaLaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-uwa-pif
  (package
    (name "texlive-uwa-pif")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uwa-pif/" "source/latex/uwa-pif/"
                                     "tex/latex/uwa-pif/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "048367w14wnk8h517xc914xvp0g10ysk0kziikk2s4q70qk2jci0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uwa-pif")
    (synopsis
     "@acronym{PIF, Participant Information Form} for a human research
protocol at the University of Western Australia")
    (description
     "This package generates a @acronym{PIF, Participant Information Form} for
a human research protocol at the @acronym{UWA, University of Western
Australia}.  It requires the UWA logo in PDF format, which is available in SVG
format at
@url{https://static-listing.weboffice.uwa.edu.au/visualid/core-rebrand/img/uwacrest/},
and uses the Calibri fonts by default.  The class works with XeLaTeX and
LuaLaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-uwthesis
  (package
    (name "texlive-uwthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uwthesis/" "tex/latex/uwthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wcxpvr86556gxbcprwcv6ipdq3flyfwbcmjkxhy6x6220sfwp56"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uwthesis")
    (synopsis "University of Washington thesis class")
    (description "This is a thesis class for the University of Washington.")
    (license license:asl2.0)))

(define-public texlive-vak
  (package
    (name "texlive-vak")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/vak/" "doc/bibtex/vak/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1v8bg5yvihskx04m1jjmhlykj2azqb0qv4b2a56vqirrwhldks75"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/vak")
    (synopsis "BibTeX style for Russian theses, books, etc")
    (description
     "The file can be used to format the bibliographies of PhD theses,
books etc., according to the latest Russian standards: GOST 7.82 -- 2001 and
GOST 7.1 -- 2003.  It introduces the minimum number of new entries and styles
to cover all frequently used situations.  The style file provides an easy way
to perform a semiautomatic, or a completely manual sort of the list of the
references.  Processing bibliographies produced by the style requires a 8-bit
BibTeX system.")
    (license license:lppl)))

(define-public texlive-vancouver
  (package
    (name "texlive-vancouver")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/vancouver/"
                                     "doc/bibtex/vancouver/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r8x945cx32zn6ky4qqrki4xrj8ipbmkgm2dijmws5m0bkkh276r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/vancouver")
    (synopsis "Bibliographic style file for Biomedical journals")
    (description
     "This BibTeX style file is expected to meet the Uniform Requirements for
Manuscripts Submitted to Biomedical Journals (also known as the Vancouver
style).")
    (license license:lppl1.3+)))

(define-public texlive-velthuis
  (package
    (name "texlive-velthuis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/velthuis/"
                                     "doc/man/man1/devnag.1"
                                     "doc/man/man1/devnag.man1.pdf"
                                     "fonts/afm/public/velthuis/"
                                     "fonts/map/dvips/velthuis/"
                                     "fonts/source/public/velthuis/"
                                     "fonts/tfm/public/velthuis/"
                                     "fonts/type1/public/velthuis/"
                                     "tex/generic/velthuis/"
                                     "tex/latex/velthuis/"
                                     "tex/plain/velthuis/"
                                     "tex/xelatex/velthuis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h9maci6b65x7zy13v5j4vlr07lnghiwckh7bn4ix7d1wmh74bij"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (propagated-inputs (list texlive-velthuis-bin texlive-xetex-devanagari))
    (home-page "https://ctan.org/pkg/devanagari")
    (synopsis "Typeset Devanagari")
    (description
     "This package provides Frans Velthuis preprocessor for Devanagari text,
and fonts and macros to use when typesetting the processed text.  The macros
provide features that support Sanskrit, Hindi, Marathi, Nepali, and other
languages typically printed in the Devanagari script.  The package provides
fonts, in both Metafont and Type 1 formats.")
    (license license:gpl3+)))

(define-public texlive-velthuis-bin
  (package
    (inherit texlive-bin)
    (name "texlive-velthuis-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '("devnag"))
            (delete-other-directories "texk" '())))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-devnag" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "utils/devnag"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "utils/devnag"
                  (invoke "make" "install"))))))))
    (native-inputs '())
    (inputs '())
    (propagated-inputs '())
    (home-page (package-home-page texlive-velthuis))
    (synopsis "Binary for @code{texlive-velthuis}")
    (description
     "This package provide the binary for @code{texlive-velthuis}.")
    (license (package-license texlive-velthuis))))

(define-public texlive-venn
  (package
    (name "texlive-venn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/venn/" "metapost/venn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08pp3b58lng4lfaphhpw5nrczlhj86kgi1ciq12f9241z4qgnq6q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/venn")
    (synopsis "Creating Venn diagrams with MetaPost")
    (description "This package provides MetaPost macros for Venn diagrams.")
    (license license:lppl)))

(define-public texlive-venturisadf
  (package
    (name "texlive-venturisadf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/venturisadf/"
                                     "fonts/afm/arkandis/venturis/"
                                     "fonts/afm/arkandis/venturis2/"
                                     "fonts/afm/arkandis/venturisold/"
                                     "fonts/afm/arkandis/venturissans/"
                                     "fonts/afm/arkandis/venturissans2/"
                                     "fonts/enc/dvips/venturisadf/"
                                     "fonts/map/dvips/venturis/"
                                     "fonts/map/dvips/venturis2/"
                                     "fonts/map/dvips/venturisold/"
                                     "fonts/map/dvips/venturissans/"
                                     "fonts/map/dvips/venturissans2/"
                                     "fonts/tfm/arkandis/venturis/"
                                     "fonts/tfm/arkandis/venturis2/"
                                     "fonts/tfm/arkandis/venturisold/"
                                     "fonts/tfm/arkandis/venturissans/"
                                     "fonts/tfm/arkandis/venturissans2/"
                                     "fonts/type1/arkandis/venturis/"
                                     "fonts/type1/arkandis/venturis2/"
                                     "fonts/type1/arkandis/venturisold/"
                                     "fonts/type1/arkandis/venturissans/"
                                     "fonts/type1/arkandis/venturissans2/"
                                     "fonts/vf/arkandis/venturis/"
                                     "fonts/vf/arkandis/venturis2/"
                                     "fonts/vf/arkandis/venturisold/"
                                     "fonts/vf/arkandis/venturissans/"
                                     "fonts/vf/arkandis/venturissans2/"
                                     "source/fonts/venturisadf/"
                                     "tex/latex/venturis/"
                                     "tex/latex/venturis2/"
                                     "tex/latex/venturisadf/"
                                     "tex/latex/venturisold/"
                                     "tex/latex/venturissans/"
                                     "tex/latex/venturissans2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nvr9g1zzm51zjws52y8cyyi3y1z77q8s7iwgcb6jq4s9n4b4xbc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/venturisadf")
    (synopsis "Venturis ADF fonts collection")
    (description
     "This package provides Venturis ADF fonts collection, serif and sans
serif complete text font families, in both Adobe Type 1 and OpenType formats
for publication.  The family is based on Utopia family.  Support for using the
fonts, in LaTeX, is also provided.")
    (license (list license:lppl1.3+
                   (license:fsf-free
                    "http://mirrors.ctan.org/fonts/utopia/README")))))

(define-public texlive-verse
  (package
    (name "texlive-verse")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/verse/" "source/latex/verse/"
                                     "tex/latex/verse/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01c9mrq0zsa8i3wrhv4i21mcbl9y2ryjjnkph8v4d60wxsz6jcpy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/verse")
    (synopsis "Aids for typesetting simple verse")
    (description
     "The package provides aids for typesetting simple verses; the package is
strong on layout, from simple alternate-line indentation to the @code{Mouse's
tale} from @emph{Alice in Wonderland}.")
    (license license:lppl)))

(define-public texlive-vlna
  (package
    (name "texlive-vlna")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/vlna.1"
                                     "doc/man/man1/vlna.man1.pdf" "doc/vlna/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nfb7mj6y9d4n89z59ppi96grfylwky97mxcv9rjflr5kpqlpga2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-vlna-bin))
    (home-page "https://ctan.org/pkg/vlna")
    (synopsis "Add @samp{~} after non-syllabic preposition, for Czech/Slovak")
    (description
     "This package provides a preprocessor for TeX source implementing the
Czech/Slovak typographical rule forbidding a non-syllabic preposition alone at
the end of a line.")
    (license license:knuth)))

(define-public texlive-vlna-bin
  (package
    (inherit texlive-bin)
    (name "texlive-vlna-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '("vlna"))
            (delete-other-directories "texk" '())))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-vlna" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "utils/vlna"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "utils/vlna"
                  (invoke "make" "install"))))))))
    (native-inputs '())
    (inputs '())
    (propagated-inputs '())
    (home-page (package-home-page texlive-vlna))
    (synopsis "Binary for @code{texlive-vlna}")
    (description
     "This package provides the binary for @code{texlive-vlna}.")
    (license (package-license texlive-vlna))))

(define-public texlive-vntex
  (package
    (name "texlive-vntex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/vntex/"
                                     "fonts/afm/vntex/chartervn/"
                                     "fonts/afm/vntex/grotesqvn/"
                                     "fonts/afm/vntex/urwvn/"
                                     "fonts/afm/vntex/vntopia/"
                                     "fonts/enc/dvips/vntex/"
                                     "fonts/enc/pdftex/vntex/"
                                     "fonts/map/dvips/vntex/"
                                     "fonts/source/vntex/vnr/"
                                     "fonts/tfm/vntex/arevvn/"
                                     "fonts/tfm/vntex/chartervn/"
                                     "fonts/tfm/vntex/cmbrightvn/"
                                     "fonts/tfm/vntex/concretevn/"
                                     "fonts/tfm/vntex/grotesqvn/"
                                     "fonts/tfm/vntex/txttvn/"
                                     "fonts/tfm/vntex/urwvn/"
                                     "fonts/tfm/vntex/vnr/"
                                     "fonts/tfm/vntex/vntopia/"
                                     "fonts/type1/vntex/arevvn/"
                                     "fonts/type1/vntex/chartervn/"
                                     "fonts/type1/vntex/cmbrightvn/"
                                     "fonts/type1/vntex/concretevn/"
                                     "fonts/type1/vntex/grotesqvn/"
                                     "fonts/type1/vntex/txttvn/"
                                     "fonts/type1/vntex/urwvn/"
                                     "fonts/type1/vntex/vnr/"
                                     "fonts/type1/vntex/vntopia/"
                                     "fonts/vf/vntex/chartervn/"
                                     "fonts/vf/vntex/urwvn/"
                                     "fonts/vf/vntex/vntopia/"
                                     "source/generic/vntex/"
                                     "tex/latex/vntex/"
                                     "tex/plain/vntex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vbpxzqvqpymw2chgrrva7alrvp6lj735hy8wqksal968sch6azx"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ec")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ec texlive-metafont))
    (home-page "https://ctan.org/pkg/vntex")
    (synopsis "Support for Vietnamese")
    (description
     "The vntex bundle provides fonts, Plain TeX, texinfo and LaTeX macros for
typesetting documents in Vietnamese.  Users of the fonts (in both Metafont and
Adobe Type 1 format) of this bundle may alternatively use the @code{lm} fonts
bundle, for which map files are available to provide a Vietnamese version.")
    ;; Vietnamese glyphs has been added according to the conditions of the
    ;; Adobe/TUG license agreement.  The package itself is released under
    ;; LPPL1.3+ terms.
    (license (list license:lppl1.3+
                   (license:fsf-free "file://source/generic/vntex/LICENSE-utopia.txt")))))

(define-public texlive-wallpaper
  (package
    (name "texlive-wallpaper")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/wallpaper/"
                                     "tex/latex/wallpaper/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07ynf0b7czqqz0ha70ccvdxmcm3s6px82s1101llwbpxhwpqis5i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/wallpaper")
    (synopsis
     "Add wallpapers (background images) to LaTeX documents, including tiling")
    (description
     "This collection contains files to add wallpapers (background images) to
LaTeX documents.  It provides simple commands to include effects such as
tiling.")
    (license license:lppl)))

(define-public texlive-wargame
  (package
    (name "texlive-wargame")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/wargame/" "source/latex/wargame/"
                                     "tex/latex/wargame/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1w2yasbwjnr41hyx7s7fm8f2lk4j0wq3bpg4rz6hd904fj391bma"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/wargame")
    (synopsis "LaTeX package to prepare hex'n'counter wargames")
    (description
     "This package can help make classic Hex'n'Counter wargames using LaTeX.
The package provide tools for generating Hex maps and boards Counters for
units, markers, and so on Counter sheets Order of Battle charts Illustrations
in the rules using the defined maps and counters The result will often be
a PDF (or set of PDFs) that contain everything one will need for
a game (rules, charts, boards, counter sheets).  The package uses NATO App6
symbology for units.  The package uses NATO App6 symbology for units.  The
package uses TikZ for most things.  The package support exporting the game to
a VASSAL module.")
    (license license:cc-by-sa4.0)))

(define-public texlive-windycity
  (package
    (name "texlive-windycity")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/windycity/"
                                     "tex/latex/windycity/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m9n3hyfmrnd84gns1aasdkdv05d9gpa69b6jnijdyvr3yxlh0x6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/windycity")
    (synopsis "Chicago style for BibLaTeX")
    (description
     "Windy City is a style for BibLaTeX that formats notes, bibliographies,
parenthetical citations, and reference lists according to the 17th edition of
@emph{The Chicago Manual of Style}.")
    (license license:lppl1.3+)))

(define-public texlive-witharrows
  (package
    (name "texlive-witharrows")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/witharrows/"
                                     "source/generic/witharrows/"
                                     "tex/generic/witharrows/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0872qr7chd175jpqyq8n3kfx38jyi7y0qmqf28mb37mkwg5dzdbd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/witharrows")
    (synopsis "Aligned math environments with arrows for comments")
    (description
     "This package provides an environment @code{WithArrows} which is similar
to the environment @code{aligned} of @code{amsmath} (and @code{mathtools}),
but gives the possibility to draw arrows on the right side of the alignment.
These arrows are usually used to give explanations concerning the mathematical
calculus presented.")
    (license license:lppl1.3+)))

(define-public texlive-wnri
  (package
    (name "texlive-wnri")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/wnri/"
                                     "fonts/source/public/wnri/"
                                     "fonts/tfm/public/wnri/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p2b847a5xa00xvv46b8p0f2fhi1k01w4l7bm2517hs7inwj3brs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/wnri")
    (synopsis "Ridgeway's fonts")
    (description
     "This package provides fonts (as Metafont source) for Old English, Indic
languages in Roman transliteration and Puget Salish (Lushootseed) and other
Native American languages.")
    (license license:gpl3+)))

(define-public texlive-wnri-latex
  (package
    (name "texlive-wnri-latex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/wnri-latex/"
                                     "source/latex/wnri-latex/"
                                     "tex/latex/wnri-latex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08ld2nys36vb368977dpwav75ffra2p8999dx4dwrs4vg6k2r2l7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/wnri-latex")
    (synopsis "LaTeX support for @code{wnri} fonts")
    (description
     "This package provides LaTeX support for the @code{wnri} fonts.")
    (license license:gpl2)))

(define-public texlive-wsemclassic
  (package
    (name "texlive-wsemclassic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/wsemclassic/"
                                     "source/latex/wsemclassic/"
                                     "tex/latex/wsemclassic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kq871pbf2xq0h0njsp3j0wygz6970y5nkara5v5kpby42kx96rl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/wsemclassic")
    (synopsis "LaTeX class for Bavarian school w-seminar papers")
    (description
     "The class is designed either to conform with the recommendations of the
Bavarian Kultusministerium for typesetting w-seminar papers (strict mode), or
to use another style which should look better.  The class is based on the
LaTeX standard @code{report} class.")
    (license license:bsd-3)))

(define-public texlive-wsuipa
  (package
    (name "texlive-wsuipa")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/wsuipa/"
                                     "fonts/source/public/wsuipa/"
                                     "fonts/tfm/public/wsuipa/"
                                     "tex/latex/wsuipa/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gj7d68gb82dxmrbz69ibgpw2q2h6sb22k8nl569r27m2sli60jy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    ;; FIXME: Font metrics generation fails with "! Strange path (turning
    ;; number is zero)" error.
    (arguments
     (list #:phases
           #~(modify-phases %standard-phases
               (delete 'generate-font-metrics))))
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/wsuipa")
    (synopsis "International Phonetic Alphabet fonts")
    (description
     "The package provides a 7-bit IPA font, as Metafont source, and macros
for support under TeXt1 and LaTeX.  The fonts (and macros) are now largely
superseded by the @code{tipa} fonts.")
    (license license:knuth)))

(define-public texlive-xcharter-math
  (package
    (name "texlive-xcharter-math")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/xcharter-math/"
                                     "fonts/opentype/public/xcharter-math/"
                                     "tex/latex/xcharter-math/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0knf8h2xgyxr6845q937sglw528cfgp9rdipp4db0qydrhc679bn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xcharter-math")
    (synopsis "XCharter-based OpenType Math font for LuaTeX and XeTeX")
    (description
     "This package provides an Unicode Math font XCharter-Math.otf meant to be
used together with XCharter Opentype Text fonts (extension of Bitstream
Charter) in LuaLaTeX or XeLaTeX documents.")
    (license (list license:silofl1.1 license:lppl1.3+))))

(define-public texlive-xcite
  (package
    (name "texlive-xcite")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xcite/" "source/latex/xcite/"
                                     "tex/latex/xcite/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r6f4wk7d3na9a8v20kqp24m46rsqgqx0n8k5hv3ynhqhzizhpll"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xcite")
    (synopsis "Use citation keys from a different document")
    (description
     "The package @code{xcite} is no longer necessary, because its
functionality has been taken over by @code{xr}, so this final version is just
a stub that loads @code{xr}.")
    (license license:lppl1.3c)))

(define-public texlive-xduthesis
  (package
    (name "texlive-xduthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xduthesis/"
                                     "source/latex/xduthesis/"
                                     "tex/latex/xduthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sdl1m869s4hcxdj3q2205x9xdgx0qy9ri9vjyma9rsv70sa648p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xduthesis")
    (synopsis "XeLaTeX template for writing Xidian University thesis")
    (description
     "This is a XeLaTeX template for writing theses to apply academic degrees
in Xidian University.  The template is designed according to the official
requirements on typesetting theses.  The template currently supports all
levels of degrees from bachelor to doctor, including both academic master and
professional master.")
    (license license:lppl1.3+)))

(define-public texlive-xduts
  (package
    (name "texlive-xduts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/xduts/" "source/xelatex/xduts/"
                                     "tex/xelatex/xduts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lgm0rqf3z3zy9ggsyhxm8ndl364a5jikb01fvcmldr7ld4hnn18"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ctex")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ctex))
    (home-page "https://ctan.org/pkg/xduts")
    (synopsis "Xidian University TeX suite")
    (description
     "XDUTS is designed to help Xidian University students use LaTeX
typesetting efficiently.  XDUTS contains a font configuration package that
meets the school's requirements and can be applied to any document class.  In
addition, there are thesis and thesis proposal templates for both
undergraduate and postgraduate that meet the school's requirements.")
    (license license:lppl1.3c)))

(define-public texlive-xecjk
  (package
    (name "texlive-xecjk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/xecjk/"
                                     "fonts/misc/xetex/fontmapping/xecjk/"
                                     "source/xelatex/xecjk/" "tex/xelatex/xecjk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mpmfrj0n00gpnh67zh627vxhpp6vim8x755vdpb75h36k8zm6yq"))))
    (outputs '("out" "doc"))
    ;; Prevent circular dependencies.
    (properties '((updater-ignored-propagated-inputs "texlive-ctex")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          (add-before 'build 'copy-ctxdocstrip.tex
            ;; There's a circular dependency between this package (where
            ;; `ctex' should be a native input) and `ctex' (where this package
            ;; is a propagated input).  To work around this, install the
            ;; specific "ctxdocstrip.tex" file from `ctex' in the build
            ;; directory and set TEXINPUTS variable accordingly so the process
            ;; can find it.
            (lambda* (#:key inputs #:allow-other-keys)
              (install-file (search-input-file inputs
                                               "tex/generic/ctex/ctxdocstrip.tex")
                            "build/")
              (setenv "TEXINPUTS" (string-append (getcwd) "/build:")))))))
    (native-inputs
     (list (package-source texlive-ctex)))
    (home-page "https://ctan.org/pkg/xecjk")
    (synopsis "Support for CJK documents in XeLaTeX")
    (description
     "This package provides a LaTeX package for typesetting CJK documents in
the way users have become used to, in the CJK package.")
    (license license:lppl1.3c)))

(define-public texlive-xecyrmongolian
  (package
    (name "texlive-xecyrmongolian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xecyrmongolian/"
                                     "source/latex/xecyrmongolian/"
                                     "tex/latex/xecyrmongolian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0097l8vx76sqpimljwxw194yg6drxzagjxflq3y99n0a0yisax05"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xecyrmongolian")
    (synopsis
     "Basic support for Cyrillic Mongolian documents using (Xe|Lua)LaTeX")
    (description
     "The @code{xecyrmongolian} package can be used to produce documents in
Cyrillic Mongolian using either XeLaTeX or LuaLaTeX.  The command
@code{\\setlanguage} can be used to load alternative hyphenation patterns so
to be able to create multilingual documents.")
    (license license:lppl1.3c)))

(define-public texlive-xmuthesis
  (package
    (name "texlive-xmuthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xmuthesis/"
                                     "source/latex/xmuthesis/"
                                     "tex/latex/xmuthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qnsh0q61zv4jrh92zkhgdk1lzk3fksa2iiv2c2hkyk55sjza6ac"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ctex")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ctex))
    (home-page "https://ctan.org/pkg/xmuthesis")
    (synopsis "XMU thesis style")
    (description "This class is designed for XMU thesis's writing.")
    (license license:lppl1.3c)))

(define-public texlive-xq
  (package
    (name "texlive-xq")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/xq/" "fonts/source/public/xq/"
                                     "fonts/tfm/public/xq/" "tex/latex/xq/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g9j4vdlcnidv247bmagqd7q357h6fkg3b5cx1765n38k1bx8ikx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/xq")
    (synopsis "Support for writing about xiangqi")
    (description
     "The package is for writing about xiangqi or chinese chess.  You can
write games or parts of games and show diagrams with special positions.")
    (license license:lppl)))

(define-public texlive-xskak
  (package
    (name "texlive-xskak")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xskak/" "source/latex/xskak/"
                                     "tex/latex/xskak/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b17y5i24adpb7f8jxf3lc5zwb1q4yf3w2vx9ql73xpi39xg6mcj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xskak")
    (synopsis "Extension to the @code{skak} package for chess typesetting")
    (description
     "Xskak, as its prime function, saves information about a chess game for
later use (e.g., to loop through a game to make an animated board).  The
package also extends the input that the parsing commands can handle and offers
an interface to define and switch between indefinite levels of styles.")
    (license license:lppl)))

(define-public texlive-xyling
  (package
    (name "texlive-xyling")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xyling/" "tex/latex/xyling/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c4bgkbd42japidvrfg3ibj4h1l8v6zlivy7bqyiyj8alzdjhq4g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xyling")
    (synopsis
     "Draw syntactic trees, etc., for linguistics literature, using XY-Pic")
    (description
     "The macros in this package model the construction of linguistic tree
structures as a genuinely graphical problem: they contain two types of
objects, ``branches'' and ``node labels'', and these are positioned relative
to a ``grid''.  It is essential that each of these three elements is
constructed independent of the other two, and hence they can be modified
without unwanted side effects.  The macros are based on the XY-Pic package.")
    (license license:lppl)))

(define-public texlive-xymtex
  (package
    (name "texlive-xymtex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xymtex/doc/"
                                     "doc/latex/xymtex/readme/"
                                     "source/latex/xymtex/base/"
                                     "source/latex/xymtex/chemist/"
                                     "source/latex/xymtex/xymtxpdf/"
                                     "source/latex/xymtex/xymtxps/"
                                     "tex/latex/xymtex/base/"
                                     "tex/latex/xymtex/chemist/"
                                     "tex/latex/xymtex/xymtxpdf/"
                                     "tex/latex/xymtex/xymtxps/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xj8q4l2xv69sqdqkr4cqzldhnqxfymm0avhc220pl3q74cabh0b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xymtex")
    (synopsis "Typesetting chemical structures")
    (description
     "XyMTeX is a set of packages for drawing a wide variety of chemical
structural formulas in a way that reflects their structure.  The package
provides three output modes: LaTeX, PostScript and PDF.")
    (license license:lppl1.3+)))

(define-public texlive-yathesis
  (package
    (name "texlive-yathesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/yathesis/"
                                     "source/latex/yathesis/"
                                     "tex/latex/yathesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0aa9875am0gxy7fxf3z9xdxva8x9anlx8k82c1hz95s3m119fccs"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments
     (list #:build-targets #~(list "yathesis.dtx")
           #:tex-format "lualatex"))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-accsupp
                  texlive-alphalph
                  texlive-attachfile2
                  texlive-babel-french
                  texlive-biblatex
                  texlive-booktabs
                  texlive-caption
                  texlive-cleveref
                  texlive-comment
                  texlive-csquotes
                  texlive-datetime2
                  texlive-denisbdoc
                  texlive-enumitem
                  texlive-environ
                  texlive-fancyvrb
                  texlive-fixfoot
                  texlive-fontawesome
                  texlive-fontspec
                  texlive-footmisc
                  texlive-glossaries
                  texlive-glossaries-extra
                  texlive-gofonts
                  texlive-hologo
                  texlive-hypdoc
                  texlive-ifmtarg
                  texlive-imakeidx
                  texlive-libertine
                  texlive-listings
                  texlive-marginnote
                  texlive-morewrites
                  texlive-mparhack
                  texlive-multirow
                  texlive-newunicodechar
                  texlive-path
                  texlive-parskip
                  texlive-pdfcol
                  texlive-pdflscape
                  texlive-pgf
                  texlive-refcount
                  texlive-siunitx
                  texlive-tcolorbox
                  texlive-textcase
                  texlive-tikzfill
                  texlive-tocbibind
                  texlive-tocvsec2
                  texlive-translator
                  texlive-underscore
                  texlive-xifthen
                  texlive-xpatch
                  texlive-zref))))
    (home-page "https://ctan.org/pkg/yathesis")
    (synopsis "LaTeX class for writing a thesis following French rules")
    (description
     "The purpose of @code{yathesis} is to facilitate the typesetting of
theses prepared in France, whatever the disciplines and institutes.  It
implements most notably recommendations from the Ministry of Higher Education
and Research, and this transparently to the user.  It has also been designed
to (optionally) take advantage of powerful tools available in LaTeX, including
packages: BibLaTeX for the bibliography; @code{glossaries} for the glossary,
list of acronyms and symbols list.")
    (license license:lppl1.3c)))

(define-public texlive-yazd-thesis
  (package
    (name "texlive-yazd-thesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/yazd-thesis/"
                                     "tex/xelatex/yazd-thesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zwzzzf8z0p0cl6l3wjqnfj80pym4wx5halb3rl1i6bmvyypgafz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/yazd-thesis")
    (synopsis "Template for the Yazd University")
    (description
     "This package offers a document class for typesetting theses and
dissertations at the Yazd University.  The class requires use of XeLaTeX.")
    (license license:lppl1.3c)))

(define-public texlive-yb-book
  (package
    (name "texlive-yb-book")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/yb-book/" "source/latex/yb-book/"
                                     "tex/latex/yb-book/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ii4c3kslbhj7im8q0d7lj130kfh1sflq8hx04hiyl7qlyfd5n1a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-anyfontsize
           texlive-biblatex
           texlive-bigfoot
           texlive-changepage
           texlive-chngcntr
           texlive-csquotes
           texlive-enumitem
           texlive-fancyhdr
           texlive-float
           texlive-footmisc
           texlive-geometry
           texlive-ifmtarg
           texlive-imakeidx
           texlive-lastpage
           texlive-libertine
           texlive-mdframed
           texlive-microtype
           texlive-needspace
           texlive-paralist
           texlive-pgf
           texlive-qrcode
           texlive-setspace
           texlive-soul
           texlive-titlesec
           texlive-ulem
           texlive-wrapfig
           texlive-xcolor
           texlive-xifthen
           texlive-xkeyval
           texlive-zref))
    (home-page "https://ctan.org/pkg/yb-book")
    (synopsis "Template for YB branded books")
    (description
     "This template helps the author design books published on Amazon under
the ``Y.B.'' brand.")
    (license license:expat)))

(define-public texlive-yfonts
  (package
    (name "texlive-yfonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/yfonts/" "source/latex/yfonts/"
                                     "tex/latex/yfonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "021sb52516ksxs1pb8nb1gchaagb0hblx55yyxzpywrryfkjd3rx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/yfonts")
    (synopsis "Support for old German fonts")
    (description
     "This package provides a LaTeX interface to the old German Gothic,
Schwabacher, Fraktur and the baroque initials.")
    (license license:lppl)))

(define-public texlive-yfonts-otf
  (package
    (name "texlive-yfonts-otf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/yfonts-otf/"
                                     "fonts/opentype/public/yfonts-otf/"
                                     "tex/latex/yfonts-otf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dnif4hiwqri67cx6bjzs0rvz3ayrkn6fs99qn4q9qggs6s25l0j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/yfonts-otf")
    (synopsis "OpenType version of the Old German fonts")
    (description
     "This is an OpenType version of the Old German fonts @code{yfrak},
@code{ygoth}, @code{yswab} designed by Yannis Haralambous in Metafont.  The
OpenType features make it easier to deal with the long/round @samp{s} and with
older forms of umlauts (small @samp{e} over the letter).  A style file
@file{yfonts-otf.sty} is provided as a replacement, for LuaLaTeX and XeLaTeX,
of @file{yfonts.sty} or @file{oldgerm.sty}.")
    (license (list license:silofl1.1 license:lppl1.3+))))

(define-public texlive-yfonts-t1
  (package
    (name "texlive-yfonts-t1")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/yfonts-t1/" "dvips/yfonts-t1/"
                                     "fonts/afm/public/yfonts-t1/"
                                     "fonts/map/dvips/yfonts-t1/"
                                     "fonts/type1/public/yfonts-t1/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1w92sgkarqx7z2ai6z059bml0kbh05fjyy9fl12x3nb0f5agjs7n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/yfonts-t1")
    (synopsis "Old German-style fonts, in Adobe type 1 format")
    (description
     "This package comprises type 1 versions of the Gothic, Schwabacher and
Fraktur fonts of Yannis Haralambous set of old German fonts.")
    ;; "Freely available for general use."
    (license (license:fsf-free "file://doc/fonts/yfonts-otf/README.md"))))

(define-public texlive-yhmath
  (package
    (name "texlive-yhmath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/yhmath/"
                                     "fonts/map/dvips/yhmath/"
                                     "fonts/source/public/yhmath/"
                                     "fonts/tfm/public/yhmath/"
                                     "fonts/type1/public/yhmath/"
                                     "fonts/vf/public/yhmath/"
                                     "source/fonts/yhmath/"
                                     "tex/latex/yhmath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0blzyr94d7ajb639j7bfnrpn52wicwfqwyba38hgh6s9hgx071cv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/yhmath")
    (synopsis "Extended maths fonts for LaTeX")
    (description
     "The @code{yhmath} bundle contains fonts (in Metafont and type 1 format)
and a LaTeX package for using them.")
    (license license:lppl1.3c)))

(define-public texlive-yinit-otf
  (package
    (name "texlive-yinit-otf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/yinit-otf/"
                                     "fonts/opentype/public/yinit-otf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0p3a56kg63smsgwr0vlfzjxrdw11j3777y09gdbdd1cc50r9p3zx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/yinit-otf")
    (synopsis
     "OTF conversion of Yannis Haralambous' Old German decorative initials")
    (description
     "This package is a conversion of the @code{yinit} font into OTF.
Original Metafont files for @code{yinit} are in the @code{yinit} package.")
    (license license:public-domain)))

(define-public texlive-york-thesis
  (package
    (name "texlive-york-thesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/york-thesis/"
                                     "source/latex/york-thesis/"
                                     "tex/latex/york-thesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wcl1zqmif2chramah8zmbgp5axbhlnjiygl7kgqnwqw5ajxkw4y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/york-thesis")
    (synopsis "Thesis class file for York University, Toronto")
    (description
     "York Graduate Studies has again changed the requirements for theses and
dissertations.  The established @code{york-thesis} class file now implements
the changes made in Spring 2005.")
    (license license:lppl1.3+)))

(define-public texlive-youngtab
  (package
    (name "texlive-youngtab")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/youngtab/"
                                     "source/generic/youngtab/"
                                     "tex/generic/youngtab/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "054dqrcrj32nsngjhxa7nig9ylz0p6smdaqc02mdpy299fwm23f2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/youngtab")
    (synopsis "Typeset Young-Tableaux")
    (description
     "This package provides a package for typesetting Young-Tableaux,
mathematical symbols for the representations of groups, providing two macros,
@code{\\yng(1)} and @code{\\young(1)} to generate the whole Young-Tableau.")
    (license license:lppl1.0+)))

(define-public texlive-yquant
  (package
    (name "texlive-yquant")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/yquant/" "tex/latex/yquant/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "054rmlp714ygsz2yviffkjjj4i45k5w9yjyl8rrrbibimgdc4f79"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/yquant")
    (synopsis "Typesetting quantum circuits in a human-readable language")
    (description
     "This LaTeX package allows quickly drawing quantum circuits.  It bridges
the gap between the two groups of packages that already exist: those that use
a logic-oriented custom language, which is then translated into TeX by means
of an external program; and the pure TeX versions that mainly provide some
macros to allow for an easier input.  @code{yquant} introduces a logic
oriented language and thus brings the best of both worlds together.  It builds
on and interacts with TikZ, which brings an enormous flexibility for
customization of individual circuit.")
    (license license:lppl1.3c)))

(define-public texlive-ytableau
  (package
    (name "texlive-ytableau")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ytableau/"
                                     "source/latex/ytableau/"
                                     "tex/latex/ytableau/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1px1gbpbm0vrv8xhdf1gfb6q6fh564y3zra0kg1ab3hcixbqsfxa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ytableau")
    (synopsis "Many-featured Young tableaux and Young diagrams")
    (description
     "The package provides several functions for drawing Young tableaux and
Young diagrams, extending the @code{young} and @code{youngtab} packages but
providing lots more features.  Skew and coloured tableaux are easy, and
pgfkeys-enabled options are provided both at package load and configurably.")
    (license license:lppl1.2+)))

(define-public texlive-zitie
  (package
    (name "texlive-zitie")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/zitie/" "tex/xelatex/zitie/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0la4fg42c20isdip5gnynzhkj0hn295lf48hbyjjfvadx7zx408s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/zitie")
    (synopsis "Create CJK character calligraphy practicing sheets")
    (description
     "This is a LaTeX package for creating CJK character calligraphy
practicing sheets (copybooks).  Currently, only XeTeX is supported.")
    (license license:lppl1.3c)))

(define-public texlive-zlmtt
  (package
    (name "texlive-zlmtt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/zlmtt/" "tex/latex/zlmtt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "014zchb0s9fj33d6h8r851v7v4cvpqzd97xaq4nv2l1lnxlii536"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/zlmtt")
    (synopsis "Use Latin Modern Typewriter fonts")
    (description
     "The package allows selection of Latin Modern Typewriter fonts with
scaling and access to all its features.")
    (license license:lppl1.3+)))

(define-public texlive-zootaxa-bst
  (package
    (name "texlive-zootaxa-bst")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/zootaxa-bst/"
                                     "doc/bibtex/zootaxa-bst/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "178daki12ky2hxjsdgz6nnc84741hdj0mn30lglp2sazqwjxrbw0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/zootaxa-bst")
    (synopsis "BibTeX style for the journal @emph{Zootaxa}")
    (description
     "This package provides a @file{.bst} reference style file for the journal
@emph{Zootaxa} that publishes contributions in zoology and classification.
This is a fork of @file{apa.bst}.")
    (license license:lppl1.3c)))

(define-public texlive-zx-calculus
  (package
    (name "texlive-zx-calculus")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/zx-calculus/"
                                     "tex/latex/zx-calculus/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04h0rxf6ricqiafb932pcfack9yc5mmq5r5q7ddszg11lwvxgh71"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/zx-calculus")
    (synopsis "Library to typeset ZX Calculus diagrams")
    (description
     "This library allows you to typeset ZX-calculus directly in LaTeX.  It
comes with many pre-built wire shapes, a highly customizable node style (with
multiple flavours for putting labels inside or outside nodes), and a debugging
mode to avoid getting lost in big diagrams.")
    (license license:expat)))

(define-public texlive-zxjafont
  (package
    (name "texlive-zxjafont")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/zxjafont/" "tex/latex/zxjafont/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n8sky4aprs7r12pvyj6q1lman57k94s7mkynnzfw1z4xnam459j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/zxjafont")
    (synopsis "Set up Japanese font families for XeLaTeX")
    (description "This package sets up Japanese font families for XeLaTeX.")
    (license license:expat)))

(define-public texlive-zxjatype
  (package
    (name "texlive-zxjatype")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/zxjatype/" "tex/latex/zxjatype/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0llm0414kdwqsajb1nl92xa8kqwvbm446pwijag2735gk8rxqz8j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/zxjatype")
    (synopsis "Standard conforming typesetting of Japanese, for XeLaTeX")
    (description "This package eases standard conforming typesetting of
Japanese, for XeLaTeX.")
    (license license:expat)))

(define-public texlive-zxjafbfont
  (package
    (name "texlive-zxjafbfont")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/zxjafbfont/"
                                     "tex/latex/zxjafbfont/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vwbr2nwxp5f8c7q1gwm9z3karjkxjxr1j4lg5p12ljqlwm7p3lw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/zxjafbfont")
    (synopsis "Fallback CJK font support for xeCJK")
    (description "This package provides fallback CJK font support for xeCJK.")
    (license license:expat)))

(define-public texlive-biblatex-cheatsheet
  (package
    (name "texlive-biblatex-cheatsheet")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-cheatsheet/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y2ry2q1kvpy8dqglqdfq3rc849hmbni0k78wr1xnjbpd102l3k9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-cheatsheet")
    (synopsis "BibLaTeX and Biber cheat sheet")
    (description "This package provides a BibLaTeX and Biber cheat sheet.")
    (license license:lppl1.3+)))

(define-public texlive-bibtex8
  (package
    (name "texlive-bibtex8")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/csf/base/" "bibtex/csf/polish-csf/"
                                     "doc/bibtex8/" "doc/man/man1/bibtex8.1"
                                     "doc/man/man1/bibtex8.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ywv5rdk08dnrqr09pnjzff37x2c9m5i1wjzfsjnvm068is58c7s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-bibtex8-bin))
    (home-page "https://ctan.org/pkg/bibtex8")
    (synopsis "BibTeX variant supporting 8-bit encodings")
    (description
     "BibTeX8 is an enhanced, portable C version of BibTeX.  It is enhanced by
conversion to larger (32-bit) capacity, addition of run-time selectable
capacity and 8-bit support extensions.  National character set and sorting
order are controlled by an external configuration file.")
    (license license:gpl3+)))

(define-public texlive-bibtex8-bin
  (package
    (inherit texlive-bin)
    (name "texlive-bibtex8-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs with-files?)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir
                       "."
                       (lambda (file)
                         (and (not (member file (append '("." "..") dirs)))
                              (or with-files?
                                  (eq? 'directory (stat:type (stat file))))))))))))
            (delete-other-directories "libs" '() #f)
            (delete-other-directories "utils" '() #f)
            ;; Tests require "texmf.cnf" to be present in the tree.  Also test
            ;; data is spread across multiple directories, which need to be
            ;; preserved.
            (delete-other-directories "texk" '("bibtex-x" "kpathsea" "tests" "web2c") #f)
            (delete-other-directories "texk/web2c" '("tests") #t)
            (with-directory-excursion "texk/kpathsea"
              (for-each
               delete-file-recursively
               (scandir "." (lambda (f)
                              (not (member f '("." ".." "texmf.cnf")))))))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons* "--enable-bibtex-x"
                 "--enable-bibtex8"
                 "--disable-bibtexu"
                 (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (add-after 'unpack 'locate-libkpathsea
              (lambda _
                (let ((kpathsea #$(this-package-input "texlive-libkpathsea")))
                  (substitute* "texk/bibtex-x/Makefile.in"
                    (("(KPATHSEA_LIBS =).*" _ lead)
                     (format #f "~a \"-L~a/lib -lkpathsea\"\n" lead kpathsea))))))
            (add-after 'unpack 'skip-bibtexu-test
              ;; This package does not build "bibtexu" binary; the test below
              ;; is therefore bound to fail.  Skip that part.
              (lambda _
                (substitute* "texk/bibtex-x/tests/bibtex8u-mem.test"
                  (("_bibtexu=.*") "_bibtexu=echo\n"))))
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/bibtex-x"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/bibtex-x"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list texlive-libkpathsea))
    (propagated-inputs '())
    (home-page (package-home-page texlive-bibtex8))
    (synopsis "Binary for @code{texlive-bibtex8}")
    (description
     "This package provides the binary for @code{texlive-bibtex8}.")
    (license (package-license texlive-bibtex8))))

(define-public texlive-bibtexu
  (package
    (name "texlive-bibtexu")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/bibtexu/" "doc/man/man1/bibtexu.1"
                                     "doc/man/man1/bibtexu.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19bp8wn0ssz7gczxp0imbpgi1zwz9x3ya67f072rjzg2zmfpphqg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-bibtexu-bin))
    (home-page "https://ctan.org/pkg/bibtexu")
    (synopsis "BibTeX variant supporting Unicode (UTF-8), via ICU")
    (description
     "BibTeXu is an enhanced, portable C version of BibTeX.  Unicode is
supported via the ICU library.")
    (license license:gpl3+)))

(define-public texlive-bibtexu-bin
  (package
    (inherit texlive-bibtex8-bin)
    (name "texlive-bibtexu-bin")
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bibtex8-bin)
       ((#:configure-flags flags)
        #~(cons* "--enable-bibtexu"
                 "--disable-bibtex8"
                 (delete "--enable-bibtex8"
                         (delete "--disable-bibtexu" #$flags))))
       ((#:phases phases)
        #~(modify-phases #$phases
            (delete 'skip-bibtexu-test)
            (add-after 'unpack 'skip-bibtex8-test
              ;; This package does not build "bibtex8" binary; the test below
              ;; is therefore bound to fail.  Skip that part.
              (lambda _
                (substitute* "texk/bibtex-x/tests/bibtex8u-mem.test"
                  (("_bibtex8=.*") "_bibtex8=echo\n"))))))))
    (native-inputs (list perl pkg-config))
    (inputs (list icu4c texlive-libkpathsea))
    (home-page (package-home-page texlive-bibtexu))
    (synopsis "Binary for @code{texlive-bibtexu}")
    (description
     "This package provides the binary for @code{texlive-bibtexu}.")
    (license (package-license texlive-bibtexu))))

(define-public texlive-bundledoc
  (package
    (name "texlive-bundledoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/arlatex.1"
                                     "doc/man/man1/arlatex.man1.pdf"
                                     "doc/man/man1/bundledoc.1"
                                     "doc/man/man1/bundledoc.man1.pdf"
                                     "doc/support/bundledoc/"
                                     "scripts/bundledoc/"
                                     "tex/latex/bundledoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1drgwqgkhr6ba4c21kyykl5y92x7dp6971if2hfcxsqk6kqy3ip1"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "arlatex" "bundledoc")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/bundledoc")
    (synopsis "Bundle together all the files needed to build a LaTeX document")
    (description
     "The @code{bundledoc} package is a post-processor for the snapshot
package that bundles together all the classes, packages and files needed to
build a given LaTeX document.  It reads the @file{.dep} file that snapshot
produces, finds each of the files mentioned therein, and archives them into
a single @file{.tar.gz} (or @file{.zip}, or whatever) file, suitable for
moving across systems, transmitting to a colleague, etc.  A script,
@command{arlatex}, provides an alternative archiving mechanism, creating
a single LaTeX file that contains all of the ancillary files of a LaTeX
document, together with the document itself, using the @code{filecontents*}
environment.")
    (license license:lppl1.3c)))

(define-public texlive-checklistings
  (package
    (name "texlive-checklistings")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/checklistings/"
                                     "scripts/checklistings/"
                                     "source/latex/checklistings/"
                                     "tex/latex/checklistings/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ggq4i7nfx6ijqikgr48qgaaf7rd9h4a834gwsz8dv5f0zmgg1za"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "checklistings.sh")))
    (home-page "https://ctan.org/pkg/checklistings")
    (synopsis
     "Pass verbatim content through a compiler and reincorporate the resulting output")
    (description
     "This package augments the @code{fancyvrb} and @code{listings} packages
to allow the source code they contain to be checked by an external tool (like
a compiler).  The external tool's messages can be automatically reincorporated
into the original document.  The package does not focus on a specific
programming language, but it is designed to work well with languages and
compilers in the ML family.")
    (license license:lppl1.2+)))

(define-public texlive-chklref
  (package
    (name "texlive-chklref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/chklref.1"
                                     "doc/man/man1/chklref.man1.pdf"
                                     "doc/support/chklref/" "scripts/chklref/"
                                     "tex/latex/chklref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1namyi035gqhvldplj0yzfkgxq91zrifqxhsf32jgxhjgcbbal6g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "chklref.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/chklref")
    (synopsis "Check for problems with labels in LaTeX")
    (description
     "It is quite common that after modifying a TeX file, many unused labels
remain in it.  The purpose of chklref is to automatically find these useless
labels.  It also looks for non starred mathematical environments with no
labels and advises the user to use a starred version instead.")
    (license license:gpl3)))

(define-public texlive-chktex
  (package
    (name "texlive-chktex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "chktex/"
                                     "doc/chktex/"
                                     "doc/man/man1/chktex.1"
                                     "doc/man/man1/chktex.man1.pdf"
                                     "doc/man/man1/chkweb.1"
                                     "doc/man/man1/chkweb.man1.pdf"
                                     "doc/man/man1/deweb.1"
                                     "doc/man/man1/deweb.man1.pdf"
                                     "scripts/chktex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vskxbrlhm5sd5jlyqszsf747fmi082ss8iy0ia1m4plmszcvvpn"))))
    (outputs '("out" "doc"))
    (properties '((updater-ignored-inputs "perl"))) ;in "-bin" already
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-chktex-bin))
    (home-page "https://ctan.org/pkg/chktex")
    (synopsis "Check for errors in LaTeX documents")
    (description
     "The program reports typographic and other errors in LaTeX documents.
Filters are also provided for checking the LaTeX parts of CWEB documents.")
    (license license:gpl2+)))

(define-public texlive-chktex-bin
  (package
    (inherit texlive-bin)
    (name "texlive-chktex-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root keep)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir
                       "."
                       (lambda (file)
                         (and (not (member file (append keep '("." ".."))))
                              (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("chktex"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-chktex" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (add-after 'unpack 'locate-global-configuration-file
              ;; `chktex' needs to know where its global configuration file is.
              ;; However, it cannot understand our convoluted TEXMFMAIN value.
              ;; This phase forces configuration file name.
              (lambda _
                (substitute* "texk/chktex/chktex-src/OpSys.c"
                  (("kpse_var_value\\(\"TEXMFMAIN\"\\)")
                   (string-append "strdup(\"" #$output "/share/texmf-dist\")")))))
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/chktex"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/chktex"
                  (invoke "make" "install"))))
            ;; Compilation forces a "/usr/bin/env perl" shebang.  Change it.
            (add-after 'install 'patch-shebang
              (lambda _
                (patch-shebang
                 (string-append #$output
                                "/share/texmf-dist/scripts/chktex/deweb.pl"))))))))
    (native-inputs (list pkg-config))
    (inputs (list perl texlive-libkpathsea))
    (propagated-inputs '())
    (home-page (package-home-page texlive-chktex))
    (synopsis "Binaries for @code{texlive-chktex}")
    (description
     "This package provides the binaries for @code{texlive-chktex}.")
    (license (package-license texlive-chktex))))

(define-public texlive-clojure-pamphlet
  (package
    (name "texlive-clojure-pamphlet")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/pamphletangler.1"
                                     "doc/man/man1/pamphletangler.man1.pdf"
                                     "doc/support/clojure-pamphlet/"
                                     "scripts/clojure-pamphlet/"
                                     "source/support/clojure-pamphlet/"
                                     "tex/latex/clojure-pamphlet/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dadr9wg7fa2vb6qkzqghrwmnns8jf4la1gb837a59jz2lh8955h"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "pamphletangler")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/clojure-pamphlet")
    (synopsis "Literate programming tool based on Clojure's Pamphlet system")
    (description
     "The Clojure pamphlet system is a system based on the Clojure literate
system.  In the Clojure's pamphlet system you have your main LaTeX file, which
can be compiled regularly.  This file contains documentation and source
code (just like in other forms of literate programming).  These code snippets
are wrapped in the @code{chunk} environment, hence they can be recognized by
the tangler in order to extract them.  Chunks can be included inside each
other by the @code{getchunk} command (which will be typesetted accordingly).
Finally, the LaTeX file will be run through the tangler to get the desired
chunk of code.")
    (license license:gpl3+)))

(define-public texlive-cluttex
  (package
    (name "texlive-cluttex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/cllualatex.1"
                                     "doc/man/man1/cllualatex.man1.pdf"
                                     "doc/man/man1/cluttex.1"
                                     "doc/man/man1/cluttex.man1.pdf"
                                     "doc/man/man1/clxelatex.1"
                                     "doc/man/man1/clxelatex.man1.pdf"
                                     "doc/support/cluttex/"
                                     "scripts/cluttex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1k2142c0j2h9vri211b3gy2azl9yxnribv5kg69yi5q9bfvz6bnh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts #~(list "cluttex.lua")
           #:phases
           #~(modify-phases %standard-phases
               (add-after 'link-scripts 'add-symlink
                 (lambda _
                   (with-directory-excursion (string-append #$output "/bin")
                     (for-each (lambda (link) (symlink "cluttex" link))
                               '("cllualatex" "clxelatex"))))))))
    (home-page "https://ctan.org/pkg/cluttex")
    (synopsis "Automation tool for running LaTeX")
    (description
     "This is another tool for the automation of LaTeX document processing,
like @command{latexmk} or @command{arara}.  The main feature of this tool is
that it does not clutter your working directory with @file{.aux} or
@file{.log} or other auxiliary files.  It has of course the usual features of
automation tools.  It automatically re-runs (La)TeX for cross-references.
MakeIndex, BibTeX, Biber, or @command{makeglossaries} will be executed if
a corresponding option is set.  Furthermore, @command{cluttex} can watch input
files for changes (using an external program).")
    (license license:gpl3+)))

(define-public texlive-components
  (package
    (name "texlive-components")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/components/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04yg9hq0wcyi1ag9y9m2fnf5h3n4fdykiwljgpw0kyc73bfyhq1m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/components")
    (synopsis "Introduction to TeX components and files")
    (description
     "This package is an introduction to the components and files users of TeX
may encounter.")
    (license license:gpl3+)))

(define-public texlive-comprehensive
  (package
    (name "texlive-comprehensive")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/comprehensive/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cmw36bn6pjb6ajlrg2yz5imkrxihzzdkh56xwdk2abwzaqn09q6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/comprehensive")
    (synopsis "Symbols accessible from LaTeX")
    (description
     "This package document the symbols accessible from LaTeX.  Over 18000
symbols are listed as a set of tables.  The tables of symbols are ordered in
a logical way (the document begins with a frequently requested symbols list),
the aim being to make the document a convenient way of looking up symbols.")
    (license license:lppl1.3+)))

(define-public texlive-ctan-o-mat
  (package
    (name "texlive-ctan-o-mat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/ctan-o-mat.1"
                                     "doc/man/man1/ctan-o-mat.man1.pdf"
                                     "doc/support/ctan-o-mat/"
                                     "scripts/ctan-o-mat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pm95xh3ji2sgdy243nbnzxsg2p4xpl3pymkm5yg2fn3nzgwgnaf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "ctan-o-mat.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/ctan-o-mat")
    (synopsis "Upload or validate a package for CTAN")
    (description
     "This program can be used to automate the upload of a package to CTAN.
The description of the package is contained in a configuration file.  The
provided information is validated in any case.  If the validation succeeds and
not only the validation is requested, then the provided archive file will be
placed in the incoming area of the CTAN for further processing by the CTAN
team.  In any case any finding during the validation is reported at the end of
the processing.  Note that the validation is the default and an official
submission has to be requested by an appropriate command line option.")
    (license license:bsd-3)))

(define-public texlive-ctan-chk
  (package
    (name "texlive-ctan-chk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/ctan_chk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09ngqgs08q8bld334jrzhnd558lv7fajfppmfrkp4kv9hc5iyz9a"))))
    (outputs '("out" "doc"))
    (properties '((upstream-name . "ctan_chk")))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ctan_chk")
    (synopsis "CTAN guidelines verifier and corrector for uploading projects")
    (description
     "@code{ctan_chk} is a basic Gawk program that uses CTAN's published
guidelines for authors to help eliminate sloppiness in uploaded
files/projects.  It is completely open for users to program additional
guidelines as well as CTAN's future adjustments.")
    (license license:gpl3)))

(define-public texlive-ctanbib
  (package
    (name "texlive-ctanbib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/ctanbib.1"
                                     "doc/man/man1/ctanbib.man1.pdf"
                                     "doc/support/ctanbib/" "scripts/ctanbib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kmgs65xl0np02mrd4snvr6s0l5igr6laq5x6vbhsi7sqdr67xqs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "ctanbib")))
    (home-page "https://ctan.org/pkg/ctanbib")
    (synopsis "Export CTAN entries to bib format")
    (description
     "This package provides a Lua script which can be used for retrieving
bibliographic information in BibLaTeX format for packages hosted on CTAN.  The
@command{ctanbib} script depends only on LuaXML.")
    (license license:lppl1.3+)))

(define-public texlive-ctanify
  (package
    (name "texlive-ctanify")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ctanify/"
                                     "doc/man/man1/ctanify.1"
                                     "doc/man/man1/ctanify.man1.pdf"
                                     "scripts/ctanify/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m6gldzm0sm4j7v2kkrpqikx004sqdq0f2gw13gc8ccqzl745cjw"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "ctanify")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/ctanify")
    (synopsis "Prepare a package for upload to CTAN")
    (description
     "Given a list of filenames, @command{ctanify} creates a tarball (a
@file{.tar.gz} file) with the files laid out in CTAN's preferred structure.
By default this tarball additionally contains a ZIP file with copies of all
files laid out in the standard TeX Directory Structure (TDS), which may be
used by those intending to install the package, or by those who need to
incorporate it in a distribution.")
    (license license:lppl1.3c)))

(define-public texlive-ctanupload
  (package
    (name "texlive-ctanupload")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/ctanupload/"
                                     "scripts/ctanupload/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0w4k9sslhnpn5l90wbr7cr7pv8fhiiabasbi6l6gw3w3nrfmarh4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "ctanupload.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/ctanupload")
    (synopsis "Support for users uploading to CTAN")
    (description
     "The package provides a Perl script that allows the uploads of
a contribution to CTAN from the command line.  The aim is to simplify the
release process for LaTeX package authors.  Note by the CTAN
team (2015-02-05): It seems that this script is currently not working.")
    (license license:gpl3)))

(define-public texlive-ctex
  (package
    (name "texlive-ctex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ctex/" "source/latex/ctex/"
                                     "tex/generic/ctex/" "tex/latex/ctex/"
                                     "tex/luatex/ctex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17zyr0cyxvp91832q35ha3qabdzh4njh96yvp4gfkkfkkszqp3jh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     ;; FIXME: I couldn't find how to build this package from source.
     (list #:phases #~(modify-phases %standard-phases (delete 'build))))
    (propagated-inputs
     (list texlive-adobemapping
           texlive-atbegshi
           texlive-beamer
           texlive-cjk
           texlive-cjkpunct
           texlive-ec
           texlive-epstopdf-pkg
           texlive-etoolbox
           texlive-everyhook
           texlive-fandol
           texlive-fontspec
           texlive-iftex
           texlive-infwarerr
           texlive-kvoptions
           texlive-kvsetkeys
           texlive-latex-bin
           texlive-ltxcmds
           texlive-luatexja
           texlive-mptopdf
           texlive-ms
           texlive-pdftexcmds
           texlive-platex-tools
           texlive-svn-prov
           texlive-tipa
           texlive-tools
           texlive-ttfutils
           texlive-ulem
           texlive-uplatex
           texlive-xcjk2uni
           texlive-xecjk
           texlive-xetex
           texlive-xkeyval
           texlive-xpinyin
           texlive-xunicode
           texlive-zhmetrics
           texlive-zhmetrics-uptex
           texlive-zhnumber))
    (home-page "https://ctan.org/pkg/ctex")
    (synopsis "LaTeX classes and packages for Chinese typesetting")
    (description
     "CTeX is a collection of macro packages and document classes for LaTeX
Chinese typesetting.")
    (license license:lppl1.3c)))

(define-public texlive-ctex-faq
  (package
    (name "texlive-ctex-faq")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ctex-faq/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15c0g0x8w7vm3hyn6lk60jf66akyfcq6x8jc2lnbjx8ydwgb26br"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ctex-faq")
    (synopsis "LaTeX FAQ by the Chinese TeX Society (ctex.org)")
    (description
     "This is the LaTeX FAQ by the Chinese TeX Society.  Most questions were
collected on the @url{bbs.ctex.org} forum, and were answered in detail by the
author.")
    (license license:fdl1.3+)))

(define-public texlive-ctib
  (package
    (name "texlive-ctib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ctib/"
                                     "fonts/source/public/ctib/"
                                     "fonts/tfm/public/ctib/"
                                     "source/latex/ctib/" "tex/latex/ctib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qvh0icrijcsyi3kvzkp890qjx7j9axv9yzzfa1paivyfp33aijn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/ctib4tex")
    (synopsis "Tibetan for TeX and LaTeX2e")
    (description
     "This LaTeX package uses a modified version of Sirlin's Tibetan font.  An
advantage of this Tibetan implementation is that all consonant clusters are
formed by TeX and Metafont.  No external preprocessor is needed.")
    (license license:gpl3+)))

(define-public texlive-ctie
  (package
    (name "texlive-ctie")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/ctie.1"
                                     "doc/man/man1/ctie.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xnb6qdi7bvlb78s6vbv4f03b37arp2ldics6mrshqlpfm9rj72f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-kpathsea))
    (home-page "https://ctan.org/pkg/ctie")
    (synopsis "C version of @code{tie} (merging Web change files)")
    (description
     "This is a version of @code{tie} converted for use with Cweb.")
    (license license:gpl3+)))

(define-public texlive-de-macro
  (package
    (name "texlive-de-macro")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/de-macro/" "scripts/de-macro/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hbia43gzwj0lb9c9k8fh9w04mmvz0jwwdm15kp59v95v4n5svmr"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "python")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "de-macro")))
    (inputs (list python))
    (home-page "https://ctan.org/pkg/de-macro")
    (synopsis "Expand private macros in a document")
    (description
     "De-macro is a Python script that helps authors who like to use private
LaTeX macros (for example, as abbreviations).  A technical editor or
a cooperating author may balk at such a manuscript; you can avoid manuscript
rejection misery by running de-macro on it.  De-macro will expand macros
defined in @code{\\(re)newcommand} or @code{\\(re)newenvironment} commands,
within the document, or in the document's private package file.")
    (license license:afl2.1)))

(define-public texlive-detex
  (package
    (name "texlive-detex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/detex.1"
                                     "doc/man/man1/detex.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vs9agbdyhq9wm1c9nd7wwnhnpvdzjh5msbmhn3xyyq45ylqvbwf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-detex-bin))
    (home-page "https://ctan.org/pkg/detex")
    (synopsis "Strip TeX from a source file")
    (description
     "Detex is a program to remove TeX constructs from a text file.  It
recognizes the @code{\\input} command.  The program assumes it is dealing with
LaTeX input if it sees the string @code{\\begin@{document@}} in the text.  In
this case, it also recognizes the @code{\\include} and @code{\\includeonly}
commands.  The author now considers this program to be obsolete and Piotr
Kubowicz's OpenDetex as its successor.")
    (license license:bsd-3)))

(define-public texlive-detex-bin
  (package
    (inherit texlive-bin)
    (name "texlive-detex-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root keep)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir
                       "."
                       (lambda (file)
                         (and (not (member file (append keep '("." ".."))))
                              (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("detex"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-detex" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/detex"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/detex"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list texlive-libkpathsea))
    (propagated-inputs '())
    (home-page (package-home-page texlive-detex))
    (synopsis "Binary for @code{texlive-detex}")
    (description
     "This package provides the binary for @code{texlive-detex}.")
    (license (package-license texlive-detex))))

(define-public texlive-digestif
  (package
    (name "texlive-digestif")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/digestif/" "scripts/digestif/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1s7nmbjxpa6klmh0cc6g4s6vd9wmlv4dxp51xb4b872hrj510zbi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "digestif.texlua")
                     #:phases
                     #~(modify-phases %standard-phases
                         (add-after 'unpack 'fix-data-path
                           (lambda _
                             (substitute* "scripts/digestif/digestif.texlua"
                               (("(local archive = )(.*)$" all beginning end)
                                (string-append beginning "\"" #$output
                                               "/share/texmf-dist/scripts/digestif/digestif.zip\""
                                               "\n"))))))))
    (home-page "https://ctan.org/pkg/digestif")
    (synopsis "Editor plugin for LaTeX, ConTeXt etc.")
    (description
     "Digestif is a code analyzer, and a language server, for LaTeX, plain TeX,
ConTeXt and Texinfo.  It provides context-sensitive completion, documentation,
code navigation, and related functionality to any text editor that speaks the
LSP protocol.")
    (license (list license:gpl3+ license:lppl1.3+ license:fdl1.3+))))

(define-public texlive-dickimaw
  (package
    (name "texlive-dickimaw")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dickimaw/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mxjqn4lblnpbmad3jk453lyx1qzcmrddis59j3jsgc5sp929w4k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dickimaw")
    (synopsis "Books and tutorials from the @emph{Dickimaw LaTeX Series}")
    (description
     "The package provides some of the books and tutorials that form part of
the @code{Dickimaw LaTeX Series}.  Only the A4 PDF of each book is detailed
here.  Other formats, such as HTML or screen optimized PDF, are available from
the package home page.

Books included are:
@itemize
@item @emph{LaTeX for Complete Novices},
@item @emph{Using LaTeX to Write a PhD thesis},
@item @emph{Creating a LaTeX minimal example}.
@end itemize")
    (license license:fdl1.3+)))

(define-public texlive-docsurvey
  (package
    (name "texlive-docsurvey")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/docsurvey/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pf5h9fy9akgc2cznvx32nzhxfx5c22dzr4ki23h4w7v7iivsw68"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/docsurvey")
    (synopsis "Survey of LaTeX documentation")
    (description
     "This package provides a survey of programming-related documentation for
LaTeX.  Included are references to printed and electronic books and manuals,
symbol lists, FAQs, the LaTeX source code, CTAN and distributions,
programming-related packages, users groups and online communities, and
information on creating packages and documentation.")
    (license license:lppl1.3+)))

(define-public texlive-dtl
  (package
    (name "texlive-dtl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/dt2dv.1"
                                     "doc/man/man1/dt2dv.man1.pdf"
                                     "doc/man/man1/dv2dt.1"
                                     "doc/man/man1/dv2dt.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kvnsr8nxrys99rp74wlxnisfripx6jpjjkqy38d3d4gw13cvb5g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-dtl-bin))
    (home-page "https://ctan.org/pkg/dtl")
    (synopsis "Tools to dis-assemble and re-assemble DVI files")
    (description
     "DTL (DVI Text Language) is a means of expressing the content of a DVI file,
which is readily readable by humans.  The DTL bundle contains an assembler
@command{dt2dv}, which produces DVI files from DTL files, and a disassembler
@command{dv2dt}, which produces DTL files from DVI files.")
    (license license:public-domain)))

(define-public texlive-dtl-bin
  (package
    (inherit texlive-bin)
    (name "texlive-dtl-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root keep)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir
                       "."
                       (lambda (file)
                         (and (not (member file (append keep '("." ".."))))
                              (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("dtl"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-dtl" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/dtl"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/dtl"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list texlive-libkpathsea))
    (propagated-inputs '())
    (home-page (package-home-page texlive-dtl))
    (synopsis "Binaries for @code{texlive-dtl}")
    (description
     "This package provides the binaries for @code{texlive-dtl}.")
    (license (package-license texlive-dtl))))

(define-public texlive-dtxgen
  (package
    (name "texlive-dtxgen")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/dtxgen/" "scripts/dtxgen/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1j1j136p4ddjlmwmhwlpmsxqpx2ixhhssfsl8l49lds80ad4y98m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "dtxgen")))
    (home-page "https://ctan.org/pkg/dtxgen")
    (synopsis "Creates a template for a self-extracting @file{.dtx} file")
    (description
     "The Bash script dtxgen creates a template for a self-extracting
@file{.dtx} file.  It is useful for those who plan to create a new documented
LaTeX source (.dtx) file.")
    (license license:gpl3+)))

(define-public texlive-dtxtut
  (package
    (name "texlive-dtxtut")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dtxtut/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zk09qdz661g1lnn2qr1s23h3x4mi7q8mdcl13p19k7qmnlc8v5d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dtxtut")
    (synopsis "Tutorial on writing @file{.dtx} and @file{.ins} files")
    (description
     "This tutorial is intended for advanced LaTeX2e users who want to learn
how to create @file{.ins} and @file{.dtx} files for distributing their
homebrewed classes and package files.")
    (license license:lppl1.3+)))

(define-public texlive-dvi2tty
  (package
    (name "texlive-dvi2tty")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/disdvi.1"
                                     "doc/man/man1/disdvi.man1.pdf"
                                     "doc/man/man1/dvi2tty.1"
                                     "doc/man/man1/dvi2tty.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "108y0qxh13x0iivgsvkk4370f471p03nyl4x9nn7lng1wrsafp6h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-dvi2tty-bin))
    (home-page "https://ctan.org/pkg/dvi2tty")
    (synopsis "Produce ASCII from DVI")
    (description
     "This package provides a DVI driver to produce an ASCII representation of
the document.")
    (license license:gpl2)))

(define-public texlive-dvi2tty-bin
  (package
    (inherit texlive-bin)
    (name "texlive-dvi2tty-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("dvi2tty"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-dvi2tty" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/dvi2tty"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/dvi2tty"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list texlive-libkpathsea texlive-libptexenc))
    (propagated-inputs '())
    (home-page (package-home-page texlive-dvi2tty))
    (synopsis "Binaries for @code{texlive-dvi2tty}")
    (description
     "This package provides the binaries for @code{texlive-dvi2tty}.")
    (license (package-license texlive-dvi2tty))))

(define-public texlive-dviasm
  (package
    (name "texlive-dviasm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dviasm/" "doc/man/man1/dviasm.1"
                                     "doc/man/man1/dviasm.man1.pdf"
                                     "scripts/dviasm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18rzkq231rnbfsi3x4ymlbbgz8zacryax8rdan9m8whl4d7lzymq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "dviasm.py")))
    (inputs (list python))
    (home-page "https://ctan.org/pkg/dviasm")
    (synopsis "Utility for editing DVI files")
    (description
     "This package provides a Python script to support changing or creating
DVI files via disassembling into text, editing, and then reassembling into
binary format.  It supports advanced features such as adding a preprint number
or watermarks.")
    (license license:gpl3+)))

(define-public texlive-dvicopy
  (package
    (name "texlive-dvicopy")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/dvicopy.1"
                                     "doc/man/man1/dvicopy.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01ccirjsm7mpyyyqf5sra3vfd7p1cg2kyzwkx08az8ijb7ysvvv8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-dvicopy-bin))
    (home-page "https://ctan.org/pkg/dvicopy")
    (synopsis "Copy DVI files, flattening VFs")
    (description
     "@command{dvicopy} is a utility program that allows one to take a DVI
file that references composite fonts (VF) and convert it into a DVI file that
does not contain such references.  It also serves as a basis for writing DVI
drivers (much like DVItype).")
    (license license:gpl3+)))

(define-public texlive-dvicopy-bin
  (package
    (inherit texlive-bin)
    (name "texlive-dvicopy-bin")
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(delete "--enable-web2c" #$flags))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/web2c"
                  (invoke "make" "dvicopy")
                  (install-file "dvicopy"
                                (string-append #$output "/bin")))))))))
    (native-inputs (list pkg-config))
    (home-page (package-home-page texlive-dvicopy))
    (synopsis "Binary for @code{texlive-dvicopy}")
    (description
     "This package provides the binary for @code{texlive-dvicopy}.")
    (license (package-license texlive-dvicopy))))

(define-public texlive-dvidvi
  (package
    (name "texlive-dvidvi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/dvidvi.1"
                                     "doc/man/man1/dvidvi.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1w153rqm7nlmcf6162glxz282nbb6b6hjf5h0p7mbzr0j1357sxj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-dvidvi-bin))
    (home-page "https://ctan.org/pkg/dvidvi")
    (synopsis "Convert one DVI file into another")
    (description
     "This @command{dvidvi} converts one DVI file into another.  The output
DVI file's contents are specified by page selection commands; series of pages
and page number ranges may be specified, as well as inclusions and
exclusions.")
    ;; Its author stated the program is to be used under the GPL.  See
    ;; <https://metadata.ftp-master.debian.org/changelogs//main/d/dvidvi/dvidvi_1.0-8.2_copyright>.
    (license license:gpl3)))

(define-public texlive-dvidvi-bin
  (package
    (inherit texlive-bin)
    (name "texlive-dvidvi-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root keep)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir
                       "."
                       (lambda (file)
                         (and (not (member file (append keep '("." ".."))))
                              (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("dvidvi"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-dvidvi" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/dvidvi"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/dvidvi"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list texlive-libkpathsea))
    (propagated-inputs '())
    (home-page (package-home-page texlive-dvidvi))
    (synopsis "Binary for @code{texlive-dvidvi}")
    (description
     "This package provides the binary for @code{texlive-dvidvi}.")
    (license (package-license texlive-dvidvi))))

(define-public texlive-dviinfox
  (package
    (name "texlive-dviinfox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dviinfox/" "scripts/dviinfox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rc662dllanawrlz2r0pnisl6zzc7c3bivsqy72iq87a92cq8kml"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "dviinfox.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/dviinfox")
    (synopsis "Perl script to print DVI meta information")
    (description
     "The package provides a Perl script which prints information about a DVI
file.  It also supports XeTeX XDV format.")
    (license license:expat)))

(define-public texlive-dviljk
  (package
    (name "texlive-dviljk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/dvihp.1"
                                     "doc/man/man1/dvihp.man1.pdf"
                                     "doc/man/man1/dvilj.1"
                                     "doc/man/man1/dvilj.man1.pdf"
                                     "doc/man/man1/dvilj2p.1"
                                     "doc/man/man1/dvilj2p.man1.pdf"
                                     "doc/man/man1/dvilj4.1"
                                     "doc/man/man1/dvilj4.man1.pdf"
                                     "doc/man/man1/dvilj4l.1"
                                     "doc/man/man1/dvilj4l.man1.pdf"
                                     "doc/man/man1/dvilj6.1"
                                     "doc/man/man1/dvilj6.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03pi78c8ghy2gghzk1ffrvf5x7h8c1r0pv5pcspwxz365x2rsbjw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-dviljk-bin))
    (home-page "https://ctan.org/pkg/dviljk")
    (synopsis "DVI to Laserjet output")
    (description
     "This package provides a DVI driver for the LaserJet printers, using
@command{kpathsea} recursive file searching.")
    (license license:gpl3+)))

(define-public texlive-dviljk-bin
  (package
    (inherit texlive-bin)
    (name "texlive-dviljk-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root keep)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir
                       "."
                       (lambda (file)
                         (and (not (member file (append keep '("." ".."))))
                              (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("dviljk"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-dviljk" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/dviljk"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/dviljk"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list texlive-libkpathsea))
    (propagated-inputs '())
    (home-page (package-home-page texlive-dviljk))
    (synopsis "Binary for @code{texlive-dviljk}")
    (description
     "This package provides the binary for @code{texlive-dviljk}.")
    (license (package-license texlive-dviljk))))

(define-public texlive-dviout-util
  (package
    (name "texlive-dviout-util")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/chkdvifont.1"
                                     "doc/man/man1/chkdvifont.man1.pdf"
                                     "doc/man/man1/dvispc.1"
                                     "doc/man/man1/dvispc.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "098pksgf2iamq96rmzg5fw7i9dlpvdksficsz1bf8k8z4djnbk8n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-dviout-util-bin))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Utilities from the @code{dviout} package")
    (description
     "This package provides two utilities: @command{chkdvifont}, which check
fonts in DVI/TFM/JFM/FONT files, and @command{dvispc}, which corrects the
page-independence of DVI file using color specials or tpic specials, and
transforms between a DVI file and a text file.")
    (license license:expat)))

(define-public texlive-dviout-util-bin
  (package
    (inherit texlive-bin)
    (name "texlive-dviout-util-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root keep)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir
                       "."
                       (lambda (file)
                         (and (not (member file (append keep '("." ".."))))
                              (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("dviout-util" "tests"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-dviout-util" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/dviout-util"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/dviout-util"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list texlive-libkpathsea texlive-libptexenc))
    (propagated-inputs '())
    (home-page (package-home-page texlive-dviout-util))
    (synopsis "Binary for @code{texlive-dviout-util}")
    (description
     "This package provides the binary for @code{texlive-dviout-util}.")
    (license (package-license texlive-dviout-util))))

(define-public texlive-dvipng
  (package
    (name "texlive-dvipng")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/dvipng/"
                                     "doc/info/dvipng.info"
                                     "doc/man/man1/dvigif.1"
                                     "doc/man/man1/dvigif.man1.pdf"
                                     "doc/man/man1/dvipng.1"
                                     "doc/man/man1/dvipng.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0454xscpjh33d5qcyiirk79y4zwpfzh4rxvgmzbd4qp1h1anjnjm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-dvipng-bin))
    (home-page "https://ctan.org/pkg/dvipng")
    (synopsis "DVI to PNG/GIF converter")
    (description
     "This program makes PNG and/or GIF graphics from DVI files as obtained
from TeX and its relatives.  It offers very fast rendering of DVI as bitmap
files, which makes it suitable for generating large amounts of images
on-the-fly, as needed in @code{preview-latex}, WeBWorK and others.  It does
not read the postamble, so it can be started before TeX finishes.")
    (license license:lgpl3)))

(define-public texlive-dvipng-bin
  (package
    (inherit texlive-bin)
    (name "texlive-dvipng-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '("xpdf"))
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("dvipng"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-dvipng" (delete "--disable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/dvipng"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/dvipng"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs
     (list freetype
           gd
           graphite2
           harfbuzz
           icu4c
           libpng
           potrace
           texlive-libkpathsea
           zziplib))
    (propagated-inputs '())
    (home-page (package-home-page texlive-dvipng))
    (synopsis "Binaries for @code{texlive-dvipng}")
    (description
     "This package provides the binaries for @code{texlive-dvipng}.")
    (license (package-license texlive-dvipng))))

(define-public texlive-dvipos
  (package
    (name "texlive-dvipos")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/dvipos.1"
                                     "doc/man/man1/dvipos.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dmaas4m9y4px53vlg0jr73xviki338fm2n176l8ldwqj0vvq1b8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-dvipos-bin))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Support DVI @samp{pos:} specials used by ConTeXt DVI output")
    (description
     "@command{dvipos} parses a DVI file looking for @samp{pos:} specials.
It then outputs the information from those specials along with information
that only a DVI postprocessor could determine, such as the current @samp{x}
and @samp{y} location.")
    (license license:gpl2+)))

(define-public texlive-dvipos-bin
  (package
    (inherit texlive-bin)
    (name "texlive-dvipos-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root keep)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir
                       "."
                       (lambda (file)
                         (and (not (member file (append keep '("." ".."))))
                              (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("dvipos"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-dvipos" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/dvipos"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/dvipos"
                  (invoke "make" "install"))))))))
    (home-page (package-home-page texlive-dvipos))
    (native-inputs (list pkg-config))
    (inputs (list texlive-libkpathsea))
    (propagated-inputs '())
    (synopsis "Binary for @code{texlive-dvipos}")
    (description
     "This package provides the binary for @code{texlive-dvipos}.")
    (license (package-license texlive-dvipos))))

(define-public texlive-dvipsconfig
  (package
    (name "texlive-dvipsconfig")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "dvips/dvipsconfig/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02vgk91y80ch4pkj83vbiz1b2ccigf152hm83p607y4n4qn2xzsf"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dvipsconfig")
    (synopsis "Collection of dvips PostScript headers")
    (description
     "This is a collection of dvips PostScript header and dvips config files.
They control certain features of the printer, including: A4, A3, usletter,
simplex, duplex / long edge, duplex / short edge, screen frequencies of
images, black/white invers, select transparency / paper for tektronix 550/560,
manual feeder, envelope feeder, and tray 1, 2 and 3, and printing a PostScript
grid underneath the page material--very useful for measuring and eliminating
paper feed errors!")
    (license license:gpl3+)))

(define-public texlive-dvisvgm
  (package
    (name "texlive-dvisvgm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/dvisvgm.1"
                                     "doc/man/man1/dvisvgm.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pm3m0x25956lk1k99479gc5dn6w4bqp0ibgihn2y5gjpma75civ"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-dvisvgm-bin))
    (home-page "https://ctan.org/pkg/dvisvgm")
    (synopsis
     "Convert DVI, EPS, and PDF files to Scalable Vector Graphics format (SVG)")
    (description
     "Dvisvgm is a command line utility that converts TeX DVI as well as EPS
and PDF files to the XML-based Scalable Vector Graphics (SVG) format.  It
provides full font support including virtual fonts, font maps, and sub-fonts.
If necessary, @command{dvisvgm} vectorizes Metafont's bitmap output in order
to always create lossless scalable output.  The embedded SVG fonts can
optionally be replaced with graphics paths so that applications that do not
support SVG fonts are enabled to render the graphics properly.")
    (license license:gpl3+)))

(define-public texlive-dvisvgm-bin
  (package
    (inherit texlive-bin)
    (name "texlive-dvisvgm-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs with-files?)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir
                       "."
                       (lambda (file)
                         (and (not (member file (append '("." "..") dirs)))
                              (or with-files?
                                  (eq? 'directory (stat:type (stat file))))))))))))
            (delete-other-directories "libs" '() #f)
            (delete-other-directories "utils" '() #f)
            ;; TODO: Unbundle stuff in texk/dvisvgm/dvisvgm-src/libs too.
            (delete-other-directories "texk" '("dvipsk" "dvisvgm") #f)
            ;; Test data is spread across multiple directories, which need to
            ;; be preserved.
            (delete-other-directories "texk/dvipsk" '("testdata") #t)))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-dvisvgm" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            ;; XXX: Ghostscript is detected, but HAVE_LIBGS is never set, so
            ;; the appropriate linker flags are not added.
            (add-after 'unpack 'patch-dvisvgm-build-files
              (lambda _
                (substitute* "texk/dvisvgm/configure"
                  (("^have_libgs=yes" all)
                   (string-append all "\nHAVE_LIBGS=1")))))
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/dvisvgm"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/dvisvgm"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs
     (list brotli
           clipper
           freetype
           ghostscript
           openssl
           potrace
           texlive-libkpathsea
           woff2
           xxhash
           zlib))
    (propagated-inputs '())
    (home-page (package-home-page texlive-dvisvgm))
    (synopsis "Binary for @code{texlive-dvisvgm}")
    (description
     "This package provides the binary for @code{texlive-dvisvgm}.")
    (license (package-license texlive-dvisvgm))))

(define-public texlive-ebong
  (package
    (name "texlive-ebong")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ebong/" "scripts/ebong/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n177627hdsa5fv64irxq8dlxbc2yxk604ifgpjvdx5ww41451k9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "ebong.py")))
    (inputs (list python))
    (home-page "https://ctan.org/pkg/ebong")
    (synopsis "Utility for writing Bengali in Rapid Roman Format")
    (description
     "This package provides a tool (preprocessor) for writing your
@code{pRaa-ne-r} ka-thaa in the Bengali language.  It allows one to write the
text in Rapid Roman Bangla and convert it to the BangTeX format by a Python
program.  All LaTeX markups are preserved in the target file.")
    (license license:public-domain)))

(define-public texlive-eijkhout
  (package
    (name "texlive-eijkhout")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/generic/eijkhout/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00y3y01jpgzww1x6zjh748hpvizlrbgrv04p8aq3cm2pzs0g17qk"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eijkhout")
    (synopsis "Victor Eijkhout's packages")
    (description
     "The package provides three unrelated tools: @code{DB_process}, to parse
and process database output; @code{CD_labeler}, to typeset user text to fit on
a CD label; and @code{repeat}, a nestable, generic loop macro.")
    (license
     (list license:gpl2+                ;CD_labeler and DB_process.tex
           license:lppl))))             ;repeat.tex

(define-public texlive-encxvlna
  (package
    (name "texlive-encxvlna")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/encxvlna/"
                                     "tex/latex/encxvlna/" "tex/plain/encxvlna/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01lgh560xhn56k5pps65lq9c5rn0kbrcfvqfikrqq83g3n7k2p8v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/encxvlna")
    (synopsis "Insert nonbreakable spaces, using encTeX")
    (description
     "The package provides tools for inserting nonbreakable spaces after
nonsyllabic prepositions and single letter conjunctions as required by Czech
and Slovak typographical rules.  It is implemented using encTeX and provides
files both for plain TeX and LaTeX.")
    (license license:lppl)))

(define-public texlive-epigram
  (package
    (name "texlive-epigram")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/generic/epigram/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zps5067mgi7xq3fpjvjln8i0rz53j7qn660khraq8ribv4glnpf"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/epigram")
    (synopsis "Display short quotations")
    (description
     "The package determines (on the basis of the width of the text of the
epigram, laid out on a single line) whether to produce a line or a displayed
paragraph.")
    (license license:public-domain)))

(define-public texlive-epsf-dvipdfmx
  (package
    (name "texlive-epsf-dvipdfmx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/epsf-dvipdfmx/"
                                     "tex/plain/epsf-dvipdfmx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xj4hag3nldxxjcpympvra5cdn19nk76af9dxq07ci585gcki3x5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/epsf-dvipdfmx")
    (synopsis "Plain TeX file for using epsf.tex with (x)dvipdfmx")
    (description
     "@file{epsf-dvipdfmx.tex} is a plain TeX file to be @code{\\input} after
@file{epsf.tex} when using plain TeX with @code{dvipdfmx}.  It is needed when
an @file{.eps} file has anything except the origin for the lower-left of its
bounding box.")
    (license license:public-domain)))

(define-public texlive-ethiop
  (package
    (name "texlive-ethiop")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ethiop/"
                                     "fonts/ofm/public/ethiop/"
                                     "fonts/ovf/public/ethiop/"
                                     "fonts/ovp/public/ethiop/"
                                     "fonts/source/public/ethiop/"
                                     "fonts/tfm/public/ethiop/"
                                     "omega/ocp/ethiop/"
                                     "omega/otp/ethiop/"
                                     "source/latex/ethiop/"
                                     "tex/latex/ethiop/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1852g96rjyrsky7mpfwlxgip11qmk800xcmqccs8cv51f5342qlq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/ethiop")
    (synopsis "LaTeX macros and fonts for typesetting Amharic")
    (description
     "This package provides Ethiopian language support for the Babel package,
including a collection of fonts and TeX macros for typesetting the characters
of the languages of Ethiopia, with Metafont fonts based on EthTeX's.  The
macros use the Babel framework.")
    (license license:gpl3+)))

(define-public texlive-ethiop-t1
  (package
    (name "texlive-ethiop-t1")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ethiop-t1/"
                                     "fonts/map/dvips/ethiop-t1/"
                                     "fonts/type1/public/ethiop-t1/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19n6i61db88nhhkq9gg3gfr3sgpaf1ylr41l0xdhpfkn71y7par1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ethiop-t1")
    (synopsis "Type 1 versions of Amharic fonts")
    (description
     "These fonts provided in this package are drop-in Adobe type
1 replacements for the fonts of the @code{ethiop} package.")
    (license license:gpl3+)))

(define-public texlive-expex-acro
  (package
    (name "texlive-expex-acro")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/expex-acro/"
                                     "source/generic/expex-acro/"
                                     "tex/generic/expex-acro/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0g662axz3qklsmrgi1ndp8v7w7vkdxanydijf5rhydabh8224az8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/expex-acro")
    (synopsis "Wrapper for the expex package")
    (description
     "This is a small wrapper for the @code{expex} package, adding ways to
define, use, and summarize glossing abbreviations.  It also provides commands
to refer to examples, as well as some inline formatting commands commonly used
in linguistics.")
    (license license:lppl1.3+)))

(define-public texlive-expkv-bundle
  (package
    (name "texlive-expkv-bundle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/expkv-bundle/"
                                     "source/latex/expkv-bundle/"
                                     "tex/context/third/expkv-bundle/"
                                     "tex/generic/expkv-bundle/"
                                     "tex/latex/expkv-bundle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09ijb71w69bnhi38i8z2bnv8d4r4sdg337v61yi66y94z8d9iid9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/expkv-bundle")
    (synopsis "Expandable @samp{key=val} implementation and friends")
    (description
     "This is a collection of different packages that provide @samp{key=value}
functionality in plainTeX, LaTeX, and ConTeXt.

At the core, the @code{expkv} package implements two expandable
@samp{key=value} parsers that are somewhat fast and robust against common bugs
in many key=value implementations (no accidental brace stripping, no fragility
for active commas or equals signs).

@code{expkv-cs} enables users to define expandable @samp{key=value} macros in
a comfortable and straightforward way.

@code{expkv-def} provides an interface to define common key types for
@code{expkv} similar to the key defining interfaces of widespread
@samp{key=value} implementations.

@code{expkv-opt} allows parsing package or class options in LaTeX via
@code{expkv}.

@code{expkv-pop} is a utility package to define prefix oriented parsers that
allow a somewhat natural formulation.")
    (license license:lppl1.3c)))

(define-public texlive-fc
  (package
    (name "texlive-fc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/fc/" "fonts/source/jknappen/fc/"
                                     "fonts/tfm/jknappen/fc/" "tex/latex/fc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0v0r8jcr1lv31mx613h76h13psj73g49p2a6dnd0nfbfharww3gr"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-sauter")))
    (build-system texlive-build-system)
    (arguments
     (list #:phases
           #~(modify-phases %standard-phases
               ;; FIXME: Font metrics cannot be generated due to "bad pos"
               ;; errors with "fcitt" fonts.
               (delete 'generate-font-metrics))))
    (native-inputs (list texlive-metafont texlive-sauter))
    (home-page "https://ctan.org/pkg/fc")
    (synopsis "Fonts for African languages")
    (description
     "This package includes fonts for African languages.  The fonts are
provided as Metafont source, in the familiar arrangement of lots of preamble
files and a modest set of glyph specifications.")
    (license license:gpl2)))

(define-public texlive-fenixpar
  (package
    (name "texlive-fenixpar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/fenixpar/"
                                     "tex/generic/fenixpar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1363dr8fnhflw0mysv23mpp2vf02vfxs43nnv95yqkbsvp9fj502"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fenixpar")
    (synopsis "One-shot changes to token registers such as @code{\\everypar}")
    (description
     "The bundle provides two packages, @code{fenxitok} and
@code{fenixpar}.  The @code{fenixtok} package provides user macros to
add material to a token register; the material will be
(automatically) removed from the token register when the register is executed.
Material may be added either to the left or to the right, and care is taken
not to override any redefinition that may be included in the token register
itself.  The @code{fenixpar} package uses the macros of @code{fenixtok} to
provide a user interface to manipulation of the @code{\\everypar} token
register.  The packages require the e-TeX extensions; with them, they work
either with Plain TeX or with LaTeX.")
    (license license:lppl)))

(define-public texlive-feupphdteses
  (package
    (name "texlive-feupphdteses")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/feupphdteses/"
                                     "tex/latex/feupphdteses/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p6qwmcwayh45cmsgyx352ffzj2fcx2gaaya5qadn0ymx0pvb0lp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/feupphdteses")
    (synopsis "Typeset Engineering PhD theses at the University of Porto")
    (description
     "This package provides a complete template for thesis/works of Faculdade
de Engenharia da Universidade do Porto (FEUP) Faculty of Engineering
University of Porto.")
    (license license:lppl)))

(define-public texlive-figflow
  (package
    (name "texlive-figflow")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/figflow/" "tex/plain/figflow/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vsrsw5rrqjym0flca9537m41vs7wlk8mhl9zmqjfaxgi8jvc9ml"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/figflow")
    (synopsis "Flow text around a figure")
    (description
     "This package provides a Plain TeX macro @code{\\figflow} that allows one
to insert a figure into an area inset into a paragraph.  Command arguments are
width and height of the figure, and the figure (and its caption) itself.  The
package does not work with LaTeX; packages such as @code{wrapfig},
@code{floatflt} and @code{picins} support the needs of LaTeX users in this
area.")
    ;; README states: "You may freely use, modify, and/or distribute this
    ;; file, without limitation."
    (license (license:fsf-free "file://doc/plain/figflow/README"))))

(define-public texlive-finbib
  (package
    (name "texlive-finbib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/finbib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dr1ivhfb83ky3q82dzzv5vvc8bl84iq7am0p1rc8fjlbj95i4wm"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/finplain")
    (synopsis "Finnish version of @file{plain.bst}")
    (description "This package provides a Finnish version of
@file{plain.bst}.")
    (license license:knuth)))

(define-public texlive-findhyph
  (package
    (name "texlive-findhyph")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/findhyph.1"
                                     "doc/man/man1/findhyph.man1.pdf"
                                     "doc/support/findhyph/" "scripts/findhyph/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bxj0li1a9qsvwmp0kmfsal4vsgsqal1lgmp4423z9nvwrwvvlrr"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "findhyph")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/findhyph")
    (synopsis "Find hyphenated words in a document")
    (description
     "Findhyph is a Perl script that will analyse the log file from running
your document with @code{\\tracingparagraphs=1} set.  The output contains
enough context to enable you to find the hyphenated word that's being
referenced.")
    (license license:gpl2)))

(define-public texlive-first-latex-doc
  (package
    (name "texlive-first-latex-doc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/first-latex-doc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13ngk5pia5vbrbb4jrrlq1lmyja08m7cy4ydcjasxha8kns001ss"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/first-latex-doc")
    (synopsis "Document for absolute LaTeX beginners")
    (description
     "The document leads a reader, who knows nothing about LaTeX, through the
production of a two page document.  The user who has completed that first
document, and wants to carry on, will find recommendations for tutorials.")
    (license license:public-domain)))

(define-public texlive-fixpdfmag
  (package
    (name "texlive-fixpdfmag")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/plain/fixpdfmag/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0s5ilsmnhvi57x9cqwp7nwpagfribmgkbl0z1ci55aw2a6bff9hn"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fixpdfmag")
    (synopsis "Fix magnification in pdfTeX")
    (description
     "This package provides a recent change to pdfTeX has caused magnification
to apply to page dimensions.")
    (license license:public-domain)))

(define-public texlive-fltpoint
  (package
    (name "texlive-fltpoint")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/fltpoint/"
                                     "source/generic/fltpoint/"
                                     "tex/generic/fltpoint/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k85cyh39rxr3jrgyxcj1lrya5zss5da62pj7q8412naaklkhd7n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fltpoint")
    (synopsis "Simple floating point arithmetic")
    (description
     "The package provides simple floating point operations (addition,
subtraction, multiplication, division and rounding).")
    (license license:lppl1.2+)))

(define-public texlive-fntproof
  (package
    (name "texlive-fntproof")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/fntproof/"
                                     "tex/generic/fntproof/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pw0nw0dalnxqxpfgpw4pglngz3iff8sxxfdn89ygz46sv6427n5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fntproof")
    (synopsis "Programmable font test pattern generator")
    (description
     "The package implements all the font testing commands of Knuth's
@file{testfont.tex}, but arranges that information necessary for each command
is supplied as arguments to that command, rather than prompted for.  This
makes it possible to type all the tests in one command line, and easy to input
the package in a file and to use the commands there.  A few additional
commands supporting this last purpose are also made available.")
    (license license:public-domain)))

(define-public texlive-font-change
  (package
    (name "texlive-font-change")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/font-change/"
                                     "tex/plain/font-change/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b2i3gwrwfa2ab95m2ksmypiwc5dmfyirymhm18g1h0zpj86ccza"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/font-change")
    (synopsis "Macros to change text and mathematics fonts in plain TeX")
    (description
     "This package provides macros to change text and mathematics fonts in
TeX.  The macros are written for plain TeX and may be used with other packages
like AmSTeX, eplain, etc.  They also work with XeTeX. The macros allow users
to change the fonts (for both text and mathematics) in their TeX document with
only one statement.  The fonts may be used readily at various predefined
sizes.")
    (license license:cc-by-sa3.0)))

(define-public texlive-fontch
  (package
    (name "texlive-fontch")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/fontch/" "tex/plain/fontch/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19v8l76181yhan6ybc47i5sq4mirc8lc7x1zxqxmk15wyvax9lm9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fontch")
    (synopsis "Changing fonts, sizes and encodings in Plain TeX")
    (description
     "The fontch macros allow the user to change font size and family anywhere
in a plain TeX document.  Sizes of 8, 10, 12, 14, 20 and 24 points are
available.  A sans serif family is defined in addition to the families already
defined in plain TeX. Optional support for Latin Modern T1 and TS1 fonts is
given.  There are macros for non-latin1 letters and for most TS1 symbols.
Math mode always uses CM fonts.  A command for producing doubled-spaced
documents is also provided.")
    (license license:lppl)))

(define-public texlive-fontinstallationguide
  (package
    (name "texlive-fontinstallationguide")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/fontinstallationguide/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i6im0nckcr9fzs0kc54dvcj3jvjz2j8jd55xgjm0r569qjj1hi5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fontinstallationguide")
    (synopsis "Font installation guide")
    (description
     "This guide discusses the most common scenarios you are likely to
encounter when installing Type 1 PostScript fonts.  While the individual tools
employed in the installation process are documented well, the actual
difficulty most users are facing when trying to install new fonts is
understanding how to put all the pieces together.  This is what this guide is
about.")
    (license license:fdl1.3+)))

(define-public texlive-fontools
  (package
    (name "texlive-fontools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/afm2afm.1"
                                     "doc/man/man1/afm2afm.man1.pdf"
                                     "doc/man/man1/autoinst.1"
                                     "doc/man/man1/autoinst.man1.pdf"
                                     "doc/man/man1/ot2kpx.1"
                                     "doc/man/man1/ot2kpx.man1.pdf"
                                     "doc/support/fontools/"
                                     "fonts/enc/dvips/fontools/"
                                     "scripts/fontools/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a4lvpl4kk711hdsw6kpgw835kn9pmfjrv8asjngxjbh6nk4yl7z"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "afm2afm" "autoinst" "ot2kpx")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/fontools")
    (synopsis "Tools to simplify using fonts (especially TT/OTF ones)")
    (description
     "This package provides tools to simplify using OpenType fonts with LaTeX.
By far the most important program in this bundle is @command{autoinst},
a wrapper script around Eddie Kohler's LCDF TypeTools.  Autoinst aims to
automate the installation of OpenType fonts in LaTeX by calling the LCDF
TypeTools (with the correct options) for all fonts you wish to install, and
generating the necessary @file{.fd} and @file{.sty} files.

In addition, this bundle contains a few other, less important utilities:
@itemize
@item @command{afm2afm}: re-encodes @file{.afm} files,
@item @command{ot2kpx}: extract kerning pairs from OpenType fonts,
@item @command{splitttc}: split an OpenType Collection file (ttc or
otc) into individual fonts.
@end itemize")
    (license license:gpl2)))

(define-public texlive-fonts-tlwg
  (package
    (name "texlive-fonts-tlwg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/fonts-tlwg/"
                                     "fonts/afm/public/fonts-tlwg/"
                                     "fonts/enc/dvips/fonts-tlwg/"
                                     "fonts/map/dvips/fonts-tlwg/"
                                     "fonts/opentype/public/fonts-tlwg/"
                                     "fonts/tfm/public/fonts-tlwg/"
                                     "fonts/type1/public/fonts-tlwg/"
                                     "fonts/vf/public/fonts-tlwg/"
                                     "source/fonts/fonts-tlwg/"
                                     "tex/latex/fonts-tlwg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19g1ksxsidf6cpcxm3knbbfpjw6jsfq2acy99cgmsy7jn33k253b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fonts-tlwg")
    (synopsis "Thai fonts for LaTeX from TLWG")
    (description
     "This package provides a collection of Thai fonts, supplied as FontForge
sources, and with LaTeX @file{.fd} files.")
    (license (list license:gpl2+
                   license:lppl1.3+
                   (license:x11-style "file://source/fonts/fonts-tlwg/COPYING")))))

(define-public texlive-fontware
  (package
    (name "texlive-fontware")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/pltotf.1"
                                     "doc/man/man1/pltotf.man1.pdf"
                                     "doc/man/man1/tftopl.1"
                                     "doc/man/man1/tftopl.man1.pdf"
                                     "doc/man/man1/vftovp.1"
                                     "doc/man/man1/vftovp.man1.pdf"
                                     "doc/man/man1/vptovf.1"
                                     "doc/man/man1/vptovf.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03w04hagary4si2f86wbhill731l7q9rmw3gmnpccs7cqlzamw3m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-fontware-bin))
    (home-page "https://ctan.org/pkg/vfware")
    (synopsis "Tools for virtual font metrics")
    (description
     "Virtual font metrics are usually created in a textual form, the Virtual
Property List, but programs that use them need to use binary files (the
Virtual Font and the TeX Font Metric).  The two programs provided in this
package translate between the two forms: @command{vptovf} takes a VPL file and
generates a VF file and a TFM file; @command{vftovp} takes a VF file and a TFM
file and generates a VPL file.")
    (license license:knuth)))

(define-public texlive-fontware-bin
  (package
    (inherit texlive-bin)
    (name "texlive-fontware-bin")
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(delete "--enable-web2c" #$flags))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/web2c"
                  (let ((bin (string-append #$output "/bin"))
                        (files '("pltotf" "tftopl" "vftovp" "vptovf")))
                    (for-each (lambda (f) (invoke "make" f)) files)
                    (for-each (lambda (f) (install-file f bin)) files)))))))))
    (native-inputs (list pkg-config))
    (home-page (package-home-page texlive-fontware))
    (synopsis "Binaries for @code{texlive-fontware}")
    (description
     "This package provides the binaries for @code{texlive-fontware}.")
    (license (package-license texlive-fontware))))

(define-public texlive-forest-quickstart
  (package
    (name "texlive-forest-quickstart")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/forest-quickstart/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bjy0bfkb90nv2dbdw8hdrm3dvm1v0r0m7a0l44ckw48vnc6amvk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/forest-quickstart")
    (synopsis "Quickstart Guide for Linguists package @code{forest}")
    (description
     "@code{forest} is a PGF/TikZ-based package for drawing linguistic (and
other kinds of) trees.  This manual provides a quickstart guide for linguists
with just the essential things that you need to get started.")
    (license license:fdl1.3+)))

(define-public texlive-fragmaster
  (package
    (name "texlive-fragmaster")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/fragmaster/"
                                     "scripts/fragmaster/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vwbkbg96dql73gayb06gs2fdxynljibjkmhliglc9ddggyx4v2m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "fragmaster.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/fragmaster")
    (synopsis "Using @command{psfrag} with pdfLaTeX")
    (description
     "Fragmaster enables you to use @command{psfrag} with pdfLaTeX.  It takes
EPS files and @command{psfrag} substitution definition files, and produces PDF
and EPS files with the substitutions included.")
    (license license:gpl3+)))

(define-public texlive-gentle
  (package
    (name "texlive-gentle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/gentle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1l5fyfdbkpqlgpgi1hrnn2sz8hchlnp7z5s5584czafvs10jg6vx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gentle")
    (synopsis "Gentle introduction to TeX")
    (description
     "The @emph{Gentle Introduction} is the longest-established comprehensive
tutorial on the use of plain TeX.")
    (license
     (license:fsf-free "file://share/texmf-dist/doc/plain/gentle/gentle.tex"))))

(define-public texlive-getoptk
  (package
    (name "texlive-getoptk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/getoptk/" "tex/plain/getoptk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19ndqi977wk6f9ikcvbllcbxmmfzdanjfznzx6pkq41caf4mj91y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/getoptk")
    (synopsis "Define macros with sophisticated options")
    (description
     "The package provides a means of defining macros whose options are taken
from a dictionary, which includes options which themselves have arguments.
The package was designed for use with Plain TeX.")
    (license license:cecill-b)))

(define-public texlive-gfnotation
  (package
    (name "texlive-gfnotation")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/gfnotation/"
                                     "tex/plain/gfnotation/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18yl6qhwd3fk6fyi6plj0bcb6iwzr4yx9aqmhs77rs5k4j2rgxsf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gfnotation")
    (synopsis "Typeset Gottlob Frege's notation in plain TeX")
    (description
     "The package implements macros for plain TeX to typeset the notation
invented by Gottlob Frege in 1879 for his books @emph{Begriffsschrift} and
@emph{Grundgesetze der Arithmetik} (two volumes).  The output styles of both
books are supported.")
    (license license:gpl3)))

(define-public texlive-gfsbaskerville
  (package
    (name "texlive-gfsbaskerville")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/gfsbaskerville/"
                                     "fonts/afm/public/gfsbaskerville/"
                                     "fonts/enc/dvips/gfsbaskerville/"
                                     "fonts/map/dvips/gfsbaskerville/"
                                     "fonts/opentype/public/gfsbaskerville/"
                                     "fonts/tfm/public/gfsbaskerville/"
                                     "fonts/type1/public/gfsbaskerville/"
                                     "fonts/vf/public/gfsbaskerville/"
                                     "tex/latex/gfsbaskerville/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hf2nr0y1l9wzxvk0s2ajy3g80fcc02avr2fqrnss23c1a0jhr8q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gfsbaskerville")
    (synopsis "Greek font, from one such by Baskerville")
    (description
     "The font is a digital implementation of Baskerville's classic Greek font,
provided by the Greek Font Society.  The font covers Greek only, and LaTeX
support provides for the use of LGR encoding.")
    (license (list license:lppl1.0+ license:silofl1.1))))

(define-public texlive-gfsporson
  (package
    (name "texlive-gfsporson")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/gfsporson/"
                                     "fonts/afm/public/gfsporson/"
                                     "fonts/enc/dvips/gfsporson/"
                                     "fonts/map/dvips/gfsporson/"
                                     "fonts/opentype/public/gfsporson/"
                                     "fonts/tfm/public/gfsporson/"
                                     "fonts/type1/public/gfsporson/"
                                     "fonts/vf/public/gfsporson/"
                                     "tex/latex/gfsporson/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11m9f3vh41w8gbla62219vf2djc5kl9i4kpg6i1iiixwrhi56smc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gfsporson")
    (synopsis "Greek font, originally from Porson")
    (description
     "Porson is an elegant Greek font, originally cut at the turn of the 19th
Century in England.  The present version has been provided by the Greek Font
Society.  The font supports the Greek alphabet only.  LaTeX support is
provided, using the LGR encoding.")
    (license (list license:lppl1.0+ license:silofl1.1))))

(define-public texlive-gobble
  (package
    (name "texlive-gobble")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/gobble/"
                                     "source/generic/gobble/"
                                     "tex/generic/gobble/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02g40fx99xn80af6bqv7zn16l8dnqihqd42vn5hbphfx85b3p49q"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ydoc")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ydoc))
    (home-page "https://ctan.org/pkg/gobble")
    (synopsis "More gobble macros for PlainTeX and LaTeX")
    (description
     "The LaTeX package @code{gobble} includes several gobble macros not
included in the LaTeX kernel.  These macros remove a number of arguments after
them, a feature regularly used inside other macros.  This includes gobble
macros for optional arguments.

The LaTeX package @code{gobble-user} provides these macros at the user level,
i.e.  using names without @samp{@@@@} so that these can be used without
@code{\\makeatletter} and @code{\\makeatother}.  The same macros are provided
inside @file{.tex} files for use with plain-TeX or other TeX formats.
However, the gobble macros for optional macros require @code{\\@@@@ifnextchar}
to be defined.")
    (license license:lppl1.3+)))

(define-public texlive-graphics-pln
  (package
    (name "texlive-graphics-pln")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/graphics-pln/"
                                     "tex/plain/graphics-pln/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bsqai7hvsb2z2ijh6mdiqz21nifhq40aym0rps2gys1kk8wh4r4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/graphics-pln")
    (synopsis "LaTeX-style graphics for Plain TeX users")
    (description
     "The Plain TeX graphics package is mostly a thin shell around the LaTeX
@code{graphicx} and @code{color} packages, with support of the LaTeX-isms in
those packages provided by @code{miniltx}.  The bundle also contains a file
@file{picture.tex}, which is a wrapper around the @file{autopict.sty}, and
provides the LaTeX picture mode to Plain TeX users.")
    (license license:lppl1.0+)))

(define-public texlive-greek-inputenc
  (package
    (name "texlive-greek-inputenc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/greek-inputenc/"
                                     "tex/latex/greek-inputenc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07zb4rnfx7hbc6d4mk03gmvb0x0mw5kz7d3ygj6x3886f0dms950"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/greek-inputenc")
    (synopsis "Greek encoding support for @code{inputenc}")
    (description
     "The bundle provides UTF-8, Macintosh Greek encoding and ISO 8859-7
definition files for use with @code{inputenc}.")
    (license license:lppl1.3+)))

(define-public texlive-greekdates
  (package
    (name "texlive-greekdates")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/greekdates/"
                                     "source/latex/greekdates/"
                                     "tex/latex/greekdates/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hwjskdllwxa14l12d0fn850sll3i9yihxlpjp2fk62v3iwkrq4r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/greekdates")
    (synopsis "Provides ancient Greek day and month names, dates, etc")
    (description
     "The package provides easy access to ancient Greek names of days and
months of various regions of Greece.  In case the historical information about
a region is not complete, we use the Athenian name of the month.  Moreover
commands and options are provided, in order to completely switch to the
ancient way, such as @code{\\today}.")
    (license license:lppl)))

(define-public texlive-greektex
  (package
    (name "texlive-greektex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/greektex/" "tex/latex/greektex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zs3kakr7k261j876r1xpynvnmjjdn5rky0acfbcjxp7mmsqpmzn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/greektex")
    (synopsis "Fonts for typesetting Greek/English documents")
    (description
     "The fonts are based on Silvio Levy's classical Greek fonts; macros and
Greek hyphenation patterns for the fonts encoding are also provided.")
    (license license:public-domain)))

(define-public texlive-greektonoi
  (package
    (name "texlive-greektonoi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/greektonoi/"
                                     "fonts/map/dvips/greektonoi/"
                                     "tex/latex/greektonoi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14phabwakq87qgh3jxs95gk1w2q3aw29vhy441538y4fxvskqhrw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/greektonoi")
    (synopsis "Facilitates writing/editing of multiaccented Greek")
    (description
     "The @code{greektonoi} mapping extends the @code{betababel} package or
the Babel @samp{polutonikogreek} option to provide a simple way to insert
ancient Greek texts with diacritical characters into your document using
a similar method to the commonly used Beta Code transliteration, but with much
more freedom.  It is designed especially for the XeTeX engine and it could
also be used for fast and easy modification of monotonic Greek texts to
polytonic.  The output text is natively encoded in Unicode, so it can be
reused in any possible way.  The @code{greektonoi} package provides, in
addition to inserting Greek accents and breathings, many other symbols used in
Greek numbers and arithmetic or in the Greek archaic period.  It could be used
with @code{greektonoi} mapping or independently.")
    (license license:lgpl3)))

(define-public texlive-gtl
  (package
    (name "texlive-gtl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/gtl/" "source/generic/gtl/"
                                     "tex/generic/gtl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gva7i2b9lark18spf452qv2p1rmi4854wpikdpya6g33gl9vq1r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gtl")
    (synopsis "Manipulating generalized token lists")
    (description
     "The package provides tools for simple operations on lists of tokens
which are not necessarily balanced.  It is in particular used a lot in the
@code{unravel} package, to go through tokens one at a time rather than having
to work with entire braced groups at a time.")
    (license license:lppl1.3c)))

(define-public texlive-hindawi-latex-template
  (package
    (name "texlive-hindawi-latex-template")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hindawi-latex-template/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q35drybrlcfcrhrd5691m66nd17b0m6hkcsqazpb1ck227zih61"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hindawi-latex-template")
    (synopsis "LaTeX template for authors of the Hindawi journals")
    (description
     "This package contains a LaTeX template for authors of the Hindawi journals.
Authors can use this template for formatting their research articles for
submissions.")
    (license license:lppl1.3+)))

(define-public texlive-hlist
  (package
    (name "texlive-hlist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/hlist/" "tex/generic/hlist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14rm9npzcanw4p4nkqd0rrm4655f9yhw58zf0qfa5azs305ba687"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hlist")
    (synopsis "Horizontal and columned lists")
    (description
     "This plain TeX and LaTeX package provides the @code{hlist} environment
in which @code{\\hitem} starts a horizontal and columned item.")
    (license license:lppl1.3c)))

(define-public texlive-hyplain
  (package
    (name "texlive-hyplain")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/hyplain/" "tex/plain/hyplain/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xj23zhv0sapjvchlcp013d32kayjf48wq5ywdak5n0fkb09mzl2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hyplain")
    (synopsis "Basic support for multiple languages in Plain TeX")
    (description
     "The package offers a means to set up hyphenation suitable for several
languages and/or dialects, and to select them or switch between them while
typesetting.")
    (license license:public-domain)))

(define-public texlive-ibycus-babel
  (package
    (name "texlive-ibycus-babel")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ibycus-babel/"
                                     "source/latex/ibycus-babel/"
                                     "tex/latex/ibycus-babel/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lwf28h6lzlblg7s7bx2dhqprxvjj78a8rlljhk9kw5pf065c7aj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ibycus-babel")
    (synopsis "Use the Ibycus 4 Greek font with Babel")
    (description
     "The package allows you to use the Ibycus 4 font for ancient Greek with
Babel.  It uses a Perl script to generate hyphenation patterns for Ibycus from
those for the ordinary Babel encoding, @samp{cbgreek}.  It sets up
@code{ibycus} as a pseudo-language you can specify in the normal Babel
manner.")
    (license license:lppl)))

(define-public texlive-ibygrk
  (package
    (name "texlive-ibygrk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/ibygrk/"
                                     "fonts/afm/public/ibygrk/"
                                     "fonts/enc/dvips/ibygrk/"
                                     "fonts/map/dvips/ibygrk/"
                                     "fonts/source/public/ibygrk/"
                                     "fonts/tfm/public/ibygrk/"
                                     "fonts/type1/public/ibygrk/"
                                     "tex/generic/ibygrk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14a1hqqwz3pfpz5rz9k8finxnlan4a3l8a0brgs98p6mdp9xl3q1"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-levy")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-levy texlive-metafont))
    (home-page "https://ctan.org/pkg/ibygrk")
    (synopsis "Fonts and macros to typeset ancient Greek")
    (description
     "Ibycus is a Greek typeface, based on Silvio Levy's realisation of
a classic Didot cut of Greek type from around 1800.  The fonts are available
both as Metafont source and in Adobe Type 1 format.  This distribution of
@code{ibycus} is accompanied by a set of macro packages to use it with Plain
TeX or LaTeX, but for use with Babel, see the @code{ibycus-babel} package.")
    (license license:gpl3+)))

(define-public texlive-inputnormalization
  (package
    (name "texlive-inputnormalization")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/inputnormalization/"
                                     "source/latex/inputnormalization/"
                                     "tex/latex/inputnormalization/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nfvcmr0lp7nig8mz3j1lwi0wbk8yf1ibdnz3lq22pysfjjl3200"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/inputnormalization")
    (synopsis "Wrapper for XeTeX's and LuaTeX's input normalization")
    (description
     "This package provides a cross engine interface to normalizing input
before it's read by TeX.")
    (license license:lppl1.3+)))

(define-public texlive-insbox
  (package
    (name "texlive-insbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/insbox/" "tex/generic/insbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0br6xpn9y11nw2pdjxck6mijbw2q6g2v31p64hwn65bwnx1fnc25"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/insbox")
    (synopsis "Insert pictures/boxes into paragraphs")
    (description
     "The package provides convenient bundling of the @code{\\parshape}
primitive.  This is a TeX package.")
    (license license:public-domain)))

(define-public texlive-js-misc
  (package
    (name "texlive-js-misc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/js-misc/" "tex/plain/js-misc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03cixw6rbg787ma8v43py07vrmhijf9cfg965ndahbzyhi6vkc96"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/js-misc")
    (synopsis "Miscellaneous macros from Joachim Schrod")
    (description
     "This package provides a bunch of packages, including: @file{idverb.tex},
for short verbatim; @file{xfig.tex}, for including xfig/transfig output in
a TeX document; and @file{cassette.tex} for setting cassette labels.")
    (license license:public-domain)))

(define-public texlive-jsclasses
  (package
    (name "texlive-jsclasses")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/platex/jsclasses/"
                                     "source/platex/jsclasses/"
                                     "tex/platex/jsclasses/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "024bgaim5rkamlwj4xa6w4yp8i37f8j6vn4jyrh8avwm9anc22pg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jsclasses")
    (synopsis "Classes tailored for use with Japanese")
    (description
     "This package provides classes @code{jsarticle} and @code{jsbook},
together with packages @code{okumacro} and @code{okuverb}.  These classes are
designed to work under ASCII Corporation's Japanese TeX system pTeX.")
    (license license:bsd-2)))

(define-public texlive-kerkis
  (package
    (name "texlive-kerkis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/kerkis/"
                                     "fonts/afm/public/kerkis/"
                                     "fonts/enc/dvips/kerkis/"
                                     "fonts/map/dvips/kerkis/"
                                     "fonts/opentype/public/kerkis/"
                                     "fonts/tfm/public/kerkis/"
                                     "fonts/type1/public/kerkis/"
                                     "fonts/vf/public/kerkis/"
                                     "tex/latex/kerkis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mkrnydgc05k2n6mrz6i3ichigf0bmy465s2vg514m7ma399khi9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/kerkis")
    (synopsis "Kerkis (Greek) font family")
    (description
     "This package provides sans-serif Greek fonts to match the URW Bookman
set (which are distributed with Kerkis).  The Kerkis font set has some support
for mathematics as well as other glyphs missing from the base URW Bookman
fonts.  Macros are provided to use the fonts in OT1, T1 (only NG/ng glyphs
missing) and LGR encodings, as well as in mathematics; small caps and
old-style number glyphs are also available.")
    (license license:lppl1.3c)))

(define-public texlive-lambda-lists
  (package
    (name "texlive-lambda-lists")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/lambda-lists/"
                                     "tex/plain/lambda-lists/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dlm6yr0z7d2j4wn1i1khf47sf79y4h2aahymm3y11ljr5pg012r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lambda-lists")
    (synopsis "Lists in ``TeX's mouth''")
    (description
     "These list-processing macros avoid the reassignments employed in the
macros shown in Appendix D of the TeXbook: all the manipulations take place in
what Knuth is pleased to call ``TeX's mouth''.")
    (license license:lppl)))

(define-public texlive-langcode
  (package
    (name "texlive-langcode")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/langcode/"
                                     "source/generic/langcode/"
                                     "tex/generic/langcode/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ygshcc0iszaldzc8ygz4bgvz05c3kv81v3m7i4q46l57x2kfx6x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/langcode")
    (synopsis "Simple language-dependent settings based on language codes")
    (description
     "The package provides a command @code{\\uselangcode@{<code>@}} to adjust
language-dependent settings such as key words, typographical conventions and
language codes (ISO 639-1).  The package provides a means of selecting macros
according to the specified code, for preparing a document that is to be
separately typeset in different languages.")
    (license license:lppl1.3+)))

(define-public texlive-lecturer
  (package
    (name "texlive-lecturer")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/lecturer/"
                                     "tex/generic/lecturer/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ry4r1zcq71kk672dnnpzah0aw2axj7frajbv6xwy6hf2hzzs0ln"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lecturer")
    (synopsis "On-screen presentations for (almost) all formats")
    (description
     "The package creates slides for on-screen presentations based on PDF
features without manipulating TeX's typesetting process.  The presentation
flow relies on PDF's abilities to display content step by step.  Features
include:

@itemize
@item Free positioning of anything anywhere in painted areas on the slide, as
well as in the main text block;
@item Numerous attributes to control the layout and the presentation flow,
from TeX's primitive dimensions to the visibility of steps;
@item Feature inheritance from global to local settings, with intermediate
types; Basic drawing facilities to produce symbols, e.g., for list items or
buttons;
@item Colours, transparency, shades, and pictures;
@item Navigation with links, pop-up menus, and customizable bookmarks;
@item Easy switch between presentation and handout; and PDF transitions.
@end itemize

Besides the traditional documentation, the distribution includes visual
documentation and six demo presentations ranging from geometric abstraction to
classic style to silly video game.")
    (license license:lppl)))

(define-public texlive-letterspacing
  (package
    (name "texlive-letterspacing")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/generic/letterspacing/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ry7rri76dgbrkzr6na2kkh7bn0jpwkhh9b5qw0cl5xwyp81rddg"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/letterspacing")
    (synopsis "Letter spacing")
    (description
     "This package helps spacing out the letters of text; the command is
@code{\\letterspace<\\hbox modifier>@{<text>@}}: the text is placed in an
@code{\\hbox} of the specified size, and space is inserted between each glyph
to make the text fit the box.  Note that letterspacing is not ordinarily
considered acceptable in modern typesetting of English.")
    (license license:knuth)))

(define-public texlive-levy
  (package
    (name "texlive-levy")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/levy/"
                                     "fonts/source/public/levy/"
                                     "fonts/tfm/public/levy/" "tex/generic/levy/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nkfsq5k2rysgsplv6rhvx8fimd7999dylzd2khvw7flryig32nv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/levy-font")
    (synopsis "Fonts for typesetting classical Greek")
    (description
     "These fonts are derivatives of Kunth's CM fonts.  Macros for use with
Plain TeX are included in the package; for use with LaTeX, see @code{lgreek}
(with English documentation) or @code{levy} (with German documentation).")
    (license license:gpl2)))

(define-public texlive-lgreek
  (package
    (name "texlive-lgreek")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lgreek/" "tex/latex/lgreek/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wa8d5mlk6jkx3m1rfddasw169sc6l6p8n4axh6i0np1imgsxx2b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lgreek")
    (synopsis "LaTeX macros for using Silvio Levy's Greek fonts")
    (description
     "This package provides a conversion of Silvio Levy's Plain TeX macros for
use with LaTeX.")
    (license license:gpl2)))

(define-public texlive-lgrmath
  (package
    (name "texlive-lgrmath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lgrmath/" "source/latex/lgrmath/"
                                     "tex/latex/lgrmath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lj4jdzwykqz1hkv2s6y2ghf1zlalx27gd6kfpbnignxmh63cpkb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lgrmath")
    (synopsis "Use LGR-encoded fonts in math mode")
    (description
     "The @code{lgrmath} package is a LaTeX package which sets the Greek
letters in math mode to use glyphs from the LGR-encoded font of one's choice.
The documentation includes a rather extensive list of the available font
family names on typical LaTeX installations.")
    (license license:lppl1.3c)))

(define-public texlive-localloc
  (package
    (name "texlive-localloc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/localloc/"
                                     "source/generic/localloc/"
                                     "tex/generic/localloc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vcfdxh800ksr4wrrvykdm27qvlhqkylbik4j93pr59g13h9g90f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/localloc")
    (synopsis "Macros for localizing TeX register allocations")
    (description
     "This package approaches the problem of the shortage of registers, by
providing a mechanism for local allocation.  The package works with Plain TeX
and LaTeX.")
    (license license:knuth)))

(define-public texlive-metatex
  (package
    (name "texlive-metatex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/metatex/" "tex/plain/metatex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pdgx59ckp9qdfidl37y8mv3dyvza9lxmhgbqk69ckywm3kbb2n9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/metatex")
    (synopsis "Incorporate Metafont pictures in TeX source")
    (description
     "METATeX is a set of plain TeX and Metafont macros that you can use to
define both the text and the figures in a single source file.  Because METATeX
sets up two way communication, from TeX to Metafont and back from Metafont to
TeX, drawing dimensions can be controlled by TeX and labels can be located by
Metafont.  Only standard features of TeX and Metafont are used, but two runs
of TeX and one of Metafont are needed.")
    (license license:gpl3+)))

(define-public texlive-midnight
  (package
    (name "texlive-midnight")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/midnight/"
                                     "tex/generic/midnight/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "024g170k8cfcddch2c0qvq1als0ncp9v2zqv77yzay5jqx4iv1d7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/midnight")
    (synopsis "Set of useful macro tools")
    (description
     "This package provides macro tools:
@itemize
@item @code{quire}: making booklets, etc.;
@item @code{gloss}: vertically align words in consecutive sentences;
@item @code{loop}: a looping construct;
@item @code{dolines}: meta'-macros to separate arguments by newlines;
@item @code{labels}: address labels and bulk mail letters;
@item @code{styledef}: selectively input part of a file;
@item @code{border}: borders around boxes.
@end itemize")
    ;; All files share the same license, which is Knuth's with additional
    ;; requirements about documentation and references to the original source
    ;; when modified.
    (license (license:fsf-free "file://tex/generic/midnight/border.tex"))))

(define-public texlive-mkgrkindex
  (package
    (name "texlive-mkgrkindex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/mkgrkindex/"
                                     "makeindex/mkgrkindex/"
                                     "scripts/mkgrkindex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bj35wdxn0xllpqzf8lrd00b5rmyy9fws84avz3ijk4k8rvfz8gk"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "mkgrkindex")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/greek-makeindex")
    (synopsis "MakeIndex working with Greek")
    (description
     "MakeIndex is resolutely stuck with Latin-based alphabets, so will not
deal with Greek indexes, unaided.  This package provides a Perl script that
will transmute the index of a Greek document in such a way that MakeIndex will
sort the entries according to the rules of the Greek alphabet.")
    (license license:lppl)))

(define-public texlive-modulus
  (package
    (name "texlive-modulus")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/modulus/"
                                     "source/generic/modulus/"
                                     "tex/generic/modulus/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07sa8bnbgclfz4p3sb00cl1b3i51nvhhlmb4p6hcyaca1n1xsn8d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/modulus")
    (synopsis "Non-destructive modulus and integer quotient operator for TeX")
    (description
     "The package provides an easy way to take the remainder of a division
operation without destroying the values of the counters containing the
dividend and divisor.  It also provides a way to take the integer quotient of
a division operation without destroying the values of the counters containing
the dividend and divisor.")
    (license license:lppl1.3c)))

(define-public texlive-mongolian-babel
  (package
    (name "texlive-mongolian-babel")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mongolian-babel/"
                                     "source/latex/mongolian-babel/"
                                     "tex/latex/mongolian-babel/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12kzips0jmjahrrfaripglg203dvvr408v5qxjvnrnxqzb8d1i2w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mongolian-babel")
    (synopsis "Language definition file for Mongolian in Babel")
    (description
     "This package provides support for Mongolian in a Cyrillic
alphabet.  (The work derives from the earlier Russian work for Babel.)")
    (license license:lppl)))

(define-public texlive-montex
  (package
    (name "texlive-montex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/montex/"
                                     "fonts/map/dvips/montex/"
                                     "fonts/source/public/montex/"
                                     "fonts/tfm/public/montex/"
                                     "fonts/type1/public/montex/"
                                     "tex/latex/montex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01rbzw0kbiy3wig2mrdclygx7a71dckq9rhqj8jpdnbjyhm9jw35"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (propagated-inputs (list texlive-cbfonts))
    (home-page "https://ctan.org/pkg/montex")
    (synopsis "Mongolian LaTeX")
    (description
     "MonTeX provides Mongolian and Manju support for the TeX and LaTeX community.
It provides all necessary characters for writing standard Mongolian in
Cyrillic and Classical (aka Traditional or Uighur) writing, and Manju as well
as transliterated Tibetan texts, for which purpose a number of additional
characters was created.

In MonTeX, both Mongolian and Manju are entered in romanized form.  The
retransliteration (from Latin input to Mongolian and Manju output) is
completely realized in TeX and Metafont so that no external preprocessor is
required.  Please note that most of the enhanced functions of MonTeX require
a working e-LaTeX environment.  This is especially true when compiling
documents with Mongolian or Manju as the main document language.  It is
recommended to choose pdfLaTeX as the resulting PDF files are truly portable.
Vertical text generated by MonTeX is not supported in DVI.")
    (license license:gpl3+)))

(define-public texlive-moreverb
  (package
    (name "texlive-moreverb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/moreverb/" "source/latex/moreverb/"
                                     "tex/latex/moreverb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kba3df9cfiz168hsxhwg3a838p3vrgfp42fmwafsf3xq3q2z5hg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/moreverb")
    (synopsis "Extended verbatim")
    (description
     "This package provides a collection of verbatim facilities that provide
line-numbered verbatim, verbatim that obeys TAB characters, verbatim input and
verbatim output to file.  The package makes use of the @code{verbatim}
package.  The package is formed from a series of small pieces, and is somewhat
unstructured.  The user who looks for thought-through verbatim facilities is
advised to consider using the @code{fancyvrb} package in place of
@code{moreverb}.")
    (license license:lppl)))

(define-public texlive-morewrites
  (package
    (name "texlive-morewrites")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/morewrites/"
                                     "source/latex/morewrites/"
                                     "tex/latex/morewrites/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16lgdlvbx0lnjca0apdp0f4fm7bhglgpvl30dlnrfjwv7jsk29ci"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/morewrites")
    (synopsis "Always room for a new write stream")
    (description
     "The package aims to solve the error @emph{No room for a new \\write},
which occurs when the user, or when the user's packages have allocated too
many streams using @code{\\newwrite} (TeX has a fixed maximum number ---
16 --- of such streams built-in to its code).  The package hooks into TeX
primitive commands associated with writing to files; it should be loaded near
the beginning of the sequence of loading packages for a document.")
    (license license:lppl1.3c)))

(define-public texlive-morisawa
  (package
    (name "texlive-morisawa")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/morisawa/"
                                     "fonts/map/dvipdfmx/morisawa/"
                                     "fonts/tfm/public/morisawa/"
                                     "fonts/vf/public/morisawa/"
                                     "source/fonts/morisawa/"
                                     "tex/latex/morisawa/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wqyiq049y0mv6d1r3d0mrjzhh5pq2vi50sr0jhd58k4wdg8zqkb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/morisawa")
    (synopsis
     "Selection of 5 standard Japanese fonts for pLaTeX and dvips")
    (description
     "The package enables selection of 5 standard Japanese fonts for pLaTeX
and dvips.")
    (license license:bsd-2)))

(define-public texlive-mpman-ru
  (package
    (name "texlive-mpman-ru")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/mpman-ru/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x3drpi21zcmkhkscvl4l7805wskqa4zskydb33i0asss5p62396"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mpman-ru")
    (synopsis "Russian translation of the MetaPost manual")
    (description
     "This package provides a translation of the MetaPost user manual, as
distributed with MetaPost itself.")
    ;; Explicitly use the same license as MetaPost.
    (license license:lppl)))

(define-public texlive-namedef
  (package
    (name "texlive-namedef")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/namedef/"
                                     "source/generic/namedef/"
                                     "tex/generic/namedef/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rc97c8zn1gb1cfqf70q5iphnbkgay4xmw1a2h55kc9wj4ql2j5d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-l3kernel))
    (home-page "https://ctan.org/pkg/namedef")
    (synopsis "TeX definitions with named parameters")
    (description
     "This package provides a prefix @code{\\named} to be used in TeX
definitions so that parameters can be identified by their name rather than by
number, giving parameters a semantic rather than syntactic meaning, making it
easy to understand long definitions.")
    (license license:lppl1.3c)))

(define-public texlive-navigator
  (package
    (name "texlive-navigator")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/navigator/"
                                     "tex/generic/navigator/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17rs718rvp9f6dakdl99abgq5rcflsw6kyxjknhjya019l2y23m3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/navigator")
    (synopsis "PDF features across formats and engines")
    (description
     "Navigator implements PDF features for all formats (with some limitations
in ConTeXt) with pdfTeX, LuaTeX and XeTeX.  Its features include: customizable
outlines (i.e.  bookmarks); anchors; links and actions (e.g., JavaScript or
user-defined PDF actions); file embedding (not in ConTeXt); document
information and PDF viewer's display (not in ConTeXt); and commands to create
and use raw PDF objects.")
    (license license:lppl)))

(define-public texlive-newsletr
  (package
    (name "texlive-newsletr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/newsletr/" "tex/plain/newsletr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c7ggyx1jnw05vn589awxxbpfqkwf7kq4qn9pm61ycb6p9n3nn0h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/newsletr")
    (synopsis "Macros for making newsletters with Plain TeX")
    (description
     "This package provides macros for making newsletters with Plain TeX.")
    ;; License is almost Knuth's, but requires marking modifications
    ;; explicitly instead of simply renaming the file.
    (license (license:fsf-free "file://doc/plain/newsletr/read.me"))))

(define-public texlive-numnameru
  (package
    (name "texlive-numnameru")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/numnameru/"
                                     "tex/latex/numnameru/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1il8qn9wkdk554r4a8h5vmdmwcvgwygcx58zwnqxflz6hqsxdjmx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/numnameru")
    (synopsis "Converts a number to the Russian spelled out name")
    (description
     "This package converts a numerical number to the Russian spelled out name
of the number.")
    (license license:lppl1.3+)))

(define-public texlive-ofs
  (package
    (name "texlive-ofs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/ofs/" "tex/generic/ofs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dcsa9xlcdvwd4qd6n6yli8arcy3s6896svgk5nbmgplan2nz1cw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ofs")
    (synopsis "Macros for managing large font collections")
    (description
     "OFS (Olsak's Font System) is a set of Plain TeX and LaTeX macros for
managing large font collections.  Its main features include:

@itemize
@item mapping from long names of fonts to the metric file name.  The user can
specify only exact long names in documents;
@item support for many font encodings;
@item printing of catalogues of fonts and test samples of font families; the
interactive macro @code{\\showfonts} shows all font families you have
installed via OFS.
@end itemize")
    (license license:knuth)))

(define-public texlive-olsak-misc
  (package
    (name "texlive-olsak-misc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/olsak-misc/"
                                     "tex/generic/olsak-misc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kl83yvj299w7v69a20i5yi91h46n0k080rg6z1jjwdxm0g893a0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/olsak-misc")
    (synopsis "Collection of plain TeX macros written by Petr Olsak")
    (description
     "This is a collection of various single-file plain TeX macros written
by Petr Olsak:

@itemize
@item @file{booklet.tex}: re-orders PDF pages and collects them for booklet
printing;
@item @file{cnv.tex}: conversion of texts;
@item @file{cnv-pu.tex}: example of usage of @file{cnv.tex} --- pdf outlines
in Unicode;
@item @file{cnv-word.tex}: example of usage of @file{cnv.tex} --- word to word
conversion;
@item @file{eparam.tex}: full expansion during parameter scanning;
@item @file{fun-coffee.tex}: generates splotches in the document;
@item @file{openclose.tex}: repairs balanced text between @code{\\Open} and
@code{\\Close} pair;
@item @file{qrcode.tex}: QR code generated at TeX level;
@item @file{scanbase.tex}: parser of text-style MySQL outputs;
@item @file{scancsv.tex}: parser of CSV format;
@item @file{seplist.tex}: macros with alternative separators of a parameter;
@item @file{xmlparser.tex}: parser of XML language.
@end itemize")
    (license license:public-domain)))

(define-public texlive-outerhbox
  (package
    (name "texlive-outerhbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/generic/outerhbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1867xhxlbskiysifmwlr10lay8khragzi36fm552cwc4vjz2ybcz"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/outerhbox")
    (synopsis "Collect horizontal material for contributing to a paragraph")
    (description
     "The package provides the @code{\\outerhbox} command, which is similar to
@code{\\hbox}, except that material is set in outer horizontal mode.  This
prevents TeX from optimising away maths penalties and the like, that are
needed when the material is @code{\\unhbox}'ed.")
    (license license:gpl3+)))

(define-public texlive-path
  (package
    (name "texlive-path")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/path/" "tex/generic/path/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09m1f9si97hrfqsyj0mzbi9djgk0w4vq13yd3v0af9v3240h1ps2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/path")
    (synopsis "Typeset paths, making them breakable")
    (description
     "This package defines a macro @code{\\path|...|}, similar to the LaTeX
@code{\\verb|...|}, that sets the text in typewriter font and allows
hyphen-less breaks at punctuation characters.  The set of characters to be
regarded as punctuation may be changed from the package's default.")
    (license license:knuth)))

(define-public texlive-pdf-trans
  (package
    (name "texlive-pdf-trans")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pdf-trans/"
                                     "tex/generic/pdf-trans/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n7l0p1950lk3n5jm3si0qqhb8b7mm7jh33fm97l2r7d3qn9jac8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdf-trans")
    (synopsis "Macros for various transformations of TeX boxes")
    (description
     "@code{pdf-trans} is a set of macros offering various transformations of
TeX boxes (based on plain and pdfeTeX primitives).")
    (license license:public-domain)))

(define-public texlive-pdfmsym
  (package
    (name "texlive-pdfmsym")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pdfmsym/"
                                     "tex/generic/pdfmsym/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13rffg6i2nx94wmgxsipbi490fncxnq3j42p5vcdg8bldfk1w5w4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfmsym")
    (synopsis "PDF Math Symbols --- various drawn mathematical symbols")
    (description
     "This package defines a handful of mathematical symbols many of which are
implemented via PDF's builtin drawing utility.  It is intended for use with
pdfTeX and LuaTeX and is supported by XeTeX to a lesser extent.  Among the
symbols it defines are some variants of commonly used ones, as well as more
obscure symbols which cannot be as easily found in other TeX or LaTeX
packages.")
    (license license:expat)))

(define-public texlive-pitex
  (package
    (name "texlive-pitex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/pitex/" "tex/plain/pitex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rqawfqmh9sh7rfpfrhbmysmn1rlzmbs26nla8fj0xr45vx60219"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pitex")
    (synopsis "Documentation macros")
    (description
     "The bundle provides macros that the author uses when writing
documentation (for example, that of the @code{texapi} and @code{yax}
packages).")
    (license license:lppl)))

(define-public texlive-pl
  (package
    (name "texlive-pl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/pl/"
                                     "dvips/pl/"
                                     "fonts/afm/public/pl/"
                                     "fonts/enc/dvips/pl/"
                                     "fonts/map/dvips/pl/"
                                     "fonts/source/public/pl/"
                                     "fonts/tfm/public/pl/"
                                     "fonts/type1/public/pl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18s3by7isk85ksvp40i6qg2ws3iyj5f35fh8h0561rw6jdc024rc"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-amsfonts"
                                               "texlive-cm")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-amsfonts texlive-cm texlive-metafont))
    (home-page "https://ctan.org/pkg/pl-mf")
    (synopsis "Polish extension of Computer Modern fonts")
    (description
     "This package provides the Polish extension of the Computer Modern
fonts (compatible with CM itself) for use with Polish TeX formats.")
    (license license:public-domain)))

(define-public texlive-placeins-plain
  (package
    (name "texlive-placeins-plain")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/plain/placeins-plain/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lhc72zdm2cjynx6lf6kafmf00nw17z3mnfhagh41h76cnm338g9"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/placeins-plain")
    (synopsis "Insertions that keep their place")
    (description
     "This TeX file provides various mechanisms (for plain TeX and close
relatives) to let insertions (footnotes, topins, pageins, etc.) float within
their appropriate section, but to prevent them from intruding into the
following section, even when sections do not normally begin a new page.")
    (license license:public-domain)))

(define-public texlive-plainpkg
  (package
    (name "texlive-plainpkg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/plainpkg/"
                                     "source/generic/plainpkg/"
                                     "tex/generic/plainpkg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10p796lms7rzwqgjf60nqm8x79hiz1cwiq1j8acjg1a6lnvadbq0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/plainpkg")
    (synopsis "Minimal method for making generic packages")
    (description
     "The package provides a minimal method for making generic (i.e.,
TeX-format-independent) packaged, combining maybeload functionality, fallback
definitions for LaTeX @code{\\ProvidesPackage} and @code{\\RequirePackage}
functionality, and handling of arbitrary (multiple) private letters (analogous
LaTeX packages use of @samp{@@@@}) in nested package files.")
    (license license:lppl1.3+)))

(define-public texlive-platex
  (package
    (name "texlive-platex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/platex.1"
                                     "doc/man/man1/platex.man1.pdf"
                                     "doc/platex/base/"
                                     "source/platex/base/"
                                     "tex/platex/base/"
                                     "tex/platex/config/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kdmnlbg5jh9ym3iasbpp5al7ljhn8fiirw6y5g4k5x3v9f3bmm8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:create-formats #~(list "platex" "platex-dev")
           #:phases
           #~(modify-phases %standard-phases
               (add-after 'unpack 'fix-build
                 ;; This phase is necessary because the build phase is
                 ;; reluctant to generate "kinsoku.tex" since there is another
                 ;; one among the inputs (texlive-ptex) already.
                 (lambda _
                   (substitute* "source/platex/base/plfmt.ins"
                     (("\\\\keepsilent\n" all)
                      (string-append all "\\askforoverwritefalse\n")))))
               (add-after 'install 'symlink-binaries
                 (lambda* (#:key inputs #:allow-other-keys)
                   (let ((euptex (search-input-file inputs "bin/euptex"))
                         (bin (string-append #$output "/bin")))
                     (mkdir-p bin)
                     (with-directory-excursion bin
                       (symlink euptex "platex"))))))))
    (propagated-inputs
     (list texlive-babel
           texlive-cm
           texlive-firstaid
           texlive-hyphen-base
           texlive-l3backend
           texlive-l3kernel
           texlive-latex
           texlive-latex-fonts
           texlive-ptex
           texlive-ptex-fonts
           texlive-tex-ini-files
           texlive-unicode-data
           texlive-uptex))
    (home-page "https://ctan.org/pkg/platex")
    (synopsis "Miscellaneous macros for pTeX and pLaTeX2e")
    (description
     "The bundle provides pLaTeX2e and miscellaneous macros for pTeX and
e-pTeX.")
    (license license:bsd-3)))

(define-public texlive-platex-tools
  (package
    (name "texlive-platex-tools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/platex-tools/"
                                     "tex/latex/platex-tools/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wdxcmag1kk6zs7dv10jdcs9ih0bs08xr14iw5bqqyppia4pa1lv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/platex-tools")
    (synopsis "Standard tools bundle")
    (description
     "This bundle is an extended version of the @code{latex-tools} bundle
developed by the LaTeX team, mainly intended to support pLaTeX2e and
upLaTeX2e.  Currently patches for the @code{latex-tools} bundle and Martin
Schroder's @code{ms} bundle are included.")
    (license license:bsd-3)))

(define-public texlive-platexcheat
  (package
    (name "texlive-platexcheat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/platexcheat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04hvm19x4z7vq2md3p3r2wwa7iqkgkxnvvj1xx3s9145m6fjib5a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/platexcheat")
    (synopsis "LaTeX cheat sheet, in Japanese")
    (description
     "This is a translation to Japanese of Winston Chang's LaTeX cheat
sheet (a reference sheet for writing scientific papers).  It has been adapted
to Japanese standards using pLaTeX, and also attached additional information
of standard LaTeX (especially about Math mode).")
    (license license:expat)))

(define-public texlive-plautopatch
  (package
    (name "texlive-plautopatch")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/plautopatch/"
                                     "tex/latex/plautopatch/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fhphmjhq0mbsarkfmfj0580b97lxxbcwanr4zpwjj5f6krqq742"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/plautopatch")
    (synopsis "Automated patches for pLaTeX/upLaTeX")
    (description
     "Japanese pLaTeX and upLaTeX formats and packages often conflict with
other LaTeX packages which are unaware of pLaTeX and upLaTeX.  In the worst
case, such packages throw a fatal error or end up with a wrong output.  The
goal of this package is that there should be no need to worry about such
incompatibilities, because specific patches are loaded automatically whenever
necessary.  This helps not only to simplify source files, but also to make the
appearance of working pLaTeX or upLaTeX sources similar to those of ordinary
LaTeX ones.")
    (license license:bsd-3)))

(define-public texlive-plipsum
  (package
    (name "texlive-plipsum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/plipsum/" "tex/plain/plipsum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q8qnv212q9mgc00w9akdvpky1gbmirqrkdmi9v1wbf7c0ws2qda"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/plipsum")
    (synopsis "@emph{Lorem ipsum} for Plain TeX developers")
    (description
     "The package provides a paragraph generator designed for use in Plain TeX
documents.  The paragraphs generated contain many f-groups (@samp{ff},
@samp{fl} etc.) so the text can act as a test of the ligatures of the font in
use.")
    (license license:lppl)))

(define-public texlive-plnfss
  (package
    (name "texlive-plnfss")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/plnfss/" "tex/plain/plnfss/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cgnp8y9m0ziq1pfvjx83vi0r0k5xpckk0kiijy0g80wd3s4zbsd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/plnfss")
    (synopsis "Font selection for Plain TeX")
    (description
     "Plnfss is a set of macros to provide easy font access (somewhat similar
to NFSS but with some limitations) with Plain TeX.  Plnfss can automatically
make use of PSNFSS @code{fd} files, i.e., when an Adobe Type 1 is used the
relevant @code{fd} file will be loaded automatically.  For @code{cmr}-like
fonts (@code{ec}, @code{vnr}, @code{csr} or @code{plr} fonts), a special
format called @code{pfd} (plain @code{fd}) is required and must be loaded
manually.")
    (license license:lppl)))

(define-public texlive-plstmary
  (package
    (name "texlive-plstmary")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/plstmary/" "tex/plain/plstmary/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03adq5fkl620z0hpbdpqcsm1qjxlr43ip1bhi5xv2izxpw952x0z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/plstmary")
    (synopsis "St Mary's Road font support for plain TeX")
    (description
     "The package provides commands to produce all the symbols of the St
Mary's Road fonts, in a Plain TeX environment.")
    (license license:public-domain)))

(define-public texlive-poormanlog
  (package
    (name "texlive-poormanlog")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/poormanlog/"
                                     "tex/generic/poormanlog/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wbpjxjn3bvi4bmcq62ydafc8a72wq2vhzfx2gcn20sn3x4qc0hg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/poormanlog")
    (synopsis "Logarithms and powers with (almost) 9 digits")
    (description
     "This small package (usable with Plain e-TeX, LaTeX, or others) with no
dependencies provides two fast expandable macros computing logarithms in base
10 and fractional powers of 10.")
    (license license:lppl1.3c)))

(define-public texlive-present
  (package
    (name "texlive-present")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/present/" "tex/plain/present/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dc7h14z7xw232mgqjayl1a4ab5pj9bz2d9wgmznh4bjylgw4lwp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/present")
    (synopsis "Presentations with Plain TeX")
    (description
     "The package offers a collection of simple macros for preparing
presentations in Plain TeX.  Slide colour and text colour may be set, links
between parts of the presentation, to other files, and to web addresses may be
inserted.  Images may be included easily, and code is available to provide
transition effects between slides or frames.  The structure of the macros is
not overly complex, so that users should find it easy to adapt the macros to
their specific needs.")
    (license license:lppl)))

(define-public texlive-ptex
  (package
    (name "texlive-ptex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/eptex.1"
                                     "doc/man/man1/eptex.man1.pdf"
                                     "doc/man/man1/makejvf.1"
                                     "doc/man/man1/makejvf.man1.pdf"
                                     "doc/man/man1/mendex.1"
                                     "doc/man/man1/mendex.man1.pdf"
                                     "doc/man/man1/pbibtex.1"
                                     "doc/man/man1/pbibtex.man1.pdf"
                                     "doc/man/man1/ppltotf.1"
                                     "doc/man/man1/ppltotf.man1.pdf"
                                     "doc/man/man1/ptekf.1"
                                     "doc/man/man1/ptekf.man1.pdf"
                                     "doc/man/man1/ptex.1"
                                     "doc/man/man1/ptex.man1.pdf"
                                     "doc/man/man1/ptftopl.1"
                                     "doc/man/man1/ptftopl.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0aqan2g9cp5nv0hh1i6d6wcsp19f8zdlrij7wi3xs0hf5kwl2ql9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:create-formats #~(list "eptex" "ptex")))
    (propagated-inputs
     (list texlive-cm
           texlive-etex
           texlive-hyphen-base
           texlive-knuth-lib
           texlive-plain
           texlive-ptex-base
           texlive-ptex-bin
           texlive-ptex-fonts
           texlive-uptex))
    (home-page "https://ctan.org/pkg/ptex")
    (synopsis "TeX system for publishing in Japanese")
    (description
     "pTeX adds features related to vertical writing, and deals with other
problems in typesetting Japanese.  A manual (in both Japanese and English) is
distributed as package @code{pTeX-manual}.")
    (license license:bsd-3)))

(define-public texlive-ptex-bin
  (package
    (inherit texlive-bin)
    (name "texlive-ptex-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("makejvf" "mendexk" "web2c"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons* "--enable-makejvf"
                 "--enable-mendexk"
                 (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/makejvf"
                    (invoke "make" "check"))
                  (with-directory-excursion "texk/mendexk"
                    (invoke "make" "check")))))
            (add-after 'build 'build-web2c-binaries
              (lambda _
                (with-directory-excursion "texk/web2c"
                  (for-each (lambda (target) (invoke "make" target))
                            '("eptex" "pmpost")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/makejvf"
                  (invoke "make" "install"))
                (with-directory-excursion "texk/mendexk"
                  (invoke "make" "install"))
                ;; Install Web2C parts.
                (let ((bin (string-append #$output "/bin")))
                  (with-directory-excursion "texk/web2c"
                    (for-each (lambda (f) (install-file f bin))
                              '("eptex" "pmpost")))
                  (with-directory-excursion bin
                    (for-each symlink
                              '("eptex" "pmpost"   "pmpost")
                              '("ptex"  "pdvitomp" "r-pmpost"))
                    ;; Some executables are symlinks to TEXLIVE-UPTEX-BIN's.
                    (let ((uptex #$(this-package-input "texlive-uptex-bin")))
                      (for-each
                       symlink
                       (map (lambda (f) (string-append uptex "/bin/" f))
                            '("upbibtex" "updvitype" "uppltotf" "uptftopl"))
                       '("pbibtex" "pdvitype" "ppltotf" "ptftopl")))))))))))
    (native-inputs (list pkg-config))
    (inputs
     (modify-inputs (package-inputs texlive-bin)
       (append cairo gmp mpfi mpfr texlive-libptexenc texlive-uptex-bin)))
    (home-page (package-home-page texlive-ptex))
    (synopsis "Binaries for @code{texlive-ptex}")
    (description
     "This package provides the binaries for @code{texlive-ptex}.")
    (license (package-license texlive-ptex))))

(define-public texlive-ptex-base
  (package
    (name "texlive-ptex-base")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/ptex/ptex-base/" "tex/ptex/ptex-base/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hfccpsfpj56v97056k77lyb09az7m24m8klf1n2v0a7kqdc1fv6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ptex-base")
    (synopsis "Plain TeX format for pTeX and e-pTeX")
    (description
     "The bundle contains the plain TeX format for pTeX and e-pTeX.")
    (license license:bsd-3)))

(define-public texlive-ptex-fontmaps
  (package
    (name "texlive-ptex-fontmaps")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/ptex-fontmaps/"
                                     "fonts/cmap/ptex-fontmaps/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/adobe/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/apple/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/arphic/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/baekmuk/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/bizud/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/canon/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/cjkunifonts-ttf/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/cjkunifonts/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/dynacomware/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/fandol/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/founder/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/haranoaji/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/hiragino-pron/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/hiragino/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/ipa/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/ipaex/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/kozuka-pr6/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/kozuka-pr6n/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/kozuka/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/moga-mobo-ex/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/moga-mobo/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/morisawa-pr6n/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/morisawa/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/ms-osx/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/ms-win10/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/ms/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/noEmbed/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/noto-otc/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/noto/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/solaris/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/sourcehan-otc/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/sourcehan/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/ume/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/unfonts/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/yu-osx/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/yu-win/"
                                     "fonts/map/dvipdfmx/ptex-fontmaps/yu-win10/"
                                     "fonts/misc/ptex-fontmaps/"
                                     "scripts/ptex-fontmaps/"
                                     "source/ptex-fontmaps/jis04cmap_exp/"
                                     "source/ptex-fontmaps/script/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07qm41d33z9vjvchsxfrqxim7zb15cg77x4aw5a06mgn3w7kz6ha"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts #~(list "kanji-config-updmap-sys.sh"
                                  "kanji-config-updmap-user.sh"
                                  "kanji-config-updmap.pl"
                                  "kanji-fontmap-creator.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/ptex-fontmaps")
    (synopsis
     "Font maps and tools for Japanese/Chinese/Korean fonts with (u)pTeX")
    (description
     "This package provides font maps and setup tools for Japanese, Korean,
Traditional Chinese, and Simplified Chinese.  It is the successor of the
@code{jfontmaps} package.  The files in this package contain font maps for
dvipdfmx to make various Japanese, Chinese, and Korean fonts available
for (u)ptex and related programs and formats.")
    (license (list license:public-domain license:gpl3))))

(define-public texlive-ptex-manual
  (package
    (name "texlive-ptex-manual")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/ptex/ptex-manual/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kvq5wx7rz6lz9a5f2fjk1y3l8sbqm10jc80s9irbkhv8rhkg8ar"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ptex-manual")
    (synopsis "Japanese pTeX manual")
    (description "This package contains the Japanese pTeX manual.")
    (license license:bsd-3)))

(define-public texlive-ptex-fonts
  (package
    (name "texlive-ptex-fonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/ptex-fonts/"
                                     "fonts/source/ptex-fonts/jis/"
                                     "fonts/source/ptex-fonts/nmin-ngoth/"
                                     "fonts/source/ptex-fonts/standard/"
                                     "fonts/tfm/ptex-fonts/dvips/"
                                     "fonts/tfm/ptex-fonts/jis/"
                                     "fonts/tfm/ptex-fonts/nmin-ngoth/"
                                     "fonts/tfm/ptex-fonts/standard/"
                                     "fonts/vf/ptex-fonts/jis/"
                                     "fonts/vf/ptex-fonts/nmin-ngoth/"
                                     "fonts/vf/ptex-fonts/standard/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0f33y28zmrc6gw01qj956vrwj3mh5gn6kph2i13yg1yi2hdl7wwa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ptex-fonts")
    (synopsis "Fonts for use with pTeX")
    (description
     "The bundle contains fonts for use with pTeX and the documents for the
@command{makejvf} program.")
    (license license:bsd-3)))

(define-public texlive-ptex2pdf
  (package
    (name "texlive-ptex2pdf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ptex2pdf/" "scripts/ptex2pdf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vc4clig35s9cir2gmls7zvj8k1qal4np0akvlgsz2zch44b0imr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "ptex2pdf.lua")))
    (home-page "https://ctan.org/pkg/ptex2pdf")
    (synopsis "Convert Japanese TeX documents to PDF")
    (description
     "The Lua script provides system-independent support of Japanese
typesetting engines in TeXworks.  As TeXworks typesetting setup does not allow
for multistep processing, this script runs one of the pTeX-based programs
followed by dvipdfmx.")
    (license license:gpl2)))

(define-public texlive-pxbase
  (package
    (name "texlive-pxbase")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/platex/pxbase/" "tex/platex/pxbase/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dq9d4ixddffjnzb73d2qacgzm27665hvq2gsfjqzikzaa70dahw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pxbase")
    (synopsis "Tools for use with (u)pLaTeX")
    (description
     "The main purpose of this package is to provide auxiliary functions which
are utilized by other packages created by the same author.  It also provides
a few user commands to assist in creating Japanese documents using
@code{(u)pLaTeX.}")
    (license license:expat)))

(define-public texlive-pxchfon
  (package
    (name "texlive-pxchfon")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/platex/pxchfon/" "fonts/sfd/pxchfon/"
                                     "fonts/tfm/public/pxchfon/"
                                     "fonts/vf/public/pxchfon/"
                                     "tex/platex/pxchfon/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vqzsp0hbgwiyv0a2675v8r20jncdaqvkd22ppnd1c14ham9097h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pxchfon")
    (synopsis "Japanese font setup for pLaTeX and upLaTeX")
    (description
     "This package enables users to declare in their document which physical
fonts should be used for the standard Japanese (logical) fonts of pLaTeX and
upLaTeX.  Font setup is realized by changing the font mapping of dvipdfmx, and
thus users can use any (monospaced) physical fonts they like, once they
properly install this package, without creating helper files for each new
font.  This package also supports setup for the fonts used in the
@code{japanese-otf} package.")
    (license license:expat)))

(define-public texlive-pxcjkcat
  (package
    (name "texlive-pxcjkcat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pxcjkcat/" "tex/latex/pxcjkcat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10lbwry55rdldfhj2v893rpp1jdzv00vxhg4hf4gsgsmv1nnp25f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pxcjkcat")
    (synopsis "LaTeX interface for the CJK category codes of upTeX")
    (description
     "The package provides management of the CJK category code table of the
upTeX extended TeX engine.  Package options are available for tailored use in
the cases of documents that are principally written in Japanese, or
principally written in English or other Western languages.")
    (license license:expat)))

(define-public texlive-pxjahyper
  (package
    (name "texlive-pxjahyper")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/platex/pxjahyper/"
                                     "tex/platex/pxjahyper/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0128yslhwbrdhshjhxk6ayfl42ds0x0sfyvp91aspwbkfjnr34p9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pxjahyper")
    (synopsis "Hyperref support for pLaTeX")
    (description
     "This package adjusts the behavior of @code{hyperref} on (u)pLaTeX so
that authors can properly create PDF documents that contain document
information in Japanese.")
    (license license:expat)))

(define-public texlive-pxjodel
  (package
    (name "texlive-pxjodel")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pxjodel/"
                                     "fonts/tfm/public/pxjodel/"
                                     "fonts/vf/public/pxjodel/"
                                     "tex/latex/pxjodel/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g5sd60zd34ark50qy2dgqrdcd5pwy5hxmi6g5jxqlj3j1n6r1ny"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pxjodel")
    (synopsis "Help change metrics of fonts from japanese-otf")
    (description
     "This package changes the setup of the @code{japanese-otf} package so
that the TFMs for direct input are all replaced by new ones with prefixed
names.  This function will assist users who want to use the
@code{japanese-otf} package together with tailored TFMs of Japanese fonts.")
    (license license:expat)))

(define-public texlive-pxrubrica
  (package
    (name "texlive-pxrubrica")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/platex/pxrubrica/"
                                     "source/platex/pxrubrica/"
                                     "tex/platex/pxrubrica/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0n8jc65szkq114qg197hc9amrpifqvha8wifxplhvbmb09kzm5mm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pxrubrica")
    (synopsis "Ruby annotations according to JIS X 4051")
    (description
     "This package provides a function to add ruby annotations (furigana) that
follow the style conventional in Japanese typography as described in the W3C
technical note @emph{Requirements for Japanese Text Layout} and the JIS
specification JIS X 4051.")
    (license license:expat)))

(define-public texlive-pxufont
  (package
    (name "texlive-pxufont")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pxufont/"
                                     "fonts/tfm/public/pxufont/"
                                     "fonts/vf/public/pxufont/"
                                     "tex/latex/pxufont/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zg6wc62nj3p04lrp6dr4hhf67hxlgy70iy2h31vji29hsp417rv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pxufont")
    (synopsis "Emulate non-Unicode Japanese fonts using Unicode fonts")
    (description
     "The set of the Japanese logical fonts (JFMs) that are used as standard
fonts in pTeX and upTeX contains both Unicode JFMs and non-Unicode JFMs.  This
bundle provides an alternative set of non-Unicode JFMs that are tied to the
virtual fonts (VFs) that refer to the glyphs in the Unicode JFMs.  Moreover it
provides a LaTeX package that redefines the NFSS settings of the Japanese
fonts of @code{(u)pLaTeX} so that the new set of non-Unicode JFMs will be
employed.  As a whole, this bundle allows users to dispense with the mapping
setup on non-Unicode JFMs.  Such a setup is useful in particular when users
want to use OpenType fonts (such as Source Han Serif) that have a glyph
encoding different from Adobe-Japan1, because mapping setups from non-Unicode
JFMs to such physical fonts are difficult to prepare.")
    (license license:expat)))

(define-public texlive-pwebmac
  (package
    (name "texlive-pwebmac")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/pwebmac/" "tex/plain/pwebmac/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z7xx51v1yksj7qvmlrm1bmxq4j3y995i4k902d99kc1vf1rp0nl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pwebmac")
    (synopsis "Consolidated WEB macros for DVI and PDF output")
    (description
     "The original WEB system by Donald Knuth has the macros webmac.tex that
produce DVI output only; for historic reasons, it will never be
modified (apart from catastrophic errors).  Han The Thanh has modified these
macros in his @file{pdfwebmac.tex} for PDF output (only) with pdfTeX.
Jonathan Kew's XeTeX has similar macros @file{xewebmac.tex} by Khaled Hosny
that modify @file{webmac.tex} for PDF output; these macros can only be used
with a specific TeX engine each.  The present @code{pwebmac} package
integrates these three WEB macro files similar to @file{cwebmac.tex} in Silvio
Levy's and Don Knuth's CWEB system, so @file{pwebmac.tex} can be used with
Plain TeX, pdfTeX, and XeTeX alike.

Its initial application is the production of PDF and HINT files for all major
WEB programs for TeX and friends.  For this purpose, the shell script
@command{makeall} was whipped together; it provides various command line
options and works around several quirks in the WEB sources.

WEB programmers who want to use @file{pwebmac.tex} instead of the default
@file{webmac.tex} in their programs have to change the first line in the TeX
file created by @code{weave}.  From there, all depends on the TeX engine you
use.")
    (license license:public-domain)))

(define-public texlive-random
  (package
    (name "texlive-random")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/random/" "tex/generic/random/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04z7s4pm620bfjwgl46g4bqxzm2ab70ai8pj1x4p0qg8n50xaylf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/random")
    (synopsis "Generate pseudo-random numbers in TeX")
    (description
     "This package generates pseudo-random integers.  Macros are to provide
random integers in a given range, or random dimensions, which can be used to
provide random real numbers.")
    (license license:public-domain)))

(define-public texlive-randomlist
  (package
    (name "texlive-randomlist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/randomlist/"
                                     "source/generic/randomlist/"
                                     "tex/generic/randomlist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04pbbxxnynyc3l94560vvnad3rx7l2ic6p078az15v5qic7rki84"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/randomlist")
    (synopsis
     "Deal with database, loop, and random in order to build personalized
exercises")
    (description
     "The main aim of this package is to work on lists, especially with random
operations.  The hidden aim is to build a personal collection of exercises
with different data for each pupil.")
    (license license:lppl1.3+)))

(define-public texlive-resumemac
  (package
    (name "texlive-resumemac")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/resumemac/"
                                     "tex/plain/resumemac/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q6ngs2inzk2nk9f06s9w9q2qhx71dw7nflmrc9hzx9w0pinw830"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/resumemac")
    (synopsis "Plain TeX macros for resumes")
    (description "This package provides a set of macros for resumes.")
    (license license:public-domain)))

(define-public texlive-ruler
  (package
    (name "texlive-ruler")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/generic/ruler/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ikap9dkdw9lzpda0f2krizqbfkyjxvyddils7clim9nhg77aq71"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ruler")
    (synopsis "Typographic ruler for TeX")
    (description
     "The file processes to produce (real) rulers; the author suggests
printing them on transparent plastic and trimming for use as a real ruler.
The rule widths are 0.05mm, which can be challenging for (old) laser
printers.")
    (license license:gpl3+)))

(define-public texlive-schemata
  (package
    (name "texlive-schemata")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/schemata/"
                                     "source/generic/schemata/"
                                     "tex/generic/schemata/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1196653ankylbcsiv1cnrrazz2qplcs27llpv947h4m94vx4sl19"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/schemata")
    (synopsis "Print topical diagrams")
    (description
     "The package facilitates the creation of topical schemata, i.e.,
outlines that use braces (or facsimiles thereof) to illustrate the breakdown
of concepts and categories in Scholastic thought from late medieval and early
modern periods.")
    (license license:lppl1.3+)))

(define-public texlive-shade
  (package
    (name "texlive-shade")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/shade/"
                                     "fonts/source/public/shade/"
                                     "tex/generic/shade/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b7m11d374cx5rcrvgd2jld1wzixvky3mqdg54hnsg9x14p2dxpg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/shade")
    (synopsis "Shade pieces of text")
    (description
     "The package provides a shaded backdrop to a box of text.  It uses
a Metafont font (provided) which generates to appropriate shading dependent on
the resolution used in the Metafont printer parameters.")
    (license license:lppl1.0+)))

(define-public texlive-simplekv
  (package
    (name "texlive-simplekv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/simplekv/"
                                     "tex/generic/simplekv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xrlqhxqzg75gvbf9iabfgz8bl01wqvnwmv9n8yqdhqv7bk0hvz9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/simplekv")
    (synopsis "Simple key/value system for TeX and LaTeX")
    (description
     "The package provides a simple key/value system for TeX and LaTeX.")
    (license license:lppl1.3c)))

(define-public texlive-swrule
  (package
    (name "texlive-swrule")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/generic/swrule/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "075mshpyi9gxbi3n0hbh3ygidzw1daxy697lhc7cc99i39y8scpi"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/swrule")
    (synopsis "Lines thicker in the middle than at the ends")
    (description
     "This package defines commands that create rules split into
a (specified) number of pieces, whose size varies to produce the
effect of a rule that swells in its centre.")
    ;; Library mentions: "The style package is copyrighted but may be used and
    ;; extended in any way, as long as a pointer to the original author is
    ;; maintained.  The author is not liable for any problem that may or may
    ;; not result from using this package. Use at your own risk".
    (license (license:fsf-free "file://tex/generic/swrule/swrule.sty"))))

(define-public texlive-systeme
  (package
    (name "texlive-systeme")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/systeme/"
                                     "tex/generic/systeme/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02n8bchq9crv21cqvji4kkrjsyp34wny5i047jyp1j2yz8i99m5y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/systeme")
    (synopsis "Format systems of equations")
    (description
     "The package allows you to enter systems of equations or inequalities in
an intuitive way, and produces typeset output where the terms and signs are
aligned vertically.  The package works with plain TeX or LaTeX, but e-TeX is
required.")
    (license license:lppl1.3c)))

(define-public texlive-tabto-generic
  (package
    (name "texlive-tabto-generic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/generic/tabto-generic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0i65jflbnhqpqf1w7pkagicic1s39gcl319z7g9zr1g80f9532dv"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tabto-generic")
    (synopsis "Tab to a measured position in the line")
    (description
     "@code{\\tabto@{<length>@}} moves the typesetting position to
@code{<length>} from the left margin of the paragraph.  If the typesetting
position is already further along, @code{\\tabto} starts a new line.")
    (license license:public-domain)))

(define-public texlive-talos
  (package
    (name "texlive-talos")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/talos/"
                                     "fonts/opentype/public/talos/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m656d4lkc9ikp7gb91yna4323lip3xcr6n3kqh1j4sqvp4rkm61"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/talos")
    (synopsis "Greek cult font from the eighties")
    (description
     "This package provides a cult Greek font from the eighties, used at the
University of Crete, Greece.  It belonged to the first TeX installation in
a Greek University and most probably the first TeX installation that supported
the Greek language.")
    (license license:gfl1.0)))

(define-public texlive-termmenu
  (package
    (name "texlive-termmenu")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/termmenu/"
                                     "source/generic/termmenu/"
                                     "tex/generic/termmenu/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d1pdz5izr43ndji7g28932dnnf8d6nxvh8bay2yk7647yh47aj4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/termmenu")
    (synopsis "Support for terminal-based menus")
    (description
     "When writing programs, it's often required to present the user with
a list of options or actions.  The user is then expected to select one of
these options for the program to process.  @code{termmenu} provides this
mechanism for TeX.")
    (license license:lppl1.3+)))

(define-public texlive-teubner
  (package
    (name "texlive-teubner")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/teubner/" "source/latex/teubner/"
                                     "tex/latex/teubner/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mzmny8csfdri7k8cvc4ralp18fy167f1xxc2y1l4gn6rn9svl6q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/teubner")
    (synopsis "Philological typesetting of classical Greek")
    (description
     "This package provides an extension to Babel @samp{greek} option for
typesetting classical Greek with a philological approach.  The package works
with the author's greek fonts using the Lispiakos font shape derived from that
of the fonts used in printers shops in Lispia.")
    (license license:lppl1.3c)))

(define-public texlive-tex
  (package
    (name "texlive-tex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/initex.1"
                                     "doc/man/man1/initex.man1.pdf"
                                     "doc/man/man1/tex.1"
                                     "doc/man/man1/tex.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05jj1pyfipz1qmdxkavz7axflgga6bpl20abzc6j3sj8xxz7g9j8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:texlive-latex-bin? #f
           #:create-formats #~(list "tex")))
    (propagated-inputs
     (list texlive-cm
           texlive-hyphen-base
           texlive-knuth-lib
           texlive-kpathsea
           texlive-plain))
    (home-page "https://ctan.org/pkg/tex")
    (synopsis "Sophisticated typesetting engine")
    (description
     "TeX is a typesetting system that incorporates a macro processor.  A TeX
source document specifies or incorporates a number of macro definitions that
instruct the TeX engine how to typeset the document.  The TeX engine also uses
font metrics generated by Metafont, or by any of several other mechanisms that
incorporate fonts from other sources into an environment suitable for TeX.
TeX has been, and continues, a basis and an inspiration for several other
programs, including e-TeX and PDFTeX.  The distribution includes the source of
Knuth's TeX book; this source is there to read, as an example of writing TeX ;
it should not be processed without Knuth's direct permission.")
    (license license:knuth)))

(define-public texlive-tex-ps
  (package
    (name "texlive-tex-ps")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/tex-ps/cmyk-hax/"
                                     "doc/generic/tex-ps/poligraf/"
                                     "dvips/tex-ps/" "tex/generic/tex-ps/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09f70q2bhmq7bn98f2g2pq62wnfhj24bzkbv652sjrw5rafp0311"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tex-ps")
    (synopsis "TeX to PostScript generic macros and add-ons")
    (description
     "This package provides TeX to PostScript generic macros and add-ons:
transformations of EPS files, prepress preparation, color separation, mirror,
etc.")
    (license license:public-domain)))

(define-public texlive-texdate
  (package
    (name "texlive-texdate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/texdate/"
                                     "source/generic/texdate/"
                                     "tex/generic/texdate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0knssay50rm8pbksph20hhfbpwwby3a9pswvxyq63imn5qppz2dp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/texdate")
    (synopsis "Date printing, formatting, and manipulation in TeX")
    (description
     "TeX and LaTeX provide few facilities for dates by default, though many
packages have filled this gap.  This package fills it, as well, with a pure
TeX-primitive implementation.  It can print dates, advance them by numbers of
days, weeks, or months, determine the weekday automatically, and print them
in (mostly) arbitrary format.  It can also print calendars (monthly and
yearly) automatically, and can be easily localized for non-English
languages.")
    (license license:lppl1.3c)))

(define-public texlive-texdimens
  (package
    (name "texlive-texdimens")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/texdimens/"
                                     "tex/generic/texdimens/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l6raryqpxydis9kq6sd4pvz7d2rzrrsnx7k9n3d3921pp208lv4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/texdimens")
    (synopsis "Conversion of TeX dimensions to decimals")
    (description
     "This package provides utilities and documentation related to TeX
dimensional units, usable both with Plain TeX and with LaTeX.")
    (license license:lppl1.3c)))

(define-public texlive-timetable
  (package
    (name "texlive-timetable")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/plain/timetable/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lnl8gi2rrzcy688qb8b1ff9yivwxdqmbcfx2ph49aymkxfym97b"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/timetable")
    (synopsis "Generate timetables")
    (description
     "This package provides a highly-configurable package, with nice output
and simple input.  The macros use a radix sort mechanism so that the order of
input is not critical.")
    (license license:lppl)))

(define-public texlive-transparent-io
  (package
    (name "texlive-transparent-io")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/transparent-io/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04zfmk25qw2cnja1zqhafabsy26zalxiawf6pm5zqx4x1jl47i6j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/transparent-io")
    (synopsis
     "Show for approval the filenames used in @code{\\input}, @code{\\openin},
or @code{\\openout}")
    (description
     "This package provides macros to make the file I/O in plain TeX more
transparent.  That is, every @code{\\input}, @code{\\openin}, and
@code{\\openout} operation by TeX is presented to the user who must check
carefully if the file name of the source is acceptable.  The user must
sometimes enter additional text and has to specify the file name that the TeX
operation should use.  The macros require a complex installation procedure;
the package contains Sed and Bash scripts.  Every installation is different
from any other as password-protected macro names and private messages have to
be chosen by the installer.  Therefore, the files in the package cannot be
used directly.  For details see the manual.")
    (license license:gpl3)))

(define-public texlive-treetex
  (package
    (name "texlive-treetex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/treetex/" "tex/plain/treetex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cv7kwa865i473l8ffsyq5n7kw6pihclf87asbpsc1rx2h4v6mhs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/treetex-plain")
    (synopsis "Draw trees")
    (description
     "This package provides macros to draw trees, within TeX or LaTeX.")
    (license license:public-domain)))

(define-public texlive-trigonometry
  (package
    (name "texlive-trigonometry")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/trigonometry/"
                                     "tex/generic/trigonometry/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "165n813kj0znfrnqkqv0gja3nyr2lznnhbmsay6l8a5nj59h7cxl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/trigonometry")
    (synopsis "Demonstration code for cos and sin in TeX macros")
    (description
     "This package provides a document that both provides macros that are
usable elsewhere, and demonstrates the macros.  The code uses the classical
analytical expansion of sin and cos.")
    (license license:knuth)))

(define-public texlive-upca
  (package
    (name "texlive-upca")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/upca/" "tex/generic/upca/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0miqn29dln9c2nlvcivsq7ciyb70ffk16v7dmzfn976xnvfsjbiw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/upca")
    (synopsis "Print UPC-A barcodes")
    (description
     "The package defines a single macro @code{\\upca}, to print UPC-A
barcodes.")
    (license license:lppl)))

(define-public texlive-uplatex
  (package
    (name "texlive-uplatex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/uplatex.1"
                                     "doc/man/man1/uplatex.man1.pdf"
                                     "doc/uplatex/base/"
                                     "source/uplatex/base/"
                                     "tex/uplatex/base/"
                                     "tex/uplatex/config/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fn5x56nn38k9b90mcyvfwla7ib7nv774z2cjncwwmbsd7s1abm1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:create-formats #~(list "uplatex" "uplatex-dev")
           #:phases
           #~(modify-phases %standard-phases
               (add-after 'unpack 'fix-build
                 ;; This phase is necessary because the build phase is
                 ;; reluctant to generate "ukinsoku.tex" since there is
                 ;; another one among the inputs (texlive-uptex) already.
                 (lambda _
                   (substitute* "source/uplatex/base/uplfmt.ins"
                     (("\\\\keepsilent\n" all)
                      (string-append all "\\askforoverwritefalse\n")))))
               (add-after 'install 'symlink-binaries
                 (lambda* (#:key inputs #:allow-other-keys)
                   (let ((euptex (search-input-file inputs "bin/euptex"))
                         (bin (string-append #$output "/bin")))
                     (mkdir-p bin)
                     (with-directory-excursion bin
                       (symlink euptex "uplatex"))))))))
    (propagated-inputs
     (list texlive-babel
           texlive-cm
           texlive-firstaid
           texlive-hyphen-base
           texlive-l3backend
           texlive-l3kernel
           texlive-latex
           texlive-latex-fonts
           texlive-platex
           texlive-tex-ini-files
           texlive-unicode-data
           texlive-uptex
           texlive-uptex-fonts))
    (home-page "https://ctan.org/pkg/uplatex")
    (synopsis "pLaTeX2e and miscellaneous macros for upTeX")
    (description
     "The bundle provides pLaTeX2e macros for upTeX by Takuji Tanaka.")
    (license license:bsd-3)))

(define-public texlive-uptex-base
  (package
    (name "texlive-uptex-base")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/uptex/uptex-base/"
                                     "tex/uptex/uptex-base/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16ghhgg1cdpbhyv073h65sqkm26zc2rya0irzf78fa1927993jlg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uptex-base")
    (synopsis "Plain TeX formats and documents for upTeX")
    (description
     "The bundle contains plain TeX format files and documents for upTeX and
and e-upTeX.")
    (license license:bsd-3)))

(define-public texlive-uptex
  (package
    (name "texlive-uptex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/euptex.1"
                                     "doc/man/man1/euptex.man1.pdf"
                                     "doc/man/man1/upbibtex.1"
                                     "doc/man/man1/upbibtex.man1.pdf"
                                     "doc/man/man1/uppltotf.1"
                                     "doc/man/man1/uppltotf.man1.pdf"
                                     "doc/man/man1/uptex.1"
                                     "doc/man/man1/uptex.man1.pdf"
                                     "doc/man/man1/uptftopl.1"
                                     "doc/man/man1/uptftopl.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14hn2n6jbibbqbdr72j74z5bz003jnlabi3kja0f0waxhas680gd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:create-formats #~(list "euptex" "uptex")))
    (propagated-inputs
     (list texlive-cm
           texlive-etex
           texlive-hyphen-base
           texlive-knuth-lib
           texlive-plain
           texlive-ptex-base
           texlive-uptex-base
           texlive-uptex-bin
           texlive-uptex-fonts))
    (home-page "https://ctan.org/pkg/uptex")
    (synopsis "Unicode version of pTeX")
    (description
     "upTeX is an extension of pTeX, using UTF-8 input and producing UTF-8
output.  It was originally designed to improve support for Japanese, but is
also useful for documents in Chinese and Korean.  It can process Chinese
simplified, Chinese traditional, Japanese, and Korean simultaneously, and can
also process original LaTeX with @code{\\inputenc@{utf8@}} and Babel
(Latin/Cyrillic/Greek etc.) by switching its @code{\\kcatcode} tables.")
    (license license:bsd-3)))

(define-public texlive-uptex-bin
  (package
    (inherit texlive-bin)
    (name "texlive-uptex-bin")
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(delete "--enable-web2c" #$flags))
       ((#:phases phases)
        #~(modify-phases #$phases
            (add-after 'build 'build-binaries
              (lambda _
                (with-directory-excursion "texk/web2c"
                  (for-each (lambda (target) (invoke "make" target))
                            '("euptex" "upbibtex" "updvitype" "upmpost"
                              "uppltotf" "uptex" "uptftopl" "wovp2ovf")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/web2c"
                  (let ((bin (string-append #$output "/bin")))
                    (for-each (lambda (f) (install-file f bin))
                              '("euptex" "upbibtex" "updvitype"
                                "upmpost" "uppltotf" "uptex" "uptftopl"
                                "wovp2ovf"))
                    (with-directory-excursion bin
                      (for-each symlink
                                '("upmpost" "upmpost")
                                '("r-upmpost" "updvitomp")))))))))))
    (native-inputs (list pkg-config))
    (inputs
     (modify-inputs (package-inputs texlive-bin)
       (append cairo gmp mpfi mpfr texlive-libptexenc)))
    (home-page (package-home-page texlive-uptex))
    (synopsis "Binaries for @code{texlive-uptex}")
    (description
     "This package provides the binaries for @code{texlive-uptex}.")
    (license (package-license texlive-uptex))))

(define-public texlive-uptex-fonts
  (package
    (name "texlive-uptex-fonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/uptex-fonts/"
                                     "fonts/cmap/uptex-fonts/"
                                     "fonts/source/uptex-fonts/"
                                     "fonts/tfm/uptex-fonts/jis/"
                                     "fonts/tfm/uptex-fonts/min/"
                                     "fonts/vf/uptex-fonts/jis/"
                                     "fonts/vf/uptex-fonts/min/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d5v2p186a9baqm335l2m8gm53qdl3xkx1kgww45225cbkmn34hw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uptex-fonts")
    (synopsis "Fonts for use with upTeX")
    (description "The bundle contains fonts (TFM and VF) for use with upTeX.")
    (license license:bsd-3)))

(define-public texlive-upzhkinsoku
  (package
    (name "texlive-upzhkinsoku")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/upzhkinsoku/"
                                     "tex/generic/upzhkinsoku/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c95fy9raykpjgnkz5h0wyjxyg2h0ksx2kb14lx2rsv65xsi909y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/upzhkinsoku")
    (synopsis "Supplementary Chinese kinsoku for Unicode *pTeX")
    (description
     "This package provides supplementary Chinese kinsoku (line breaking rules
etc.)@: settings for Unicode (e-)upTeX (when using Unicode as its internal
encoding), and ApTeX.  Both LaTeX and plain TeX are supported.")
    (license license:knuth)))

(define-public texlive-variations
  (package
    (name "texlive-variations")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/variations/"
                                     "tex/generic/variations/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ad1yc1v32ds4wj36fql6fjiacziw4ynvw0rpj3x01k6jdvh44xh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/variations")
    (synopsis "Typeset tables of variations of functions")
    (description
     "The package provides macros for typesetting tables showing variations of
functions according to French usage.  These macros may be used by both LaTeX
and plain TeX users.")
    (license license:gpl3+)))

(define-public texlive-varisize
  (package
    (name "texlive-varisize")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/varisize/" "tex/plain/varisize/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nd89zhwyg5z9wcy1lixg3hzcfw83lsilkjhhy9kir0fi9whdbv4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/varisize")
    (synopsis "Change font size in Plain TeX")
    (description
     "This package provides a series of files, each of which defines
a size-change macro.  Note that @file{10point.tex} is by convention called by
one of the other files, so that there's always a way back.")
    (license license:public-domain)))

(define-public texlive-xgreek
  (package
    (name "texlive-xgreek")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xgreek/" "source/latex/xgreek/"
                                     "tex/latex/xgreek/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xw27z7hglkxqhlsv3mshpszzmf4bsnsg6l17n1wqhi60mxin5sz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xgreek")
    (synopsis "Greek language support for XeLaTeX and LuaLaTeX")
    (description
     "This package has been designed so to allow people to typeset Greek
language documents using XeLaTeX or LuaLaTeX.  Practically, it provides all
the capabilities of the @samp{greek} option of the Babel package.

The package can be invoked with any of the following options:
@samp{monotonic} (for typesetting modern monotonic Greek),
@samp{polytonic} (for typesetting modern polytonic Greek), and
@samp{ancient} (for typesetting ancient texts).  The default option is
@samp{monotonic}.")
    (license license:lppl1.3c)))

(define-public texlive-xii
  (package
    (name "texlive-xii")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/xii/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19jhzv5hqzj59wrfcr1dsj6z56qfckax694idgf8arri5lnbkdd8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xii")
    (synopsis "Christmas silliness (English)")
    (description
     "This is the plain TeX file @file{xii.tex}.  Call @samp{pdftex xii.tex}
to produce a (perhaps) surprising typeset document.")
    (license license:lppl)))

(define-public texlive-xii-lat
  (package
    (name "texlive-xii-lat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/xii-lat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nn54xv71kcmn9jbkcslz6a64cvjcay9x96rrxnakdj9qcqd27r5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xii-lat")
    (synopsis "Christmas silliness (Latin)")
    (description
     "This is the plain TeX file @file{xii-lat.tex}.  Call @samp{pdftex
xii-lat.tex} to produce a (perhaps) surprising typeset document.")
    (license license:lppl)))

(define-public texlive-xintsession
  (package
    (name "texlive-xintsession")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/xintsession/"
                                     "tex/plain/xintsession/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rd2jmq62ariq73qwch1hz1jmzdw6sn48ngh64pgm6qkqbpddxkv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xintsession")
    (synopsis
     "Interactive computing sessions (fractions, floating points, polynomials)")
    (description
     "This package provides support for interactive computing sessions with
e-TeX (or pdfTeX) executed on the command line.  Once @code{xintsession} is
loaded, e-TeX becomes an interactive computing software capable of executing
arbitrary precision calculations, or exact calculations with arbitrarily big
fractions.  It can also manipulate polynomials as algebraic entities.
Numerical variables and functions can be defined during the session, and each
evaluation result is stored in automatically labeled variables.  A file is
automatically created storing inputs and outputs.")
    (license license:lppl1.3c)))

(define-public texlive-xlop
  (package
    (name "texlive-xlop")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/xlop/" "tex/generic/xlop/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yqks7jvb5ikg2xx038rsxbkhagms1zqjmipnv49rqliavcq03gj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xlop")
    (synopsis "Calculate and display arithmetic operations")
    (description
     "Xlop (eXtra Large OPeration) will typeset arithmetic problems either
in-line or as in school (using French school conventions).  Many other
features allow dealing with numbers (tests, display, some high level
operations, etc.)")
    (license license:lppl1.3+)))

(define-public texlive-xtuthesis
  (package
    (name "texlive-xtuthesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xtuthesis/"
                                     "tex/latex/xtuthesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fdk9dkikqlkjwrg8qjm2phvsyyvddshf78bjy6liyz5hqakk6r8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xtuthesis")
    (synopsis "XTU thesis template")
    (description
     "The package provides a thesis template for the Xiangtan University.")
    (license license:lppl1.3+)))

(define-public texlive-yannisgr
  (package
    (name "texlive-yannisgr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/yannisgr/"
                                     "fonts/source/public/yannisgr/"
                                     "fonts/tfm/public/yannisgr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0s5cfid1r6jn34kzvmxwxyxpvyb0rayn80x3n7k515p1plqmmrnq"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-levy")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-levy texlive-metafont))
    (home-page "https://ctan.org/pkg/yannisgr")
    (synopsis "Greek fonts by Yannis Haralambous")
    (description
     "This package provides a family of 7-bit fonts with a code table designed
for setting modern polytonic Greek.  The fonts are provided as Metafont
source; macros to produce a Greek variant of Plain TeX (including
a hyphenation table adapted to the fonts code table) are provided.")
    (license license:gpl2)))

(define-public texlive-zhlineskip
  (package
    (name "texlive-zhlineskip")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/zhlineskip/"
                                     "tex/latex/zhlineskip/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "070vi0pra74in55r0pq2k35s3x3xk6gjwvnsif7bnx4k7wn39mal"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/zhlineskip")
    (synopsis "Line spacing for CJK documents")
    (description
     "This package supports typesetting CJK documents.  It allows users to
specify the two ratios between the leading and the font size of the body text
and the footnote text.  For CJK typesetting, these ratios usually range from
1.5 to 1.67.  This package is also capable of restoring the math leading to
that of the Latin text (usually 1.2 times the font size).")
    (license license:lppl1.3c)))

(define-public texlive-zhlipsum
  (package
    (name "texlive-zhlipsum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/zhlipsum/"
                                     "source/latex/zhlipsum/"
                                     "tex/latex/zhlipsum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lhc3a8l5sizyw0v1cfsrwwwymmyab1yvx99iqhdh7avrzmi2gda"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ctex")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ctex))
    (home-page "https://ctan.org/pkg/zhlipsum")
    (synopsis "Chinese dummy text")
    (description
     "This package provides an interface to dummy text in Chinese language,
which will be useful for testing Chinese documents.  UTF-8, GBK and Big5
encodings are supported.")
    (license license:lppl1.3c)))

(define-public texlive-zztex
  (package
    (name "texlive-zztex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/zztex/" "tex/plain/zztex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07vx3m2g4vl2v1nxxy5dih67jg406y2i94sgkrmplm54b0pp42g3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/zztex")
    (synopsis "TeX macro package for producing books, journals, and manuals")
    (description
     "The ZzTeX macro package is a full-featured TeX macro package specially
designed for producing books, journals, and manuals.  ZzTeX runs under Plain
TeX.")
    (license license:expat)))

(define-public texlive-lcdftypetools
  (package
    (name "texlive-lcdftypetools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/cfftot1.1"
                                     "doc/man/man1/cfftot1.man1.pdf"
                                     "doc/man/man1/mmafm.1"
                                     "doc/man/man1/mmafm.man1.pdf"
                                     "doc/man/man1/mmpfb.1"
                                     "doc/man/man1/mmpfb.man1.pdf"
                                     "doc/man/man1/otfinfo.1"
                                     "doc/man/man1/otfinfo.man1.pdf"
                                     "doc/man/man1/otftotfm.1"
                                     "doc/man/man1/otftotfm.man1.pdf"
                                     "doc/man/man1/t1dotlessj.1"
                                     "doc/man/man1/t1dotlessj.man1.pdf"
                                     "doc/man/man1/t1lint.1"
                                     "doc/man/man1/t1lint.man1.pdf"
                                     "doc/man/man1/t1rawafm.1"
                                     "doc/man/man1/t1rawafm.man1.pdf"
                                     "doc/man/man1/t1reencode.1"
                                     "doc/man/man1/t1reencode.man1.pdf"
                                     "doc/man/man1/t1testpage.1"
                                     "doc/man/man1/t1testpage.man1.pdf"
                                     "doc/man/man1/ttftotype42.1"
                                     "doc/man/man1/ttftotype42.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gb8k5w6lg9fdxhs36caxlvq96s7np35yq9y78165igyf6y3ig70"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-glyphlist texlive-lcdftypetools-bin))
    (home-page "https://ctan.org/pkg/lcdf-typetools")
    (synopsis "Bundle of outline font manipulation tools")
    (description
     "This bundle of tools comprises:
@itemize
@item @command{cfftot1}, which translates a Compact Font Format
(CFF) font, or a PostScript-flavored OpenType font, into PostScript
Type 1 format.  It correctly handles subroutines and hints;

@item @command{mmafm} and @command{mmpfb}, which create instances of
multiple-master fonts;

@item @command{otfinfo}, which reports information about OpenType
fonts, such as the features they support and the contents of their
size optical size features;

@item @command{otftotfm}, which creates TeX font metrics and encodings
that correspond to a PostScript-flavored OpenType font.  It will
interpret glyph positionings, substitutions, and ligatures as far as
it is able.  You can say which OpenType features should be activated;

@item @command{t1dotlessj}, which creates a Type 1 font whose only
character is a dotless j matching the input font's design;

@item @command{t1lint}, which checks a Type 1 font for correctness;

@item @command{t1reencode}, which replaces a font's internal encoding
with one you specify;

@item @command{t1testpage}, which creates a PostScript proof for
a Type 1 font.
@end itemize")
    (license license:gpl3+)))

(define-public texlive-lcdftypetools-bin
  (package
    (inherit texlive-bin)
    (name "texlive-lcdftypetools-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("lcdf-typetools"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-lcdf-typetools" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/lcdf-typetools"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/lcdf-typetools"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list texlive-libkpathsea))
    (propagated-inputs '())
    (home-page (package-home-page texlive-lcdftypetools))
    (synopsis "Binaries for @code{texlive-lcdftypetools}")
    (description
     "This package provides the binaries for @code{texlive-lcdftypetools}.")
    (license (package-license texlive-lcdftypetools))))

(define-public texlive-latex
  (package
    (name "texlive-latex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/base/" "makeindex/latex/"
                                     "source/latex/base/" "tex/latex/base/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1s87lh7dprgn0gmiai2l7ala3c6qha8lchqjhcix6122dxqdsvvr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:texlive-latex-bin? #f
      #:tex-engine "tex"
      #:tex-format #f
      #:build-targets #~(list "unpack.ins")
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'fix-lua-build
            ;; The literal tab in the dtx file is translated to the string
            ;; "^^I" in the generated Lua file, which causes a syntax error.
            (lambda _
              (substitute* "source/latex/base/ltluatex.dtx"
                (("\t") "  ")))))))
    (home-page "https://ctan.org/pkg/latex")
    (synopsis "TeX macro package that defines LaTeX")
    (description
     "LaTeX is a widely-used macro package for TeX, providing many basic
document formatting commands extended by a wide range of packages.")
    (license license:lppl1.3c)))

(define-public texlive-latexbug
  (package
    (name "texlive-latexbug")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latexbug/"
                                     "source/latex/latexbug/"
                                     "tex/latex/latexbug/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l9cyw41knbw3prsi4rbd2av4qfpkvzjs754847kv72dq1304m1i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latexbug")
    (synopsis "Bug-classification for LaTeX related bugs")
    (description
     "The package is written in order to help identifying the rightful
addressee for a bug report.  The LaTeX team asks that it will be loaded in any
test file that is intended to be sent to the LaTeX bug database as part of
a bug report.")
    (license license:lppl1.3c)))

(define-public texlive-lcyw
  (package
    (name "texlive-lcyw")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lcyw/" "source/latex/lcyw/"
                                     "tex/latex/lcyw/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yijk9l2ls6sq45ifx6m9d7xxk0ysrnn1y3fjz8wxwgwxp88x9fh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lcyw")
    (synopsis "Make classic Cyrillic CM fonts accessible in LaTeX")
    (description
     "The package makes the classic CM Cyrillic fonts accessible for use with
LaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-lhcyr
  (package
    (name "texlive-lhcyr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "source/latex/lhcyr/" "tex/latex/lhcyr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09cg2hs5g20axbfpv2k6df5pi3xm0aywcswhnknllykr6z0ip2zw"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lhcyr")
    (synopsis "Non-standard Cyrillic input scheme")
    (description
     "This package provides a collection of three LaTeX2e styles intended for
typesetting Russian and bilingual English-Russian documents, using the
@code{lh} fonts and without the benefit of Babel's language-switching
mechanisms.  The packages (@code{hcyralt} and @code{hcyrwin} for use under
emTeX, and @code{hcyrkoi} for use under teTeX} provide mappings between the
input encoding and the font encoding, which is described as OT1.  The way this
is done does not match the way @code{inputenc} would do the job, for output
via fontenc to one of the T2 series of font encodings.")
    (license license:knuth)))

(define-public texlive-luafindfont
  (package
    (name "texlive-luafindfont")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/luafindfont.1"
                                     "doc/man/man1/luafindfont.man1.pdf"
                                     "doc/support/luafindfont/"
                                     "scripts/luafindfont/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19dz91gpiphlh9736q2r0zglsgslhkyacs4i6yaf2pc5sa9g367q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "luafindfont.lua")))
    (home-page "https://ctan.org/pkg/luafindfont")
    (synopsis "Search fonts in the LuaTeX font database")
    (description "This Lua script searches for fonts in the font database.")
    (license license:lppl1.3c)))

(define-public texlive-bidi
  (package
    (name "texlive-bidi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/bidi/" "source/xelatex/bidi/"
                                     "tex/xelatex/bidi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "111gwl3d5kqbzpwwgsh0cz0fipmhq63xsbdkg09bhj3gl59k9icr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bidi")
    (synopsis "Bidirectional typesetting in plain TeX and LaTeX using XeTeX")
    (description
     "The @code{bidi} package provides a convenient interface for typesetting
bidirectional texts with plain TeX and LaTeX.  The package includes
adaptations for use with many other commonly-used packages.")
    (license license:lppl1.3+)))

(define-public texlive-bidi-atbegshi
  (package
    (name "texlive-bidi-atbegshi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/bidi-atbegshi/"
                                     "tex/xelatex/bidi-atbegshi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08gawna9hf5p3rn0v5qzszk61zqknixafvh6d2x37x960x493gn7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bidi-atbegshi")
    (synopsis "Bidi-aware shipout macros")
    (description
     "The package adds some commands to the @code{atbegshi} package for proper
placement of background material in the left and right corners of the output
page, in both LTR and RTL modes.  The package only works with @code{xelatex}
format and should be loaded before the @code{bidi} package.")
    (license license:lppl1.3+)))

(define-public texlive-bidicontour
  (package
    (name "texlive-bidicontour")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/bidicontour/"
                                     "tex/xelatex/bidicontour/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kiqbn5map3d9bmlvr5cq1snssw44c772xzjp6yyjvg6wg1zy0bn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bidicontour")
    (synopsis "Bidi-aware coloured contour around text")
    (description
     "The package is a re-implementation of the @code{contour} package, making
it Bidi-aware, and adding support of the xdvipdfmx (when the outline option of
the package is used).")
    (license license:lppl1.3+)))

(define-public texlive-bidipagegrid
  (package
    (name "texlive-bidipagegrid")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/bidipagegrid/"
                                     "tex/xelatex/bidipagegrid/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19jkg4apf1g3whigcchbcf8p14lpxkz9ih2vrw00akwfh8v3ssrk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bidipagegrid")
    (synopsis "Bidi-aware page grid in background")
    (description "The package provides Bidi-aware page grid in background.  It
is based on @code{pagegrid}.")
    (license license:lppl1.3+)))

(define-public texlive-bidipresentation
  (package
    (name "texlive-bidipresentation")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/bidipresentation/"
                                     "tex/xelatex/bidipresentation/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b9md68zzj3nzi9b4hdavjz43nwair1xg3b240p0bp5ly5l6pvmr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bidipresentation")
    (synopsis "Experimental bidi presentation")
    (description
     "This package provides a great portion of the code is borrowed from the
texpower bundle, with modifications to get things working properly in both
right to left and left to right modes.")
    (license license:lppl1.3+)))

(define-public texlive-bidishadowtext
  (package
    (name "texlive-bidishadowtext")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/bidishadowtext/"
                                     "tex/xelatex/bidishadowtext/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nq71bgz7vag9k138mx8hsf42cjvgry2g4z9jiqmq4almm23a1gq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bidishadowtext")
    (synopsis "Bidi-aware shadow text")
    (description
     "This package allows you to typeset Bidi-aware shadow text.  It is
a re-implementation of the @code{shadowtext} package adding Bidi support.")
    (license license:lppl1.3+)))

(define-public texlive-alphalph
  (package
    (name "texlive-alphalph")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/alphalph/"
                                     "source/latex/alphalph/"
                                     "tex/generic/alphalph/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ap59hmg0brg2wlh3bl77jxfxrk7hphhdal8cr05mby9bw35gffy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/alphalph")
    (synopsis "Convert numbers to letters")
    (description
     "This package provides commands @code{\\alphalph} and @code{\\AlphAlph}.
They are like @code{\\number} but the expansion consists of lowercase and
uppercase letters respectively (1 to a, 26 to z, 27 to aa, 52 to zz, 53 to ba,
702 to zz, 703 to aaa, etc.).  Alphalph's commands can be used as
a replacement for LaTeX's @code{\\@@alph} and @code{\\@@Alph} macros.")
    (license license:lppl1.3c+)))

(define-public texlive-antt
  (package
    (name "texlive-antt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/antt/"
                                     "doc/latex/antt/"
                                     "fonts/afm/public/antt/"
                                     "fonts/enc/dvips/antt/"
                                     "fonts/map/dvips/antt/"
                                     "fonts/opentype/public/antt/"
                                     "fonts/tfm/public/antt/"
                                     "fonts/type1/public/antt/"
                                     "tex/latex/antt/"
                                     "tex/plain/antt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fvmgb581ixc4fvw5l0g11hlvdpf0cld6db0cg3vysw5yabas3vm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/antt")
    (synopsis "Type 1 family of a Polish traditional type")
    (description
     "Antykwa Torunska is a serif font designed by the late Polish typographer
Zygfryd Gardzielewski, reconstructed and digitized as Type 1.")
    (license license:gfl1.0)))

(define-public texlive-asana-math
  (package
    (name "texlive-asana-math")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/asana-math/"
                                     "fonts/opentype/public/asana-math/"
                                     "fonts/truetype/public/asana-math/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1q934gackj9j7b7bvlq7yv1pr9rxrhhip1as7ywgx8d45ddig2rq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/asana-math")
    (synopsis "Font to typeset maths in Xe(La)TeX and Lua(La)TeX")
    (description
     "The Asana-Math font is an OpenType font that includes almost all
mathematical Unicode symbols and it can be used to typeset mathematical text
with any software that can understand the MATH OpenType table.")
    (license license:silofl1.1)))

(define-public texlive-avantgar
  (package
    (name "texlive-avantgar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "dvips/avantgar/"
                                     "fonts/afm/adobe/avantgar/"
                                     "fonts/afm/urw/avantgar/"
                                     "fonts/map/dvips/avantgar/"
                                     "fonts/tfm/adobe/avantgar/"
                                     "fonts/tfm/urw35vf/avantgar/"
                                     "fonts/type1/urw/avantgar/"
                                     "fonts/vf/adobe/avantgar/"
                                     "fonts/vf/urw35vf/avantgar/"
                                     "tex/latex/avantgar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1200x40k7wprm4n7srxvgrax2l52vn6d5ri2x0q7zbzzsfxfzkym"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/urw-base35")
    (synopsis "Replacement for Adobe's Avant Garde font")
    (description
     "This package provides a drop-in replacement for the Avant Garde font
from Adobe's basic set.")
    (license license:gpl3+)))

(define-public texlive-undergradmath
  (package
    (name "texlive-undergradmath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/undergradmath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z8my3fwqc8rfc1843j7lcmfka2023z9k0js4ygh1m8kilc2nrr7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/undergradmath")
    (synopsis "LaTeX Math for undergraduates cheat sheet")
    (description
     "This is a cheat sheet for writing mathematics with LaTeX.  It is aimed
at US undergraduates.")
    (license license:cc-by-sa4.0)))

(define-public texlive-underscore
  (package
    (name "texlive-underscore")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/underscore/" "tex/latex/underscore/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0slxsxc9azmv3gsm55jkhkv8a06wafankp55hhsdd6k4prp8szrb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/underscore")
    (synopsis "Control the behaviour of @samp{_} in text")
    (description
     "This package causes @code{\\_} in text mode (i.e.,
@code{\\textunderscore}) to print an underscore so that hyphenation of words
either side of it is not affected; a package option controls whether an actual
hyphenation point appears after the underscore, or merely a break point.  The
package also arranges that, while in text, @samp{_} itself behaves as
@code{\\textunderscore} (the behaviour of @samp{_} in maths mode is not
affected).")
    (license license:lppl1.2+)))

(define-public texlive-unicode-data
  (package
    (name "texlive-unicode-data")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/unicode-data/"
                                     "tex/generic/unicode-data/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x0jryv2jdqifjq0c8ki9ppxqxf9qpvnazrwfdx71jqprb702krw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:texlive-latex-bin? #f))
    (home-page "https://ctan.org/pkg/unicode-data")
    (synopsis "Unicode data and loaders for TeX")
    (description "This bundle provides generic access to Unicode Consortium
data for TeX use.  It contains a set of text files provided by the Unicode
Consortium which are currently all from Unicode 8.0.0, with the exception of
@code{MathClass.txt} which is not currently part of the Unicode Character
Database.  Accompanying these source data are generic TeX loader files
allowing this data to be used as part of TeX runs, in particular in building
format files.  Currently there are two loader files: one for general character
set up and one for initializing XeTeX character classes as has been carried
out to date by @code{unicode-letters.tex}.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-generic-unicode-data texlive-unicode-data)

(define-public texlive-hologo
  (package
    (name "texlive-hologo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/hologo/"
                                     "source/generic/hologo/"
                                     "tex/generic/hologo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0n62zwz93ab6vfb0hd2h0ncj9gwavg01i3djj7wyr7gyj20xb34x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hologo")
    (synopsis "Collection of logos with bookmark support")
    (description
     "The package defines a single command @code{\\hologo}, whose argument is
the usual case-confused ASCII version of the logo.  The command is
bookmark-enabled, so that every logo becomes available in bookmarks without
further work.")
    (license license:lppl1.3c)))

(define-public texlive-hook-pre-commit-pkg
  (package
    (name "texlive-hook-pre-commit-pkg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/hook-pre-commit-pkg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mikg4p9wxb28vgwh1acgdhwa2fqnc8rw3jg355d6s137m40awc6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hook-pre-commit-pkg")
    (synopsis "Pre-commit git hook for LaTeX package developers")
    (description
     "This package provides a pre-commit git hook to check basic LaTeX
syntax for the use of package developers.  It is installed by copying
it into the @file{.git/.hooks} file.  It then checks the following
file types: @file{.sty}, @file{.dtx}, @file{.bbx}, @file{.cbx}, and
@file{.lbx}.  It performs the following checks:

@itemize

@item each line must be terminated by @samp{%}, without a space before it;

@item empty lines are allowed, but not lines with nothing but spaces in them;

@item @code{\\begin@{macro@}} and @code{\\end@{macro@}} must be paired;

@item @code{\\begin@{macrocode@}} and @code{\\end@{macrocode@}} must be
paired;

@item @code{\\begin@{macro@}} must have a second argument;

@item one space must be printed between @samp{%} and @code{\\begin@{macro@}}
or @code{\\end@{macro@}}. @samp{%} must be the first character in the line;

@item four spaces must be printed between @samp{%} and
@code{\\begin@{macrocode@}} or @code{\\end@{macrocode@}};

@item @code{\\cs} argument must not start with a backslash.

@end itemize")
    (license license:gpl3)))

(define-public texlive-hopatch
  (package
    (name "texlive-hopatch")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hopatch/" "source/latex/hopatch/"
                                     "tex/latex/hopatch/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03hafzf0kpjhn5x392bziwyx0vf6fwcsy0xrn0c0jzn5cq5nqhap"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hopatch")
    (synopsis "Load patches for packages")
    (description
     "Hopatch provides a command with which the user may register of patch code
for a particular package.  Hopatch will apply the patch immediately, if the
relevant package has already been loaded; otherwise it will store the patch
until the package appears.")
    (license license:lppl1.3+)))

(define-public texlive-hyphen-base
  (package
    (name "texlive-hyphen-base")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/generic/config/language.dat"
                                     "tex/generic/config/language.dat.lua"
                                     "tex/generic/config/language.def"
                                     "tex/generic/config/language.us"
                                     "tex/generic/config/language.us.def"
                                     "tex/generic/config/language.us.lua"
                                     "tex/generic/hyphen/dumyhyph.tex"
                                     "tex/generic/hyphen/hyphen.tex"
                                     "tex/generic/hyphen/hypht1.tex"
                                     "tex/generic/hyphen/zerohyph.tex"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12i6f99lmvjvq0bim9yxzdspi5fnirfsvin6hqdn30mrfdyp5l4p"))))
    (build-system texlive-build-system)
    (arguments (list #:texlive-latex-bin? #f))
    (home-page "https://tug.org/texlive/")
    (synopsis "Core hyphenation support files")
    (description "This package includes Knuth's original @file{hyphen.tex},
@file{zerohyph.tex} to disable hyphenation, @file{language.us} which starts
the autogenerated files @file{language.dat} and @file{language.def} (and
default versions of those), etc.")
    (license license:knuth)))

(define-public texlive-hyphenex
  (package
    (name "texlive-hyphenex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "source/generic/hyphenex/"
                                     "tex/generic/hyphenex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1v1p93i56xgp01zly30bkfgb9py8nav1r620dbgz1q7438zbhzpp"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hyphenex")
    (synopsis "US English hyphenation exceptions file")
    (description
     "Exceptions for American English hyphenation patterns are occasionally
published in the TeX User Group journal TUGboat.  This bundle provides
alternative Perl and Bourne shell scripts to convert the source of such an
article into an exceptions file, together with a recent copy of the article
and machine-readable files.")
    (license license:public-domain)))

(define-public texlive-index
  (package
    (name "texlive-index")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/index/" "doc/latex/index/"
                                     "makeindex/index/" "source/latex/index/"
                                     "tex/latex/index/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0f1infc8fcpw16crciampy4cqqhl4hzypyfacbwsk4cnl0fyivns"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/index")
    (synopsis "Extended index for LaTeX including multiple indexes")
    (description
     "This is a reimplementation of LaTeX's indexing macros to provide better
support for indexing.  For example, it supports multiple indexes in a single
document and provides a more robust @code{\\index} command.")
    (license license:lppl1.2+)))        ;from "index.dtx"

(define-public texlive-installfont
  (package
    (name "texlive-installfont")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/installfont/"
                                     "scripts/installfont/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wgksqg88hdzfvrywrv91al9skpj2vly09ly7qmzahqsyvdgmb9p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "installfont-tl")))
    (home-page "https://ctan.org/pkg/installfont")
    (synopsis "Bash script for installing a LaTeX font family")
    (description
     "With this script you can install a LaTeX font family (PostScript Type 1,
TrueType and OpenType formats are supported).  Font series from light to ultra
bold, and (faked) small caps and (faked) slanted shapes are supported, but not
expert fonts.  The script will rename the fonts automatically (optional) or
will otherwise expect the @file{.afm} files and the font files (in PostScript
Type1 format) named in the Karl Berry scheme (e.g., @file{5bbr8a.pfb}).  After
running the script, you should have a working font installation in your local
TeX tree.")
    (license license:lppl)))

(define-public texlive-dvipdfmx
  (package
    (name "texlive-dvipdfmx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/dvipdfm/"
                                     "doc/dvipdfmx/"
                                     "doc/man/man1/dvipdfm.1"
                                     "doc/man/man1/dvipdfm.man1.pdf"
                                     "doc/man/man1/dvipdfmx.1"
                                     "doc/man/man1/dvipdfmx.man1.pdf"
                                     "doc/man/man1/dvipdft.1"
                                     "doc/man/man1/dvipdft.man1.pdf"
                                     "doc/man/man1/ebb.1"
                                     "doc/man/man1/ebb.man1.pdf"
                                     "doc/man/man1/extractbb.1"
                                     "doc/man/man1/extractbb.man1.pdf"
                                     "doc/man/man1/xdvipdfmx.1"
                                     "doc/man/man1/xdvipdfmx.man1.pdf"
                                     "dvipdfmx/"
                                     "fonts/cmap/dvipdfmx/"
                                     "fonts/map/dvipdfmx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0p6mlpymrhsalisfda0gbqg6b941fd164kcw0nc51pzc98aws1xz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'delete-map-file
            ;; This map file is supposed to be generated in a profile hook.
            (lambda _
              (delete-file "fonts/map/dvipdfmx/updmap/kanjix.map"))))))
    (propagated-inputs (list texlive-dvipdfmx-bin texlive-glyphlist))
    (home-page "https://ctan.org/pkg/dvipdfmx")
    (synopsis "Extended version of dvipdfm")
    (description
     "Dvipdfmx (formerly dvipdfm-cjk) is a development of dvipdfm created to
support multi-byte character encodings and large character sets for East Asian
languages.  Dvipdfmx, if called with the name dvipdfm, operates in a dvipdfm
compatibility mode, so that users of the both packages need only keep one
executable.  A secondary design goal is to support as many PDF features as
does pdfTeX.")
    (license license:gpl3+)))

(define-public texlive-dvipdfmx-bin
  (package
    (inherit texlive-bin)
    (name "texlive-dvipdfmx-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("dvipdfm-x"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-dvipdfm-x" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/dvipdfm-x"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/dvipdfm-x"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list libpaper libpng texlive-libkpathsea))
    (propagated-inputs '())
    (home-page (package-home-page texlive-dvipdfmx))
    (synopsis "Binaries for @code{texlive-dvipdfmx}")
    (description
     "This package provides the binaries for @code{texlive-dvipdfmx}.")
    (license (package-license texlive-dvipdfmx))))

(define-public texlive-dvips
  (package
    (name "texlive-dvips")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/dvips/"
                                     "doc/info/dvips.info"
                                     "doc/man/man1/afm2tfm.1"
                                     "doc/man/man1/afm2tfm.man1.pdf"
                                     "doc/man/man1/dvips.1"
                                     "doc/man/man1/dvips.man1.pdf"
                                     "dvips/base/"
                                     "dvips/config/"
                                     "fonts/enc/dvips/base/"
                                     "tex/generic/dvips/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b2ai5ccnawlfshs5azrgp0azmwyxm1pi1q4c5i6mwvkgdbc1pww"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-dvips-bin))
    (home-page "https://ctan.org/pkg/dvips")
    (synopsis "DVI to PostScript drivers")
    (description
     "This package provides files needed for converting DVI files to
PostScript.")
    (license license:lppl)))

(define-public texlive-dvips-bin
  (package
    (inherit texlive-bin)
    (name "texlive-dvips-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            ;; XXX: One test needs "texmf.cnf" file to be present in the tree.
            (delete-other-directories "texk" '("dvipsk" "kpathsea" "tests"))
            (with-directory-excursion "texk/kpathsea"
              (for-each
               delete-file-recursively
               (scandir "." (lambda (f)
                              (not (member f '("." ".." "texmf.cnf")))))))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-dvipsk" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/dvipsk"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/dvipsk"
                  (invoke "make" "install"))))))))
    (native-inputs (list perl pkg-config))
    (inputs (list texlive-libkpathsea))
    (propagated-inputs '())
    (home-page (package-home-page texlive-dvips))
    (synopsis "Binaries for @code{texlive-dvips}")
    (description
     "This package provides the binaries for @code{texlive-dvips}.")
    (license (package-license texlive-dvips))))

(define-public texlive-ketcindy
  (package
    (name "texlive-ketcindy")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/ketcindy/" "scripts/ketcindy/"
                                     "tex/latex/ketcindy/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jy8fzfqwbmnza43j70c22wr0nvx9km8g4n5vcgnjvc6js2nyxas"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "ketcindy.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/ketcindy")
    (synopsis "Macros for graphic generation and Cinderella plugin")
    (description
     "KETpic is a macro package designed for computer algebra systems (CAS) to
generate LaTeX source codes for high-quality mathematical artwork.  KETcindy
is a plugin for Cinderella that allows generating graphics using KETpic.  The
generated code can be included in any LaTeX document.")
    (license license:gpl3+)))

(define-public texlive-lacheck
  (package
    (name "texlive-lacheck")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/lacheck.1"
                                     "doc/man/man1/lacheck.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hhx65yd800bl3y2sq20lix60wd2b2j3k7n9s788mlsn8b0p7yq3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-lacheck-bin))
    (home-page "https://ctan.org/pkg/lacheck")
    (synopsis "LaTeX checker")
    (description
     "Lacheck is a tool for finding common mistakes in LaTeX documents.")
    (license license:gpl3+)))

(define-public texlive-lacheck-bin
  (package
    (inherit texlive-bin)
    (name "texlive-lacheck-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '("lacheck"))
            (delete-other-directories "texk" '())))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-lacheck" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "utils/lacheck"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "utils/lacheck"
                  (invoke "make" "install"))))))))
    (native-inputs '())
    (inputs '())
    (propagated-inputs '())
    (home-page (package-home-page texlive-lacheck))
    (synopsis "Binary for @code{texlive-lacheck}")
    (description
     "This package provides the binary for @code{texlive-lacheck}.")
    (license (package-license texlive-lacheck))))

(define-public texlive-latex-git-log
  (package
    (name "texlive-latex-git-log")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/latex-git-log.1"
                                     "doc/man/man1/latex-git-log.man1.pdf"
                                     "doc/support/latex-git-log/"
                                     "scripts/latex-git-log/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01v6frspg1zrs976bwsdz6qczg0h5z6by90hmlyy4z6l5shscpix"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "latex-git-log")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/latex-git-log")
    (synopsis "Typeset @samp{git log} information")
    (description
     "The program is run within a Git repository, and outputs the entire
version history, as a LaTeX table.  That output will typically be redirected
to a file; the author recommends typesetting in landscape orientation.")
    (license license:gpl3+)))

(define-public texlive-latex-papersize
  (package
    (name "texlive-latex-papersize")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/latex-papersize/"
                                     "scripts/latex-papersize/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19nich5n4prd3g4lqm9iwn9h27h54mnycd6p4g5p18jc0b56l3n8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "latex-papersize.py")))
    (inputs (list python))
    (home-page "https://ctan.org/pkg/latex-papersize")
    (synopsis "Calculate LaTeX settings for any font and paper size")
    (description
     "The package is a Python script, whose typical use is when preparing
printed material for users with low vision.  The most effective way of doing
this is to print on (notional) small paper, and then to magnify the result;
the script calculates the settings for various font and paper sizes.")
    (license license:asl2.0)))

(define-public texlive-latex-via-exemplos
  (package
    (name "texlive-latex-via-exemplos")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latex-via-exemplos/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11nhv72ixwr0g19nr7dir5awgdapxq0l295hm1pcggr62wqh67l1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latex-via-exemplos")
    (synopsis "LaTeX course written in Brazilian Portuguese language")
    (description
     "This is a LaTeX2e course written in Brazilian Portuguese language.")
    (license license:gpl2+)))

(define-public texlive-latex2man
  (package
    (name "texlive-latex2man")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/info/latex2man.info"
                                     "doc/man/man1/latex2man.1"
                                     "doc/man/man1/latex2man.man1.pdf"
                                     "doc/support/latex2man/"
                                     "scripts/latex2man/"
                                     "tex/latex/latex2man/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c5pfnhw80fh132k2dmj3qdjgvl9dm6xzv55f54g2wlswpzlinis"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "latex2man")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/latex2man")
    (synopsis "Translate LaTeX-based manual pages into Unix man format")
    (description
     "Latex2man is a tool to translate UNIX manual pages written with LaTeX
into the troff format understood by the UNIX man(1) command.  Alternatively
HTML, TexInfo, or LaTeX code can be produced too.  Output of parts of the text
may be suppressed using the conditional text feature (for this, LaTeX
generation may be used).  There is a LaTeX package (@file{latex2man.sty}) for
writing the man page and a Perl script, @command{latex2man} that does the
actual translation.")
    (license license:lppl1.0+)))

(define-public texlive-latex2nemeth
  (package
    (name "texlive-latex2nemeth")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/latex2nemeth/"
                                     "scripts/latex2nemeth/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04l3pnzwnh86ixlj7pjy6wgkzqm5i3ka332yfkl5f6cw48dw6xw5"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "icedtea")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:link-scripts #~(list "latex2nemeth")
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'locate-java
            (lambda* (#:key inputs #:allow-other-keys)
              (substitute* "scripts/latex2nemeth/latex2nemeth"
                (("java") (search-input-file inputs "/bin/java"))))))))
    (inputs (list icedtea))
    (home-page "https://ctan.org/pkg/latex2nemeth")
    (synopsis "Convert LaTeX source to Braille with math in Nemeth")
    (description
     "This package provides a program that converts LaTeX source to
Braille/Nemeth.  It supports the Greek language, which is only Braille level
1, but also English at level 1.  Simple pictures in PSTricks are also
supported in order to produce tactile graphics with specialized equipment.
Note that embossing will need LibreOffice and @code{odt2braille} as this
project does not deal with embossers drivers.")
    (license license:gpl3)))

(define-public texlive-latexdiff
  (package
    (name "texlive-latexdiff")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/latexdiff-vc.1"
                                     "doc/man/man1/latexdiff-vc.man1.pdf"
                                     "doc/man/man1/latexdiff.1"
                                     "doc/man/man1/latexdiff.man1.pdf"
                                     "doc/man/man1/latexrevise.1"
                                     "doc/man/man1/latexrevise.man1.pdf"
                                     "doc/support/latexdiff/"
                                     "scripts/latexdiff/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03fnz7gilzwzgsqij10npfy8k2imhk5glfjijr52qgmg28r3xvi1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts
           #~(list "latexdiff-vc.pl" "latexdiff.pl" "latexrevise.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/latexdiff")
    (synopsis
     "Determine and mark up significant differences between LaTeX files")
    (description
     "Latexdiff is a Perl script for visual mark up and revision of
significant differences between two LaTeX files.  Various options are
available for visual markup using standard LaTeX packages such as color.
Changes not directly affecting visible text, for example in formatting
commands, are still marked in the LaTeX source.  A rudimentary revision
facilility is provided by another Perl script, @command{latexrevise}, which
accepts or rejects all changes.  Manual editing of the difference file can be
used to override this default behaviour and accept or reject selected changes
only.")
    (license license:gpl3)))

(define-public texlive-latexfileversion
  (package
    (name "texlive-latexfileversion")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/latexfileversion/"
                                     "scripts/latexfileversion/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12kw9s415dnlaadx6yn2jddvflvbs754rkz30xhr3di2ldpvp2jj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "latexfileversion")))
    (home-page "https://ctan.org/pkg/latexfileversion")
    (synopsis "Prints the version and date of a LaTeX class or style file")
    (description
     "This simple shell script prints the version and date of a LaTeX class or
style file.")
    (license license:lppl)))

(define-public texlive-latexindent
  (package
    (name "texlive-latexindent")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/latexindent/"
                                     "scripts/latexindent/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06ddl4gmjn8lhb05njc56n9wx9cjwnv3z7yxq17y83r4s6shf9dl"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl-file-homedir"
                                        "perl-yaml-tiny")))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts #~(list "latexindent.pl")
           #:phases
           #~(modify-phases %standard-phases
               (add-after 'link-scripts 'wrap-perl-script
                 (lambda _
                   (wrap-program (string-append #$output "/bin/latexindent")
                     `("PERL5LIB" ":" prefix (,(getenv "PERL5LIB")))))))))
    (inputs (list perl perl-file-homedir perl-yaml-tiny))
    (home-page "https://ctan.org/pkg/latexindent")
    (synopsis "Indent a LaTeX document, highlighting the programming structure")
    (description
     "The Perl script processes a LaTeX file, indenting parts so as to
highlight the structure for the reader.")
    (license license:gpl3)))

(define-public texlive-latexpand
  (package
    (name "texlive-latexpand")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/latexpand/"
                                     "scripts/latexpand/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0v0yn4n6v0kgxwh00ryfkrx7a4sxhkm0pbgnylvi8jfg24gz89ls"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "latexpand")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/latexpand")
    (synopsis "Expand @code{\\input} and @code{\\include} in a LaTeX document")
    (description
     "Latexpand is a Perl script that simply replaces @code{\\input} and
@code{\\include} commands with the content of the input or included file.  The
script does not deal with @code{\\includeonly} commands.")
    (license license:bsd-3)))

(define-public texlive-light-latex-make
  (package
    (name "texlive-light-latex-make")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/llmk.1"
                                     "doc/man/man1/llmk.man1.pdf"
                                     "doc/support/light-latex-make/"
                                     "scripts/light-latex-make/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0g5xc2cna1fdgksw0w56idkmfw5rfqifimg8picm4478vlq2srp4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "llmk.lua")))
    (home-page "https://ctan.org/pkg/light-latex-make")
    (synopsis "Build tool for LaTeX documents")
    (description
     "Light LaTeX Make (llmk) is yet another build tool specific for LaTeX
documents.  Its aim is to provide a simple way to specify a workflow of
processing LaTeX documents and encourage people to always explicitly show the
right workflow for each document.  You can describe the workflows either in an
external file @file{llmk.toml} or in a LaTeX document source in the form of
magic comments.  It provides a uniform way to describe the workflows available
for nearly all TeX environments, and behaves exactly the same in any
environment.  At this point, @command{llmk} intentionally does not provide any
method for user configuration.  Therefore one can guarantee that for a LaTeX
document with an llmk setup, the process of typesetting the document will be
reproduced in any TeX environment with the program.")
    (license license:expat)))

(define-public texlive-listings-ext
  (package
    (name "texlive-listings-ext")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/listings-ext/"
                                     "scripts/listings-ext/"
                                     "source/latex/listings-ext/"
                                     "tex/latex/listings-ext/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "044d93vdlw1amkpm8nv50390a5ba7x7d2w1y3mfg5bfvfb5cci6r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts #~(list "listings-ext.sh")))
    (home-page "https://ctan.org/pkg/listings-ext")
    (synopsis "Automated input of source")
    (description
     "The package provides a means of marking a source, so that samples of it
may be included in a document (by means of the @code{listings} package) in
a stable fashion, regardless of any change to the source.  The markup in the
source text defines tags for blocks of source.  These tags are processed by
a shell script to make a steering file that is used by the package when LaTeX
is being run.")
    (license license:lppl1.2+)))

(define-public texlive-ltxfileinfo
  (package
    (name "texlive-ltxfileinfo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/ltxfileinfo/"
                                     "scripts/ltxfileinfo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nbcplq48cw768pjyg832ymqmjr9rlrcpl6jmkq8mrvvydgy8nai"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "ltxfileinfo")))
    (home-page "https://ctan.org/pkg/ltxfileinfo")
    (synopsis "Print version information for a LaTeX file")
    (description
     "@command{ltxfileinfo} displays version information for LaTeX files.
If no path information is given, the file is searched using
@command{kpsewhich}.")
    (license license:gpl3+)))

(define-public texlive-ltximg
  (package
    (name "texlive-ltximg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/ltximg.1"
                                     "doc/man/man1/ltximg.man1.pdf"
                                     "doc/support/ltximg/" "scripts/ltximg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pxyh0w7jkdapzfjgp6fmvfq1hs6mz6qbpykd33r4c5ghyks4cwb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "ltximg.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/ltximg")
    (synopsis "Extract LaTeX environments into separate image files")
    (description
     "@command{ltximg} is a Perl script that automates the process of
extracting and converting environments provided by TikZ, PStricks and other
packages from input file to image formats and standalone files using
Ghostscript and @code{poppler-utils}.  It generates a file with only extracted
environments and another with all extracted environments converted to
@code{\\includegraphics}.")
    (license license:gpl3+)))

(define-public texlive-luajittex
  (package
    (name "texlive-luajittex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/luajithbtex.1"
                                     "doc/man/man1/luajithbtex.man1.pdf"
                                     "doc/man/man1/luajittex.1"
                                     "doc/man/man1/luajittex.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ky6maprb0xnzb38bz9bd28q54pa32015wjczc2zfbqibyxrmv9s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:create-formats
           #~(and (not #$(or (target-ppc64le?)
                             (target-riscv64?)))
                  (list "luajithbtex" "luajittex"))))
    (propagated-inputs
     (list texlive-cm
           texlive-etex
           texlive-hyphen-complete
           texlive-knuth-lib
           texlive-luajittex-bin
           texlive-luatex
           texlive-plain
           texlive-tex-ini-files
           texlive-unicode-data))
    (home-page "https://ctan.org/pkg/luajittex")
    (synopsis "LuaTeX with JIT compiler, with and without HarfBuzz")
    (description
     "This package provides LuaTeX with just-in-time (JIT) compiler, with and
without HarfBuzz.")
    (license license:gpl2)))

(define-public texlive-luajittex-bin
  (package
    (inherit texlive-bin)
    (name "texlive-luajittex-bin")
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons* "--disable-web2c"
                 "--enable-luajithbtex"
                 "--enable-luajittex"
                 (delete "--disable-luajittex"
                         (delete "--disable-luajithbtex"
                                 (delete "--enable-web2c" #$flags)))))
       ((#:phases phases)
        #~(modify-phases #$phases
            (add-after 'unpack 'force-libs-build
              ;; Once Web2C is disabled, build process refuses to build
              ;; libraries in the source tree, in particular pplib and luajit,
              ;; required for LuajitTeX.  The following change forces building
              ;; them.
              ;;
              ;; XXX: Skip build on architectures not supporting LuaJIT.  It
              ;; avoid creating conditional inputs in TEXLIVE-LUAJITTEX, which
              ;; would give more manual work after an update.
              (lambda _
                #$@(if (or (target-ppc64le?)
                           (target-riscv64?))
                       '("skip")
                       '((substitute* "libs/configure"
                           (("x\\$need_(pplib|luajit)") "xyes"))))))
            (add-after 'install 'install-binaries
              (lambda _
                (let ((out #$output))
                  #$@(if (or (target-ppc64le?)
                             (target-riscv64?))
                         '("skip")
                         '((with-directory-excursion "texk/web2c"
                             (invoke "make" "luajittex")
                             (invoke "make" "luajithbtex")
                             (let ((bin (string-append out "/bin")))
                               (install-file ".libs/luajittex" bin)
                               (install-file ".libs/luajithbtex" bin))))))))))))
    (native-inputs (list pkg-config))
    (home-page (package-home-page texlive-luajittex))
    (synopsis "Binaries for @code{texlive-luajittex}")
    (description
     "This package provides the binaries for @code{texlive-luajittex}.")
    (license (package-license texlive-luajittex))))

(define-public texlive-match-parens
  (package
    (name "texlive-match-parens")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/match_parens.1"
                                     "doc/man/man1/match_parens.man1.pdf"
                                     "doc/support/match_parens/"
                                     "scripts/match_parens/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0adb84qgwjr54x1qkz18a501afyv8s0wrqjnid398lbqphhc7w07"))))
    (outputs '("out" "doc"))
    (properties '((upstream-name . "match_parens")
                  (updater-extra-inputs "ruby")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "match_parens")))
    (inputs (list ruby))
    (home-page "https://ctan.org/pkg/match_parens")
    (synopsis
     "Find mismatches of parentheses, braces, (angle) brackets, in texts")
    (description
     "Mismatches of parentheses, braces, (angle) brackets, especially in TeX
sources which may be rich in those, may be difficult to trace.  This little
Ruby script helps you by writing your text to standard output, after adding
a left margin to your text, which will normally be almost empty, but will
clearly show any mismatches.")
    (license license:gpl3+)))

(define-public texlive-mflua
  (package
    (name "texlive-mflua")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "metafont/mflua/" "scripts/mflua/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ngbhdh8hgpjfqnrjlnp27x3qziks3yf2zp1qq7r4bjfa5jx9gr6"))))
    (build-system texlive-build-system)
    (arguments (list #:create-formats #~(list "mflua")))
    (propagated-inputs (list texlive-luatex texlive-metafont texlive-mflua-bin))
    (home-page "https://ctan.org/pkg/mflua")
    (synopsis "Configuration and base files for MFLua")
    (description
     "MFLua is an extension of Metafont which embeds a Lua interpreter.  It
doesn’t introduce any new primitives, so a Metafont file can be used with
MFLua without any modification to produce exactly the same result.")
    ;; The license is the same as Metafont's, with a couple of files
    ;; released under Public Domain terms.
    (license (list license:knuth license:public-domain))))

(define-public texlive-mflua-bin
  (package
    (inherit texlive-bin)
    (name "texlive-mflua-bin")
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons* "--disable-web2c"
                 "--enable-mflua"
                 ;; LuaJIT is not ported to some architectures yet.
                 #$@(if (or (target-ppc64le?)
                            (target-riscv64?))
                        '()
                        '("--enable-mfluajit"))
                 (delete "--disable-mflua"
                         (delete "--disable-mfluajit"
                                 (delete "--enable-web2c" #$flags)))))
       ((#:phases phases)
        #~(let ((bin (string-append #$output "/bin")))
            ;; Once Web2C is disabled, build process refuses to build
            ;; libraries in the source tree, in particular lua53 and luajit,
            ;; required for MfluaJIT.  The following changes forces building
            ;; them.
            (modify-phases #$phases
              #$@(if (or (target-ppc64le?) (target-riscv64?))
                     '()
                     '((add-after 'unpack 'force-luajit-build
                         (lambda _
                           (substitute* "libs/configure"
                             (("x\\$need_luajit") "xyes"))))
                       (add-after 'install 'install-mfluajiit
                         (lambda _
                           (with-directory-excursion "texk/web2c"
                             (invoke "make" "mfluajit")
                             (install-file ".libs/mfluajit" bin))))))
              (add-after 'unpack 'force-lua53-build
                (lambda _
                  (substitute* "libs/configure"
                    (("x\\$need_lua53") "xyes"))))
              (add-after 'install 'install-mflua
                (lambda _
                  (with-directory-excursion "texk/web2c"
                    (invoke "make" "mflua")
                    (install-file ".libs/mflua" bin)))))))))
    (native-inputs (list pkg-config))
    (inputs (modify-inputs (package-inputs texlive-bin)
              (append potrace)))
    (home-page (package-home-page texlive-mflua))
    (synopsis "Binaries for @code{texlive-mflua}")
    (description
     "This package provides the binaries for @code{texlive-mflua}.")
    (license (package-license texlive-mflua))))

(define-public texlive-mkjobtexmf
  (package
    (name "texlive-mkjobtexmf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/mkjobtexmf/"
                                     "doc/man/man1/mkjobtexmf.1"
                                     "doc/man/man1/mkjobtexmf.man1.pdf"
                                     "scripts/mkjobtexmf/"
                                     "source/generic/mkjobtexmf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04wzq2260my5894kc8qhl954h6hri77vvg5kx8mf03kdlf3rvww6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "mkjobtexmf.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/mkjobtexmf")
    (synopsis "Generate a texmf tree for a particular job")
    (description
     "The package provides a Perl script, which runs a program and tries to
find the names of file used.  Two methods are available, option
@samp{-recorder} of (Web2C) TeX and the program strace.  Then it generates
a directory with a texmf tree.  It checks the found files and tries sort them
in this texmf tree.  The script may be used for archiving purposes or to speed
up later TeX runs.")
    (license license:artistic2.0)))

(define-public texlive-make4ht
  (package
    (name "texlive-make4ht")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/make4ht/" "scripts/make4ht/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bi1kmi2i6rk3zhbrpyc6rjkvsh2cadwbhshlm7njprfvjpw182r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "make4ht")))
    (propagated-inputs (list texlive-tex4ht))
    (home-page "https://ctan.org/pkg/make4ht")
    (synopsis "Build system for TeX4ht")
    (description
     "@code{make4ht} is a simple build system for TeX4ht, a TeX to XML
converter.  It provides a command line tool that drives the conversion
process.  It also provides a library which can be used to create customized
conversion tools.")
    (license license:lppl1.3+)))

(define-public texlive-makecell
  (package
    (name "texlive-makecell")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/makecell/"
                                     "source/latex/makecell/"
                                     "tex/latex/makecell/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n122230s49jizldn8ps1pfa5dsg8wmh5x8wla4y6rsgjcccqn4s"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:tex-format "latex"
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'replace-obsolete-package
            ;; "slashbox" is no longer provided in TeX Live.  It is superseded
            ;; by `diagbox', which is backward compatible.
            (lambda _
              (substitute* "source/latex/makecell/makecell.dtx"
                (("\\\\usepackage\\{slashbox\\}")
                 "\\usepackage{diagbox}"))))
          (add-after 'replace-obsolete-package 'load-float
            ;; Loading `float' package prevents the "Unknown float option `H'"
            ;; error.
            (lambda _
              (substitute* "source/latex/makecell/makecell.dtx"
                (("usepackage\\{diagbox\\}.*" line)
                 (string-append line "\\usepackage{float}\n")))))
          (add-after 'load-float 'remove-hsize-reference
            ;; Replace "\hsize" primitive with a dummy value to prevent
            ;; a "missing number treated as zero" error.
            (lambda _
              (substitute* "source/latex/makecell/makecell.dtx"
                (("\\\\ttabbox\\[\\\\hsize\\]") "\\ttabbox[10cm]")))))))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-diagbox
                  texlive-etoolbox
                  texlive-float
                  texlive-hypdoc
                  texlive-multirow
                  texlive-pict2e))))
    (home-page "https://ctan.org/pkg/makecell")
    (synopsis "Tabular column heads and multilined cells")
    (description
     "This package supports common layouts for tabular column heads in whole
documents, based on one-column tabular environment.  In addition, it can
create multi-lined tabular cells.

The package also offers:
@itemize
@item a macro which changes the vertical space around all the cells in a @code{tabular}
environment,
@item macros for multirow cells, which use the facilities
of the @code{multirow} package,
@item macros to number rows in tables, or to skip cells;
@item diagonally divided cells;
@item horizontal lines in @code{tabular} environments with defined thickness.
@end itemize")
    (license license:lppl)))


(define-public texlive-optexcount
  (package
    (name "texlive-optexcount")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/optexcount/"
                                     "scripts/optexcount/"
                                     "source/support/optexcount/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rjyhyirkx11v04c8b0kjjz8745kdnj190vzkyyzafwnzfcbd754"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "python")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "optexcount")))
    (inputs (list python))
    (home-page "https://ctan.org/pkg/optexcount")
    (synopsis "Python script for counting words in OpTeX documents")
    (description
     "OpTeXcount is a basic Python utility that analyzes OpTeX source code.
It is inspired by already existing TeXcount for LaTeX.  The functionality is
really lightweight and basic.  It counts words and other elements of OpTeX
document and sorts them out into individual categories.  Users can print the
source code with highlighted words using several colors, so they see what is
considered as word, header etc.")
    (license license:expat)))

(define-public texlive-patgen
  (package
    (name "texlive-patgen")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/patgen.1"
                                     "doc/man/man1/patgen.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qz8sb2dbjzsjarjydfm4f36ksv68sc7dz23p066hbbq1g91sjdl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-kpathsea texlive-patgen-bin))
    (home-page "https://ctan.org/pkg/patgen")
    (synopsis "Generate hyphenation patterns")
    (description
     "Patgen takes a list of hyphenated words and generates a set of patterns
that can be used by the TeX 82 hyphenation algorithm.")
    (license license:public-domain)))

(define-public texlive-patgen-bin
  (package
    (inherit texlive-bin)
    (name "texlive-patgen-bin")
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(delete "--enable-web2c" #$flags))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/web2c"
                  (invoke "make" "patgen")
                  (install-file "patgen"
                                (string-append #$output "/bin")))))))))
    (native-inputs (list pkg-config))
    (home-page (package-home-page texlive-patgen))
    (synopsis "Binary for @code{texlive-patgen}")
    (description
     "This package provides the binary for @code{texlive-patgen}.")
    (license (package-license texlive-patgen))))

(define-public texlive-pdfbook2
  (package
    (name "texlive-pdfbook2")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/pdfbook2.1"
                                     "doc/man/man1/pdfbook2.man1.pdf"
                                     "doc/support/pdfbook2/" "scripts/pdfbook2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cw0xw2dmcgmkms8d94pchbbg17lfvvbnzbagaqpy2fzxi2kb4w8"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "python")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "pdfbook2")))
    (inputs (list python))
    (home-page "https://ctan.org/pkg/pdfbook2")
    (synopsis "Create booklets from PDF files")
    (description
     "This Python program creates print-ready PDF files from some input PDF
files for booklet printing.  The resulting files need to be printed in
landscape/long edge double sided printing.  The default paper format depends
on the locale and is chosen by @code{pdfjam}.  It can be chosen using the
@code{--paper} option.  Before the PDF is composed, the input file is cropped
to the relevant area in order to discard unnecessary white spaces.  In this
process, all pages are cropped to the same dimensions.  Extra margins can be
defined at the edges of the booklet and in the middle where the binding
occurs.")
    (license license:gpl3)))

(define-public texlive-pdfcrop
  (package
    (name "texlive-pdfcrop")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/pdfcrop/" "scripts/pdfcrop/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g5ijqyyq5dqilwjk0s61ps5w6dxxgpjllzqh0bjfc26p9jrc4nn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts #~(list "pdfcrop.pl")
           #:phases
           #~(modify-phases %standard-phases
               (add-after 'link-scripts 'add-symlink
                 (lambda _
                   (with-directory-excursion (string-append #$output "/bin")
                     (symlink "pdfcrop" "rpdfcrop")))))))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/pdfcrop")
    (synopsis "Crop PDF graphics")
    (description
     "This package provides a Perl script that can either trim pages of any
whitespace border, or trim them of a fixed border.")
    (license license:lppl1.3c)))

(define-public texlive-pdfjam
  (package
    (name "texlive-pdfjam")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/pdfjam.1"
                                     "doc/man/man1/pdfjam.man1.pdf"
                                     "doc/support/pdfjam/" "scripts/pdfjam/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yivz2hawv7lisqhbcz494wlc9clz3zg2hilarp5h29ncyda1dzs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "pdfjam")))
    (home-page "https://ctan.org/pkg/pdfjam")
    (synopsis "Shell scripts interfacing to @code{pdfpages}")
    (description
     "The package makes available the @command{pdfjam} shell script that
provides a simple interface to much of the functionality of the excellent
@code{pdfpages} package for LaTeX.  The @command{pdfjam} script takes one or
more PDF files (and/or JPG/PNG graphics files) as input, and produces one or
more PDF files as output.  It is useful for joining files together, selecting
pages, reducing several source pages onto one output page, etc.")
    (license license:gpl2+)))

(define-public texlive-pdflatexpicscale
  (package
    (name "texlive-pdflatexpicscale")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/pdflatexpicscale/"
                                     "scripts/pdflatexpicscale/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "089n7r17c9kj1hhgm0hkfjhrqp2bhwjrj1czb3qllz7rm2x230h1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "pdflatexpicscale.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/pdflatexpicscale")
    (synopsis
     "Support software for downscaling graphics to be included by pdfLaTeX")
    (description
     "The package provides a script to scale pictures down to a target
resolution before creating a PDF document with pdfLaTeX.")
    (license license:lppl)))

(define-public texlive-pdftex-quiet
  (package
    (name "texlive-pdftex-quiet")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/pdftex-quiet/"
                                     "scripts/pdftex-quiet/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gpxwiiiq05m24ahx9mnhn7i6rldqkmx041p1bnnddswajs9wgm3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "pdftex-quiet")))
    (home-page "https://ctan.org/pkg/pdftex-quiet")
    (synopsis "Bash wrapper for pdfTeX limiting its output to relevant errors")
    (description
     "This package provides a Bash script aiming at reducing pdfTeX's output
to relevant errors, which are displayed in a red bold font.")
    (license license:gpl3)))

(define-public texlive-pdftosrc
  (package
    (name "texlive-pdftosrc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/pdftosrc.1"
                                     "doc/man/man1/pdftosrc.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dfx13860iwdc8ify8vaiypilaf55j5ya5xhpl0hmvxwgss9acrc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdftosrc")
    (synopsis "Extract source file or stream from PDF file")
    (description
     "@command{pdftosrc} extracts an embedded source file, or extracts and
uncompresses a PDF stream given by object number.")
    (license license:gpl2+)))

(define-public texlive-pdfxup
  (package
    (name "texlive-pdfxup")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/pdfxup.1"
                                     "doc/man/man1/pdfxup.man1.pdf"
                                     "doc/support/pdfxup/" "scripts/pdfxup/"
                                     "tex/latex/pdfxup/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zk4nw1acqz77cy17l8mzi06f0aag16ikp8ymjsl110iw8p8my98"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "pdfxup")))
    (home-page "https://ctan.org/pkg/pdfxup")
    (synopsis "Create N-up PDF pages with minimal margins")
    (description
     "@command{pdfxup} is a shell script that creates a PDF document where
each page is obtained by combining several pages of a PDF file given as
output.")
    (license license:lppl1.3+)))

(define-public texlive-pfarrei
  (package
    (name "texlive-pfarrei")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pfarrei/" "scripts/pfarrei/"
                                     "source/latex/pfarrei/" "tex/latex/pfarrei/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1js0bn7avlrpjp98jpbwalsxlb16pgvqlcby6rnr8l3488j2fh7c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "a5toa4.tlu" "pfarrei.tlu")))
    (home-page "https://ctan.org/pkg/pfarrei")
    (synopsis "LaTeX support of pastors' and priests' work")
    (description
     "In @emph{Die TeXnische Komodie} (issue 1/2013) Christian Justen
described his use of LaTeX in his work as priest (similar requirements may be
encountered in the work of pastors and other ministers of religion).  One
point was to arrange A5 pages onto A4 landscape paper, either side-by-side or
as a booklet.  Justen made two Bash scripts for this job; the package provides
one Texlua script for both requirements.")
    (license license:lppl1.3+)))

(define-public texlive-pkfix
  (package
    (name "texlive-pkfix")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/pkfix/" "scripts/pkfix/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "173l1qaydv29va9cgip9p3i3vf27x6ndsqjm4nvdpliblai6fkwf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "pkfix.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/pkfix")
    (synopsis "Replace PK fonts in PostScript with Type 1 fonts")
    (description
     "The Perl script @command{pkfix} looks for DVIPSBitmapFont comments in
PostScript files, generated by not too old dvips, and replaces them by type
1 versions of the fonts, if possible.")
    (license license:lppl1.3+)))

(define-public texlive-pkfix-helper
  (package
    (name "texlive-pkfix-helper")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/pkfix-helper.1"
                                     "doc/man/man1/pkfix-helper.man1.pdf"
                                     "doc/support/pkfix-helper/"
                                     "scripts/pkfix-helper/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vq52g65an1v9g0kdhsy0xpsf1hj69gl4cr5aq1m816i8ahhzxxy"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "pkfix-helper")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/pkfix-helper")
    (synopsis "Make PostScript files accessible to pkfix")
    (description
     "Pkfix is a useful utility for replacing resolution-dependent bitmapped
fonts in a dvips-produced PostScript file with the corresponding
resolution-independent vector fonts.  Unfortunately, @command{pkfix} needs to
parse certain PostScript comments that appear only in files produced by dvips
versions later than 5.58 (circa 1996); it fails to work on PostScript files
produced by older versions of dvips.  Pkfix-helper is a program that attempts
to insert newer-dvips comments into an older-dvips PostScript file, thereby
making the file suitable for processing by @command{pkfix}.
@command{pkfix-helper} can sometimes process documents fully autonomously but
does require the user to verify and, if needed, correct its decisions.")
    (license license:lppl1.3c)))

(define-public texlive-purifyeps
  (package
    (name "texlive-purifyeps")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/purifyeps.1"
                                     "doc/man/man1/purifyeps.man1.pdf"
                                     "doc/support/purifyeps/"
                                     "scripts/purifyeps/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0523kgilwd142a43fw1r406rn8ck67hp78aqhsws931glf7j9y8p"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "purifyeps")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/purifyeps")
    (synopsis "Make EPS work with both LaTeX/dvips and pdfLaTeX")
    (description
     "While pdfLaTeX has a number of nice features, its primary shortcoming
relative to standard LaTeX+dvips is that it is unable to read ordinary
Encapsulated PostScript (EPS) files, the most common graphics format in the
LaTeX world.  Purifyeps converts EPS files into a purified form that can be
read by both LaTeX+dvips and pdfLaTeX.  The trick is that the standard LaTeX2e
graphics packages can parse Metapost-produced EPS directly.  Hence,
@command{purifyeps} need only convert an arbitrary EPS file into the same
stylized format that Metapost outputs.")
    (license license:lppl)))

(define-public texlive-seetexk
  (package
    (name "texlive-seetexk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/dvibook.1"
                                     "doc/man/man1/dvibook.man1.pdf"
                                     "doc/man/man1/dviconcat.1"
                                     "doc/man/man1/dviconcat.man1.pdf"
                                     "doc/man/man1/dviselect.1"
                                     "doc/man/man1/dviselect.man1.pdf"
                                     "doc/man/man1/dvitodvi.1"
                                     "doc/man/man1/dvitodvi.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bhv5xgv8jpam5apdybd0cggnvcizk2r6zs7lim1hmhzafpqqlcx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-seetexk-bin))
    (home-page "https://ctan.org/pkg/dvibook")
    (synopsis "Utilities for manipulating DVI files")
    (description
     "The package provides a collection of utilities for manipulating DVI
files:

@itemize

@item @command{dvibook}, which will rearrange the pages of a DVI file into
signatures as used when printing a book;

@item @command{dviconcat}, for concatenating pages of DVI file(s);

@item @command{dviselect}, which will select pages from one DVI file to create
a new DVI file;

@item @command{dvitodvi}, which will rearrange the pages of a DVI file to
create a new file;

@item @command{libtex}, a library for manipulating the files, from the old
SeeTeX project.

@end itemize")
    (license license:expat)))

(define-public texlive-seetexk-bin
  (package
    (inherit texlive-bin)
    (name "texlive-seetexk-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("seetexk"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-seetexk" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/seetexk"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/seetexk"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list texlive-libkpathsea))
    (propagated-inputs '())
    (home-page (package-home-page texlive-seetexk))
    (synopsis "Binary for @code{texlive-seetexk}")
    (description
     "This package provides the binary for @code{texlive-seetexk}.")
    (license (package-license texlive-seetexk))))

(define-public texlive-spix
  (package
    (name "texlive-spix")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/spix.1"
                                     "doc/man/man1/spix.man1.pdf"
                                     "doc/support/spix/" "scripts/spix/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k1vkkrn14svqarbqpfccw3qqiz1slngngrwgs4fj5y0ilrym0bf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "spix.py")))
    (inputs (list python))
    (home-page "https://ctan.org/pkg/spix")
    (synopsis "Yet another TeX compilation tool")
    (description
     "SpiX offers a way to store information about the compilation process for
a TeX file inside the TeX file itself.  Just write the commands as comments in
the TeX files, and SpiX will extract and run those commands.  Everything is
stored in the TeX file (so that you are not missing some piece of information
that is located somewhere else), in a human-readable format (no need to know
SpiX to understand it).")
    (license license:gpl3+)))

(define-public texlive-srcredact
  (package
    (name "texlive-srcredact")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/srcredact.1"
                                     "doc/man/man1/srcredact.man1.pdf"
                                     "doc/support/srcredact/"
                                     "scripts/srcredact/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a0mmr3ggxxv69zfwlrlagbczy83ngy2kxzw437n0iksz6bgrvpx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "srcredact.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/srcredact")
    (synopsis "Tool for redacting sources")
    (description
     "This package provides a tool to keep a master source, consisting of
different chunks intended for different audiences.  The tool allows extracting
the versions intended for different audiences and to incorporate the changes
made in any of these versions into the master document.")
    (license license:gpl2)))

(define-public texlive-sty2dtx
  (package
    (name "texlive-sty2dtx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/sty2dtx.1"
                                     "doc/man/man1/sty2dtx.man1.pdf"
                                     "doc/support/sty2dtx/" "scripts/sty2dtx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06930x3c52f3x9rqcmsif7y6rw11g1myya3wp77p20vfi7whxhsv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "sty2dtx.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/sty2dtx")
    (synopsis "Create a @file{.dtx} file from a @file{.sty} file")
    (description
     "The package provides a Perl script that converts a @file{.sty}
file (LaTeX package) to @file{.dtx} format (documented LaTeX source), by
surrounding macro definitions with macro and macrocode environments.  The
macro name is automatically inserted as an argument to the macro environment.
Code lines outside macro definitions are wrapped only in macrocode
environments.  Empty lines are removed.  The script should not be thought to
be fool proof and 100% accurate but rather as a good start to the business of
making a @file{.dtx} file from an undocumented style file.  Full @file{.dtx}
files are generated.  A template based on the skeleton file from @code{dtxtut}
is used.  User level macros are added automatically to the Usage section of
the @file{.dtx} file.  A corresponding @file{.ins} file can be generated as
well.")
    (license license:gpl3)))

(define-public texlive-tex-ini-files
  (package
    (name "texlive-tex-ini-files")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/tex-ini-files/"
                                     "tex/generic/tex-ini-files/"
                                     "tex/latex/tex-ini-files/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dk525x1dwgvijksa3x61lkwhvhp6vmwkw249yg7njcyca2bwa65"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:texlive-latex-bin? #f))
    (home-page "https://www.ctan.org/pkg/tex-ini-files")
    (synopsis "Files for creating TeX formats")
    (description
     "This bundle provides a collection of model @file{.ini} files for
creating TeX formats.  These files are commonly used to introduced
distribution-dependent variations in formats.  They are also used to allow
existing format source files to be used with newer engines, for example to
adapt the plain e-TeX source file to work with XeTeX and LuaTeX.")
    (license license:public-domain)))

(define-deprecated-package texlive-generic-tex-ini-files texlive-tex-ini-files)

(define-public texlive-metafont
  (package
    (name "texlive-metafont")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/inimf.1"
                                     "doc/man/man1/inimf.man1.pdf"
                                     "doc/man/man1/mf-nowin.1"
                                     "doc/man/man1/mf-nowin.man1.pdf"
                                     "doc/man/man1/mf.1"
                                     "doc/man/man1/mf.man1.pdf"
                                     "metafont/base/"
                                     "metafont/config/"
                                     "metafont/misc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0273syb24s8bky93hskqpwcmr8nz1i6yjz2lbf4zx7nj436dpa78"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:texlive-latex-bin? #f
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'build 'generate-mf.base
            ;; Even though the file "mf.base" does not appear in tlpdb, it
            ;; must be generated and provided in metafont package.
            (lambda _
              (let* ((cwd (getcwd))
                     (mf (string-append cwd "/metafont"))
                     (modes #$(this-package-input "texlive-modes")))
                (setenv "MFINPUTS"
                        (string-append
                         modes "/share/texmf-dist/fonts/source/public/modes:"
                         mf "/base:"
                         mf "/misc:"
                         mf "/roex:"
                         mf "/feynmf:"
                         mf "/mfpic:"
                         mf "/config")))
              ;; "build" directory was not created during `build' phases since
              ;; there is no ".ins" nor ".dtx" file to process.
              (mkdir-p "build")
              (with-directory-excursion "build"
                (invoke "inimf" "mf.mf")
                (install-file "mf.base"
                              (string-append #$output
                                             "/share/texmf-dist/web2c"))))))))
    (propagated-inputs (list texlive-kpathsea texlive-modes))
    (home-page "https://ctan.org/pkg/metafont")
    (synopsis "Metafont base files")
    (description "This package provides the Metafont base files needed to
build fonts using the Metafont system.")
    (license license:knuth)))

(define-deprecated-package texlive-metafont-base texlive-metafont)

(define-public texlive-metatype1
  (package
    (name "texlive-metatype1")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "source/metapost/metatype1/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nhbsn33w6zbzbvi3a32ng6ib5dbh0vll9g2c5ssiv1ysxqrg6yq"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/metatype1")
    (synopsis "Generate Type 1 fonts from MetaPost")
    (description
     "The system employs scripts, common utility programs, and a set of
MetaPost macros to provide a means of expressing the details outline fonts
directly in the MetaPost language.  The system was employed to generate the
Latin Modern fonts, and the distribution includes an example development of
Knuth's logo fonts.")
    (license license:public-domain)))

(define-public texlive-mf2pt1
  (package
    (name "texlive-mf2pt1")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/info/mf2pt1.info" "doc/support/mf2pt1/"
                                     "metapost/mf2pt1/" "scripts/mf2pt1/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17dq4csl10j89rrxgyqjp3fjqkd9q6djgz9yi33y72w5ymjgiaik"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "mf2pt1.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/mf2pt1")
    (synopsis "Convert stylized Metafont to PostScript Type 1")
    (description
     "@command{mf2pt1} is a Perl script that facilitates producing PostScript
Type 1 fonts from a Metafont source file.  It is not, as the name may imply,
an automatic converter of arbitrary Metafont fonts to Type 1 format.
@command{mf2pt1} imposes a number of restrictions on the Metafont input.  If
these restrictions are met, it will produce valid Type 1 output with more
accurate control points than can be reverse-engineered by TeXtrace,
@command{mftrace}, and other programs which convert bitmaps to outline
fonts.")
    (license license:lppl1.3c)))

(define-public texlive-mfirstuc
  (package
    (name "texlive-mfirstuc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mfirstuc/"
                                     "scripts/mfirstuc/"
                                     "source/latex/mfirstuc/"
                                     "tex/latex/mfirstuc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fvdnfybfi7nych97i117s6wqf0w8drgzpf3qzfns9qxjxm0bv3l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mfirstuc")
    (synopsis "Uppercase the first letter of a word")
    (description
     "The package provides commands @code{\\makefirstuc} that uppercases the
first letter in its argument (with a check for a semantic markup command at
the start of the argument), and @code{\\xmakefirstuc} which expands the
argument before uppercasing.  It also provides
@code{\\capitalisewords@{phrase@}} which applies @code{\\makefirstuc} to each
word in the phrase, where the words are separated by regular
spaces.  (Exceptions can be made for words that shouldn't be converted.)")
    (license license:lppl1.3+)))

(define-public texlive-mfnfss
  (package
    (name "texlive-mfnfss")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mfnfss/" "source/latex/mfnfss/"
                                     "tex/latex/mfnfss/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1775vg12sk38givqq2zjapx4nxlyl95rf596r2inf8mv5phsi704"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mfnfss")
    (synopsis "Packages to typeset old german and Pandora fonts in LaTeX")
    (description
     "This bundle contains two packages: @code{oldgerm}, a package to typeset
with old german fonts designed by Yannis Haralambous, and @code{pandora},
a package to typeset with Pandora fonts designed by Neena Billawala.  Note
that support for the Pandora fonts is also available via the
@code{pandora-latex} package.")
    (license license:lppl)))

(define-public texlive-modes
  (package
    (name "texlive-modes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/modes/"
                                     "fonts/source/public/modes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15m78jhapl70bvalic790jpwyllr1ishl9wsdiwqf396dssr1g39"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:texlive-latex-bin? #f))
    (home-page "https://ctan.org/pkg/modes")
    (synopsis "Collection of Metafont @code{mode_def}'s")
    (description
     "The modes file collects all known Metafont modes for printing or display
devices, of whatever printing technology.  Special provision is made for
write-white printers, and a landscape mode is available, for making suitable
fonts for printers with pixels whose aspect is non-square.  The file also
provides definitions that make @code{\\specials} identifying the mode in
Metafont's GF output, and put coding information and other Xerox-world
information in the TFM file.")
    (license license:public-domain)))

(define-public texlive-mptopdf
  (package
    (name "texlive-mptopdf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/context/scripts/mkii/"
                                     "doc/man/man1/mptopdf.1"
                                     "doc/man/man1/mptopdf.man1.pdf"
                                     "scripts/context/perl/mptopdf.pl"
                                     "tex/context/base/mkii/"
                                     "tex/generic/context/mptopdf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03782qwjz0fnr8l0h8rc8hj32wxaz8zc8v20l94lrkhmc3d40j6z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:link-scripts #~(list "mptopdf.pl")
      #:create-formats #~(list "mptopdf")
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'fix-perl-header
            (lambda* (#:key inputs #:allow-other-keys)
              (let ((perl (search-input-file inputs "/bin/perl")))
                (substitute* "scripts/context/perl/mptopdf.pl"
                  (("exec perl") (string-append "exec " perl)))))))))
    (inputs (list perl))
    (propagated-inputs (list texlive-pdftex texlive-plain))
    (home-page "https://ctan.org/pkg/mptopdf")
    (synopsis "Native MetaPost graphics inclusion - mpost to PDF")
    (description
     "The @code{mptopdf} script does standalone conversion from mpost to PDF,
using the @file{supp-*} and @file{syst-*} files.  They also allow native
MetaPost graphics inclusion in LaTeX (via pdftex.def) and ConTeXt.  They can
be used independently of the rest of ConTeXt.")
    ;; Use the same licensing as ConTeXt.
    (license (list license:lppl1.3c+
                   license:gpl2+
                   license:cc-by-sa4.0))))

(define-public texlive-fontinst
  (package
    (name "texlive-fontinst")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/fontinst/"
                                     "doc/man/man1/fontinst.1"
                                     "doc/man/man1/fontinst.man1.pdf"
                                     "scripts/texlive-extra/fontinst.sh"
                                     "source/fontinst/base/"
                                     "tex/fontinst/base/"
                                     "tex/fontinst/latinetx/"
                                     "tex/fontinst/latinmtx/"
                                     "tex/fontinst/mathetx/"
                                     "tex/fontinst/mathmtx/"
                                     "tex/fontinst/misc/"
                                     "tex/fontinst/smbletx/"
                                     "tex/fontinst/smblmtx/"
                                     "tex/latex/fontinst/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qqggn44w07a0aslsf3jdygwv1gfs90qahkan0gnibxsz7i44kqm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "fontinst.sh")))
    (home-page "https://ctan.org/pkg/fontinst")
    (synopsis "Tools for converting and installing fonts for TeX and LaTeX")
    (description
     "This package provides TeX macros for converting Adobe Font Metric files
to TeX metric and virtual font format.  Fontinst helps mainly with the number
crunching and shovelling parts of font installation.  This means in practice
that it creates a number of files which give the TeX metrics (and related
information) for a font family that TeX needs to do any typesetting in these
fonts.")
    (license license:lppl1.1+)))

(define-deprecated-package texlive-tex-fontinst-base texlive-fontinst)

(define-public texlive-fontname
  (package
    (name "texlive-fontname")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/fontname/" "doc/info/fontname.info"
                                     "fonts/map/fontname/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "014kiwbqz77yn8w58cb6fzqj0vlfmgyq09mxdj15ipjfgxjyvcbj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fontname")
    (synopsis "Scheme for naming fonts in TeX")
    (description
     "This is Fontname, a naming scheme for (the base part of) external TeX
font filenames.  This makes at most eight-character names from (almost)
arbitrarily complex font names, thus helping portability of TeX documents.")
    (license license:gpl3+)))

(define-public texlive-forloop
  (package
    (name "texlive-forloop")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/forloop/" "source/latex/forloop/"
                                     "tex/latex/forloop/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b6gys199rzlcg54s9v5l8s7igw3akhj8avr4q6f1j2bin9bgyn3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/forloop")
    (synopsis "Iteration in LaTeX")
    (description
     "The package provides a command @code{\\forloop} for doing iteration in
LaTeX macro programming.")
    ;; No version for the LGPL is specified.  Assuming the broader one.
    (license license:lgpl2.0+)))

(define-public texlive-cbfonts          ;71 MiB of greek fonts
  (package
    (name "texlive-cbfonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cbfonts/"
                                     "fonts/enc/dvips/cbfonts/"
                                     "fonts/map/dvips/cbfonts/"
                                     "fonts/source/public/cbfonts/"
                                     "fonts/tfm/public/cbfonts/"
                                     "fonts/type1/public/cbfonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l0dpgvngah227snzk6j5hf3kxs5cz5jvlpkv8pbapw6jx084np6"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-cm")))
    (build-system texlive-build-system)
    (arguments
     (list #:phases
           #~(modify-phases %standard-phases
               ;; FIXME: Font metrics cannot be generated due to "bad pos"
               ;; errors.
               (delete 'generate-font-metrics))))
    (native-inputs (list texlive-cm texlive-metafont))
    (propagated-inputs (list texlive-cbfonts-fd))
    (home-page "https://ctan.org/pkg/cbgreek-complete")
    (synopsis "Complete set of Greek fonts")
    (description
     "This bundle presents the whole of Beccari's original Greek font set,
which use the @i{Lispiakos} font shape derived from the shape of the fonts
used in printers' shops in Lispia.  The fonts are available both as Metafont
source and in Adobe Type 1 format, and at the same wide set of design sizes as
are such font sets as the EC fonts.")
    (license license:lppl1.3c+)))

(define-public texlive-cbfonts-fd
  (package
    (name "texlive-cbfonts-fd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cbfonts-fd/"
                                     "source/fonts/cbfonts-fd/"
                                     "tex/latex/cbfonts-fd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r2kmnccvrq181ac7gyff9y3wn7dydx50jy8f9n6qhnb824pdn78"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cbfonts-fd")
    (synopsis "LaTeX font description files for the CB Greek fonts")
    (description
     "The package provides font description files for all the many shapes
available from the @code{cbfonts} collection.  The files provide the means
whereby the @acronym{NFSS, New Font Selection Scheme} knows which fonts
a LaTeX user is requesting.

Tip: installing @code{texlive-cbfonts} will automatically propagate this one.")
    (license license:lppl1.3c+)))

(define-public texlive-ccicons
  (package
    (name "texlive-ccicons")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/ccicons/"
                                     "doc/latex/ccicons/"
                                     "fonts/enc/dvips/ccicons/"
                                     "fonts/map/dvips/ccicons/"
                                     "fonts/opentype/public/ccicons/"
                                     "fonts/tfm/public/ccicons/"
                                     "fonts/type1/public/ccicons/"
                                     "source/fonts/ccicons/"
                                     "source/latex/ccicons/"
                                     "tex/latex/ccicons/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lyxbjpkxny6hl7pmnpka0gmgx7qv66pibvwcfs9dvwhdcvwjr4x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ccicons")
    (synopsis "LaTeX support for Creative Commons icons")
    (description
     "The package provides the means to typeset Creative Commons icons, in
documents licensed under CC licences.  A font (in Adobe Type 1 format) and
LaTeX support macros are provided.")
    (license (list license:lppl1.3c license:silofl1.1))))

(define-public texlive-cite
  (package
    (name "texlive-cite")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cite/" "tex/latex/cite/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b1amznayxj80dmqbzcysmj7q8aksbyz98k6djsqi0mhwp1cd0fd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cite")
    (synopsis "Improved citation handling in LaTeX")
    (description
     "The package supports compressed, sorted lists of numerical citations,
and also deals with various punctuation and other issues of representation,
including comprehensive management of break points.  The package is compatible
with both @code{hyperref} and @code{backref}.  The package is (unsurprisingly)
part of the cite bundle of the author's citation-related packages.")
    (license (license:fsf-free "/share/texmf-dist/doc/latex/cite/README"))))

(define-public texlive-cm
  (package
    (name "texlive-cm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cm/" "fonts/map/dvips/cm/"
                                     "fonts/pk/ljfour/public/cm/dpi600/"
                                     "fonts/source/public/cm/"
                                     "fonts/tfm/public/cm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10adgjc3lkj2z50jp1f9n83bdrx8bqxd76rl605d0d5pb435k97m"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-mfware-bin")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:texlive-latex-bin? #f
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'generate-font-metrics 'generate-pk
            (lambda _
              (let* ((cwd (getcwd))
                     (pkdir
                      (string-append cwd "/fonts/pk/ljfour/public/cm/dpi600"))
                     (build-dir (string-append cwd "/build"))
                     (gftopk
                      (string-append
                       #$(this-package-native-input "texlive-mfware-bin")
                       "/bin/gftopk")))
                (with-directory-excursion "fonts/source/public/cm/"
                  (mkdir-p pkdir)
                  (for-each
                   (lambda (font)
                     (let ((font-name (basename font ".mf")))
                       (invoke gftopk
                               (string-append build-dir "/" font-name ".600gf")
                               (string-append pkdir "/" font-name ".pk"))))
                   (find-files "." "cm(.*[0-9]+.*|inch)\\.mf$")))))))))
    (native-inputs (list texlive-metafont texlive-mfware-bin))
    (home-page "https://ctan.org/pkg/cm")
    (synopsis "Computer Modern fonts for TeX")
    (description
     "This package provides the Computer Modern fonts by Donald Knuth.  The
Computer Modern font family is a large collection of text, display, and
mathematical fonts in a range of styles, based on Monotype Modern 8A.")
    (license license:knuth)))

(define-deprecated-package texlive-fonts-cm texlive-cm)

(define-public texlive-cmbright
  (package
    (name "texlive-cmbright")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cmbright/"
                                     "doc/latex/cmbright/"
                                     "fonts/source/public/cmbright/"
                                     "fonts/tfm/public/cmbright/"
                                     "source/latex/cmbright/"
                                     "tex/latex/cmbright/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sj6g877p6ak045x7737g3lg4kab8hgc2s2g6i23dw9d35csqf8d"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-amsfonts"
                                               "texlive-ec")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-amsfonts texlive-ec texlive-metafont))
    (home-page "https://ctan.org/pkg/cmbright")
    (synopsis "Computer Modern Bright fonts")
    (description
     "This package provides a family of sans serif fonts for TeX and LaTeX,
based on Donald Knuth's CM fonts.  It comprises OT1, T1 and TS1 encoded text
fonts of various shapes as well as all the fonts necessary for mathematical
typesetting, including AMS symbols.  This collection provides all the
necessary files for using the fonts with LaTeX.")
    (license license:lppl)))

(define-public texlive-cmcyr
  (package
    (name "texlive-cmcyr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cmcyr/"
                                     "fonts/map/dvips/cmcyr/"
                                     "fonts/source/public/cmcyr/"
                                     "fonts/tfm/public/cmcyr/"
                                     "fonts/type1/public/cmcyr/"
                                     "fonts/vf/public/cmcyr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wlz8hq3dzjz46d2r414rb6jl9iz864bj32ia9pgkqdpypw0ani3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/cmcyr")
    (synopsis "Computer Modern fonts with Cyrillic extensions")
    (description
     "These are the Computer Modern fonts extended with Russian letters, in
Metafont sources and ATM Compatible Type 1 format.  The fonts are provided in
KOI-7, but virtual fonts are available to recode them to three other Russian
8-bit encodings.")
    (license license:public-domain)))

(define-public texlive-cmextra
  (package
    (name "texlive-cmextra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "fonts/source/public/cmextra/"
                                     "fonts/tfm/public/cmextra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00my52lh3cn8bn211fpn7373b7khaylx4fgkrd2m72xgaymil308"))))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/knuth-local")
    (synopsis "Knuth's local information")
    (description
     "This package provides a collection of experimental programs and
developments based on, or complementary to, the matter in his distribution
directories.")
    (license license:public-domain)))

(define-public texlive-cm-lgc
  (package
    (name "texlive-cm-lgc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cm-lgc/"
                                     "fonts/afm/public/cm-lgc/"
                                     "fonts/enc/dvips/cm-lgc/"
                                     "fonts/map/dvips/cm-lgc/"
                                     "fonts/ofm/public/cm-lgc/"
                                     "fonts/ovf/public/cm-lgc/"
                                     "fonts/tfm/public/cm-lgc/"
                                     "fonts/type1/public/cm-lgc/"
                                     "fonts/vf/public/cm-lgc/"
                                     "tex/latex/cm-lgc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nj3gp0kpzlqkm22lj2ym9c95xw323xc5z91gsyv8xs716868gp2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cm-lgc")
    (synopsis "Type 1 CM-based fonts for Latin, Greek and Cyrillic")
    (description
     "The fonts are converted from METAFONT sources of the Computer Modern
font families, using @command{textrace}.  Supported encodings are: T1 (Latin),
T2A (Cyrillic), LGR (Greek) and TS1.  The package also includes Unicode
virtual fonts for use with Omega.  The font set is not a replacement for any
of the other Computer Modern-based font sets (for example, cm-super for Latin
and Cyrillic, or cbgreek for Greek), since it is available at a single size
only; it offers a compact set for general working.  The fonts themselves are
encoded to external standards, and virtual fonts are provided for use with
TeX.")
    (license license:gpl2+)))

(define-public texlive-cm-super
  (package
    (name "texlive-cm-super")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cm-super/"
                                     "dvips/cm-super/"
                                     "fonts/afm/public/cm-super/"
                                     "fonts/enc/dvips/cm-super/"
                                     "fonts/map/dvips/cm-super/"
                                     "fonts/map/vtex/cm-super/"
                                     "fonts/type1/public/cm-super/"
                                     "tex/latex/cm-super/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1k3afl0x0bqbr5mnawbnp7rr2126dwn0vwnxzibm9ggvzqilnkm6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cm-super")
    (synopsis "Computer Modern Super family of fonts")
    (description
     "The CM-Super family provides Adobe Type 1 fonts that replace the
T1/TS1-encoded Computer Modern (EC/TC), T1/TS1-encoded Concrete,
T1/TS1-encoded CM bright and LH Cyrillic fonts (thus supporting all European
languages except Greek), and bringing many ameliorations in typesetting
quality.  The fonts exhibit the same metrics as the METAFONT-encoded
originals.")
    ;; With font exception
    (license license:gpl2+)))

(define-deprecated-package texlive-fonts-cm-super texlive-cm-super)

(define-public texlive-cnbwp
  (package
    (name "texlive-cnbwp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/cnbwp/" "doc/latex/cnbwp/"
                                     "makeindex/cnbwp/" "tex/latex/cnbwp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ha4lv0k4ysyqxnaf6w0v0bc0375lxdcyg55ih16kp3mdmadbc49"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cnbwp")
    (synopsis "Typeset working papers of the Czech National Bank")
    (description
     "The package supports proper formatting of Working Papers of the Czech
National Bank (WP CNB).  The package was developed for CNB but it is also
intended for authors from outside CNB.")
    (license license:lppl)))

(define-public texlive-cns
  (package
    (name "texlive-cns")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cns/cns40-1/"
                                     "doc/fonts/cns/cns40-2/"
                                     "doc/fonts/cns/cns40-3/"
                                     "doc/fonts/cns/cns40-4/"
                                     "doc/fonts/cns/cns40-5/"
                                     "doc/fonts/cns/cns40-6/"
                                     "doc/fonts/cns/cns40-7/"
                                     "doc/fonts/cns/cns40-b5/"
                                     "fonts/misc/cns/"
                                     "fonts/tfm/cns/c0so12/"
                                     "fonts/tfm/cns/c1so12/"
                                     "fonts/tfm/cns/c2so12/"
                                     "fonts/tfm/cns/c3so12/"
                                     "fonts/tfm/cns/c4so12/"
                                     "fonts/tfm/cns/c5so12/"
                                     "fonts/tfm/cns/c6so12/"
                                     "fonts/tfm/cns/c7so12/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00v6sf0a0fm09z54d3zhvdwc2gi712knbxnx3mlj2ri5x2jisyqa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cjk-fonts")
    (synopsis "Chinese/Japanese/Korean bitmap fonts")
    (description
     "This bundle provides fonts to go with the @code{cjk} macro package for Chinese,
Japanese and Korean with LaTeX2e.  The package aims to supersede HLaTeX fonts
bundle.")
    (license license:public-domain)))

(define-public texlive-courier
  (package
    (name "texlive-courier")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "dvips/courier/"
                                     "fonts/afm/adobe/courier/"
                                     "fonts/afm/urw/courier/"
                                     "fonts/map/dvips/courier/"
                                     "fonts/tfm/adobe/courier/"
                                     "fonts/tfm/urw35vf/courier/"
                                     "fonts/type1/adobe/courier/"
                                     "fonts/type1/urw/courier/"
                                     "fonts/vf/adobe/courier/"
                                     "fonts/vf/urw35vf/courier/"
                                     "tex/latex/courier/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08g6lm12b0k6333pxcaqdf67v87fz5mrqp3jgal8qhrls5ym8q6r"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/urw-base35")
    (synopsis "Replacement for Adobe's Courier font")
    (description
     "This package provides a drop-in replacement for the Courier font from
Adobe's basic set.")
    ;; No license version specified.
    (license license:gpl3+)))

(define-public texlive-csbulletin
  (package
    (name "texlive-csbulletin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/csbulletin/"
                                     "tex/latex/csbulletin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15zjwwjdxs0avb5y4g29nyvhafrv2s8pgqihhi2kb72y8wzj9cdz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/csbulletin")
    (synopsis
     "LaTeX class for articles submitted to the CSTUG Bulletin (@emph{Zpravodaj})")
    (description
     "The package provides the class for articles for the CSTUG
Bulletin (@emph{Zpravodaj Ceskoslovenskeho sdruzeni uzivatelu TeXu}).  You can
see the structure of a document by looking at the source file of the manual.")
    (license license:lppl1.3c)))

(define-public texlive-cslatex
  (package
    (name "texlive-cslatex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "source/cslatex/base/"
                                     "source/cslatex/cspsfonts/"
                                     "tex/cslatex/base/"
                                     "tex/cslatex/cspsfonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dddk20v3acc3pb3wkg58y2y6z6fkx0ifsi03fffm0903z1h2zhm"))))
    (build-system texlive-build-system)
    (arguments
     (list
      #:create-formats #~(list "cslatex" "pdfcslatex")
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'fix-build
            ;; This phase is necessary because the build phase is reluctant to
            ;; generate "hyphen.cfg" since there is another one among the
            ;; inputs already.
            (lambda _
              (substitute* "source/cslatex/base/cslatex.ins"
                (("\\keepsilent\n" all)
                 (string-append all "\\askforoverwritefalse\n"))))))))
    (propagated-inputs
     (list texlive-atbegshi
           texlive-atveryend
           texlive-cm
           texlive-csplain
           texlive-everyshi
           texlive-firstaid
           texlive-hyphen-base
           texlive-l3kernel
           texlive-l3packages
           texlive-latex
           texlive-latex-fonts
           texlive-tex-ini-files
           texlive-unicode-data))
    (home-page "https://ctan.org/pkg/cslatex")
    (synopsis "LaTeX support for Czech/Slovak typesetting")
    (description
     "This package provides LaTeX support for Czech and Slovak typesetting.")
    (license license:gpl3+)))

(define-public texlive-cstex
  (package
    (name "texlive-cstex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/cstex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vsbq9a31ymvrj0bx48n93chyqmma3q7b49k7dmhb0hkic6h73aj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cstex")
    (synopsis "Support for Czech/Slovak languages")
    (description
     "CSTeX is a Czech and Slovak languages distribution of Plain and LaTeX.")
    (license license:gpl2)))

(define-public texlive-cweb
  (package
    (name "texlive-cweb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/ctangle.1"
                                     "doc/man/man1/ctangle.man1.pdf"
                                     "doc/man/man1/ctwill-proofsort.1"
                                     "doc/man/man1/ctwill-proofsort.man1.pdf"
                                     "doc/man/man1/ctwill-refsort.1"
                                     "doc/man/man1/ctwill-refsort.man1.pdf"
                                     "doc/man/man1/ctwill-twinx.1"
                                     "doc/man/man1/ctwill-twinx.man1.pdf"
                                     "doc/man/man1/ctwill.1"
                                     "doc/man/man1/ctwill.man1.pdf"
                                     "doc/man/man1/cweave.1"
                                     "doc/man/man1/cweave.man1.pdf"
                                     "doc/man/man1/cweb.1"
                                     "doc/man/man1/cweb.man1.pdf"
                                     "doc/man/man1/twill-refsort.1"
                                     "doc/man/man1/twill-refsort.man1.pdf"
                                     "doc/man/man1/twill.1"
                                     "doc/man/man1/twill.man1.pdf"
                                     "tex/plain/cweb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "072zxy3ynjq1ar1yclnxhdxpdw7hzgk2c7cskz4m37sx439k2dnz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cwebbin")
    (synopsis "CWEB for ANSI-C/C++ compilers")
    (description
     "This package provides a highly portable and extended version of
Levy/Knuth CWEB 3.64c.  TeX macros, CWEB macros, and NLS catalogs are included
for German, French (partially), and Italian program documentation on any
machine.")
    (license license:knuth)))

(define-public texlive-cyrplain
  (package
    (name "texlive-cyrplain")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/plain/cyrplain/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wdcibxs0g53warxs6vz39s3chldzh05p7v1ksskppghg5qzgh8z"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/t2")
    (synopsis "Support for using T2 encoding")
    (description
     "The T2 bundle provides a variety of separate support functions for using
Cyrillic characters in LaTeX:
@itemize
@item the @code{mathtext} package, for using Cyrillic letters transparently in
formulae;
@item the @code{citehack} package, for using Cyrillic (or indeed any
non-ASCII) characters in citation keys;
@item support for Cyrillic in BibTeX;
@item support for Cyrillic in Makeindex;
@item various items of font support.
@end itemize")
    (license license:lppl)))

(define-public texlive-tex-gyre
  (package
    (name "texlive-tex-gyre")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/tex-gyre/"
                                     "fonts/afm/public/tex-gyre/"
                                     "fonts/enc/dvips/tex-gyre/"
                                     "fonts/map/dvips/tex-gyre/"
                                     "fonts/opentype/public/tex-gyre/"
                                     "fonts/tfm/public/tex-gyre/"
                                     "fonts/type1/public/tex-gyre/"
                                     "source/fonts/tex-gyre/"
                                     "tex/latex/tex-gyre/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bn8g6rav0v47zbf1gjwp64x0l5340wb5iiiw4kdg69qingkj5lq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tex-gyre")
    (synopsis "TeX fonts extending URW fonts")
    (description
     "The TeX-GYRE bundle consist of multiple font families:
@itemize @bullet
@item Adventor, based on the URW Gothic L family of fonts;
@item Bonum, based on the URW Bookman L family;
@item Chorus, based on URW Chancery L Medium Italic;
@item Cursor, based on URW Nimbus Mono L;
@item Heros, based on URW Nimbus Sans L;
@item Pagella, based on URW Palladio L;
@item Schola, based on the URW Century Schoolbook L family;
@item Termes, based on the URW Nimbus Roman No9 L family of fonts.
@end itemize

The constituent standard faces of each family have been greatly extended
(though Chorus omits Greek support and has no small-caps family).  Each
family is available in Adobe Type 1 and Open Type formats, and LaTeX
support (for use with a variety of encodings) is provided.")
    ;; The GUST font license (GFL) is legally identical to the LaTeX Project
    ;; Public License (LPPL), version 1.3c or later, but comes with an
    ;; additional but not legally binding clause.
    (license license:lppl1.3c+)))

(define-public texlive-tex-gyre-math
  (package
    (name "texlive-tex-gyre-math")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/tex-gyre-math/"
                                     "fonts/opentype/public/tex-gyre-math/"
                                     "source/fonts/tex-gyre-math/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1k5fx03bg702636hh7hv4kzzxhbbic26rp5g4lq2bgajd5dgc5xy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tex-gyre-math")
    (synopsis "Maths fonts to match tex-gyre text fonts")
    (description
     "TeX-Gyre-Math is a collection of maths fonts to match the text fonts of
the TeX-Gyre collection.  The collection is available in OpenType format,
only; fonts conform to the developing standards for OpenType maths fonts.
TeX-Gyre-Math-Bonum (to match TeX-Gyre-Bonum), TeX-Gyre-Math-Pagella (to match
TeX-Gyre-Pagella), TeX-Gyre-Math-Schola (to match TeX-Gyre-Schola) and
TeX-Gyre-Math-Termes (to match TeX-Gyre-Termes) fonts are provided.")
    (license license:gfl1.0)))

(define-public texlive-crop
  (package
    (name "texlive-crop")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/crop/" "source/latex/crop/"
                                     "tex/latex/crop/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m0dg69bhbvqrq9d2yl6ip36w1bf5cibp386jj2wbywisa2hn3qf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/crop")
    (synopsis "Support for cropmarks")
    (description
     "This package provides a package providing corner marks for camera
alignment as well as for trimming paper stacks, and additional page
information on every page if required.  Most macros are easily adaptable to
personal preferences.  An option is provided for selectively suppressing
graphics or text, which may be useful for printing just colour graphics on
a colour laser printer and the rest on a cheap mono laser printer.  A page
info line contains the time and a new cropmarks index and is printed at the
top of the page.  A configuration command is provided for the info line font.
Options for better collaboration with dvips, pdfTeX and vtex are provided.")
    (license license:lppl)))

(define-public texlive-ctablestack
  (package
    (name "texlive-ctablestack")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/ctablestack/"
                                     "source/luatex/ctablestack/"
                                     "tex/luatex/ctablestack/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13l779436aj3hlchwvhkpiikbyfa2j4swzfrwqkjh9l8bc2cwg7n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ctablestack")
    (synopsis "Catcode table stable support")
    (description
     "This package provides a method for defining category code table stacks
in LuaTeX.  It is required by the @code{luatexbase} package which uses
@code{ctablestack} to provide a back-compatibility form of this concept.")
    (license license:lppl1.3+)))

(define-public texlive-lm
  (package
    (name "texlive-lm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/lm/"
                                     "fonts/afm/public/lm/"
                                     "fonts/enc/dvips/lm/"
                                     "fonts/map/dvipdfm/lm/"
                                     "fonts/map/dvips/lm/"
                                     "fonts/opentype/public/lm/"
                                     "fonts/tfm/public/lm/"
                                     "fonts/type1/public/lm/"
                                     "tex/latex/lm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zgp0pc30n8jqr7kiv6j77i9i8dzzyh8zv72n24n74lb28k0sfmr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:texlive-latex-bin? #f))
    (home-page "https://ctan.org/pkg/lm")
    (synopsis "Latin Modern family of fonts")
    (description "The Latin Modern fonts are derived from the famous Computer
Modern fonts designed by Donald E. Knuth and described in Volume E of his
Computers & Typesetting series.")
    ;; The GUST font license (GFL) is legally identical to the LaTeX Project
    ;; Public License (LPPL), version 1.3c or later, but comes with an
    ;; additional but not legally binding clause.
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-fonts-lm texlive-lm)

(define-public texlive-lm-math
  (package
    (name "texlive-lm-math")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/lm-math/"
                                     "fonts/opentype/public/lm-math/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gqdk8x3r1iz4n8j6r3pcqbwalxvkihayvmjfq4iv6hwb0pvys8z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lm-math")
    (synopsis "OpenType maths fonts for Latin Modern")
    (description
     "Latin Modern Math is a maths companion for the Latin Modern family of
fonts, in OpenType format.  For use with LuaLaTeX or XeLaTeX, support is
available from the @code{unicode-math} package.")
    (license license:gfl1.0)))

(define-public texlive-lwarp
  (package
    (name "texlive-lwarp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lwarp/"
                                     "scripts/lwarp/"
                                     "source/latex/lwarp/"
                                     "tex/latex/lwarp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17sgnbhpbj6hsmqi2xljmqajhl4ccyqyh20qhc161vcfd9ri0qgg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "lwarpmk.lua")))
    (home-page "https://ctan.org/pkg/lwarp")
    (synopsis "Converts LaTeX to HTML")
    (description
     "This package converts LaTeX to HTML by using LaTeX to process the user's
document and generate HTML tags.  External utility programs are only used for
the final conversion of text and images.  Math may be represented by SVG files
or MathJax.  Hundreds of LaTeX packages are supported, and their load order is
automatically verified.  Documents may be produced by LaTeX, LuaLaTeX,
XeLaTeX, and by several CJK engines, classes, and packages.  A texlua script
automates compilation, index, glossary, and batch image processing, and also
supports latexmk.  Configuration is semi-automatic at the first manual
compile.  Support files are self-generated.  Print and HTML versions of each
document may coexist.  Assistance is provided for HTML import into EPUB
conversion software and word processors.")
    (license license:lppl1.3+)))

(define-public texlive-knuth-lib
  (package
    (name "texlive-knuth-lib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "fonts/source/public/knuth-lib/"
                                     "fonts/tfm/public/knuth-lib/"
                                     "tex/generic/knuth-lib/"
                                     "tex/plain/knuth-lib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dl8z340n6m6xn7wari4hir0syxqi0kl2fhnf0bvnmkqhqwyzpca"))))
    (properties '((updater-extra-native-inputs "texlive-cm")))
    (build-system texlive-build-system)
    (arguments (list #:texlive-latex-bin? #f))
    (native-inputs (list texlive-cm texlive-metafont))
    (home-page "https://ctan.org/pkg/knuth-lib")
    (synopsis "Small library of METAFONT sources")
    (description
     "This is a collection of core TeX and METAFONT macro files from Donald
Knuth, including the plain format, plain base, and the MF logo fonts.")
    (license license:knuth)))

(define-deprecated-package texlive-fonts-knuth-lib texlive-knuth-lib)

(define-public texlive-knuth-local
  (package
    (name "texlive-knuth-local")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "fonts/source/public/knuth-local/"
                                     "fonts/tfm/public/knuth-local/"
                                     "mft/knuth-local/" "tex/plain/knuth-local/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02cf32f57fr6bngiv9xiw8bh4sq53p9br034ap74s80h3bgcmn1f"))))
    (properties '((updater-extra-native-inputs "texlive-knuth-lib")))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/knuth-local")
    (native-inputs (list texlive-knuth-lib texlive-metafont))
    (synopsis "Knuth's local information")
    (description
     "This package provides a collection of experimental programs and
developments based on, or complementary to, the matter in his distribution
directories.")
    (license license:public-domain)))

(define-public texlive-lapdf
  (package
    (name "texlive-lapdf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lapdf/" "tex/latex/lapdf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rnwgb3fy8f4app543lx72f4rhc5c4kladnazkay9lr8hkfa8s4d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lapdf")
    (synopsis "PDF drawing directly in TeX documents")
    (description
     "The package provides the means to use PDF drawing primitives to produce
high quality, colored graphics.  It uses Bezier curves (integral and rational)
from degree one to seven, allows TeX typesetting in the graphic, offers most
of the standard math functions, allows plotting normal, parametric and polar
functions.  The package has linear, logx, logy, logxy and polar grids with
many specs; it can rotate, clip and do many nice things easily it has two
looping commands for programming and many instructive example files.")
    (license license:gpl3+)))

(define-public texlive-latex-fonts
  (package
    (name "texlive-latex-fonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/latex-fonts/"
                                     "fonts/source/public/latex-fonts/"
                                     "fonts/tfm/public/latex-fonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bzqzzhs15w7dqz90hfjnaffjqh24q14w2h1h8vnxzvrlsyv21vq"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-cm")))
    (build-system texlive-build-system)
    (arguments (list #:texlive-latex-bin? #f))
    (native-inputs (list texlive-cm texlive-metafont))
    (home-page "https://ctan.org/pkg/latex-fonts")
    (synopsis "Collection of fonts used in LaTeX distributions")
    (description
     "This is a collection of fonts for use with standard LaTeX packages and
classes. It includes invisible fonts (for use with the slides class), line and
circle fonts (for use in the @code{picture} environment) and LaTeX symbol
fonts.")
    (license license:lppl1.2+)))

(define-deprecated-package texlive-fonts-latex texlive-latex-fonts)

(define-public texlive-latex-make
  (package
    (name "texlive-latex-make")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/latex-make/"
                                     "scripts/latex-make/"
                                     "source/support/latex-make/"
                                     "tex/latex/latex-make/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ll6v1mdi1m5fp3s0c4dkgh351lg9ckzdfwz3k488y6cbcvrpm5x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/latex-make")
    (synopsis "Easy compiling of complex (and simple) LaTeX documents")
    (description
     "This package provides several tools that aim to simplify the compilation
of LaTeX documents:

@itemize

@item @file{LaTeX.mk}: a Makefile snippet to help compiling LaTeX documents in
DVI, PDF, PS, ...  format.  Dependencies are automatically tracked: one should
be able to compile documents with a one-line Makefile containing @samp{include
LaTeX.mk}.  Complex documents (with multiple bibliographies, indexes,
glossaries, ...)  should be correctly managed.

@item @file{figlatex.sty}: a LaTeX package to easily insert Xfig figures.  It
can interact with LaTeX.mk so that the latter automatically invokes
@command{fig2dev} if needed.

@end itemize")
    (license license:gpl3+)))

(define-public texlive-latex-mr
  (package
    (name "texlive-latex-mr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latex-mr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zd948d9y63js7980g2bvxpf67hshh2xa3n2ihbzwhpw6l9cbh1w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latex-mr")
    (synopsis
     "Practical guide to LaTeX and Polyglossia for Marathi and other Indian
languages")
    (description
     "This document aims to introduce LaTeX and Polyglossia for Indian languages.
Though the document often discusses the language Marathi, the discussion
applies to other India languages also.  We assume that the user of this
document knows basic (La)TeX or has, at least, tried her hand on it.  This
document is not very suitable for first time users.")
    (license license:lppl1.3+)))

(define-public texlive-latexbangla
  (package
    (name "texlive-latexbangla")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latexbangla/"
                                     "tex/latex/latexbangla/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19h1axbfp1xclbhffdiczzqpr4lk2jw8kkz4qqh8f2rnhjxd94vw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latexbangla")
    (synopsis "Enhanced LaTeX integration for Bangla")
    (description
     "This package simplifies the process of writing Bangla in LaTeX and
addresses most of the associated typesetting issues.  Its notable features
are:

@itemize
@item automated transition from Bangla to English and vice versa;
@item patch for the unproportionate whitespace issue in popular Bangla fonts;
@item full support for all the common commands and environments;
@item Bangla numbering for page, section, chapter, footnotes, extending
Polyglossia's support.
@item new @code{theorem}, @code{problems}, @code{example}, @code{solution} and
other environments, all of which are in Bangla.
@end itemize")
    (license license:lppl1.3+)))

(define-public texlive-liftarm
  (package
    (name "texlive-liftarm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/liftarm/" "tex/latex/liftarm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dqi322kqlqbh4hli6nwm88nsg4dkr2fnrwi4i70gxyzxdh1mjj4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/liftarm")
    (synopsis "Draw liftarms")
    (description
     "This package can be used to draw liftarms with TikZ.  It provides
several options for the appearance of the liftarms, a command which connects
two liftarms and an environment to describe a construction.")
    (license license:lppl1.3+)))

(define-public texlive-lpic
  (package
    (name "texlive-lpic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lpic/" "tex/latex/lpic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15jzvpn3gnj5c0wachbsjazll9qlibyzxf4i2g8ad7l4yd967m3c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lpic")
    (synopsis "Put LaTeX material over included graphics")
    (description
     "The package defines a convenient interface to put any LaTeX material on
top of included graphics.  The LaTeX material may also be rotated and typeset
on top of a white box overshadowing the graphics.  The coordinates of the
LaTeX boxes are given relative to the original, unscaled graphics; when the
graphics is rescaled, the LaTeX annotations stay at their right places (unless
you do something extreme).  In a draft mode, the package enables you to draw
a coordinate grid over the picture for easy adjustment of positions of the
annotations.")
    (license license:lppl1.3+)))

(define-public texlive-lroundrect
  (package
    (name "texlive-lroundrect")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lroundrect/"
                                     "source/latex/lroundrect/"
                                     "tex/latex/lroundrect/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yjfg9z0s8drij13fdhii1r9j9i57c112iv2q0airndycm6y8wsg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lroundrect")
    (synopsis "LaTeX macros for using the @code{roundrect} MetaPost routines")
    (description
     "This LaTeX package provides ways to use the extremely configurable
rounded rectangles of the @code{roundrect} MetaPost package with LaTeX.  It is
chiefly useful for examples, but also has macros for particular types of boxes
which are useful on their own.")
    (license license:lppl1.3+)))

(define-public texlive-luamesh
  (package
    (name "texlive-luamesh")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luamesh/" "metapost/luamesh/"
                                     "scripts/luamesh/" "tex/lualatex/luamesh/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02qq6d51pihkxz4zbcxppikkzpr99mw8kmp64gm986fpcn6k2wns"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luamesh")
    (synopsis "Computes and draws 2D Delaunay triangulation")
    (description
     "The package computes and draws 2D Delaunay triangulation.
The algorithm is written with Lua, and depending upon the choice of the
engine, the drawing is done by MetaPost (with @code{luamplib}) or by TikZ.
The Delaunay triangulation algorithm is the Bowyer and Watson algorithm.
Several macros are provided to draw the global mesh, the set of points, or
a particular step of the algorithm.")
    (license license:lppl1.3+)))

(define-public texlive-luasseq
  (package
    (name "texlive-luasseq")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luasseq/" "scripts/luasseq/"
                                     "source/lualatex/luasseq/"
                                     "tex/lualatex/luasseq/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mkhzysyhpbblpwwy4d4983b5np23jnxl9ai986g0n1vpyv0kc47"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luasseq")
    (synopsis "Drawing spectral sequences in LuaLaTeX")
    (description
     "The package is an update of the author's @code{sseq} package, for use
with LuaLaTeX.  This version uses less memory, and operates faster than the
original; it also offers several enhancements.")
    (license license:lppl1.3+)))

(define-public texlive-maker
  (package
    (name "texlive-maker")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/maker/" "tex/latex/maker/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08shs5fah2yfdgsydk93jfb1sz42qckal2p031vs95vqd8rpq11g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/maker")
    (synopsis "Include Arduino or Processing code in LaTeX documents")
    (description
     "The first version of the package allows including Arduino or Processing
code using three different forms: writing the code directly in the LaTeX
document, writing Arduino or Processing commands in line with the text,
calling to Arduino or Processing files.  All these options support the syntax
highlighting of the official IDE.")
    (license license:lppl1.3c)))

(define-public texlive-makeshape
  (package
    (name "texlive-makeshape")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/makeshape/"
                                     "source/latex/makeshape/"
                                     "tex/latex/makeshape/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mc7qxqs87f87s4rzdd7fqy44sxc9a6imz62kqmigfap2kjwnflb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/makeshape")
    (synopsis "Declare new PGF shapes")
    (description
     "The package simplifies production of custom shapes with correct anchor
borders, in PGF/TikZ; the only requirement is a PGF path describing the anchor
border.  The package also provides macros that help with the management of
shape parameters, and the definition of anchor points.")
    (license license:lppl1.3+)))

(define-public texlive-mathspic
  (package
    (name "texlive-mathspic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mathspic/"
                                     "doc/man/man1/mathspic.1"
                                     "doc/man/man1/mathspic.man1.pdf"
                                     "scripts/mathspic/" "tex/latex/mathspic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rlcskfvpl4niv680v8fgfpfxkrhfavmm8431ffp3vjjbqrhv7xr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts #~(list "mathspic.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/mathspic")
    (synopsis "Perl filter program for use with PiCTeX")
    (description
     "MathsPIC (Perl) is a development of the earlier MathsPIC (DOS) program,
now implemented as a Perl script, being much more portable than the earlier
program.  MathsPIC parses a plain text input file and generates a plain text
output-file containing commands for drawing a diagram.  It produces output
containing PiCTeX and (La)TeX commands, which may then be processed by plain
TeX or LaTeX in the usual way.  MathsPIC also outputs a comprehensive log
file.  MathsPIC facilitates creating figures using PiCTeX by providing an
environment for manipulating named points and also allows the use of variables
and maths (advance, multiply, and divide)---in short---it takes the pain out
of PiCTeX.")
    (license license:lppl)))

(define-public texlive-mercatormap
  (package
    (name "texlive-mercatormap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mercatormap/"
                                     "tex/latex/mercatormap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11kcwzly8m8wqyppymanpvgabyjl1w33xzsy43sb5p4xv8fdaa5j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mercatormap")
    (synopsis
     "Spherical Mercator coordinate systems and Web Mercator tile integration")
    (description
     "This package extends TikZ with tools to create map graphics.  The
provided coordinate system relies on the Web Mercator projection used on the
Web by OpenStreetMap and others.  The package supports the seamless
integration of graphics from public map tile servers by a Python script.
Also, common map elements like markers, geodetic networks, bar scales, routes,
orthodrome pieces, and more are part of the package.")
    (license license:lppl1.3+)))

(define-public texlive-mflogo
  (package
    (name "texlive-mflogo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mflogo/"
                                     "fonts/source/public/mflogo/"
                                     "fonts/tfm/public/mflogo/"
                                     "source/latex/mflogo/"
                                     "tex/latex/mflogo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r53qlrcqfwc0dfr7ji1nxnqrj6n0qrlg1rl7fjlw6ap3q9y434k"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-knuth-lib")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-knuth-lib texlive-metafont))
    (home-page "https://ctan.org/pkg/mflogo")
    (synopsis "LaTeX support for Metafont logo fonts")
    (description
     "This package provides LaTeX and font definition files to access the
Knuthian mflogo fonts described in The Metafontbook and to typeset Metafont
logos in LaTeX documents.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-mflogo texlive-mflogo)

(define-public texlive-mflogo-font
  (package
    (name "texlive-mflogo-font")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/mflogo-font/"
                                     "fonts/afm/hoekwater/mflogo-font/"
                                     "fonts/map/dvips/mflogo-font/"
                                     "fonts/type1/hoekwater/mflogo-font/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "094mknjv8ki2pvj1zin0f1z4f1w12g0cfqjiqcsawjsry4yfrmbg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mflogo-font")
    (synopsis "METAFONT logo font")
    (description
     "These fonts were created in Metafont by Knuth, for his own publications.
At some stage, the letters P and S were added, so that the MetaPost logo could
also be expressed.  The fonts were originally issued (of course) as Metafont
source; they have since been autotraced and reissued in Adobe Type 1 format by
Taco Hoekwater.")
    (license license:knuth)))

(define-deprecated-package texlive-fonts-mflogo-font texlive-mflogo-font)

(define-public texlive-mfware
  (package
    (name "texlive-mfware")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/gftodvi.1"
                                     "doc/man/man1/gftodvi.man1.pdf"
                                     "doc/man/man1/gftopk.1"
                                     "doc/man/man1/gftopk.man1.pdf"
                                     "doc/man/man1/gftype.1"
                                     "doc/man/man1/gftype.man1.pdf"
                                     "doc/man/man1/mft.1"
                                     "doc/man/man1/mft.man1.pdf"
                                     "doc/man/man1/pktogf.1"
                                     "doc/man/man1/pktogf.man1.pdf"
                                     "doc/man/man1/pktype.1"
                                     "doc/man/man1/pktype.man1.pdf"
                                     "mft/base/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17y01wh22f0ah9vwwa9yanp1rvm24jkhwzv2rzwxsfxbyn73msxx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-mfware-bin))
    (home-page "https://ctan.org/pkg/mfware")
    (synopsis "Supporting tools for use with Metafont")
    (description
     "This package provides a collection of programs (as web source) for
processing the output of Metafont.")
    (license license:public-domain)))

(define-public texlive-mfware-bin
  (package
    (inherit texlive-bin)
    (name "texlive-mfware-bin")
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(delete "--enable-web2c" #$flags))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/web2c"
                  (let ((bin (string-append #$output "/bin"))
                        (files '("gftodvi" "gftopk" "gftype" "mft" "pktogf"
                                 "pktype")))
                    (for-each (lambda (f) (invoke "make" f)) files)
                    (for-each (lambda (f) (install-file f bin)) files)))))))))
    (native-inputs (list pkg-config))
    (home-page (package-home-page texlive-mfware))
    (synopsis "Binaries for @code{texlive-mfware}")
    (description
     "This package provides the binaries for @code{texlive-mfware}.")
    (license (package-license texlive-mfware))))

(define-public texlive-milsymb
  (package
    (name "texlive-milsymb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/milsymb/" "tex/latex/milsymb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0n0lba66mapk1b6k7gwr23acq2cg5i5258lc6n3l47x16wmcbvbd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/milsymb")
    (synopsis "TikZ-based drawing of military symbols")
    (description
     "The package offers commands to draw military symbols as per
@url{https://www.awl.edu.pl/images/en/APP_6_C.pdf, NATO APP-6(C)}.  It has
a set of commands for drawing all symbols found in the document up to the
control measures, as well as support for custom non-standard symbols.  Control
measures are planned to be included in a future release.")
    (license license:cc-by-sa4.0)))

(define-public texlive-miniplot
  (package
    (name "texlive-miniplot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/miniplot/" "tex/latex/miniplot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k98mfd4bf43br74wyjqjlwb93yzi2b5r53jsrsr58p6lg59c200"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/miniplot")
    (synopsis "Package for easy figure arrangement")
    (description
     "MiniPlot is a package to help the LaTeX user typeset EPS figures using
an easy-to-use interface.  Figures can be arranged as one-figure-only or as
a collection of figures in columns and rows which can itself contain
sub-figures in columns and rows.  Wrapped figures are also supported.  This
package provides commands to display a framebox instead of the figure as the
graphics package does already but additionally it writes useful information
such as the label and scaling factor into these boxes.")
    (license license:lppl)))

(define-public texlive-mkpic
  (package
    (name "texlive-mkpic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/mkpic/" "scripts/mkpic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a8jzsgw63siirifpsvwjmfbj68fv58hnn5vrv737i9vbjrv0vm7"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "mkpic")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/mkpic")
    (synopsis "Perl interface to @code{mfpic}")
    (description
     "@code{mkpic} provides an easy interface for making small pictures with
@code{mfpic}.  To this end you create an input file consisting of commands,
one per line, with space separated parameters (or you modify the DATA section
of the @code{mkpic} script, which is used if you run it without an input
file).")
    (license license:gpl3+)))

(define-public texlive-modiagram
  (package
    (name "texlive-modiagram")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/modiagram/"
                                     "tex/latex/modiagram/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0817c3yj5q4srbl29kqw16cg3c6gwr9ahy33hyicqbqap034fnyd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/modiagram")
    (synopsis "Drawing molecular orbital diagrams")
    (description
     "The package provides an environment MOdiagram and some commands, to
create molecular orbital diagrams using TikZ.")
    (license license:lppl1.3c)))

(define-public texlive-neuralnetwork
  (package
    (name "texlive-neuralnetwork")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/neuralnetwork/examples/"
                                     "tex/latex/neuralnetwork/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11k0hwg1mx52mrp7csp93m4rvv22vq91l4ij1ylgbw9flh189p8x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/neuralnetwork")
    (synopsis "Graph-drawing for neural networks")
    (description
     "The package provides facilities for graph-drawing, with facilities
designed for neural network diagrams.")
    (license license:gpl3+)))

(define-public texlive-nl-interval
  (package
    (name "texlive-nl-interval")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nl-interval/"
                                     "tex/latex/nl-interval/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0n11a26d48jr6lngfc128fpvahdnbvnlxz9kxp7hirl0cm8ssiwa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nl-interval")
    (synopsis "Represent intervals on the number line")
    (description
     "This package provides macros to simplify the process of representing
intervals on the number line.")
    (license license:lppl1.3c)))

(define-public texlive-nndraw
  (package
    (name "texlive-nndraw")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nndraw/" "source/latex/nndraw/"
                                     "tex/latex/nndraw/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08mhl61b2fzsnfz6ldrlz9m5s37w2c4wml8gpd2f4wc9rjag68l4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nndraw")
    (synopsis "Draw neural networks")
    (description
     "With this package you can create fully connected neural networks in
a simple and efficient way.")
    (license license:lppl1.3+)))

(define-public texlive-numericplots
  (package
    (name "texlive-numericplots")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/numericplots/"
                                     "tex/latex/numericplots/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "187h4q35s2asfgv9zxw992316v37p5nnvphjylnxfvygxci36lwg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/numericplots")
    (synopsis "Plot numeric data (including Matlab export) using PSTricks")
    (description
     "Plotting numeric data is a task which has often to be done for
scientific papers.  LaTeX itself provides no facilities for drawing more than
the simplest plots from supplied data.  The package will process user input,
and uses PSTricks to plot the results.  The package provides Matlab functions
to transform Matlab results to plottable data.")
    (license license:gpl3)))

(define-public texlive-outilsgeomtikz
  (package
    (name "texlive-outilsgeomtikz")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/outilsgeomtikz/"
                                     "tex/latex/outilsgeomtikz/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sds34i59x4wvqn6x9bcln8wdzs29z4bw6bvlj36jvj6hgx4hx95"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/outilsgeomtikz")
    (synopsis "Some geometric tools, with TikZ")
    (description
     "This package provides some commands, with French keys, to display
geometric tools using TikZ, for example a pen, a compass, a rule, a square, or
a protractor.")
    (license license:lppl1.3c)))

(define-public texlive-pb-diagram
  (package
    (name "texlive-pb-diagram")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pb-diagram/"
                                     "tex/latex/pb-diagram/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g790ykz0xq01d8zmy6llr33imh42dy51700c9z49xga4dvnyqlv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pb-diagram")
    (synopsis "Commutative diagram package using LAMSTeX or Xy-pic fonts")
    (description
     "The package provides a @code{diagram} environment.  This allows the
LaTeX user to easily create complex commutative diagrams, by placing formula
nodes on a conceptual grid and attaching arrows to them.")
    (license license:gpl2+)))

(define-public texlive-pbibtex-base
  (package
    (name "texlive-pbibtex-base")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/ptex/pbibtex/" "pbibtex/bib/"
                                     "pbibtex/bst/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06glwwv1rw4n5cpg6cs70yzgyix65nhfsakyq72sn82yss1gvf8z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pbibtex-base")
    (synopsis "Bibliography styles and miscellaneous files for pBibTeX")
    (description
     "These are miscellaneous files, including bibliography
styles (@file{.bst}), for pBibTeX, which is a Japanese extended version of
BibTeX contained in TeX Live.")
    (license license:bsd-3)))

(define-public texlive-pbibtex-manual
  (package
    (name "texlive-pbibtex-manual")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pbibtex-manual/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "030rhhb4xcijvjc0x1ylyk6xz5mn90wrlp5ss4yr6qlpzmq21b50"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pbibtex-manual")
    (synopsis "Documentation files for (u)pBibTeX")
    (description
     "The bundle contains documentation files for Japanese pBibTeX and
upBibTeX.  For historical reasons, this also contains old documentation files
for JBibTeX.")
    (license license:bsd-3)))

(define-public texlive-petri-nets
  (package
    (name "texlive-petri-nets")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/petri-nets/"
                                     "scripts/petri-nets/"
                                     "tex/generic/petri-nets/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m6qmahbw1q5vs63mr30kf75di86drhi8z3a8p7yn9n524jn435c"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "pn2pdf")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/petri-nets")
    (synopsis "Set TeX/LaTeX packages for drawing Petri nets")
    (description
     "Petri-nets offers a set of TeX/LaTeX packages about Petri nets and
related models.  Three packages are available: the first allows the user to
draw Petri-nets in PostScript documents; the second defines macros related to
PBC, M-nets and B(PN) models; and a third that combines the other two.")
    (license license:gpl3+)))

(define-public texlive-pgf-blur
  (package
    (name "texlive-pgf-blur")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pgf-blur/"
                                     "source/latex/pgf-blur/"
                                     "tex/latex/pgf-blur/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lsndflhx56gawqkcyjyh8pll986m7msraq5qr1asppybf4m0hij"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pgf-blur")
    (synopsis "PGF/TikZ package for blurred shadows")
    (description
     "The package adds blurred/faded/fuzzy shadows to PGF/TikZ pictures.
It is configured as a TikZ/PGF library module.")
    (license (list license:lppl license:public-domain))))

(define-public texlive-pgf-interference
  (package
    (name "texlive-pgf-interference")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pgf-interference/"
                                     "tex/latex/pgf-interference/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1aa741h358iwn0zd25y3wsr4mr1q2fia1mrfqrbz6p00fvv0rgv5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pgf-interference")
    (synopsis "Drawing interference patterns with PGF/TikZ")
    (description
     "This LaTeX package makes it possible to simulate interference patterns
occurring on a screen if monochromatic light is diffracted at regular
structures of slits.")
    (license license:lppl1.3+)))

(define-public texlive-pgf-periodictable
  (package
    (name "texlive-pgf-periodictable")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pgf-periodictable/"
                                     "tex/latex/pgf-periodictable/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pdp3zx3b5rq2qz2fdl6dk192lk8bnxwrv9kng9x8q13740j4jc9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pgf-periodictable")
    (synopsis "Create custom periodic tables of elements")
    (description
     "The purpose of this package is to provide the periodic table of elements
in a simple way.  It relies on PGF/TikZ to offer a full or partial periodic
table with a variety of options and displaying the desired data for all the
118 elements.")
    (license license:lppl1.3+)))

(define-public texlive-pgf-pie
  (package
    (name "texlive-pgf-pie")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pgf-pie/" "tex/latex/pgf-pie/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nvg61v9pzc0mqs8m818ixi8rmw2wv3h7s17shjc7mcdqkp7k1qq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-carlisle texlive-latex texlive-pgf))
    (home-page "https://ctan.org/pkg/pgf-pie")
    (synopsis "Draw pie charts, using PGF")
    (description
     "The package provides the means to draw pie (and variant) charts,
using PGF/TikZ.")
    (license (list license:gpl2 license:lppl1.3c))))

(define-public texlive-pgf-soroban
  (package
    (name "texlive-pgf-soroban")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pgf-soroban/"
                                     "tex/latex/pgf-soroban/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vcycmd5a3z6p9glbgw4lsxs0zv0lidvs240i18kv8s39yx6f88r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pgf-soroban")
    (synopsis "Create images of the soroban using TikZ/PGF")
    (description
     "The package makes it possible to create pictures of the
soroban (Japanese abacus) using PGF/TikZ.")
    (license license:lppl)))

(define-public texlive-pgf-spectra
  (package
    (name "texlive-pgf-spectra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pgf-spectra/"
                                     "tex/latex/pgf-spectra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "131rr4hbychlk1bphhak2i21ajvp4v2fvlw48ak7plmqb5gz81df"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pgf-spectra")
    (synopsis "Draw continuous or discrete spectra using PGF/TikZ")
    (description
     "The purpose of this package is to draw the spectra of elements in
a simple way.  It relies on PGF/TikZ for drawing the desired spectrum,
continuous or discrete.  There are data available for the spectra of 98
elements and their ions (from the NASA database and from NIST).  It also
allows the user to draw spectra using their own data.")
    (license license:lppl1.3+)))

(define-public texlive-pgf-umlcd
  (package
    (name "texlive-pgf-umlcd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pgf-umlcd/"
                                     "tex/latex/pgf-umlcd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14zx2jms616qfzwqbgixz0pd3qzjzr2bxr6ahhy7mgj3i7rlbr8r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-latex texlive-pgf))
    (home-page "https://ctan.org/pkg/pgf-umlcd")
    (synopsis "Some LaTeX macros for UML class diagrams")
    (description
     "This package provides some LaTeX macros for UML class diagrams.")
    (license (list license:gpl2 license:lppl1.3c))))

(define-public texlive-pgf-umlsd
  (package
    (name "texlive-pgf-umlsd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pgf-umlsd/"
                                     "tex/latex/pgf-umlsd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bw23gm9x6ijhn3h0q7af0n9wxnc3ixfjc23v8x49s80gh96gmqg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-latex texlive-pgf))
    (home-page "https://ctan.org/pkg/pgf-umlsd")
    (synopsis "Draw UML sequence diagrams")
    (description
     "This package provides LaTeX macros to draw UML diagrams using PGF.")
    (license license:gpl3+)))

(define-public texlive-pgfkeyx
  (package
    (name "texlive-pgfkeyx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pgfkeyx/" "tex/latex/pgfkeyx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0g5wvhlyfplv0fd0nsxpw3al9wmk0hw0pjvyyplh1vzdk5rr3xzq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pgfkeyx")
    (synopsis "Extended and more robust version of @code{pgfkeys}")
    (description
     "The package extends and improves the robustness of the @code{pgfkeys}
package.  In particular, it can deal with active comma, equality sign, and
slash in key parsing.  The difficulty with active characters has long been
a problem with the @code{pgfkeys} package.  The package also introduces
handlers beyond those that @code{pgfkeys} can offer.")
    (license license:lppl1.3+)))

(define-public texlive-pgfmolbio
  (package
    (name "texlive-pgfmolbio")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/pgfmolbio/"
                                     "scripts/pgfmolbio/"
                                     "source/lualatex/pgfmolbio/"
                                     "tex/lualatex/pgfmolbio/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12kajg7jrhd612lk7m6gwadxb5y7v9znqjlg1n3n05zwrmfd54w1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pgfmolbio")
    (synopsis "Draw graphs typically found in molecular biology texts")
    (description
     "The package draws graphs typically found in molecular biology texts.
Currently, the package contains modules for drawing DNA sequencing
chromatograms and protein domain diagrams.")
    (license license:lppl1.3+)))

(define-public texlive-pgfmorepages
  (package
    (name "texlive-pgfmorepages")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pgfmorepages/"
                                     "tex/latex/pgfmorepages/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k0njkw34ql0vlpmay155rr4v0sszizhh1pixy20npbk26dkzljw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pgfmorepages")
    (synopsis "Assemble multiple logical pages onto a physical page")
    (description
     "This package replaces and extends the @code{pgfpages} sub-package of the
PGF system.  It provides the capability to arrange multiple logical pages on
multiple physical pages, for example as for arranging pages to make
booklets.")
    (license license:lppl1.3c)))

(define-public texlive-pgfopts
  (package
    (name "texlive-pgfopts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pgfopts/" "source/latex/pgfopts/"
                                     "tex/latex/pgfopts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0p4bfqgkwmzhismrs7a10sblbgx4b6w259vdp1dd3hxvhc2kbnyn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-pgf))
    (home-page "https://ctan.org/pkg/pgfopts")
    (synopsis "LaTeX package options with @code{pgfkeys}")
    (description
     "The @code{pgfkeys} package (part of the PGF distribution) is a way of
defining and using large numbers of keys for key-value syntaxes.  However,
@code{pgfkeys} itself does not offer means of handling LaTeX class and package
options.  This package adds such option handling to @code{pgfkeys}, in the
same way that @code{kvoptions} adds the same facility to the LaTeX standard
@code{keyval} package.")
    (license license:lppl1.3+)))

(define-public texlive-pgfornament
  (package
    (name "texlive-pgfornament")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pgfornament/"
                                     "tex/generic/pgfornament/am/"
                                     "tex/generic/pgfornament/pgfhan/"
                                     "tex/generic/pgfornament/vectorian/"
                                     "tex/latex/pgfornament/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02fmyyp1hgasa8k6v0nkdvdmqfbiscyyk3hpqg63b5956ksgap21"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pgfornament")
    (synopsis "Drawing of vectorian ornaments with PGF/TikZ")
    (description
     "This package allows the drawing of vectorian ornaments (196) with
PGF/TikZ.")
    (license license:lppl1.3+)))

(define-public texlive-pgfornament-han
  (package
    (name "texlive-pgfornament-han")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pgfornament-han/"
                                     "tex/latex/pgfornament-han/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c16wbykv6dyqv3d4gvy6fwqzww0fkg605vwb74mvc63a7n3jqxl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pgfornament-han")
    (synopsis "Library for Chinese traditional motifs and patterns")
    (description
     "This package provides a @code{pgfornament} library for Chinese
traditional motifs and patterns.  The command @code{\\pgfornamenthan} takes
the same options as @code{\\pgfornament} from the @code{pgfornament} package,
but renders Chinese traditional motifs instead.")
    (license license:lppl1.3c)))

(define-public texlive-pgfplots
  (package
    (name "texlive-pgfplots")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/context/third/pgfplots/"
                                     "doc/generic/pgfplots/"
                                     "doc/latex/pgfplots/"
                                     "doc/plain/pgfplots/"
                                     "scripts/pgfplots/"
                                     "source/context/third/pgfplots/"
                                     "source/latex/pgfplots/"
                                     "tex/context/third/pgfplots/"
                                     "tex/generic/pgfplots/"
                                     "tex/latex/pgfplots/"
                                     "tex/plain/pgfplots/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c0gah7ia61s435zlyq4ay9snkrs2xcs627wky7c0sp8mgxyybwr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-pgf))
    (home-page "https://ctan.org/pkg/pgfplots")
    (synopsis "Create normal/logarithmic plots in two and three dimensions")
    (description
     "PGFPlots draws high-quality function plots in normal or logarithmic
scaling with a user-friendly interface directly in TeX.  The user supplies
axis labels, legend entries and the plot coordinates for one or more plots and
PGFPlots applies axis scaling, computes any logarithms and axis ticks and
draws the plots, supporting line plots, scatter plots, piecewise constant
plots, bar plots, area plots, mesh-- and surface plots and some more.
PGFPlots is based on PGF/TikZ (PGF); it runs equally for LaTeX/TeX/ConTeXt.")
    (license license:gpl3+)))

(define-public texlive-picinpar
  (package
    (name "texlive-picinpar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/picinpar/" "tex/latex/picinpar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1s6ymq4zg0wl6pfx34shansv3y1qlh6h3q58a97zpz5x21n1a5pq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/picinpar")
    (synopsis "Insert pictures into paragraphs")
    (description
     "This package provides a legacy package for creating windows in
paragraphs, for inserting graphics, etc.  Users should note that Pieter van
Oostrum (in a published review of packages of this sort) does not recommend
this package; Picins is recommended instead.")
    (license license:gpl3+)))

(define-public texlive-pictex
  (package
    (name "texlive-pictex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pictex/" "tex/generic/pictex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wwlh9d7b3gsk3f29d6vk0ic7nnvc533jfg2z019vsf6pin9qvgv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pictex")
    (synopsis "Picture drawing macros for TeX and LaTeX")
    (description
     "PicTeX is an early and very comprehensive drawing package that mostly
draws by placing myriads of small dots to make up pictures.  It has a tendency
to run out of space; packages @code{m-pictex} and @code{pictexwd} deal with
the problems in different ways.")
    (license license:lppl1.0+)))

(define-public texlive-pictex2
  (package
    (name "texlive-pictex2")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/latex/pictex2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qqf08yharknq6csk01jdff62mg011bryqlq5mbmjwqwh7wxs0wy"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pictex2")
    (synopsis "Adds relative coordinates and improves the @code{\\plot} command")
    (description
     "This package adds two user commands to standard PiCTeX.  One command
uses relative coordinates, thus eliminating the need to calculate the
coordinate of every point manually as in standard PiCTeX.  The other command
modifies @code{\\plot} to use a rule instead of dots if the line segment is
horizontal or vertical.")
    (license license:lppl)))

(define-public texlive-pictexsum
  (package
    (name "texlive-pictexsum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pictexsum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00yd0945qiss5jizkxncg8a9bdsld7mkhaipi92bbn1ghqicsw5a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pictexsum")
    (synopsis "Summary of PicTeX commands")
    (description
     "The document summarises the commands of PicTeX.  While it is no
substitute for the PicTeX manual itself, the document is a useful aide-memoire
for those who have read the manual.")
    (license license:bsd-2)))

(define-public texlive-pinlabel
  (package
    (name "texlive-pinlabel")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pinlabel/" "tex/latex/pinlabel/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hfa6gdmc6f59840fia3pdll2bgjwyqk57plcqxb4vc0f7kdqqay"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pinlabel")
    (synopsis "TeX labelling package")
    (description
     "Pinlabel is a labelling package for attaching perfectly formatted TeX
labels to figures and diagrams in both EPS and PDF formats.  It is suitable
both for labelling a new diagram and for relabelling an existing diagram.  The
package uses coordinates derived from GhostView and labels are placed with
automatic and consistent spacing relative to the object labelled.")
    (license license:lppl)))

(define-public texlive-pixelart
  (package
    (name "texlive-pixelart")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pixelart/" "tex/latex/pixelart/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14hridmq92md46vxaiv8ja5lij2zl449vbvq2x2dv4qqs7bi42ab"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pixelart")
    (synopsis "Draw pixel-art pictures")
    (description
     "This package provides a LuaLaTeX package to draw pixel-art pictures
using TikZ.")
    (license license:lppl1.3+)))

(define-public texlive-pixelarttikz
  (package
    (name "texlive-pixelarttikz")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pixelarttikz/"
                                     "tex/latex/pixelarttikz/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13v5qdij5wngqh9flv2amxnh5l3qa4vxvv5ayc1m26vvmy1j7xw8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pixelarttikz")
    (synopsis "Work with PixelArts, with TikZ")
    (description
     "The package defines commands and an environment for displaying pixel
arts.")
    (license license:lppl1.3c)))

(define-public texlive-plain-doc
  (package
    (name "texlive-plain-doc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/plain-doc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "062d6hg4npy57307avvyd2sdxnmyrh5ia2rdb17p6cx555k8zxwq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/csname-doc")
    (synopsis "List of Plain TeX control sequence names")
    (description
     "The document constitutes a list of every control sequence
name (@dfn{csname}) described in the TeXbook, together with an indication of
whether the csname is a primitive TeX command, or is defined in
@file{plain.tex}.")
    (license license:public-domain)))

(define-public texlive-pmgraph
  (package
    (name "texlive-pmgraph")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pmgraph/" "tex/latex/pmgraph/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a4nd6c9i9y6g34ipjz2ia0m4vizlvx0wcn0yql53pk8k8zrlgnn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pmgraph")
    (synopsis "Poor man's graphics")
    (description
     "This package provides a set of extensions to LaTeX @code{picture}
environment, including a wider range of vectors, and a lot more box frame
styles.")
    (license license:gpl3+)))

(define-public texlive-postage
  (package
    (name "texlive-postage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/postage/" "source/latex/postage/"
                                     "tex/latex/postage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sa9fm5hh57p0srnrd98jljj6200hnl17pmhw2v5q7jjgqj1n5gq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/postage")
    (synopsis "Stamp letters with Deutsche Post's service Internetmarke")
    (description
     "The postage package is used for franking letters with Deutsche Post's
online postage service Internetmarke.  Note that in order to print valid
stamps you must point to a valid PDF of Deutsche Post's Ausdruck
4-spaltig (DIN A4).")
    (license license:lppl1.3c)))

(define-public texlive-prerex
  (package
    (name "texlive-prerex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/prerex/" "doc/man/man5/prerex.5"
                                     "doc/man/man5/prerex.man5.pdf"
                                     "tex/latex/prerex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cmkr8533p4lqnj9x7nlcqj0slin021y13mr4mx2hvd35ya0dd80"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "readline")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:tests? #true
      #:modules '((guix build texlive-build-system)
                  ((guix build gnu-build-system) #:prefix gnu:)
                  (guix build utils)
                  (srfi srfi-1))
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'unpack-prerex-source
            (lambda _
              (mkdir-p "build")
              (with-directory-excursion "build"
                (invoke "tar" "xvf"
                        ;; Tarball includes a version number that we ignore.
                        (first (find-files ".." "^prerex-.*\\.tar.gz"))
                        "--strip-components=1"))))
          (add-after 'unpack-prerex-source 'build-prerex
            (lambda args
              (with-directory-excursion "build"
                (for-each (lambda (phase)
                            (apply (assoc-ref gnu:%standard-phases phase) args))
                          '(configure build check install))))))))
    (native-inputs (list readline))
    (home-page "https://ctan.org/pkg/prerex")
    (synopsis "Interactive editor and macro support for prerequisite charts")
    (description
     "This package consists of @file{prerex.sty}, a LaTeX package for
producing charts of course nodes linked by arrows representing pre- and
co-requisites, and @command{prerex}, an interactive program for creating and
editing chart descriptions.  The implementation of @file{prerex.sty} uses PGF,
so that it may be used equally happily with LaTeX or PDFLaTeX; @code{prerex}
itself is written in C.  The package includes source code for a previewer
application, a lightweight Qt-4 and Poppler-based prerex-enabled PDF viewer.")
    (license (list license:gpl2 license:lppl))))

(define-public texlive-productbox
  (package
    (name "texlive-productbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/productbox/"
                                     "source/latex/productbox/"
                                     "tex/latex/productbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12jj5am2h6lqmhc0dz9v8p2j9ci104s9xplki7ncn3fmhy5mm2fq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/productbox")
    (synopsis "Typeset a three-dimensional product box")
    (description
     "The package enables typesetting of a three-dimensional product box.
This product box can be rendered as it is standing on a surface and some light
is shed onto it.  Alternatively it can be typeset as a wireframe to be cut out
and glued together.  This will lead to a physical product box.")
    (license
     (list
      (license:fsf-free "https://tug.ctan.org/macros/latex/contrib/gene/productbox/productbox.ins")))))

(define-public texlive-ps2eps
  (package
    (name "texlive-ps2eps")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/bbox.1"
                                     "doc/man/man1/bbox.man1.pdf"
                                     "doc/man/man1/ps2eps.1"
                                     "doc/man/man1/ps2eps.man1.pdf"
                                     "scripts/ps2eps/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1anrvgs0hd3790dwpxqal0c2drjmvh93vnyqap40rvp8axwi0a6n"))))
    (outputs '("out" "doc"))
    (properties '((updater-ignored-inputs "perl"))) ;in "-bin" already
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-ps2eps-bin))
    (home-page "https://ctan.org/pkg/ps2eps")
    (synopsis "Produce Encapsulated PostScript from PostScript")
    (description
     "@command{ps2eps} produces Encapsulated PostScript Files (EPS/EPSF) from
a one-page PostScript document, or any PostScript document.  A correct
bounding box is calculated for the EPS files and some PostScript command
sequences that can produce erroneous results on printers are filtered.  The
input is cropped to include just the image contained in the PostScript file.
The EPS files can then be included into TeX documents.

Included in the distribution is the @command{bbox} program, an application to
produce bounding box values for Rawppm or Rawpbm format files.")
    (license license:gpl3+)))

(define-public texlive-ps2eps-bin
  (package
    (inherit texlive-bin)
    (name "texlive-ps2eps-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '("ps2eps"))
            (delete-other-directories "texk" '())))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-ps2eps" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (add-after 'unpack 'configure-ghostscript-executable
              ;; ps2eps.pl uses the "gswin32c" ghostscript executable on
              ;; Windows, and the "gs" ghostscript executable on Unix.  It
              ;; detects Unix by checking for the existence of the "/usr/bin"
              ;; directory.  Since Guix System does not have "/usr/bin", it is
              ;; also detected as a Windows system :(.
              (lambda _
                (substitute* "utils/ps2eps/ps2eps-src/bin/ps2eps.pl"
                  (("gswin32c") "gs"))))
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "utils/ps2eps"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "utils/ps2eps"
                  (invoke "make" "install"))))))))
    (native-inputs '())
    (inputs (list perl))
    (propagated-inputs '())
    (home-page (package-home-page texlive-ps2eps))
    (synopsis "Binaries for @code{texlive-ps2eps}")
    (description
     "This package provides the binaries for @code{texlive-ps2eps}.")
    (license (package-license texlive-ps2eps))))

(define-public texlive-ps2pk
  (package
    (name "texlive-ps2pk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/mag.1"
                                     "doc/man/man1/mag.man1.pdf"
                                     "doc/man/man1/pfb2pfa.1"
                                     "doc/man/man1/pfb2pfa.man1.pdf"
                                     "doc/man/man1/pk2bm.1"
                                     "doc/man/man1/pk2bm.man1.pdf"
                                     "doc/man/man1/ps2pk.1"
                                     "doc/man/man1/ps2pk.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14xq9x5rf15ibzr41cm5rm4v3rpmj50rfsqp4zzvyhmpmyw4dsx3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-ps2pk-bin))
    (home-page "https://ctan.org/pkg/ps2pk")
    (synopsis "Generate a PK font from an Adobe Type 1 font")
    (description
     "This package provides tools to generate a PK file from an Adobe Type
1 font.  PK fonts are (or used to be) valuable in enabling previewers to view
documents generated that use Type 1 fonts.")
    (license license:isc)))

(define-public texlive-ps2pk-bin
  (package
    (inherit texlive-bin)
    (name "texlive-ps2pk-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("ps2pk"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-ps2pk" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/ps2pk"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/ps2pk"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list texlive-libkpathsea))
    (propagated-inputs '())
    (home-page (package-home-page texlive-ps2pk))
    (synopsis "Binaries for @code{texlive-ps2pk}")
    (description
     "This package provides the binaries for @code{texlive-ps2pk}.")
    (license (package-license texlive-ps2pk))))

(define-public texlive-psutils
  (package
    (name "texlive-psutils")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/epsffit.1"
                                     "doc/man/man1/epsffit.man1.pdf"
                                     "doc/man/man1/extractres.1"
                                     "doc/man/man1/extractres.man1.pdf"
                                     "doc/man/man1/includeres.1"
                                     "doc/man/man1/includeres.man1.pdf"
                                     "doc/man/man1/psbook.1"
                                     "doc/man/man1/psbook.man1.pdf"
                                     "doc/man/man1/psjoin.1"
                                     "doc/man/man1/psjoin.man1.pdf"
                                     "doc/man/man1/psnup.1"
                                     "doc/man/man1/psnup.man1.pdf"
                                     "doc/man/man1/psresize.1"
                                     "doc/man/man1/psresize.man1.pdf"
                                     "doc/man/man1/psselect.1"
                                     "doc/man/man1/psselect.man1.pdf"
                                     "doc/man/man1/pstops.1"
                                     "doc/man/man1/pstops.man1.pdf"
                                     "doc/man/man1/psutils.1"
                                     "doc/man/man1/psutils.man1.pdf"
                                     "dvips/getafm/"
                                     "psutils/"
                                     "scripts/psutils/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ba514lz3pc03ll0kb9apdx62mi2yiyd7bnargkp2bbf62dq79cc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (properties '((updater-ignored-inputs "perl"))) ;in "-bin" already
    (propagated-inputs (list texlive-psutils-bin))
    (home-page "https://ctan.org/pkg/psutils")
    (synopsis "PostScript utilities")
    (description
     "This package provides a bundle of utilities for manipulating PostScript
documents, including page selection and rearrangement, resizing the page,
arrangement into signatures for booklet printing, and page merging for N-up
printing.  Utilities include @command{psbook}, @command{psselect},
@command{pstops}, @command{psnup}, @command{psresize}, @command{epsffit}.")
    (license
     (list license:lgpl2.1+
           (license:fsf-free
            "https://tug.org/svn/texlive/trunk/Build/source/texk/psutils/psutils-src/LICENSE?revision=57915&view=markup")))))

(define-public texlive-psutils-bin
  (package
    (inherit texlive-bin)
    (name "texlive-psutils-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root keep)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir
                       "."
                       (lambda (file)
                         (and (not (member file (append keep '("." ".."))))
                              (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("psutils"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-psutils" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (add-after 'unpack 'patch-psutils-tests
              (lambda _
                ;; This test fails due to a rounding difference with libpaper
                ;; 1.2: <https://github.com/rrthomas/libpaper/issues/23>.
                ;;
                ;; Adjust the expected outcome to account for the minute
                ;; difference.
                (substitute* "texk/psutils/tests/playres.ps"
                  (("844\\.647799") "844.647797"))
                ;; Test suite also fails because it expects to find
                ;; "texmf.cnf" in "../kpathsea/" directory, but we removed it
                ;; in a snippet.  Point to the real "texmf.cnf".
                (let ((kpathsea #$(this-package-input "texlive-libkpathsea")))
                  (substitute* "texk/psutils/psutils.test"
                    (("(TEXMFCNF=).+?;" _ var)
                     (string-append var
                                    kpathsea
                                    "/share/texmf-dist/web2c;"))))))
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/psutils"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/psutils"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list libpaper perl texlive-libkpathsea))
    (propagated-inputs '())
    (synopsis "Binaries for @code{texlive-psutils}")
    (description
     "This package provides the binaries for @code{texlive-psutils}.")
    (license (package-license texlive-psutils))))

(define-public texlive-ptolemaicastronomy
  (package
    (name "texlive-ptolemaicastronomy")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ptolemaicastronomy/"
                                     "source/latex/ptolemaicastronomy/"
                                     "tex/latex/ptolemaicastronomy/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05j082s8aj57lzbxlhddi7f6gscpl5j66zmmaj6kabpnv152r0l7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ptolemaicastronomy")
    (synopsis "Diagrams of sphere models for variably strict conditionals")
    (description
     "David K. Lewis (Counterfactuals, Blackwell 1973) introduced a sphere
semantics for counterfactual conditionals.  He jokingly referred to the
diagrams depicting such sphere models as Ptolemaic astronomy, hence the name
of this package.  The macros provided in this package aid in the construction
of sphere model diagrams in the style of Lewis.")
    (license license:lppl1.3c)))

(define-public texlive-puyotikz
  (package
    (name "texlive-puyotikz")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/puyotikz/" "scripts/puyotikz/"
                                     "tex/latex/puyotikz/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15vw485phk523kby1q1wn0s0f7185cqj7sjsr8hc6iccdbzwknc0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/puyotikz")
    (synopsis "Quickly typeset board states of Puyo Puyo games")
    (description
     "This LaTeX package permits quickly typesetting board states of Puyo Puyo
games.  It supports large and small boards with arbitrary shape, hidden rows,
current and next puyos, labels and move planning markers.")
    (license license:expat)))

(define-public texlive-pxpgfmark
  (package
    (name "texlive-pxpgfmark")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pxpgfmark/"
                                     "tex/latex/pxpgfmark/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c026i1bda0fxfrjhpv4laaj75ra6j8l2v6bxsgplng7f11nx36l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pxpgfmark")
    (synopsis "e-pTeX driver for PGF inter-picture connections")
    (description
     "The distributed drivers do not support the PGF feature of inter-picture
connections under e-pTeX and @code{dvipdfmx}.  The package uses existing
features of @code{dvipdfmx} to fix this problem.")
    (license license:expat)))

(define-public texlive-pxpic
  (package
    (name "texlive-pxpic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pxpic/" "source/latex/pxpic/"
                                     "tex/latex/pxpic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03qn6r503sd9sskp9fl1qxmkjwigg01mx4wqzgjdf6824sk2ckg9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pxpic")
    (synopsis "Draw pixel pictures")
    (description
     "With @code{pxpic} you draw pictures pixel by pixel.  It was inspired by
a lovely post by Paulo Cereda, among other things (most notably a beautiful
duck) showcasing the use of characters from the Mario video games by Nintendo
in LaTeX.")
    (license license:lppl1.3c)))

(define-public texlive-pxtatescale
  (package
    (name "texlive-pxtatescale")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pxtatescale/"
                                     "tex/latex/pxtatescale/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1f9xm6nc9h6r2n5rsz6iw4m1x8r13anisv08j5hkidcyvj6n2s6n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pxtatescale")
    (synopsis
     "Patch to graphics driver for scaling in vertical direction of pTeX")
    (description
     "This package patches graphics driver @code{dvipdfmx} to support correct
scaling in vertical direction of Japanese pTeX and upTeX.")
    (license license:expat)))

(define-public texlive-qcircuit
  (package
    (name "texlive-qcircuit")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/qcircuit/" "tex/latex/qcircuit/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gyygba4zv6ncbwailjh9fvwn95d4ckrn2vj2ja089drr0sd8zkq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/qcircuit")
    (synopsis "Macros to generate quantum circuits")
    (description
     "The package supports those within the quantum information community who
typeset quantum circuits, using @code{xy-pic} package, offering macros
designed to help users generate circuits.")
    (license license:gpl2)))

(define-public texlive-quantikz
  (package
    (name "texlive-quantikz")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/quantikz/" "tex/latex/quantikz/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14qscaw959x93cmjzshcxk2xwypdyqcczqg924ksfwz52x3qgxs3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/quantikz")
    (synopsis "Draw quantum circuit diagrams")
    (description
     "The purpose of this package is to extend TikZ with the functionality for
drawing quantum circuit diagrams.")
    (license license:cc-by4.0)))

(define-public texlive-quran
  (package
    (name "texlive-quran")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/quran/" "tex/latex/quran/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14vi3l8h0jzv9x2rarpnqw7axcvcn3hn0xn3zpjnzc6h03534zif"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/quran")
    (synopsis "Easy way to typeset any part of the @emph{Holy Quran}")
    (description
     "This package offers the user an easy way to typeset the @emph{Holy
Quran}.  It provides several macros for typesetting the whole or any part of
the Quran based on its popular division, including @emph{Surah}, @emph{Ayah},
@emph{Juz}, @emph{Hizb}, @emph{Quarter}, and @emph{Page}.  Besides the Arabic
original, translations to English, German, French, and Persian are provided,
as well as an English transliteration.")
    (license license:lppl1.3c)))

(define-public texlive-quran-bn
  (package
    (name "texlive-quran-bn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/quran-bn/" "tex/latex/quran-bn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00s1awx5s7h95nld2h32d7cm7zhr9qsqkqs9jq7p8cybkhhp8amf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/quran-bn")
    (synopsis "Bengali translations to the @code{quran} package")
    (description
     "The package is prepared for typesetting some Bengali translations of the
Holy Quran.  It adds two Bengali translations to the @code{quran} package.")
    (license license:lppl1.3+)))

(define-public texlive-quran-de
  (package
    (name "texlive-quran-de")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/quran-de/"
                                     "tex/xelatex/quran-de/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06syk1ifxcy8wxfxgnrh6d3hpx4bdprxgkc9jicaaca6j6m3rm65"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/quran-de")
    (synopsis "German translations to the @code{quran} package")
    (description
     "The package is prepared for typesetting some German translations of the
Holy Quran.  It adds three more German translations to the @code{quran}
package.")
    (license license:lppl1.3c)))

(define-public texlive-quran-ur
  (package
    (name "texlive-quran-ur")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/quran-ur/" "tex/latex/quran-ur/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13cziawsh8j4drwibp0558gd05b47rdk9cb0cd9cf6043has9ap9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/quran-ur")
    (synopsis "Urdu translations to the @code{quran} package")
    (description
     "The package is prepared for typesetting some Urdu translations of the
Holy Quran.  It adds eight Urdu translations to the @code{quran} package.")
    (license license:lppl1.3c)))

(define-public texlive-qyxf-book
  (package
    (name "texlive-qyxf-book")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/qyxf-book/"
                                     "tex/latex/qyxf-book/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sgjdfpmwjqh40sbanj772bwimbf3az7wah65hxaz5198xd67m1y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/qyxf-book")
    (synopsis "Book Template for Qian Yuan Xue Fu")
    (description
     "@code{qyxf-book} is a LaTeX document class (template) developed by Qian
Yuan Xue Fu (QYXF), a student club of Xi'an Jiaotong University (XJTU).  It
creates a minimalistic document style, and several color schemes are offered.
Currently the template is only designed for Chinese typesetting.")
    (license license:expat)))

(define-public texlive-r-und-s
  (package
    (name "texlive-r-und-s")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/r_und_s/" "tex/latex/r_und_s/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15w8sggvlh28567y1d4vpbq8and12hvhphfvd7vabbn8g1l6h1yi"))))
    (outputs '("out" "doc"))
    (properties '((upstream-name . "r_und_s")))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/r-und-s")
    (synopsis "Chemical hazard codes")
    (description
     "The @code{r-und-s} package decodes the german R- und S-Satze, which are
numerically coded security advice for chemical substances into plain text.
This is, e.g., used to compose security sheets or lab protocols and especially
useful for students of chemistry.  There are four packages, giving texts in
German, English, French and Dutch.")
    (license license:bsd-2)))

(define-public texlive-randbild
  (package
    (name "texlive-randbild")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/randbild/"
                                     "source/latex/randbild/"
                                     "tex/latex/randbild/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1y9qf73163ai738pf6qvaqxy5s2cymyg19qyyfs8dfx2gygcyny9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/randbild")
    (synopsis "Marginal pictures")
    (description
     "This package provides environments @code{randbild} to draw small
marginal plots (using the packages PSTricks and @code{pst-plot}), and
@code{randbildbasis} (the same, only without the automatically drawn
coordinate system).")
    (license license:lppl)))

(define-public texlive-randomwalk
  (package
    (name "texlive-randomwalk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/randomwalk/"
                                     "source/latex/randomwalk/"
                                     "tex/latex/randomwalk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mmisgiy0c6qww6xyp9r825snh1dkmn81qjg39c7n1jxig3a8rj3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/randomwalk")
    (synopsis "Random walks using TikZ")
    (description
     "The @code{randomwalk} package provides a user command, @code{\\RandomWalk},
to draw random walks with a given number of steps.  Lengths and angles of the
steps can be customized in various ways.")
    (license license:lppl1.3c)))

(define-public texlive-realhats
  (package
    (name "texlive-realhats")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/realhats/"
                                     "source/latex/realhats/"
                                     "tex/latex/realhats/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ybxjhhl28rx9i9zkm4qd97avq801nsz3h8r2igfirzgxym3ijfy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/realhats")
    (synopsis "Put real hats on symbols instead of @samp{^}")
    (description
     "This LaTeX package makes @code{\\hat} put real hats on symbols.")
    (license license:expat)))

(define-public texlive-reotex
  (package
    (name "texlive-reotex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/reotex/" "tex/latex/reotex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hcjk3nms2gg1h99mxnivb5n3382yq92c578mw0pxbwi0f67z3iw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/reotex")
    (synopsis "Draw Reo Channels and Circuits")
    (description
     "The package defines macros and other utilities to design Reo Circuits.")
    (license license:lppl)))

(define-public texlive-robotarm
  (package
    (name "texlive-robotarm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/robotarm/"
                                     "source/latex/robotarm/"
                                     "tex/latex/robotarm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lhvbwq979whvjwx9gyfhsxz20x6imhh57xm843zk6068lv0b3wj"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:tex-format "latex"
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'add-missing-ins-file
            ;; TeX Live distribution is missing the appropriate ".ins" file to
            ;; generate the package.  Create it, but ignore all documentation
            ;; related files in there.
            (lambda _
              (with-output-to-file "source/latex/robotarm/robotarm.ins"
                (lambda ()
                  (display "\\input docstrip.tex
\\generate{\\file{robotarm.sty}{\\from{robotarm.dtx}{robotarm-package}}}
\\endbatchfile"))))))))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-hypdoc
                  texlive-tools))))
    (home-page "https://ctan.org/pkg/robotarm")
    (synopsis "TikZ powered LaTeX package to draw parameterized 2D robot arms")
    (description
     "This LaTeX package uses TikZ to draw parameterized 2D robot arms, for
example to be used in educational material.")
    (license license:lppl1.3+)))

(define-public texlive-rojud
  (package
    (name "texlive-rojud")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/rojud/" "fonts/map/dvips/rojud/"
                                     "fonts/tfm/public/rojud/"
                                     "fonts/type1/public/rojud/"
                                     "tex/latex/rojud/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vq5m755wa5j9y072gmyf7pl7cisxh029b5j8rm46kqllfpaz4zj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rojud")
    (synopsis "Font with the images of the counties of Romania")
    (description
     "This package provides a Type 1 font with images of the 42 counties of Romania,
constructed using a general method which is described in detail in the
documentation.  The package name is an abbreviation of @emph{judetele
Romaniei} (i.e., counties of Romania).")
    (license license:lppl)))

(define-public texlive-rviewport
  (package
    (name "texlive-rviewport")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rviewport/"
                                     "source/latex/rviewport/"
                                     "tex/latex/rviewport/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13mrihyid25h70800ix0mbqhs8dbi39nyif8f12mj54jpfdjhxcz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rviewport")
    (synopsis "Relative viewport for graphics inclusion")
    (description
     "Package @code{graphicx} provides a useful keyword viewport which allows
to show just a part of an image.  However, one needs to put there the actual
coordinates of the viewport window.  Sometimes it is useful to have relative
coordinates as fractions of natural size.  For example, one may want to print
a large image on a spread, putting a half on a verso page, and another half on
the next recto page.  For this one would need a viewport occupying exactly one
half of the file's bounding box, whatever the actual width of the image may
be.  This package adds a new keyword @code{rviewport} to the @code{graphicx}
package specifying relative viewport for graphics inclusion: a window defined
by the given fractions of the natural width and height of the image.")
    (license license:lppl)))

(define-public texlive-sa-tikz
  (package
    (name "texlive-sa-tikz")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sa-tikz/" "tex/latex/sa-tikz/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wdxdgc7jh0h7pql8wja9h4qjc7vr4gv03y4nk2mlxxycwsxiimn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sa-tikz")
    (synopsis "TikZ library to draw switching architectures")
    (description
     "The package provides a library that offers an easy way to draw switching
architectures and to customize their aspect.")
    (license license:lppl1.3+)))

(define-public texlive-sacsymb
  (package
    (name "texlive-sacsymb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sacsymb/" "tex/latex/sacsymb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pwkb8z4bvgqbffcclfif04iqkpdp6lciwmwvwci3mi9bc6yh4vr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sacsymb")
    (synopsis "Sacred symbols prepared with TikZ")
    (description
     "The @code{sacsymb} package contains symbols used in objective
reduction (Orch OR) theory of consciousness as applied to the three brains
model of psychological experience.  These symbols are prepared using TikZ.")
    (license license:lppl1.0+)))

(define-public texlive-schemabloc
  (package
    (name "texlive-schemabloc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/schemabloc/"
                                     "tex/latex/schemabloc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nmjj4b065nmb4kqs4hlvc3jkz64cn5gbyfjavpxlpgfbbl6wnw4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/schemabloc")
    (synopsis "Draw block diagrams, using TikZ")
    (description
     "The package provides a set of macros for constructing block diagrams,
using TikZ.")
    (license license:lppl)))

(define-public texlive-schulmathematik
  (package
    (name "texlive-schulmathematik")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/schulmathematik/"
                                     "tex/latex/schulmathematik/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ry0h810chqvjrlbppn4y6090482wjr7gnymxj2vc44lcifqkaxy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/schulmathematik")
    (synopsis
     "Commands and document classes for German-speaking teachers of
mathematics and physics")
    (description
     "The @code{schulmathematik} bundle provides two LaTeX packages and six
document classes for German-speaking teachers of mathematics and physics.")
    (license license:lppl1.3+)))

(define-public texlive-scratch
  (package
    (name "texlive-scratch")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/scratch/" "tex/latex/scratch/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1np9mhfmn07clkzsg1glfxw1mkxihvv7yd10bnhc8lxxan9rymj1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/scratch")
    (synopsis "Draw programs like Scratch")
    (description
     "This package permits drawing program charts in the style of the
@url{https://scratch.mit.edu, Scratch} project.  This package is obsolete.
From now on, Scratch is now version 3 with a new design.  Use the
@code{scratch3} package to draw blocks with the new design.")
    (license license:lppl1.3c)))

(define-public texlive-scratch3
  (package
    (name "texlive-scratch3")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/scratch3/" "tex/latex/scratch3/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0g8s0p7j058z7hdm4p7kgh7nsyk4wn22lp3j25d5b4hr0xyxmhby"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/scratch3")
    (synopsis "Draw programs like Scratch")
    (description
     "This package permits drawing program charts in the style of the
@url{https://scratch.mit.edu, Scratch} project.")
    (license license:lppl1.3c)))

(define-public texlive-scsnowman
  (package
    (name "texlive-scsnowman")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/scsnowman/"
                                     "tex/latex/scsnowman/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qr1cb19383hsxqh3a0640713m343v3jgxfk9whdxm0z11am5if0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/scsnowman")
    (synopsis "Snowman variants using TikZ")
    (description
     "This LaTeX package provides a command @code{\\scsnowman} which can
display many variants of snowman")
    (license license:bsd-2)))

(define-public texlive-setdeck
  (package
    (name "texlive-setdeck")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/setdeck/" "tex/latex/setdeck/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11kk04nf37hmv7qw2azjl5r0cqf08khj41b1gp4nikrqvz2p1g49"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/setdeck")
    (synopsis "Typeset cards for Set")
    (description "The package will typeset cards for use in a game of Set.")
    (license license:gpl3)))

(define-public texlive-sexam
  (package
    (name "texlive-sexam")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/sexam/" "tex/xelatex/sexam/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bwzxm8xj7p930rgxh6j6rzb7r26i0w61ixy74wkqwmvb3951rf6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sexam")
    (synopsis "Typeset Arabic exam scripts")
    (description
     "The package provides a modified version of the @code{exam} package made
compatible with XeLaTeX and Polyglossia to typeset Arabic exams.")
    (license license:lppl1.3+)))

(define-public texlive-signchart
  (package
    (name "texlive-signchart")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/signchart/"
                                     "source/latex/signchart/"
                                     "tex/latex/signchart/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vg7xkrc0chp0r9j05ra499n4zkwg1gh9ywfnb54yhwcas301izs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/signchart")
    (synopsis "Create sign charts")
    (description
     "The package allows users to easily typeset sign charts directly into
their (La)TeX document.")
    (license license:lppl1.3+)))

(define-public texlive-simplenodes
  (package
    (name "texlive-simplenodes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/simplenodes/"
                                     "tex/latex/simplenodes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d3bqia3a7rnd57v8yld4i5d9nwrshkxxv6w2vglhpp447yv0nq7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/simplenodes")
    (synopsis "Simple nodes in four colors written in TikZ for LaTeX")
    (description
     "This is a LaTeX macro package for generating simple node-based flow
graphs or diagrams built upon the TikZ package.  The package provides two
basic commands, one to generate a node and one to create links between nodes.
The positioning of the nodes is not handled by the package itself but is
preferably done in a tabular environment.  In total, four simple node types
are defined, loosely based on the nomenclature and color patterns of the
popular Java script Bootstrap.")
    (license license:expat)))

(define-public texlive-simpleoptics
  (package
    (name "texlive-simpleoptics")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/simpleoptics/"
                                     "tex/latex/simpleoptics/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hna56av80k1gc3fm2nbw2dy31sfdw7v14v8yppad4f2d12skpzd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/simpleoptics")
    (synopsis "Drawing lenses and mirrors for optical diagrams")
    (description
     "This package provides some of macros for drawing simple lenses and
mirrors for use in optical diagrams.")
    (license license:lppl1.3c)))

(define-public texlive-simurgh
  (package
    (name "texlive-simurgh")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/simurgh/"
                                     "tex/lualatex/simurgh/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11256ssaq6hw6c93ldfgyp0gagv69hl54yg1c8wl5wkc0mrh42rb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/simurgh")
    (synopsis "Typeset Parsi in LuaLaTeX")
    (description
     "The package provides an automatic and unified interface for Parsi
typesetting in LaTeX, using the LuaTeX engine.")
    (license license:gpl2)))

(define-public texlive-smartdiagram
  (package
    (name "texlive-smartdiagram")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/smartdiagram/"
                                     "source/latex/smartdiagram/"
                                     "tex/latex/smartdiagram/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qlgafprxqjhy14imb3isgqjsp1y78qrcqlr0n1rvgwppmi1fd0c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/smartdiagram")
    (synopsis "Generate diagrams from lists")
    (description
     "The package will create smart diagrams from lists of items, for simple
documents and for presentations.")
    (license license:lppl1.3+)))

(define-public texlive-spath3
  (package
    (name "texlive-spath3")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/spath3/" "source/latex/spath3/"
                                     "tex/latex/spath3/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16hg6kbr0rzk1xsyrmhnkc0dr4vq8pamqdqncjx6n5jdpwr9kzkx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/spath3")
    (synopsis "Manipulate soft paths in PGF")
    (description
     "The @code{spath3} library provides methods for manipulating the soft
paths of TikZ/PGF.  Packaged with it are two TikZ libraries that make use of
the methods provided.  These are libraries for drawing calligraphic paths and
for drawing knot diagrams.")
    (license license:lppl1.3c)))

(define-public texlive-spectralsequences
  (package
    (name "texlive-spectralsequences")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/spectralsequences/"
                                     "tex/latex/spectralsequences/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fdgkvhhg8i0j7c4ibc9d2xjbhgbpqvqp1shpqaslg5mdahml58f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/spectralsequences")
    (synopsis "Print spectral sequence diagrams using PGF/TikZ")
    (description
     "The package is a specialized tool built on top of PGF/TikZ for drawing
spectral sequences.  It provides a powerful, concise syntax for specifying the
data of a spectral sequence, and then allows the user to print various pages
of spectral sequences, automatically choosing which subset of the classes,
differentials, and structure lines to display on each page.  It also handles
most of the details of the layout.  At the same time, it is extremely
flexible.  @code{spectralsequences} is closely integrated with TikZ to ensure
that users can take advantage of as much as possible of its expressive power.
It is possible to turn off most of the automated layout features and draw
replacements using TikZ commands.  The package also provides a carefully
designed error reporting system intended to ensure that it is as clear as
possible what is going wrong.")
    (license license:lppl)))

(define-public texlive-strands
  (package
    (name "texlive-strands")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/strands/" "source/latex/strands/"
                                     "tex/latex/strands/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jhvbzy8qjrjmb6j7kjwjn1iqgnszvhwlnpsag8sl1f8qgg1ns9z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/strands")
    (synopsis "Draw objects constructed from strands")
    (description
     "This package permits drawing objects constructed from strands, like set
partitions, permutations, braids, etc.")
    (license license:lppl1.3+)))

(define-public texlive-swebib
  (package
    (name "texlive-swebib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/swebib/" "doc/latex/swebib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bw7ls5gbi31gr9h4mqv2blva1skqymprp350n9wm086kgyv4s8h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/swebib")
    (synopsis "Swedish bibliography styles")
    (description
     "The bundle contains Swedish versions of the standard bibliography
styles, and of the style @code{plainnat}.  The styles should be functionally
equivalent to the corresponding original styles, apart from the Swedish
translations.  The styles do not implement Swedish collation.")
    (license license:lppl1.2+)))

(define-public texlive-swimgraf
  (package
    (name "texlive-swimgraf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/swimgraf/" "tex/latex/swimgraf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09s6wb3nzrxj20qrjyyr3r1fl2nbsgj1a4va101nwqb81pcmp4aq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/swimgraf")
    (synopsis "Graphical/textual representations of swimming performances")
    (description
     "The package provides two macros that produce representations of
a swimmer's performances.  The user records data in a text file and specifies
as arguments of the macros the date range of interest.  The macros extract the
relevant information from the file and process it: @code{\\swimgraph} produces
a graph of the times in a single swimming event (specified as an argument),
plotting long course and short course times in separate lines.  Records and
qualifying times, stored in text files, may optionally be included on the
graph. @code{\\swimtext} produces a written record of the times in all events.
Files of current world and Canadian records are included.")
    (license license:lppl)))

(define-public texlive-syntaxdi
  (package
    (name "texlive-syntaxdi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/syntaxdi/" "tex/latex/syntaxdi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q6f45vr1dq5pildna9i6vxxqg76kylnlb2rfqs9f87r73dg0xak"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/syntaxdi")
    (synopsis "Create railroad syntax diagrams")
    (description
     "This package provides TikZ styles for creating special syntax diagrams
known as railroad diagrams.")
    (license license:lppl1.3+)))

(define-public texlive-t1utils
  (package
    (name "texlive-t1utils")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/t1ascii.1"
                                     "doc/man/man1/t1ascii.man1.pdf"
                                     "doc/man/man1/t1asm.1"
                                     "doc/man/man1/t1asm.man1.pdf"
                                     "doc/man/man1/t1binary.1"
                                     "doc/man/man1/t1binary.man1.pdf"
                                     "doc/man/man1/t1disasm.1"
                                     "doc/man/man1/t1disasm.man1.pdf"
                                     "doc/man/man1/t1mac.1"
                                     "doc/man/man1/t1mac.man1.pdf"
                                     "doc/man/man1/t1unmac.1"
                                     "doc/man/man1/t1unmac.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hdk57179nn57wnmvr3jasjavkvmrn6ryph6jvjhsfqprn7bhf1y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-t1utils-bin))
    (home-page "https://ctan.org/pkg/t1utils")
    (synopsis "Simple Type 1 font manipulation programs")
    (description
     "This package provides a collection of simple programs for manipulating
Adobe Type 1 fonts, comprising:

@itemize
@item @command{t1ascii}: convert PFB (binary) to PFA (ASCII) fonts;
@item @command{t1binary}: convert PFA to PFB fonts;
@item @command{t1disasm}: convert PFA or PFB fonts to human-readable
and -editable format;
@item @command{t1asm}: reassemble such editable formats to a font;
@item @command{t1unmac}: extract font resources from a Macintosh font file;
@item @command{t1mac}: generate a Macintosh font from a Type 1 font.
@end itemize")
    (license license:public-domain)))

(define-public texlive-t1utils-bin
  (package
    (inherit texlive-bin)
    (name "texlive-t1utils-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "texk" '())
            (delete-other-directories "utils" '("t1utils"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-t1utils" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "utils/t1utils"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "utils/t1utils"
                  (invoke "make" "install"))))))))
    (native-inputs '())
    (inputs '())
    (propagated-inputs '())
    (home-page (package-home-page texlive-t1utils))
    (synopsis "Binaries for @code{texlive-t1utils}")
    (description
     "This package provides the binaries for @code{texlive-t1utils}.")
    (license (package-license texlive-t1utils))))

(define-public texlive-table-fct
  (package
    (name "texlive-table-fct")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/table-fct/"
                                     "tex/latex/table-fct/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1l21dvfp4ypbfn5jvyrb2kwg8s8xfvcwlwxgcyix2ghawv9gsp7m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/table-fct")
    (synopsis
     "Draw a variations table of functions and a convexity table of its graph")
    (description
     "This package offers two environnements, to draw variations table of
a function and a convexity table of its graph.")
    (license license:lppl1.3+)))

(define-public texlive-templates-fenn
  (package
    (name "texlive-templates-fenn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/templates-fenn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1s91swqsysva49cjrb9khgik5mvhxcb3wr2wz4l2683gdgxlbgkf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/templates-fenn")
    (synopsis "Templates for TeX usage")
    (description
     "This package provides a set of templates for using LaTeX packages that
the author uses, comprising:

@itemize
@item @file{scrlttr2.tex}: a letter, written with @code{scrlttr2.cls} from the
KOMA-Script bundl,
@item @file{dinbrief.tex}: a letter according to the German
(DIN) standards, written with @file{dinbrief.cls},
@item @file{kbrief.tex}: a brief memo (@emph{Kurzbrief}) to accompany
enclosures, as used in German offices, again based on @code{dinbrief},
@item @file{vermerk.tex}: a general form for taking down notes on events in
the office,
@item @file{diabetes.tex}: a diary for the basis-bolus insulin therapy of
diabetes mellitus, using @file{scrartcl.cls} from the KOMA-Script bundle.
@end itemize")
    (license license:lppl)))

(define-public texlive-templates-sommer
  (package
    (name "texlive-templates-sommer")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/templates-sommer/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0z75xhawsmcxv4f24cqcvfi0r22gavjpg4si6nwrgc8sg82x24m6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/templates-sommer")
    (synopsis "Templates for TeX usage")
    (description
     "This package provides a set of templates for using LaTeX packages that the
author uses, comprising:

@itemize
@item @file{hausarbeit.tex}: for students of the Lehrstuhl Volkskunde an der
Friedrich-Schiller-Universitat Jena,
@item @file{psycho-Dipl.tex}: for diploma theses in psychology.
@end itemize")
    (license license:lppl)))

(define-public texlive-termcal-de
  (package
    (name "texlive-termcal-de")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/termcal-de/"
                                     "source/latex/termcal-de/"
                                     "tex/latex/termcal-de/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0av913y88vfv0yb68xx1lrqpxd8hwx8x7zzb1qcb2d9r5ry1l8z7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/termcal-de")
    (synopsis "German localization for @code{termcal}")
    (description
     "This package provides a German localization to the @code{termcal}
package written by Bill Mitchell, which is intended to print a term calendar
for use in planning a class.")
    (license license:lppl1.3c)))

(define-public texlive-tex4ht
  (package
    (name "texlive-tex4ht")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/tex4ht/"
                                     "scripts/tex4ht/"
                                     "source/generic/tex4ht/"
                                     "tex/generic/tex4ht/"
                                     "tex4ht/base/unix/"
                                     "tex4ht/base/win32/"
                                     "tex4ht/bin/"
                                     "tex4ht/ht-fonts/alias/"
                                     "tex4ht/ht-fonts/aliase/mathtime/"
                                     "tex4ht/ht-fonts/ascii/manfnt/"
                                     "tex4ht/ht-fonts/cp1256/charset/"
                                     "tex4ht/ht-fonts/css/emacspeak/cm/"
                                     "tex4ht/ht-fonts/dbcs/cjk/b5ka/"
                                     "tex4ht/ht-fonts/gb2312/charset/"
                                     "tex4ht/ht-fonts/gbk/charset/"
                                     "tex4ht/ht-fonts/html-speech/charset/"
                                     "tex4ht/ht-fonts/iso8859/1/charset/"
                                     "tex4ht/ht-fonts/iso8859/1/chess/"
                                     "tex4ht/ht-fonts/iso8859/1/cm/"
                                     "tex4ht/ht-fonts/iso8859/1/devanagari/"
                                     "tex4ht/ht-fonts/iso8859/1/euro/"
                                     "tex4ht/ht-fonts/iso8859/1/go/"
                                     "tex4ht/ht-fonts/iso8859/1/html/charset/"
                                     "tex4ht/ht-fonts/iso8859/1/ipa/"
                                     "tex4ht/ht-fonts/iso8859/1/mathtime/"
                                     "tex4ht/ht-fonts/iso8859/1/mongolian/"
                                     "tex4ht/ht-fonts/iso8859/1/ps2mf/"
                                     "tex4ht/ht-fonts/iso8859/1/sw/"
                                     "tex4ht/ht-fonts/iso8859/1/tibetan/"
                                     "tex4ht/ht-fonts/iso8859/1/xypic/"
                                     "tex4ht/ht-fonts/iso8859/2/charset/"
                                     "tex4ht/ht-fonts/iso8859/2/html/charset/"
                                     "tex4ht/ht-fonts/iso8859/5/charset/"
                                     "tex4ht/ht-fonts/iso8859/5/cm/sauter/"
                                     "tex4ht/ht-fonts/iso8859/5/cyrillic/"
                                     "tex4ht/ht-fonts/iso8859/5/html/charset/"
                                     "tex4ht/ht-fonts/iso8859/5/lh/lh-t2a/"
                                     "tex4ht/ht-fonts/iso8859/6/charset/"
                                     "tex4ht/ht-fonts/iso8859/6/html/charset/"
                                     "tex4ht/ht-fonts/iso8859/7/charset/"
                                     "tex4ht/ht-fonts/iso8859/8/hebrew/"
                                     "tex4ht/ht-fonts/jsml/charset/"
                                     "tex4ht/ht-fonts/koi/8r/charset/"
                                     "tex4ht/ht-fonts/koi/8r/lh/lh-t2a/"
                                     "tex4ht/ht-fonts/mozilla/charset/"
                                     "tex4ht/ht-fonts/ooffice/charset/"
                                     "tex4ht/ht-fonts/share/adobe/helvetic/"
                                     "tex4ht/ht-fonts/symbol/charset/"
                                     "tex4ht/ht-fonts/symbol/cyrillic/"
                                     "tex4ht/ht-fonts/symbol/hebrew/"
                                     "tex4ht/ht-fonts/symbol/mathtime/"
                                     "tex4ht/ht-fonts/unicode/Baskervaldx/"
                                     "tex4ht/ht-fonts/unicode/Century_Schoolbook_L/"
                                     "tex4ht/ht-fonts/unicode/EB_Garamond_Initials/"
                                     "tex4ht/ht-fonts/unicode/EB_Garamond_Italic/"
                                     "tex4ht/ht-fonts/unicode/EB_Garamond_Regular/"
                                     "tex4ht/ht-fonts/unicode/Fourier-Math-Extension/"
                                     "tex4ht/ht-fonts/unicode/Fourier-Math-Letters/"
                                     "tex4ht/ht-fonts/unicode/Fourier-Math-Symbols/"
                                     "tex4ht/ht-fonts/unicode/Kp--M-Ex/"
                                     "tex4ht/ht-fonts/unicode/Kp--M-Exa/"
                                     "tex4ht/ht-fonts/unicode/Kp--M-Sy/"
                                     "tex4ht/ht-fonts/unicode/Kp--M-Sya/"
                                     "tex4ht/ht-fonts/unicode/Kp--M/"
                                     "tex4ht/ht-fonts/unicode/Kp-Companion/"
                                     "tex4ht/ht-fonts/unicode/Kp-Expert/"
                                     "tex4ht/ht-fonts/unicode/Kp-Light-M-Ex/"
                                     "tex4ht/ht-fonts/unicode/Kp-Light-M-Sy/"
                                     "tex4ht/ht-fonts/unicode/Kp-Light-M-Syb/"
                                     "tex4ht/ht-fonts/unicode/Kp-Light-M-Syc/"
                                     "tex4ht/ht-fonts/unicode/Kp-Light-M-Syd/"
                                     "tex4ht/ht-fonts/unicode/Kp-Light-M/"
                                     "tex4ht/ht-fonts/unicode/Kp-Light-SmallCaps/"
                                     "tex4ht/ht-fonts/unicode/Kp-SC-Expert/"
                                     "tex4ht/ht-fonts/unicode/Kp-SmallCaps/"
                                     "tex4ht/ht-fonts/unicode/Kp/"
                                     "tex4ht/ht-fonts/unicode/LibertineMath/"
                                     "tex4ht/ht-fonts/unicode/Linux_Biolinum_T/"
                                     "tex4ht/ht-fonts/unicode/Linux_Libertine_Display_T/"
                                     "tex4ht/ht-fonts/unicode/Linux_Libertine_Initials_T/"
                                     "tex4ht/ht-fonts/unicode/Linux_Libertine_Mono_T/"
                                     "tex4ht/ht-fonts/unicode/Linux_Libertine_T/"
                                     "tex4ht/ht-fonts/unicode/MinLib/"
                                     "tex4ht/ht-fonts/unicode/MnSymbol/"
                                     "tex4ht/ht-fonts/unicode/NCXFourierMath/"
                                     "tex4ht/ht-fonts/unicode/NewTXMath/"
                                     "tex4ht/ht-fonts/unicode/Nimbus_Roman_No9_L/"
                                     "tex4ht/ht-fonts/unicode/Open_Sans_ExtraBold/"
                                     "tex4ht/ht-fonts/unicode/Open_Sans_Light/"
                                     "tex4ht/ht-fonts/unicode/STIX/"
                                     "tex4ht/ht-fonts/unicode/STIX_Two/"
                                     "tex4ht/ht-fonts/unicode/Sf-Kp-Sc/"
                                     "tex4ht/ht-fonts/unicode/Spectral/"
                                     "tex4ht/ht-fonts/unicode/TeXGyreTermes/"
                                     "tex4ht/ht-fonts/unicode/TeXGyreTermesX/"
                                     "tex4ht/ht-fonts/unicode/Tt-Kp-Exp/"
                                     "tex4ht/ht-fonts/unicode/Tt-Kp/"
                                     "tex4ht/ht-fonts/unicode/URW_Chancery_L/"
                                     "tex4ht/ht-fonts/unicode/Utopia/"
                                     "tex4ht/ht-fonts/unicode/adobe/courier/"
                                     "tex4ht/ht-fonts/unicode/adobe/helvetic/"
                                     "tex4ht/ht-fonts/unicode/adobe/mathptm/"
                                     "tex4ht/ht-fonts/unicode/adobe/palatino/"
                                     "tex4ht/ht-fonts/unicode/adobe/symbol/"
                                     "tex4ht/ht-fonts/unicode/adobe/times/"
                                     "tex4ht/ht-fonts/unicode/adobe/zapfding/"
                                     "tex4ht/ht-fonts/unicode/ae/"
                                     "tex4ht/ht-fonts/unicode/ams/cyrillic/"
                                     "tex4ht/ht-fonts/unicode/ams/euler/"
                                     "tex4ht/ht-fonts/unicode/ams/symbols/"
                                     "tex4ht/ht-fonts/unicode/antt/"
                                     "tex4ht/ht-fonts/unicode/arabi/"
                                     "tex4ht/ht-fonts/unicode/arev/"
                                     "tex4ht/ht-fonts/unicode/arphic/"
                                     "tex4ht/ht-fonts/unicode/bbold/"
                                     "tex4ht/ht-fonts/unicode/bitstrea/charter/"
                                     "tex4ht/ht-fonts/unicode/cbgreek/"
                                     "tex4ht/ht-fonts/unicode/cfrinitials/"
                                     "tex4ht/ht-fonts/unicode/charset/"
                                     "tex4ht/ht-fonts/unicode/chess/"
                                     "tex4ht/ht-fonts/unicode/cjk/b5ka/"
                                     "tex4ht/ht-fonts/unicode/cjk/gbksong/"
                                     "tex4ht/ht-fonts/unicode/cjk/utf8/"
                                     "tex4ht/ht-fonts/unicode/cm/"
                                     "tex4ht/ht-fonts/unicode/coch/"
                                     "tex4ht/ht-fonts/unicode/concrete/"
                                     "tex4ht/ht-fonts/unicode/cs/"
                                     "tex4ht/ht-fonts/unicode/currency/"
                                     "tex4ht/ht-fonts/unicode/cyklop/"
                                     "tex4ht/ht-fonts/unicode/cyrillic/cmcyr/"
                                     "tex4ht/ht-fonts/unicode/dstroke/"
                                     "tex4ht/ht-fonts/unicode/ebg/"
                                     "tex4ht/ht-fonts/unicode/ec/"
                                     "tex4ht/ht-fonts/unicode/erewMath/"
                                     "tex4ht/ht-fonts/unicode/fontawesome/"
                                     "tex4ht/ht-fonts/unicode/fourier-orns/"
                                     "tex4ht/ht-fonts/unicode/futr-sup/"
                                     "tex4ht/ht-fonts/unicode/futrc9d/"
                                     "tex4ht/ht-fonts/unicode/futrd8t/"
                                     "tex4ht/ht-fonts/unicode/greek/ibygrk/"
                                     "tex4ht/ht-fonts/unicode/hebrew/"
                                     "tex4ht/ht-fonts/unicode/html/charset/"
                                     "tex4ht/ht-fonts/unicode/iwona/"
                                     "tex4ht/ht-fonts/unicode/jknappen/tc/"
                                     "tex4ht/ht-fonts/unicode/latex/"
                                     "tex4ht/ht-fonts/unicode/lh/lh-t2a/"
                                     "tex4ht/ht-fonts/unicode/libertine/"
                                     "tex4ht/ht-fonts/unicode/libertinus/"
                                     "tex4ht/ht-fonts/unicode/lm/"
                                     "tex4ht/ht-fonts/unicode/marvosym/"
                                     "tex4ht/ht-fonts/unicode/math/"
                                     "tex4ht/ht-fonts/unicode/mathabx/"
                                     "tex4ht/ht-fonts/unicode/mathdesign/"
                                     "tex4ht/ht-fonts/unicode/mathkerncmssi/"
                                     "tex4ht/ht-fonts/unicode/mathtime/"
                                     "tex4ht/ht-fonts/unicode/mflogo/"
                                     "tex4ht/ht-fonts/unicode/misc/"
                                     "tex4ht/ht-fonts/unicode/musix/"
                                     "tex4ht/ht-fonts/unicode/ntxsups/"
                                     "tex4ht/ht-fonts/unicode/ntxtm/"
                                     "tex4ht/ht-fonts/unicode/pl/"
                                     "tex4ht/ht-fonts/unicode/public/"
                                     "tex4ht/ht-fonts/unicode/pxfonts/"
                                     "tex4ht/ht-fonts/unicode/stickstooMath/"
                                     "tex4ht/ht-fonts/unicode/stmaryrd/"
                                     "tex4ht/ht-fonts/unicode/stxickstooMath/"
                                     "tex4ht/ht-fonts/unicode/t1xtt/"
                                     "tex4ht/ht-fonts/unicode/tcxtt/"
                                     "tex4ht/ht-fonts/unicode/tibetan/"
                                     "tex4ht/ht-fonts/unicode/tipa/"
                                     "tex4ht/ht-fonts/unicode/txbexs/"
                                     "tex4ht/ht-fonts/unicode/txbmiaX/"
                                     "tex4ht/ht-fonts/unicode/txbsys/"
                                     "tex4ht/ht-fonts/unicode/txexas/"
                                     "tex4ht/ht-fonts/unicode/txexs/"
                                     "tex4ht/ht-fonts/unicode/txfonts/"
                                     "tex4ht/ht-fonts/unicode/txmiaX/"
                                     "tex4ht/ht-fonts/unicode/txsyb/"
                                     "tex4ht/ht-fonts/unicode/txsyc/"
                                     "tex4ht/ht-fonts/unicode/txsys/"
                                     "tex4ht/ht-fonts/unicode/txtt/"
                                     "tex4ht/ht-fonts/utf8/charset/"
                                     "tex4ht/ht-fonts/viqr/charset/"
                                     "tex4ht/ht-fonts/viscii/charset/"
                                     "tex4ht/ht-fonts/win/1251/charset/"
                                     "tex4ht/ht-fonts/win/1251/cm/sauter/"
                                     "tex4ht/ht-fonts/win/1251/cyrillic/"
                                     "tex4ht/ht-fonts/win/1251/lh/lh-t2a/"
                                     "tex4ht/xtpipes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p9kf450xkf8zic6sfhwbxvvkigxf8gqcrl41l308lsvgykiv87k"))))
    (outputs '("out" "doc"))
    (properties '((updater-ignored-inputs "perl"))) ;in "-bin" already
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-tex4ht-bin))
    (home-page "https://ctan.org/pkg/tex4ht")
    (synopsis "Convert (La)TeX to HTML/XML")
    (description
     "This package provides a converter from TeX and LaTeX to SGML-based
formats such as (X)HTML, MathML, OpenDocument, and Docbook, providing
a configurable (La)TeX-based authoring system for hypertext.  TeX4ht does not
independently parse (La)TeX source (so it avoids the difficulties encountered
by many other converters, arising from the irregularity of (La)TeX syntax).
Instead, TeX4ht uses (La)TeX itself (with myriad macro modifications) to
produce a helper DVI file that it can then process.  This technique allows
TeX4ht to approach the robustness characteristic of restricted-syntax systems
such as @code{gellmu}.")
    (license license:lppl)))

(define-public texlive-tex4ht-bin
  (package
    (inherit texlive-bin)
    (name "texlive-tex4ht-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("tex4htk"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-tex4htk" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/tex4htk"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/tex4htk"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list perl texlive-libkpathsea))
    (propagated-inputs '())
    (home-page (package-home-page texlive-tex4ht))
    (synopsis "Binaries for @code{texlive-tex4ht}")
    (description
     "This package provides the binaries for @code{texlive-tex4ht}.")
    (license (package-license texlive-tex4ht))))

(define-public texlive-tex4ebook
  (package
    (name "texlive-tex4ebook")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/tex4ebook/"
                                     "scripts/tex4ebook/" "tex/latex/tex4ebook/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03yg3lryql7lfh5rbdhak6j8mlafrn1rhmi514la3vaccq9p2lc1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "tex4ebook")))
    (propagated-inputs (list texlive-make4ht texlive-tex4ht))
    (home-page "https://ctan.org/pkg/tex4ebook")
    (synopsis "Converter from LaTeX to EBook formats")
    (description
     "This is a bundle of Lua scripts and LaTeX packages for conversion of
LaTeX files to EBook formats such as EPUB, MOBI and EPUB3.  TeX4ht is used as
the conversion engine.")
    (license license:lppl1.3+)))

(define-public texlive-texaccents
  (package
    (name "texlive-texaccents")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/texaccents.1"
                                     "doc/man/man1/texaccents.man1.pdf"
                                     "doc/support/texaccents/"
                                     "scripts/texaccents/"
                                     "source/support/texaccents/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kh4cpvrxgcvnmzxgb3my4jawyqd4348cy6h195346pvdb5xsphh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "texaccents.sno")))
    (home-page "https://ctan.org/pkg/texaccents")
    (synopsis "Convert composite accented characters to Unicode")
    (description
     "This small utility, written in SNOBOL, converts the composition of
special characters to Unicode.")
    (license license:expat)))

(define-public texlive-texcount
  (package
    (name "texlive-texcount")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/texcount/" "scripts/texcount/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ab1kp0zh2r65x1v42sc5bwxmlifa8splrakq589fgd0aap0l8n1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "texcount.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/texcount")
    (synopsis "Count words in a LaTeX document")
    (description
     "TeXcount is a Perl script that counts words in the text of LaTeX files.
It has rules for handling most of the common macros, and can provide
colour-coded output showing which parts of the text have been counted.")
    (license license:lppl)))

(define-public texlive-texdef
  (package
    (name "texlive-texdef")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/texdef/" "scripts/texdef/"
                                     "source/support/texdef/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jkc6c4nvzp228d7dcmp0gv2q5qassjq1p40fz4pmbxiyias7zw3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:link-scripts #~(list "texdef.pl")
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'link-scripts 'add-symlink
            (lambda _
              (with-directory-excursion (string-append #$output "/bin")
                (symlink "texdef" "latexdef")))))))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/texdef")
    (synopsis "Display the definitions of TeX commands")
    (description
     "This (Perl) script displays the definitions of (La)TeX command
sequences/macros.  Various options allow the selection of the used class as
well as package files and other factors that may influence the
definition (before/after the preamble, inside an environment, ...).  The
script creates a temporary TeX file which is then compiled using (La)TeX to
find the @code{\\meaning} of the command sequence.  The result is formatted
and presented to the user.  Length or number command sequences (dimensions,
@code{\\char}..., count registers, ...)  are recognized and the contained
value is also shown (using @code{\\the}).  Special definitions like protected
macros are also recognized and the underlying macros are shown as well.  The
script will show plain TeX definitions by default.  LaTeX and ConTeXt are
supported, including flavours (pdf(La)TeX, Lua(La)TeX, Xe(La)TeX, ...).  The
flavour can be selected using a command line option, or via the script name:
@command{latexdef} will use LaTeX as default, etc.")
    (license license:gpl3)))

(define-public texlive-texdiff
  (package
    (name "texlive-texdiff")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/texdiff.1"
                                     "doc/man/man1/texdiff.man1.pdf"
                                     "doc/support/texdiff/" "scripts/texdiff/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cp2k217ziwdgh5c7lg22p58ajv7j410ncag620lkdwajc5jqx1d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "texdiff")))
    (home-page "https://ctan.org/pkg/texdiff")
    (synopsis "Compare documents and produce tagged merge")
    (description
     "Two files are compared and a new TeX file is output.  When the output
file is processed with (La)TeX it marks new changes with blue and old text
with red with a strike-through line.  Furthermore, passages with changes are
marked at the margin with grey bars by the LaTeX @code{changebar} package.")
    (license license:artistic2.0)))

(define-public texlive-texdirflatten
  (package
    (name "texlive-texdirflatten")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/texdirflatten.1"
                                     "doc/man/man1/texdirflatten.man1.pdf"
                                     "doc/support/texdirflatten/"
                                     "scripts/texdirflatten/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0f2h9qlqfml9p83znxh81i7cmwfbsr0zrladrf3486v4aja859kx"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "texdirflatten")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/texdirflatten")
    (synopsis "Collect files related to a LaTeX job in a single directory")
    (description
     "The Perl script parses a LaTeX file recursively, scanning all child
files, and collects details of any included and other data files.  These
component files, are then all put into a single directory (thus flattening the
document's directory tree).")
    (license license:artistic2.0)))

(define-public texlive-texdoc
  (package
    (name "texlive-texdoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/texdoc.1"
                                     "doc/man/man1/texdoc.man1.pdf"
                                     "doc/support/texdoc/" "scripts/texdoc/"
                                     "texdoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vcnsiknl3x1gp62cf3vv4810rcb83rnvfkhsz74bsdn2kcrbz97"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:link-scripts #~(list "texdoc.tlu")
      #:phases
      #~(modify-phases %standard-phases
          ;; The following phase prevents the following warning: "Info:
          ;; Running Texdoc not installed in the current TEXMFMAIN".
          (add-after 'unpack 'eschew-warning
            (lambda _
              (substitute* "scripts/texdoc/texdoc.tlu"
                (("if texmf ~= nil") "if false"))))
          ;; `kpse.find_file' is not able to locate "texlive.tlpdb", resulting
          ;; in the following error: "texdoc error: No texlive.tlpdb nor
          ;; shipped tlpdb data found".  This phase explicitly points `texdoc'
          ;; into the right direction.
          (add-after 'unpack 'set-tlpdb-location
            (lambda* (#:key native-inputs inputs #:allow-other-keys)
              (let ((tlpdb (search-input-file (or native-inputs inputs)
                                              "/share/tlpkg/texlive.tlpdb")))
                (substitute* "scripts/texdoc/texdoclib-const.tlu"
                  (("(local tlpdb=\").*" _ prefix)
                   (string-append prefix tlpdb "\"\n")))
                (substitute* "scripts/texdoc/texdoclib-search.tlu"
                  (("(local texlive_tlpdb = ).*" _ prefix)
                   (string-append prefix "'" tlpdb "'\n")))))))))
    (propagated-inputs (list texlive-kpathsea))
    (home-page "https://ctan.org/pkg/texdoc")
    (synopsis "Documentation access for TeX Live")
    (description
     "@command{texdoc} is a Lua script providing easy access to the
documentation in TeX Live: PDF, DVI, plain text files, and more.  Viewing and
other configuration can be extensively customized.")
    (license license:gpl3+)))

(define-public texlive-texdoctk
  (package
    (name "texlive-texdoctk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/texdoctk.1"
                                     "doc/man/man1/texdoctk.man1.pdf"
                                     "scripts/texdoctk/" "texdoctk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18xxivpgjdh8v6kg0b45zjv18sm9a4ljpwk6a4cghg5l5yggrjcx"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl-tk")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:link-scripts #~(list "texdoctk.pl")
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'link-scripts 'wrap-perl-script
            (lambda _
              (wrap-program (string-append #$output "/bin/texdoctk")
                `("PERL5LIB" ":" prefix (,(getenv "PERL5LIB")))))))))
    (inputs (list perl perl-tk))
    (propagated-inputs (list texlive-kpathsea))
    (home-page "https://ctan.org/pkg/texdoctk")
    (synopsis "Easy access to package documentation")
    (description
     "This package provides a Perl/Tk-based GUI for easy access to package
documentation for TeX on Unix platforms; the databases it uses are based on
the texmf/doc subtrees of teTeX, but database files for local configurations
with modified/extended directories can be derived from them.  Note that
@command{texdoctk} is not a viewer itself, but an interface for finding
documentation files and opening them with the appropriate viewer; so it relies
on appropriate programs to be installed on the system.  However, the choice of
these programs can be configured by the sysadmin or user.")
    (license license:gpl3+)))

(define-public texlive-texdraw
  (package
    (name "texlive-texdraw")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/info/texdraw.info"
                                     "doc/support/texdraw/"
                                     "tex/generic/texdraw/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pqrmyc8jnwk06qbrf18cyny1z4ncq0snp4jc0r7qgnh6bmlbncs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/texdraw")
    (synopsis "Graphical macros, using embedded PostScript")
    (description
     "TeXdraw is a set of macro definitions for TeX, which allow the user to
produce PostScript drawings from within TeX and LaTeX.  TeXdraw has been
designed to be extensible.  Drawing segments are relocatable, self-contained
units.  Using a combination of TeX's grouping mechanism and the
@code{gsave}/@code{grestore} mechanism in PostScript, drawing segments allow
for local changes to the scaling and line parameters.  Using TeX's macro
definition capability, new drawing commands can be constructed from drawing
segments.")
    (license license:cc-by4.0)))

(define-public texlive-texfot
  (package
    (name "texlive-texfot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/texfot.1"
                                     "doc/man/man1/texfot.man1.pdf"
                                     "doc/support/texfot/" "scripts/texfot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qa4diwssmm73dz0nsc4ypfakknzvraq3zxh5yhbyxwysi33v3ph"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "texfot.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/texfot")
    (synopsis "Filter clutter from the output of a TeX run")
    (description
     "The package provides a small Perl script to filter the online output
from a TeX run, attempting to show only those messages which probably deserve
some change in the source.  The TeX invocation itself need not change.")
    (license license:public-domain)))

(define-public texlive-texliveonfly
  (package
    (name "texlive-texliveonfly")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/texliveonfly/"
                                     "scripts/texliveonfly/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15nrgkh9wkaccbyd8jgcyw5xjjhqj3jyy3spbfd679fywq14l8c2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "texliveonfly.py")))
    (inputs (list python))
    (home-page "https://ctan.org/pkg/texliveonfly")
    (synopsis "On-the-fly download of missing TeX live packages")
    (description
     "The package provides a script that performs on the fly downloads of
missing packages, while a document is being compiled.  To use the script,
replace your (LaTeX) compilation command with @samp{texliveonfly.py
file.tex}.")
    (license license:gpl3)))

(define-public texlive-texloganalyser
  (package
    (name "texlive-texloganalyser")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/texloganalyser/"
                                     "scripts/texloganalyser/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qlrpqwfyakhh163ckznw5z8jwm5frp3krpi7fxnf9pz03c7shhr"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "texloganalyser")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/texloganalyser")
    (synopsis "Analyse TeX logs")
    (description
     "This Perl script allows the user to extract (and display) elements of
the log file.")
    (license license:bsd-2)))

(define-public texlive-texlogfilter
  (package
    (name "texlive-texlogfilter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/texlogfilter.1"
                                     "doc/man/man1/texlogfilter.man1.pdf"
                                     "doc/support/texlogfilter/"
                                     "scripts/texlogfilter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wf3g3m2n82n443aq3hfpnj0wzz6r4j8qwg78s6k2fm63x7s14ll"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "texlogfilter")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/texlogfilter")
    (synopsis "Filter LaTeX engines output or log file")
    (description
     "@command{texlogfilter} is a Perl script designed to filter LaTeX engines
output or log file (LaTeX, pdfLaTeX, LuaLaTeX or XeLaTeX).  It reduces the
LaTeX output or log to keep only warnings and errors.  The result is
colorised.  Options allow masking specific warnings, such as box or
references/citations warnings.  It's also possible to add custom filter
patterns.")
    (license license:lppl1.3+)))

(define-public texlive-texlogsieve
  (package
    (name "texlive-texlogsieve")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/texlogsieve.1"
                                     "doc/man/man1/texlogsieve.man1.pdf"
                                     "doc/support/texlogsieve/"
                                     "scripts/texlogsieve/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dgfq5crqqfvcfmpbbx70mbhanir3iyqzxni8zxkyrc1fljibjay"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "texlogsieve")))
    (home-page "https://ctan.org/pkg/texlogsieve")
    (synopsis "Filter and summarize LaTeX log files")
    (description
     "@command{texlogsieve} reads a LaTeX log file (or the standard input if
no file is specified), filters out less relevant messages, and displays
a summary report.")
    (license license:gpl3+)))

(define-public texlive-texnegar
  (package
    (name "texlive-texnegar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/texnegar/"
                                     "source/latex/texnegar/"
                                     "tex/latex/texnegar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rza5bmn7cm85aznnffpmfv6b8776jxkpfwhs0y04f83sdjapw63"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/texnegar")
    (synopsis "Kashida justification in XeLaTeX and LuaLaTeX")
    (description
     "In some cursive scripts such as Persian or Arabic, kashida is used to
create justification.  In this type of justification characters are elongated
rather than expanding spaces between words.  This package extends the kashida
justification to be used with the LuaTeX engine.")
    (license license:lppl1.3c)))

(define-public texlive-texosquery
  (package
    (name "texlive-texosquery")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/texosquery/"
                                     "scripts/texosquery/"
                                     "source/support/texosquery/"
                                     "tex/latex/texosquery/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17s947p011qar5aaz11ysby3nqqrnk0qv4m26hsl5y6divqb2dan"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts
           #~(list "texosquery-jre5.sh" "texosquery-jre8.sh" "texosquery.sh")))
    (home-page "https://ctan.org/pkg/texosquery")
    (synopsis "Java application to query OS information")
    (description
     "This package provides a Java application to query OS information
designed for use in TeX's shell escape mechanism.  The application can query
the following:

@itemize
@item locale and codeset,
@item current working directory,
@item user home directory
@item temporary directory,
@item OS name, arch and version,
@item current date and time in PDF format (for TeX formats that don't provide
@code{\\pdfcreationdate}),
@item date-time stamp of a file in PDF format (for TeX formats that don't
provide @code{\\pdffilemoddate}),
@item size of a file in bytes (for TeX formats that don't provide
@code{\\pdffilesize}),
@item contents of a directory (captured as a list),
@item directory contents filtered by regular expression (captured as a list),
@item URI or canonical path of a file.  All paths use a forward slash as
directory divider so results can be used, for example, in commands like
@code{\\includegraphics}.
@end itemize

There are files provided for easy access in TeX documents.
@file{texosquery.tex} provides generic TeX code, whereas @file{texosquery.sty}
is a LaTeX package, which provides commands to run @command{texosquery} using
TeX's shell escape mechanism and capture the result in a control sequence.")
    (license license:lppl1.3+)))

(define-public texlive-texplate
  (package
    (name "texlive-texplate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/texplate/"
                                     "scripts/texplate/"
                                     "source/support/texplate/main/kotlin/org/islandoftex/texplate/"
                                     "source/support/texplate/main/resources/org/islandoftex/texplate/templates/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "027vfbqm95ysp7sqlcz3p5b2107mcjg540x73nsf2d1g83k4ps4r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "texplate.sh")))
    (home-page "https://ctan.org/pkg/texplate")
    (synopsis "Tool for creating document structures based on templates")
    (description
     "TeXplate is a tool for creating document structures based on templates.
The application name is a word play on TeX and template, so the purpose seems
quite obvious: we want to provide an easy and straightforward framework for
reducing the typical code boilerplate when writing TeX documents.  Also note
that one can easily extrapolate the use beyond articles and theses: the
application is powerful enough to generate any text-based structure, given
that a corresponding template exists.")
    (license license:bsd-3)))

(define-public texlive-texproposal
  (package
    (name "texlive-texproposal")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/texproposal/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yxb3yagljsdp4s07fzd6498889i7cscch68fb77jbfc2z4srvsy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/texproposal")
    (synopsis "Proposal prototype for LaTeX promotion in Chinese universities")
    (description
     "This package contains the original source code and necessary attachment
of the document @emph{Proposal for Offering TeX Courses and Relevant Resources
in Chongqing University}.  This proposal could be helpful if one is
considering to suggest their (Chinese) university or company to use TeX (or
LaTeX, or XeLaTeX} as a typesetting system.

The present proposal mainly explains the importance and necessity of
introducing TeX, a typesetting system often used in academic writing, to
students and teachers.  This proposal starts from a brief introduction of TeX,
then steps further into its fascinating application to academic writing and
dissertation formatting.  Finally, a set of possible implementation strategies
with regard to the proper introduction of TeX and relevant resources to our
university, is proposed.")
    ;; The content of the project itself is released under CC-BY 4.0 terms,
    ;; but the underlying code used to format and display that content is
    ;; licensed under the Expat license.
    (license (list license:cc-by4.0 license:expat))))

(define-public texlive-texware
  (package
    (name "texlive-texware")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/dvitype.1"
                                     "doc/man/man1/dvitype.man1.pdf"
                                     "doc/man/man1/pooltype.1"
                                     "doc/man/man1/pooltype.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12kiigypny8rnbvxrx63q1cakjl50dp3n6ky9vpild36kn06a8ah"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-texware-bin))
    (home-page "https://ctan.org/pkg/texware")
    (synopsis "Utility programs for use with TeX")
    (description
     "This package provides basic utility programs, comprising:
@command{dvitype}, which converts a TeX output (DVI) file to a plain text
file; @command{pooltype}, which converts a TeX-suite program's pool (string)
file into human-readable form; @command{tftopl} and @command{pltotf}, which
convert TeX Font Metric (TFM) file to human readable Property List (PL) files
and vice versa.")
    (license license:public-domain)))

(define-public texlive-texware-bin
  (package
    (inherit texlive-bin)
    (name "texlive-texware-bin")
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(delete "--enable-web2c" #$flags))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/web2c"
                  (let ((bin (string-append #$output "/bin"))
                        (files '("dvitype" "pooltype")))
                    (for-each (lambda (f) (invoke "make" f)) files)
                    (for-each (lambda (f) (install-file f bin)) files)))))))))
    (native-inputs (list pkg-config))
    (home-page (package-home-page texlive-texware))
    (synopsis "Binaries for @code{texlive-texware}")
    (description
     "This package provides the binaries for @code{texlive-texware}.")
    (license (package-license texlive-texware))))

(define-public texlive-ticollege
  (package
    (name "texlive-ticollege")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ticollege/"
                                     "tex/latex/ticollege/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qbng6vq8w3ln2aw2kckbjih8hz3m2yr1b0bx8bx1a7bf5fhmd6i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ticollege")
    (synopsis
     "Graphical representation of keys on a standard scientific calculator")
    (description
     "This package provides commands to draw scientific calculator keys with
the help of TikZ.  It also provides commands to draw the content of screens
and of menu items.")
    (license license:lppl)))

(define-public texlive-tie
  (package
    (name "texlive-tie")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/tie.1"
                                     "doc/man/man1/tie.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rr0j2a76jwikg6a8fp9mvacwzk90nndknv9px42c2zx2bsdaqz8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-kpathsea))
    (home-page "https://ctan.org/pkg/tie")
    (synopsis "Allow multiple web change files")
    (description
     "Tie was originally developed to allow web programmers to apply more than
one change file to their source.  The program may also be used to create a new
version of a @file{.web} file that incorporates existing changes.")
    ;; The license, provided as the "tie.w" source file, is morally equivalent
    ;; to CC BY-SA.
    (license (license:fsf-free "file://tie.w"))))

(define-public texlive-tikz-3dplot
  (package
    (name "texlive-tikz-3dplot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-3dplot/"
                                     "tex/latex/tikz-3dplot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05hw2wxs4q477x16ffh6wcmypdf7mz7500dxnfywiqi0pgzmnh89"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-3dplot")
    (synopsis "Coordinate transformation styles for 3d plotting in TikZ")
    (description
     "The package provides straightforward ways to define three-dimensional
coordinate frames through which to plot in TikZ.  The user can specify the
orientation of the main coordinate frame, and use standard TikZ commands and
coordinates to render their @code{tikzfigure}.  A secondary coordinate frame
is provided to allow rotations and translations with respect to the main
coordinate frame.  In addition, the package can also handle plotting
user-specified functions in spherical polar coordinates, where both the radius
and fill color can be expressed as parametric functions of polar angles.")
    (license license:lppl1.3+)))

(define-public texlive-tikz-among-us
  (package
    (name "texlive-tikz-among-us")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-among-us/"
                                     "tex/latex/tikz-among-us/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rrkzh1hain7mvnx4r5s7pccxvcj0izjbjwyrjg3nwin03mqqxy1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-among-us")
    (synopsis "Create some AmongUs characters in TikZ environments")
    (description
     "This package recreates some AmongUs characters in TikZ environments.
Some interesting uses alongside other packages are also supported.")
    (license license:lppl1.3c)))

(define-public texlive-tikz-bagua
  (package
    (name "texlive-tikz-bagua")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-bagua/"
                                     "tex/latex/tikz-bagua/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kn0ggpxz5ksnnxsfhbhavik7n8mpblm9x3qjxcsg2qhs286lwyh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-bagua")
    (synopsis "Draw Bagua symbols in Yijing")
    (description
     "This package provides commands for drawing symbols in Yijing (I Ching)
or Zhouyi using TikZ.  There is no need for extra special fonts for showing
these symbols.")
    (license license:lppl1.3c)))

(define-public texlive-tikz-bayesnet
  (package
    (name "texlive-tikz-bayesnet")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-bayesnet/"
                                     "tex/latex/tikz-bayesnet/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fmm93h0kl6q45sglfz1ssrnj20sqds9kvamf1dqzmfw2g77qwqr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-bayesnet")
    (synopsis
     "Draw Bayesian networks, graphical models and directed factor graphs")
    (description
     "The package provides a library supporting the display of Bayesian networks,
graphical models and (directed) factor graphs in LaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-tikz-bbox
  (package
    (name "texlive-tikz-bbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-bbox/"
                                     "tex/latex/tikz-bbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h224gmdbx63dff0zikv9grf5p7780rdxng2ws9d68k7rk961lb7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-bbox")
    (synopsis "Precise determination of bounding boxes in TikZ")
    (description
     "The built-in determination of the bounding box in TikZ is not entirely
accurate.  This is because, for Bezier curves, it is the smallest box that
contains all control points, which is in general larger than the box that just
contains the curve.  This library determines the exact bounding box of the
curve.")
    (license license:lppl1.3c)))

(define-public texlive-tikz-cd
  (package
    (name "texlive-tikz-cd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-cd/" "tex/generic/tikz-cd/"
                                     "tex/latex/tikz-cd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "188vd02cwy7r58cnam4aj4lq1jp295mmn3q1w3ki7p6n8v1gnl0c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-cd")
    (synopsis "Create commutative diagrams with TikZ")
    (description
     "The general-purpose drawing package TiKZ can be used to typeset
commutative diagrams and other kinds of mathematical pictures.  The purpose of
this package is to make the process of creation of such diagrams easier by
providing a convenient set of macros and reasonable default settings.  This
package also includes an arrow tip library that match closely the arrows
present in the Computer Modern typeface.")
    (license license:lppl1.3+)))

(define-public texlive-tikz-dependency
  (package
    (name "texlive-tikz-dependency")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-dependency/"
                                     "tex/latex/tikz-dependency/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12a31jqrxlaj8jj5f7p9vgwp8yqinl5ab0c3nfv4b1c9a08p8q3s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-dependency")
    (synopsis "Library for drawing dependency graphs")
    (description
     "The package provides a library that draws together existing TikZ
facilities to make a comfortable environment for drawing dependency graphs.
Basic facilities of the package include a lot of styling facilities, to let
you personalize the look and feel of the graphs.")
    (license (list license:lppl license:gpl2))))

(define-public texlive-tikz-dimline
  (package
    (name "texlive-tikz-dimline")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-dimline/"
                                     "tex/latex/tikz-dimline/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15zxc3zxl8mk0rq3b30d2a89lxlnybih49j8w8c6xsfn5mqbn8br"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-dimline")
    (synopsis "Technical dimension lines using PGF/TikZ")
    (description
     "@code{tikz-dimline} helps drawing technical dimension lines in TikZ
@code{picture} environments.")
    (license license:wtfpl2)))

(define-public texlive-tikz-ext
  (package
    (name "texlive-tikz-ext")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-ext/"
                                     "tex/generic/tikz-ext/"
                                     "tex/latex/tikz-ext/" "tex/plain/tikz-ext/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07ys0brfww0ik6g67gwd3rwiiz8ly0209d4hkkx18vw53sfj0dv2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-ext")
    (synopsis "Collection of libraries for PGF/TikZ")
    (description
     "This is a collection of libraries for PGF/TikZ.  Currently these are
@code{transformations.mirror}, @code{paths.arcto}, @code{paths.ortho},
@code{paths.timer}, @code{patterns.images}, @code{topaths.arcthrough} and
@code{misc}.")
    (license (list license:fdl1.3+ license:lppl))))

(define-public texlive-tikz-feynhand
  (package
    (name "texlive-tikz-feynhand")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-feynhand/"
                                     "tex/latex/tikz-feynhand/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11cz44yqxm7dhx53h27r3n5q911dhllzfl53a401w1wnybymj84s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-feynhand")
    (synopsis "Feynman diagrams with TikZ")
    (description
     "This package lets you draw Feynman diagrams using TikZ.  It is a low-end
modification of the TikZ-Feynman package, one of whose principal advantages is
the automatic generation of diagrams, for which it needs LuaTeX.
TikZ-FeynHand only provides the manual mode and hence runs in LaTeX without
any reference to LuaTeX.  In addition it provides some new styles for vertices
and propagators, alternative shorter keywords in addition to TikZ-Feynman's
longer ones, some shortcut commands for quickly customizing the diagrams look,
and the new feature of putting one propagator on top of another.")
    (license license:gpl3+)))

(define-public texlive-tikz-feynman
  (package
    (name "texlive-tikz-feynman")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-feynman/"
                                     "tex/latex/tikz-feynman/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yndmpghf3z5jddr3zcm5xw7v7zb6715d870ckjd5gifkvyv3nsy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-iftex texlive-pgfopts))
    (home-page "https://ctan.org/pkg/tikz-feynman")
    (synopsis "Feynman diagrams with TikZ")
    (description
     "This is a LaTeX package allowing Feynman diagrams to be easily generated
within LaTeX with minimal user instructions and without the need of external
programs.  It builds upon the TikZ package and leverages the graph placement
algorithms from TikZ in order to automate the placement of many vertices.
@code{tikz-feynman} allows fine-tuned placement of vertices so that even
complex diagrams can still be generated with ease.")
    (license license:lppl1.3+)))

(define-public texlive-tikz-imagelabels
  (package
    (name "texlive-tikz-imagelabels")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-imagelabels/"
                                     "source/latex/tikz-imagelabels/"
                                     "tex/latex/tikz-imagelabels/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hvyrkpabnqscnsqz56hby71vpbby03va0xa6gcjjxak65lscwkv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-imagelabels")
    (synopsis "Put labels on images using TikZ")
    (description
     "This package adds label texts to an existing image with the aid
of TikZ.  This may be used to label certain features in an image.")
    (license license:lppl1.3+)))

(define-public texlive-tikz-inet
  (package
    (name "texlive-tikz-inet")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-inet/"
                                     "tex/latex/tikz-inet/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1f4n5mp9hb92li2xywfzfrs8hjyrkd15xp97nh5rdgan695hvdpq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-inet")
    (synopsis "Draw interaction nets with TikZ")
    (description
     "The package extends TikZ with macros to draw interaction nets.")
    (license license:lppl)))

(define-public texlive-tikz-kalender
  (package
    (name "texlive-tikz-kalender")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-kalender/"
                                     "tex/latex/tikz-kalender/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cwdssvbaibjf7nla0d88nyzip407kgqvndid2p2gxc0b2afp69f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-kalender")
    (synopsis "LaTeX based calendar using TikZ")
    (description
     "This package generates a calendar included events provided as
@file{.events} files.")
    (license license:cc-by-sa4.0)))

(define-public texlive-tikz-karnaugh
  (package
    (name "texlive-tikz-karnaugh")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-karnaugh/"
                                     "tex/latex/tikz-karnaugh/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "091s9gavh8f4jya01nkjhzgh3f5b80ijiiaj7simnxawn60mh1z1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-karnaugh")
    (synopsis "Typeset Karnaugh maps using TikZ")
    (description
     "The @code{tikz-karnaugh} package is a LaTeX package used to draw
Karnaugh maps.  It uses TikZ to produce high quality graph from 1 to 12
variables, but this upper limit depends on the TeX memory usage and can be
different for you.  You can control colour, styles and distances.  It can be
considered as an upgrade and extension of Andreas W. Wieland's @code{karnaugh}
package towards TikZ supporting.")
    (license license:lppl1.0+)))

(define-public texlive-tikz-ladder
  (package
    (name "texlive-tikz-ladder")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-ladder/"
                                     "tex/latex/tikz-ladder/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fkq7z58h7g71ag4j77vy87hqgpp5q8qvw7kv1pmkff7ycrj8alw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-ladder")
    (synopsis "Draw ladder diagrams using TikZ")
    (description
     "The @code{tikz-ladder} package contains a collection of symbols for
typesetting ladder diagrams (PLC program) in agreement with the international
standard IEC-61131-3/2013.  It includes blocks (for representing functions and
function blocks) besides contacts and coils.  It extends the circuit library
of TikZ and allows you to draw a ladder diagram in the same way as you would
draw any other circuit.")
    (license license:lppl1.0+)))

(define-public texlive-tikz-lake-fig
  (package
    (name "texlive-tikz-lake-fig")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-lake-fig/"
                                     "tex/latex/tikz-lake-fig/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vyr3will7jivwc30aj13bm9gjj4nyl02754p42phn0y7gdf82kr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-lake-fig")
    (synopsis "Schematic diagrams of lakes")
    (description
     "This package contains a collection of schematic diagrams of lakes for
use in LaTeX documents.  Diagrams include representations of material budgets,
fluxes, and connectivity arrangements.")
    (license license:lppl1.3+)))

(define-public texlive-tikz-layers
  (package
    (name "texlive-tikz-layers")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-layers/"
                                     "tex/latex/tikz-layers/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1j5wbsybd10zmmiz3lfkb9gzjhxjnbhp7lmdq1fzngywxsb81iz6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-layers")
    (synopsis
     "Add graphical layers on TikZ: @code{behind}, @code{above} and @code{glass}")
    (description
     "TikZ-layers is a tiny package that provides, alongside
@code{background}, typical graphical layers on TikZ: @code{behind},
@code{above} and @code{glass}.  The layers may be selected with one of the
styles @code{on behind layer}, @code{on above layer}, @code{on glass layer} as
an option to a @code{scope} environment.")
    (license license:lppl1.3+)))

(define-public texlive-tikz-mirror-lens
  (package
    (name "texlive-tikz-mirror-lens")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-mirror-lens/"
                                     "tex/latex/tikz-mirror-lens/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sddmlki3bdd9js9vs1m1haqcdk3g1ji086jp1h4nfw6dy1s6y56"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-mirror-lens")
    (synopsis "Spherical mirrors and lenses in TikZ")
    (description
     "This package allows the automatic drawing of the image of objects in
spherical mirrors and lenses from the data of the focus, from the position and
height of the object.  It calculates the position and height of the image, and
also displays the notable rays.")
    (license license:lppl1.3c)))

(define-public texlive-tikz-nef
  (package
    (name "texlive-tikz-nef")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-nef/" "tex/latex/tikz-nef/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18b2452hfcndqhljq2hn437z6myc45hn62s4bnnjb0f3xnayq1qr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-nef")
    (synopsis "Create diagrams for neural networks")
    (description
     "The @code{nef} TikZ library provides predefined styles and shapes to
create diagrams for neural networks constructed with the methods of
the Neural Engineering Framework (NEF).  The following styles are
supported:
@itemize
@item @code{ea}: ensemble array,
@item @code{ens}: ensemble,
@item @code{ext}: external input or output,
@item @code{inhibt}: inhibitory connection,
@item @code{net}: network,
@item @code{pnode}: pass-through node,
@item @code{rect}: rectification ensemble,
@item @code{recurrent}: recurrent connection.
@end itemize")
    (license license:expat)))

(define-public texlive-tikz-network
  (package
    (name "texlive-tikz-network")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-network/"
                                     "tex/latex/tikz-network/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bs08sxxps4kjvgv53lc07ihkcaz2v1ygdc16vn46yy5dp16w2sz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-network")
    (synopsis "Draw networks with TikZ")
    (description
     "This package allows the creation of images of complex networks that are
seamlessly integrated into the underlying LaTeX files.")
    (license license:gpl3+)))

(define-public texlive-tikz-opm
  (package
    (name "texlive-tikz-opm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-opm/" "tex/latex/tikz-opm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kv26i1lfm9zsvqsajaz9fmz1gv7az3pknk29gg6zwjlg5nxqac3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-opm")
    (synopsis "Typeset OPM diagrams")
    (description
     "This package typesets OPM (Object-Process Methodology) diagrams using
LaTeX and PGF/TikZ.")
    (license license:lppl1.3+)))

(define-public texlive-tikz-optics
  (package
    (name "texlive-tikz-optics")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-optics/"
                                     "tex/latex/tikz-optics/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ii7h57klxq8fjag363wmaaxi9bnds898nl6s1abiqb13pgbmb9n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-optics")
    (synopsis "Library for drawing optical setups with TikZ")
    (description
     "This package provides a new TikZ library designed to easily draw optical
setups with TikZ.  It provides shapes for lens, mirror, etc.  The
geometrically (in)correct computation of light rays through the setup is left
to the user.")
    (license license:lppl1.3+)))

(define-public texlive-tikz-page
  (package
    (name "texlive-tikz-page")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-page/"
                                     "source/latex/tikz-page/"
                                     "tex/latex/tikz-page/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ck1jr37wd7mx8irm0niv43pmfy2ix5s08vybai8k0jgpvvwwi1j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-page")
    (synopsis "Small macro to help building nice and complex layout materials")
    (description
     "The package provides a small macro to help building nice and complex
layout materials.")
    (license license:lppl1.3+)))

(define-public texlive-tikz-palattice
  (package
    (name "texlive-tikz-palattice")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-palattice/"
                                     "tex/latex/tikz-palattice/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vbzr6821q88x4yipa9czcqgpwnkzkkzynxxbxyzy1kh9657hqvg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-palattice")
    (synopsis "Draw particle accelerator lattices with TikZ")
    (description
     "This package allows for drawing a map of a particle accelerator just by
giving a list of elements --- similar to lattice files for simulation
software.  The package includes 12 common element types like dipoles,
quadrupoles, cavities, or screens, as well as automatic labels with element
names, a legend, a rule, and an environment to fade out parts of the
accelerator.  The coordinate of any element can be saved and used for custom
TikZ drawings or annotations.  Thereby, lattices can be connected to draw
injection/extraction or even a complete accelerator facility.")
    (license license:lppl1.3+)))

(define-public texlive-tikz-planets
  (package
    (name "texlive-tikz-planets")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-planets/"
                                     "tex/latex/tikz-planets/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sgdkcn0li4k48m0fvhdk6j1kjvh6kzgjbq2jjwnzrdxz97s7hig"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-planets")
    (synopsis "Illustrate celestial mechanics and the solar system")
    (description
     "This TikZ-package makes it easy to illustrate celestial mechanics and
the solar system.  You can use it to draw sketches of the eclipses, the phases
of the Moon, etc.")
    (license license:cc-by-sa4.0)))

(define-public texlive-tikz-qtree
  (package
    (name "texlive-tikz-qtree")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-qtree/"
                                     "tex/latex/tikz-qtree/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15w7mr0rhra80rvf4zci2gkd5cy13ijlh64ay0bay87iviwbkn83"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-qtree")
    (synopsis "Use existing Qtree syntax for trees in TikZ")
    (description
     "The package provides a macro for drawing trees with TikZ using the easy
syntax of Alexis Dimitriadis Qtree.  It improves on TikZ's standard
tree-drawing facility by laying out tree nodes without collisions; it improves
on Qtree by adding lots of features from TikZ (for example, edge labels,
arrows between nodes); and it improves on @code{pst-qtree} in being usable
with pdfTeX and XeTeX.")
    (license license:gpl3+)))

(define-public texlive-tikz-relay
  (package
    (name "texlive-tikz-relay")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-relay/"
                                     "tex/latex/tikz-relay/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06q0iamg001lvqmi51j61xbwamgnhiah0aw9qv61n7fnxqpwj66c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-relay")
    (synopsis "TikZ library for typesetting electrical diagrams")
    (description
     "This package contains a collection of symbols for typesetting electrical
wiring diagrams for relay control systems.  The symbols are meant to be in
agreement with the international standard IEC-60617 which has been adopted
worldwide, with perhaps the exception of the USA.  It extends and modifies,
when needed, the TikZ-library @code{circuits.ee.IEC}.  A few non-standard
symbols are also included mainly to be used in presentations, particularly
with the @code{beamer} package.")
    (license license:lppl1.0+)))

(define-public texlive-tikz-sfc
  (package
    (name "texlive-tikz-sfc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-sfc/" "tex/latex/tikz-sfc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0blgyqvmnbwafx85mz4gkyhk0g0zqfmsd98gm3h794a4jfs3zl31"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-sfc")
    (synopsis
     "Symbols collection for typesetting Sequential Function Chart (SFC)
diagrams")
    (description
     "This package contains a collection of symbols for typesetting Sequential
Function Chart (SFC) diagrams in agreement with the international standard
IEC-61131-3/2013.  It includes steps (normal and initial), transitions,
actions and actions qualifiers (with and without time duration).  It extends
the circuit library of TikZ and allows you to draw an SFC diagram in same way
you would draw any other circuit.")
    (license license:lppl1.0+)))

(define-public texlive-tikz-swigs
  (package
    (name "texlive-tikz-swigs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-swigs/"
                                     "tex/latex/tikz-swigs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0brbq02vafaajzrwrkg20gy5k3zlzvv7ycgkw0aa20l8rxjcyv71"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-swigs")
    (synopsis "Horizontally and vertically split elliptical nodes")
    (description
     "This package provides horizontally and vertically split
elliptical (pairs of) nodes in TikZ.  The package name derives from the fact
that split ellipses of this type are used to represent Single-World
Intervention Graph (SWIG) models which are used in counterfactual causal
inference.")
    (license (list license:lppl1.3c license:gpl3+))))

(define-public texlive-tikz-timing
  (package
    (name "texlive-tikz-timing")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-timing/"
                                     "source/latex/tikz-timing/"
                                     "tex/latex/tikz-timing/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19zs6agcli2glm92z8y89nr4049v5sqvnlddbwlwym5rni33kh1m"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ydoc")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ydoc))
    (propagated-inputs (list texlive-svn-prov))
    (home-page "https://ctan.org/pkg/tikz-timing")
    (synopsis "Easy generation of timing diagrams as TikZ pictures")
    (description
     "This package provides macros and an environment to generate timing
diagrams (digital waveforms) without much effort.  The TikZ package is used to
produce the graphics.  A tabular-like environment is provided to produce
larger timing diagrams.")
    (license license:lppl)))

(define-public texlive-tikz-trackschematic
  (package
    (name "texlive-tikz-trackschematic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-trackschematic/"
                                     "tex/latex/tikz-trackschematic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11dak88q9n54i385sjk4nxini2fycdfmhs2h41fdf9k2012ykdnx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-trackschematic")
    (synopsis "TikZ library for creating track diagrams in railways")
    (description
     "This TikZ library is a toolbox of symbols geared primarily towards
creating track schematic for either research or educational purposes.  It
provides a TikZ frontend to some of the symbols which may be needed to
describe situations and layouts in railway operation.  The library is divided
into sublibraries: @code{topology}, @code{trafficcontrol}, @code{vehicles},
@code{constructions}, @code{electrics}, @code{symbology}, and
@code{measures}.")
    (license license:isc)))

(define-public texlive-tikz-truchet
  (package
    (name "texlive-tikz-truchet")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikz-truchet/"
                                     "source/latex/tikz-truchet/"
                                     "tex/latex/tikz-truchet/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1v959iw7swkkam73q759m09s5fcv932gx9d1vqj6n3b2yzxxc85b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikz-truchet")
    (synopsis "Draw Truchet tiles")
    (description
     "This is a package for LaTeX that draws Truchet tiles, as used in Colin
Beveridge's article Too good to be Truchet in issue 08 of Chalkdust.")
    (license license:expat)))

(define-public texlive-tikzbricks
  (package
    (name "texlive-tikzbricks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikzbricks/"
                                     "tex/latex/tikzbricks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wf5hdwpprbbxmd0rrwvk54raiwpv4q6qgd2gpbba6d26bmgjd1w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikzbricks")
    (synopsis "Drawing bricks with TikZ")
    (description
     "This package provides a small LaTeX package to draw bricks with TikZ.
The user can modify color, shape, and viewpoint.")
    (license license:lppl1.3c)))

(define-public texlive-tikzcodeblocks
  (package
    (name "texlive-tikzcodeblocks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikzcodeblocks/"
                                     "tex/latex/tikzcodeblocks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04c8bjl3l97vsh7cydbh20wnq93my19avkhcf4kh0g5cvq02nizp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikzcodeblocks")
    (synopsis "Helps to draw codeblocks like Scratch, NEPO and PXT in TikZ")
    (description
     "@code{tikzcodeblocks} is a LaTeX package for typesetting blockwise
graphic programming languages like Scratch, NEPO or PXT.")
    (license license:lppl1.3c)))

(define-public texlive-tikzducks
  (package
    (name "texlive-tikzducks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/tikzducks/"
                                     "tex/generic/tikzducks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cs4mywxcz2r2y7dpbbmc44sc6vjwbqq6b5nqxjwwqdi2khrgqfl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikzducks")
    (synopsis "Package for using rubber ducks in TikZ")
    (description
     "The package is a LaTeX package for ducks to be used in TikZ pictures.")
    (license license:lppl1.3c)))

(define-public texlive-tikzfill
  (package
    (name "texlive-tikzfill")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikzfill/" "tex/latex/tikzfill/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11a0mma05wx9v9aprwr7lh1k3njx0xgpbs943rkliy9f1az0lqma"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikzfill")
    (synopsis "TikZ libraries for filling with images and patterns")
    (description
     "This is a collection of TikZ libraries which add further options to fill
TikZ paths with images and patterns.  The libraries comprise fillings with
images from files and from TikZ pictures.  Also, patterns of hexagons and of
rhombi are provided.")
    (license license:lppl1.3+)))

(define-public texlive-tikzinclude
  (package
    (name "texlive-tikzinclude")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikzinclude/"
                                     "source/latex/tikzinclude/"
                                     "tex/latex/tikzinclude/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mcgzbfvj6pksr18813kpnknkdpzlyi0rncbn9g11ac0g0lyzgqq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikzinclude")
    (synopsis "Import TikZ images from collections")
    (description
     "The package addresses the problem of importing only one TikZ-image from
a file holding multiple images.")
    (license license:lppl1.3+)))

(define-public texlive-tikzlings
  (package
    (name "texlive-tikzlings")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikzlings/"
                                     "tex/latex/tikzlings/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cqja06i3s8w3wbz6dhlhbri1zhqsyh8jhyahi5v8q9ywdm389yd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikzlings")
    (synopsis "Collection of cute little animals and similar creatures")
    (description
     "This package provides a collection of LaTeX packages for drawing cute
little animals and similar creatures using TikZ.  Currently, the following
TikZlings are included: anteater, bat, bear, bee, bug, cat, chicken, coati,
elephant, hippo, koala, marmot, mole, mouse, owl, panda, penguin, pig, rhino,
sheep, sloth, snowman, squirrel, and wolf.  These little drawings can be
customized in many ways.")
    (license license:lppl1.3c)))

(define-public texlive-tikzmark
  (package
    (name "texlive-tikzmark")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikzmark/"
                                     "source/latex/tikzmark/"
                                     "tex/latex/tikzmark/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m3yij12kgbgficln9vdgc43bi0si7j0j86lv2k69f1bwf865w4z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikzmark")
    (synopsis "Use TikZ's method of remembering a position on a page")
    (description
     "The @code{tikzmark} package defines a command to remember a position on
a page for later (or earlier) use, primarily (but not exclusively) with
TikZ.")
    (license license:lppl1.3c)))

(define-public texlive-tikzmarmots
  (package
    (name "texlive-tikzmarmots")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikzmarmots/"
                                     "tex/latex/tikzmarmots/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0j1z78r43czg09inw76ksgs97l7klivi93w7hvcvafd47h9zcvsg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikzmarmots")
    (synopsis "Drawing little marmots in TikZ")
    (description
     "This is a LaTeX package for marmots to be used in TikZ pictures.
These little figures are constructed in such a way that they may even borrow
some garments and other attributes from the TikZducks.")
    (license license:lppl1.3c)))

(define-public texlive-tikzorbital
  (package
    (name "texlive-tikzorbital")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikzorbital/"
                                     "tex/latex/tikzorbital/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rjbl8gcsf752hkrn2j7angvwh55vldsd168w581frmx3g25d9rb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikzorbital")
    (synopsis "Atomic and molecular orbitals using TikZ")
    (description
     "This package draws atomic s, p and d orbitals, as well as molecular
orbital diagrams.")
    (license license:lppl)))

(define-public texlive-tikzpackets
  (package
    (name "texlive-tikzpackets")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikzpackets/"
                                     "tex/latex/tikzpackets/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0i5v0yblm3fw0wy0vhl2a0g1r8ib72d2knk60apqvqizl98fn8ff"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikzpackets")
    (synopsis "Display network packets")
    (description
     "This package allows you to easily display network packets graphically.")
    (license license:expat)))

(define-public texlive-tikzpagenodes
  (package
    (name "texlive-tikzpagenodes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikzpagenodes/"
                                     "source/latex/tikzpagenodes/"
                                     "tex/latex/tikzpagenodes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13ddkwm4a1x2b47zqjk2m55y2dwl09rl3s0pm1vmxv7h2sawgqbr"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ydoc")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ydoc))
    (home-page "https://ctan.org/pkg/tikzpagenodes")
    (synopsis "Single TikZ node for the whole page")
    (description
     "The package provides special PGF/TikZ nodes for the text, marginpar,
footer and header area of the current page.  They are inspired by the current
page node defined by PGF/TikZ itself.")
    (license license:lppl)))

(define-public texlive-tikzpeople
  (package
    (name "texlive-tikzpeople")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikzpeople/"
                                     "tex/latex/tikzpeople/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sgxabjy54zcw0dkb5hgi9d84ilq4ik30xwwd1n8jhhmi4vg2sm7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikzpeople")
    (synopsis "Draw people-shaped nodes in TikZ")
    (description
     "This package provides people-shaped nodes in the style of Microsoft
Visio clip art, to be used with TikZ.  The available, highly customizable,
node shapes are: alice, bob, bride, builder, businessman, charlie, chef,
conductor, cowboy, criminal, dave, devil, duck, graduate, groom, guard,
jester, judge, maninblack, mexican, nun, nurse, physician, pilot, police,
priest, sailor, santa, surgeon.")
    (license license:lppl1.3+)))

(define-public texlive-tikzpfeile
  (package
    (name "texlive-tikzpfeile")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikzpfeile/"
                                     "source/latex/tikzpfeile/"
                                     "tex/latex/tikzpfeile/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h6kkrm462hk2hvbdqqjai3gxsslibghxbjyq3ih0vps7fakglc6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikzpfeile")
    (synopsis "Draw arrows using PGF/TikZ")
    (description
     "In a document with a lot of diagrams created with PGF/TikZ, there is
a possibility of the reader being distracted by different sorts of arrowheads
in the diagrams and in the text (as, e.g., in @code{\\rightarrow}).  The
package defines macros to create all arrows using PGF/TikZ, so as to avoid the
problem.")
    (license license:lppl)))

(define-public texlive-tikzpingus
  (package
    (name "texlive-tikzpingus")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikzpingus/"
                                     "makeindex/tikzpingus/"
                                     "tex/latex/tikzpingus/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03gld5j5dhz28imphgrf5cr6pf9ls0rgk46xg0jns9m064g9mh7h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikzpingus")
    (synopsis "Penguins with TikZ")
    (description
     "@code{tikzpingus} is a package similar to tikzducks but with penguins
and a vast set of gadgets and extras (capable of changing the wing-positions,
body-types, and more).")
    (license license:gpl3)))

(define-public texlive-tikzposter
  (package
    (name "texlive-tikzposter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikzposter/"
                                     "source/latex/tikzposter/"
                                     "tex/latex/tikzposter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hl5p14a79575s5n5rx4yy8vxcb2qrdhx851rhms7dk2sqcfynn5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikzposter")
    (synopsis "Create scientific posters using TikZ")
    (description
     "This package provides a document class provides a simple way of using
TikZ for generating posters.  Several formatting options are available, and
spacing and layout of the poster is to a large extent automated.")
    (license license:lppl1.2+)))

(define-public texlive-tikzscale
  (package
    (name "texlive-tikzscale")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikzscale/"
                                     "source/latex/tikzscale/"
                                     "tex/latex/tikzscale/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1iq7f9jnw86rhp7b3sim3z56ygj005zygzfc0bdnpmx5s4ds1gpv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikzscale")
    (synopsis "Resize pictures while respecting text size")
    (description
     "The package extends the @code{\\includegraphics} command to support
@code{tikzpicture} environments.  It allows scaling of TikZ images and
PGFPlots to a given width or height without changing the text size.")
    (license license:lppl1.3+)))

(define-public texlive-tikzsymbols
  (package
    (name "texlive-tikzsymbols")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikzsymbols/"
                                     "source/latex/tikzsymbols/"
                                     "tex/latex/tikzsymbols/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q19w9adpfxrsh7jmf4qpjarhgb4wng66kjkmalcxijd99kxbkhk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikzsymbols")
    (synopsis "Some symbols created using TikZ")
    (description
     "The package provides various emoticons, cooking symbols and trees.")
    (license license:lppl1.3c)))

(define-public texlive-tikztosvg
  (package
    (name "texlive-tikztosvg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/tikztosvg.1"
                                     "doc/man/man1/tikztosvg.man1.pdf"
                                     "doc/support/tikztosvg/"
                                     "scripts/tikztosvg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1h1g3vsljx3bz929krr21i65n20drwhwxi88gwcvrxrgsvi9xj08"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "tikztosvg")))
    (home-page "https://ctan.org/pkg/tikztosvg")
    (synopsis "Utility for rendering TikZ diagrams to SVG")
    (description
     "This package provides a shell script that calls XeTeX and
@command{pdf2svg} to convert TikZ environments to SVG files.")
    (license license:gpl3)))

(define-public texlive-tikzviolinplots
  (package
    (name "texlive-tikzviolinplots")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tikzviolinplots/"
                                     "tex/latex/tikzviolinplots/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12nrjivmqbpm71kzfgsl6ih5lxv9sv79iidh2yjjyl5dvhlbjkhm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tikzviolinplots")
    (synopsis "Draws violin plots from data")
    (description
     "This package enables the user to draw violin plots, calculating the
kernel density estimation from the data and plotting the resulting curve
inside a @code{tikzpicture} environment.  It supports different kernels, and
allows the user to either set the bandwidth value for each plot or use
a default value.")
    (license license:lppl1.3+)))

(define-public texlive-tile-graphic
  (package
    (name "texlive-tile-graphic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tile-graphic/"
                                     "source/latex/tile-graphic/"
                                     "tex/latex/tile-graphic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vg2nrb6cjgkmbkv8igs76vzl1vzvisqlm1y612j4144v26n05nw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tile-graphic")
    (synopsis "Create tiles of a graphical file")
    (description
     "This package breaks a given graphical file into @samp{n} rows and
@samp{m} columns of subgraphics, which are called tiles.  The tiles can be
written separately to individual PDF files, or packaged into a single PDF
file.")
    (license license:lppl1.2+)))

(define-public texlive-timing-diagrams
  (package
    (name "texlive-timing-diagrams")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/timing-diagrams/"
                                     "tex/latex/timing-diagrams/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06hzcbbinrlvdsp9jxs82xi9b94x76f239z5b1x3y41ip3n51b1p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/timing-diagrams")
    (synopsis "Draw timing diagrams")
    (description
     "The package provides commands to draw and annotate various kinds of
timing diagrams, using TikZ.")
    (license license:lppl1.3+)))

(define-public texlive-tipfr
  (package
    (name "texlive-tipfr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tipfr/" "tex/latex/tipfr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1frgk49mw7wi18065y4ikg75vg03d2vbdflfnyanixn46zpf2p8z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tipfr")
    (synopsis "Produces calculator's keys with the help of TikZ")
    (description
     "The package provides commands to draw calculator keys with the help of
TikZ.  It also provides commands to draw the content of screens and of menu
items.")
    (license license:lppl)))

(define-public texlive-tkz-base
  (package
    (name "texlive-tkz-base")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tkz-base/" "tex/latex/tkz-base/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0p62amxjf7ab72a4pcgd03cd4799n7k1adhlbwlck3dr4zn5m8wx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tkz-base")
    (synopsis "Tools for drawing with a cartesian coordinate system")
    (description
     "The bundle is a set of packages, designed to give mathematics
teachers (and students) easy access to programming of drawings with TikZ.")
    (license license:lppl1.3+)))

(define-public texlive-tkz-berge
  (package
    (name "texlive-tkz-berge")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tkz-berge/" "tex/latex/tkz-berge/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16pgdkf0s97gkd662pddvxr5jbk68mcbikz4rclmv88d9zlgccxr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tkz-berge")
    (synopsis "Macros for drawing graphs of graph theory")
    (description
     "The package provides a collection of useful macros for drawing classic
graphs of graph theory, or to make other graphs.  This package has been taken
temporarily out of circulation to give the author time to investigate some
problems.")
    (license license:lppl1.3c)))

(define-public texlive-tkz-doc
  (package
    (name "texlive-tkz-doc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tkz-doc/"
                                     "tex/latex/tkz-doc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nqwfl75id6sga4bm7ha9qqp6zzgwflvqncr438db13bhxsq5mkw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tkz-doc")
    (synopsis "Documentation macros for the TKZ series of packages")
    (description
     "This bundle offers a documentation class (@code{tkz-doc}) and
a package (@code{tkzexample}).  These files are used in the documentation of
the author's packages @code{tkz-base}, @code{tkz-euclide}, @code{tkz-fct},
@code{tkz-linknodes}, and @code{tkz-tab}.")
    (license license:lppl1.3+)))

(define-public texlive-tkz-euclide
  (package
    (name "texlive-tkz-euclide")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tkz-euclide/"
                                     "tex/latex/tkz-euclide/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x8i8xr5k66yrvbwcj2affsvq219hhjzmwwy5afn3dzzbvbvdjph"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tkz-euclide")
    (synopsis "Tools for drawing Euclidean geometry")
    (description
     "The @code{tkz-euclide} package is a set of files designed to give math
teachers and students easy access to the programming of Euclidean geometry
with TikZ.")
    (license license:lppl1.3+)))

(define-public texlive-tkz-fct
  (package
    (name "texlive-tkz-fct")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tkz-fct/" "tex/latex/tkz-fct/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0czwqkdws24qdp22s6p3m87fpfqmwdqjzwxckzkn3ig6rcl63nqj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tkz-fct")
    (synopsis "Tools for drawing graphs of functions")
    (description
     "The @code{tkz-fct} package is designed to give math teachers (and
students) easy access to programming graphs of functions with TikZ and
Gnuplot.")
    (license license:lppl1.3+)))

(define-public texlive-tkz-graph
  (package
    (name "texlive-tkz-graph")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tkz-graph/"
                                     "tex/latex/tkz-graph/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mdfdi97d8q7jqy7l3pqqs7ai4ph5r1aci3ahfsg5zmpmkwr981r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tkz-graph")
    (synopsis "Draw graph-theory graphs")
    (description
     "The package is designed to create graph diagrams as simply as possible,
using TikZ.")
    (license license:lppl1.3+)))

(define-public texlive-tkz-orm
  (package
    (name "texlive-tkz-orm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tkz-orm/" "tex/latex/tkz-orm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qmwiglz59djq0xkpsfgqzdf6872z33z9faxn86krs5mxmrik6cc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tkz-orm")
    (synopsis "Create Object-Role Model (ORM) diagrams")
    (description
     "The package provides styles for drawing Object-Role Model (ORM) diagrams
in TeX based on the PGF and TikZ picture environment.")
    (license (list license:gpl2 license:lppl1.3+))))

(define-public texlive-tkz-tab
  (package
    (name "texlive-tkz-tab")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tkz-tab/" "tex/latex/tkz-tab/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0j50pf0lf9dbi0zfnqm62rlyazsgbmpcqwlajqsjccqqkirdv6pb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tkz-tab")
    (synopsis "Tables of signs and variations using PGF/TikZ")
    (description
     "The package provides comprehensive facilities for preparing lists of
signs and variations, using PGF.  This package has been taken temporarily out
of circulation to give the author time to investigate some problems.")
    (license license:lppl1.3+)))

(define-public texlive-tkzexample
  (package
    (name "texlive-tkzexample")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tkzexample/"
                                     "tex/latex/tkzexample/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1y445fjvy13cqa9y1sbac43wbmidvfn7vb7jws11fl4lj7vvgvhz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tkzexample")
    (synopsis "Package for the documentation of all @samp{tkz-} packages")
    (description
     "This package is needed to compile the documentation of all @samp{tkz-}
packages (like @code{tkz-euclide}).")
    (license license:lppl1.3+)))

(define-public texlive-tlcockpit
  (package
    (name "texlive-tlcockpit")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/tlcockpit.1"
                                     "doc/man/man1/tlcockpit.man1.pdf"
                                     "doc/support/tlcockpit/"
                                     "scripts/tlcockpit/"
                                     "source/support/tlcockpit/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nv0wx21x022isw8rycvqdqwiz4ay6ws36bbcpqfqkjmvz5qr76w"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "icedtea")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:link-scripts #~(list "tlcockpit.sh")
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'locate-java
            (lambda* (#:key inputs #:allow-other-keys)
              (let ((java (search-input-file inputs "/bin/java")))
                (substitute* "scripts/tlcockpit/tlcockpit.sh"
                  (("java -") (string-append java " -")))))))))
    ;; FIXME: missing EventTarget.class.
    (inputs (list icedtea))
    (home-page "https://ctan.org/pkg/tlcockpit")
    (synopsis "GUI frontend to TeX Live Manager")
    (description
     "This package aims at being a GUI for @command{tlmgr}, the TeX Live
Manager, with a modern look and feel.")
    (license license:gpl3+)))

(define-public texlive-tonevalue
  (package
    (name "texlive-tonevalue")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tonevalue/"
                                     "tex/latex/tonevalue/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16a724k0c8s3i2pdjfsq5v2z4v5nqdpnxvh63j4ngj822w9llg1z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tonevalue")
    (synopsis
     "Tool for linguists and phoneticians to visualize tone value patterns")
    (description
     "This package provides a TikZ-based solution to typeset visualisations of
tone values.  Currently, unt's model is implemented.  Support for more models
is planned.")
    (license license:asl2.0)))

(define-public texlive-tpic2pdftex
  (package
    (name "texlive-tpic2pdftex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/tpic2pdftex.1"
                                     "doc/man/man1/tpic2pdftex.man1.pdf"
                                     "doc/tpic2pdftex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02nf2fg4xzh8lbbddvm44qyvcvfn5b7kzcyg729a58l29gd88pbs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-tpic2pdftex-bin))
    (home-page "https://ctan.org/pkg/tpic2pdftex")
    (synopsis "Use @code{tpic} commands in pdfTeX")
    (description
     "The Awk script converts Pic language, embedded inline (delimited by
@code{.PS} and @code{.PE} markers), to @code{\\pdfliteral} commands.")
    (license license:gpl3+)))

(define-public texlive-tpic2pdftex-bin
  (package
    (inherit texlive-bin)
    (name "texlive-tpic2pdftex-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '("tpic2pdftex"))
            (delete-other-directories "texk" '())))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons* "--enable-tpic2pdftex" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "utils/tpic2pdftex"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "utils/tpic2pdftex"
                  (invoke "make" "install"))))))))
    (native-inputs '())
    (inputs '())
    (propagated-inputs '())
    (home-page (package-home-page texlive-tpic2pdftex))
    (synopsis "Binary for @code{texlive-tpic2pdftex}")
    (description
     "This package provides the binary for @code{texlive-tpic2pdftex}.")
    (license (package-license texlive-tpic2pdftex))))

(define-public texlive-tqft
  (package
    (name "texlive-tqft")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tqft/" "source/latex/tqft/"
                                     "tex/latex/tqft/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08lykpnw0hifhmh96pb7s3dd8sbzmz3gqyrwy5ann9fqxxjczf2d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tqft")
    (synopsis "Drawing TQFT diagrams with TikZ/PGF")
    (description
     "The package defines some node shapes useful for drawing TQFT diagrams
with TikZ/PGF.  That is, it defines highly customisable shapes that look like
cobordisms between circles, such as those used in TQFT and other mathematical
diagrams.")
    (license license:lppl1.3+)))

(define-public texlive-tram
  (package
    (name "texlive-tram")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tram/"
                                     "fonts/source/public/tram/"
                                     "tex/latex/tram/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b26615dd1qs12vl9d82xcxlc718s5jgirzygss9g7m908w2hqch"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tram")
    (synopsis "Typeset tram boxes in LaTeX")
    (description
     "Tram boxes are highlighted with patterns of dots; the package defines an
environment @code{tram} that typesets its content into a tram box.  The
pattern used may be selected in an optional argument to the environment.")
    (license license:lppl)))

(define-public texlive-tsemlines
  (package
    (name "texlive-tsemlines")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/latex/tsemlines/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c7sjdrgqbjw6f2s3185k5rlkig643pkkahjisx16h0akbbdm4k3"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tsemlines")
    (synopsis "Support for the ancient @code{\\emline} macro")
    (description
     "Occasional Documents appear, that use graphics generated by TeXcad from
the EmTeX distribution.  These documents often use the @code{\\emline} macro,
which produced lines at an arbitrary orientation.  The present package
emulates the macro, using TikZ.")
    (license license:public-domain)))

(define-public texlive-ttfutils
  (package
    (name "texlive-ttfutils")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/ttf2afm.1"
                                     "doc/man/man1/ttf2afm.man1.pdf"
                                     "doc/man/man1/ttf2pk.1"
                                     "doc/man/man1/ttf2pk.man1.pdf"
                                     "doc/man/man1/ttf2tfm.1"
                                     "doc/man/man1/ttf2tfm.man1.pdf"
                                     "doc/man/man1/ttfdump.1"
                                     "doc/man/man1/ttfdump.man1.pdf"
                                     "doc/ttf2pk/"
                                     "fonts/enc/ttf2pk/base/"
                                     "fonts/sfd/ttf2pk/"
                                     "ttf2pk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16rxhypar4gw0fsbqzh6r2mppqxd3cdjzv11c84mqzk7qvifvb6y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-ttfutils-bin))
    (home-page "https://ctan.org/pkg/ttfutils")
    (synopsis "Convert TrueType to TFM and PK fonts")
    ;; XXX: "ttf2afm" is actually provided by PDFTeX, through "texlive-bin".
    (description
     "This package provides utilities to convert TrueType to TFM and PK fonts:
@command{ttf2afm}, @command{ttf2pk}, @command{ttf2tfm}, and
@command{ttfdump}.")
    (license license:gpl2+)))

(define-public texlive-ttfutils-bin
  (package
    (inherit texlive-bin)
    (name "texlive-ttfutils-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("ttfdump" "ttf2pk2"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons* "--enable-ttfdump"
                 "--enable-ttf2pk2"
                 (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/ttfdump"
                    (invoke "make" "check"))
                  (with-directory-excursion "texk/ttf2pk2"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/ttfdump"
                  (invoke "make" "install"))
                (with-directory-excursion "texk/ttf2pk2"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list freetype texlive-libkpathsea))
    (propagated-inputs '())
    (home-page (package-home-page texlive-ttfutils))
    (synopsis "Binaries for @code{texlive-ttfutils}")
    (description
     "This package provides the binaries for @code{texlive-ttfutils}.")
    (license (package-license texlive-ttfutils))))

(define-public texlive-twemojis
  (package
    (name "texlive-twemojis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/twemojis/"
                                     "source/latex/twemojis/"
                                     "tex/latex/twemojis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wim1325dcx779305cany8rsifi67y8pbwifs4qbh090dzx5sy6r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/twemojis")
    (synopsis "Use Twitter's open source emojis through LaTeX commands")
    (description
     "This package provides a simple wrapper which allows using Twitter's
open source emojis through LaTeX commands.  This relies on images, so no fancy
Unicode font stuff is needed and it should work on every installation.")
    (license (list license:lppl1.3+ license:cc-by4.0))))

(define-public texlive-typeoutfileinfo
  (package
    (name "texlive-typeoutfileinfo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/typeoutfileinfo/"
                                     "scripts/typeoutfileinfo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0r28n4r20grdg1gc2ym4vc8gp79favks43mp9q96dxnywd4pcik6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "typeoutfileinfo.sh")))
    (propagated-inputs (list texlive-fileinfo))
    (home-page "https://ctan.org/pkg/typeoutfileinfo")
    (synopsis "Display class/package/file information")
    (description
     "The package provides a minimalist shell script, for Unix systems,
that displays the information content in a @code{\\ProvidesFile},
@code{\\ProvidesPackage} or @code{\\ProvidesClass} command in a LaTeX source
file.")
    (license license:lppl1.3+)))

(define-public texlive-tzplot
  (package
    (name "texlive-tzplot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tzplot/" "tex/latex/tzplot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09k84vjvl3qkp8jffv3j5bksq3jaad2p71yj715z39qf36hwvm7s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tzplot")
    (synopsis "Plot graphs with TikZ abbreviations")
    (description
     "This is a LaTeX package that provides TikZ-based macros to make it easy
to draw graphs.  The macros provided in this package are just abbreviations
for TikZ codes, which can be complicated; but using the package will hopefully
make drawing easier, especially when drawing repeatedly.  The macros were
chosen and developed with an emphasis on drawing graphs in economics.")
    (license license:lppl1.3c)))

(define-public texlive-upmendex
  (package
    (name "texlive-upmendex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/upmendex.1"
                                     "doc/man/man1/upmendex.man1.pdf"
                                     "doc/support/upmendex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mj8nmqr3z7b802kvjmnkckq89l694an7s639yghf3b9b5v7xihx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-upmendex-bin))
    (home-page "https://ctan.org/pkg/upmendex")
    (synopsis "Multilingual index processor")
    (description
     "The package is a multilingual index processor with the following
features:
@itemize

@item mostly compatible with @command{makeindex} and upper compatible with
@command{mendex};

@item supports UTF-8 and works with upLaTeX, XeLaTeX and LuaLaTeX;

@item supports Latin (including non-English), Greek, Cyrillic, Korean Hangul
and Chinese Han (Hanzi ideographs) scripts, as well as Japanese Kana.

@item supports Devanagari, Thai, Arabic and Hebrew scripts (experimental).

@item supports four kinds of sort orders (Pinyin, Radical-Stroke, Stroke and
Zhuyin) for Chinese Han scripts (Hanzi ideographs).

@item applies International Components for Unicode (ICU) for sorting process.

@end itemize")
    (license license:bsd-3)))

(define-public texlive-upmendex-bin
  (package
    (inherit texlive-bin)
    (name "texlive-upmendex-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs/" '())
            (delete-other-directories "utils/" '())
            (delete-other-directories "texk/" '("upmendex"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-upmendex" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/upmendex"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda* (#:key inputs native-inputs #:allow-other-keys)
                (with-directory-excursion "texk/upmendex"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list icu4c texlive-libkpathsea))
    (propagated-inputs '())
    (home-page (package-home-page texlive-upmendex))
    (synopsis "Binary for @code{texlive-upmendex}")
    (description
     "This package provides the binary for @code{texlive-upmendex}.")
    (license (package-license texlive-upmendex))))

(define-public texlive-utf8mex
  (package
    (name "texlive-utf8mex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/mex/utf8mex/" "tex/mex/utf8mex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13013asha1v6vk743hxk4naciiham0cpar6jw0ndlh7mbmyll2y8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/utf8mex")
    (synopsis "Tools to produce formats that read Polish language input")
    (description
     "The bundle provides files for building formats to read input in Polish
encodings.")
    (license license:public-domain)))

(define-public texlive-utfsym
  (package
    (name "texlive-utfsym")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/utfsym/" "tex/latex/utfsym/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bbdhi9fy3bzm9qrjca8ghl04pv9iky380if17w1hxhp2jpd691b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/utfsym")
    (synopsis "Provides various Unicode symbols")
    (description
     "This package provides various symbols from the Unicode in order to be
able to use them originally in a school setting such as on worksheets.")
    (license license:cc0)))

(define-public texlive-venndiagram
  (package
    (name "texlive-venndiagram")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/venndiagram/"
                                     "source/latex/venndiagram/"
                                     "tex/latex/venndiagram/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n48jgb0kbbnyk5pjg99l8hb1b3f1h30z78cl9lza2pi11p8mbgj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/venndiagram")
    (synopsis "Creating Venn diagrams with TikZ")
    (description
     "The package assists generation of simple two- and three-set Venn
diagrams for lectures or assignment sheets.")
    (license license:lppl)))

(define-public texlive-visualfaq
  (package
    (name "texlive-visualfaq")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/visualfaq/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fjx5y95n8bhsnwsw34sazbgygznvw76z01rrxmn1bp8za7751n0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/visualfaq")
    (synopsis "Visual LaTeX FAQ")
    (description
     "Having trouble finding the answer to a LaTeX question?  The @emph{Visual
LaTeX FAQ} is a search interface that presents over a hundred typeset samples
of frequently requested document formatting.  Simply click on a hyperlinked
piece of text and the @emph{Visual LaTeX FAQ} will send your web browser to
the appropriate page in the TeX FAQ.")
    (license license:lppl)))

(define-public texlive-visualfaq-fr
  (package
    (name "texlive-visualfaq-fr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/visualfaq-fr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xk0qly49dqkrw1qjhnyp4r7y5jykghlp1y26hipghlaqqhdynga"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/visualfaq-fr")
    (synopsis "FAQ LaTeX visuelle francophone")
    (description
     "The Visual LaTeX FAQ is an innovative new search interface on LaTeX
Frequently Asked Questions.  This version is a French translation, offering
links to the French-speaking LaTeX FAQ.")
    (license license:lppl1.3c)))

(define-public texlive-visualpstricks
  (package
    (name "texlive-visualpstricks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/visualpstricks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wfri908smlw1ngqq1mjll2b80b29piicqmv67x0xs1v3kc2sz3s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/visualpstricks")
    (synopsis "Visual help for PSTricks based on images with minimum text")
    (description
     "Visual help for PSTricks based on images with minimum text, one image
per command or per parameter.")
    (license license:gpl3+)))

(define-public texlive-visualtikz
  (package
    (name "texlive-visualtikz")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/visualtikz/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1q0a1mhc330z8cnhghp2p46bxsmzz8cdba8hcvssglz0gsq5z5fc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/visualtikz")
    (synopsis "Visual help for TikZ based on images with minimum text")
    (description
     "This package provides a visual help for TikZ based on images with
minimum text: an image per command or parameter.  The document is in French,
but will be translated into English later.")
    (license license:lppl1.3+)))

(define-public texlive-web
  (package
    (name "texlive-web")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/tangle.1"
                                     "doc/man/man1/tangle.man1.pdf"
                                     "doc/man/man1/weave.1"
                                     "doc/man/man1/weave.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i8lvhz9k777c8wwqn8mh51w896d0ql7zxy9zbv9fpp0137n5bnj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-kpathsea))
    (home-page "https://ctan.org/pkg/web")
    (synopsis "Original literate programming system")
    (description
     "The system processes web files in two ways: firstly to rearrange them to
produce compilable code (using the program @command{tangle}), and secondly to
produce a TeX source (using the program @command{weave}) that may be typeset
for comfortable reading.")
    (license license:knuth)))

(define-public texlive-wheelchart
  (package
    (name "texlive-wheelchart")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/wheelchart/"
                                     "tex/latex/wheelchart/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ibpdhxip5wiwifjk1ck0r7wcbmbl2z7nbqay1zshncgb1igfr2x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/wheelchart")
    (synopsis "Draw wheelcharts with TikZ")
    (description
     "This package is based on the package TikZ and can be used to draw
wheelcharts with TikZ.  It provides several options to customize the
wheelcharts.")
    (license license:lppl1.3c)))

(define-public texlive-worldflags
  (package
    (name "texlive-worldflags")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/worldflags/"
                                     "tex/latex/worldflags/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1773hr3af98b7jvpkdg27v542iwclgznvbzal6aw3i1csf0a9dy1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/worldflags")
    (synopsis "Drawing flags with TikZ")
    (description
     "This is a package for drawing flags using TikZ.  Currently the national
flags of all independent nations are included, along with some other flags of
various organizations.  A flag can be drawn as a single TikZ-picture within
ordinary text, and as a picture element within a TikZ-picture.  The appearance
of a flag (size, frame etc.)  can be adapted using optional parameters.")
    (license license:lppl1.3+)))

(define-public texlive-xepersian
  (package
    (name "texlive-xepersian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/xepersian/"
                                     "fonts/misc/xetex/fontmapping/xepersian/"
                                     "source/xelatex/xepersian/"
                                     "tex/xelatex/xepersian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xyrzx3s3sfb4mx5jwxdnvs0m95952npa5s2ipkcj913shn3v94k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xepersian")
    (synopsis "Persian for LaTeX, using XeTeX")
    (description
     "This package provides a convenient interface for typesetting Persian and
English texts in LaTeX, using the XeTeX engine.")
    (license license:lppl1.3c)))

(define-public texlive-xepersian-hm
  (package
    (name "texlive-xepersian-hm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/xepersian-hm/"
                                     "source/xelatex/xepersian-hm/"
                                     "tex/xelatex/xepersian-hm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lq5bam9vx2phwphy2ig9hygsz4vvz4bx2c6f87my84kp8n3w25n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xepersian-hm")
    (synopsis "Fixes kashida feature in XePersian package")
    (description
     "The kashida feature in XePersian has problems with some fonts such as
the HM Series fonts and the XB Series fonts.  This package fixes these
problems.")
    (license license:lppl1.3c)))

(define-public texlive-xindex
  (package
    (name "texlive-xindex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/xindex/" "scripts/xindex/"
                                     "tex/latex/xindex/" "tex/lualatex/xindex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yxb42ipyfknb5rgqgcj1f8kwvvdavajjrw8b0pp3cggfa5whn17"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "xindex.lua")))
    (home-page "https://ctan.org/pkg/xindex")
    (synopsis "Unicode compatible index generation")
    (description
     "This package provides a Unicode compatible index program for LaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-xistercian
  (package
    (name "texlive-xistercian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xistercian/"
                                     "source/latex/xistercian/"
                                     "tex/latex/xistercian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "021iwd8w19dbj1iqm1fdf9s06lysbrackz0g897nmsf0fks6qf4r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xistercian")
    (synopsis "Cistercian numerals in LaTeX")
    (description
     "@code{xistercian} allows you to use Cistercian numerals in LaTeX.
The glyphs are created using PGF and to a certain degree configurable.  You
can use Cistercian numerals as page numbers using
@code{\\pagenumbering@{cistercian@}}.  The two main macros are:
@code{\\cistercian@{<counter>@}}, which formats the LaTeX2e counter as
a Cistercian numeral, and @code{\\cisterciannum@{<integer>@}}, formats the
integer (given as a string) as a Cistercian numeral.")
    (license license:lppl1.3c)))

(define-public texlive-xpdfopen
  (package
    (name "texlive-xpdfopen")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/pdfclose.1"
                                     "doc/man/man1/pdfclose.man1.pdf"
                                     "doc/man/man1/pdfopen.1"
                                     "doc/man/man1/pdfopen.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "130wvaypfrg9sav0pdcdy1g10fll8pqcsqsy70fxlzzr937glsh1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-xpdfopen-bin))
    (home-page "https://ctan.org/pkg/xpdfopen")
    (synopsis "Commands to control PDF readers, under X11")
    (description
     "The command-line programs @command{pdfopen} and @command{pdfclose} allow
you to control the X Window System version of Adobe's Acrobat Reader from the
command line or from within a (shell) script.  The programs work with
@command{xpdf} and @command{evince}.")
    (license license:public-domain)))

(define-public texlive-xpdfopen-bin
  (package
    (inherit texlive-bin)
    (name "texlive-xpdfopen-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '("xpdfopen"))
            (delete-other-directories "texk" '())))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-xpdfopen" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "utils/xpdfopen"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "utils/xpdfopen"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list libxt))
    (propagated-inputs '())
    (home-page (package-home-page texlive-xpdfopen))
    (synopsis "Binaries for @code{texlive-xpdfopen}")
    (description
     "This package provides the binaries for @code{texlive-xpdfopen}.")
    (license (package-license texlive-xpdfopen))))

(define-public texlive-xpicture
  (package
    (name "texlive-xpicture")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xpicture/"
                                     "source/latex/xpicture/"
                                     "tex/latex/xpicture/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pzqnrk7mw1k9madah2ym9qsy20d8i1x1abkvkxvx7rxw7w38s2p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xpicture")
    (synopsis "Extensions of LaTeX picture drawing")
    (description
     "The package extends the facilities of the @code{pict2e} and the
@code{curve2e} packages, providing extra reference frames, conic section
curves, graphs of elementary functions and other parametric curves.")
    (license license:lppl1.3+)))

(define-public texlive-amiri
  (package
    (name "texlive-amiri")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/amiri/"
                                     "fonts/truetype/public/amiri/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1d6yrh34fka9371a3vq72df593prik6s7z1i6myd0nix0c9jihp6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/amiri")
    (synopsis "Classical Arabic typeface, Naskh style")
    (description
     "Amiri is a classical Arabic typeface in Naskh style for typesetting books
and other running text.  It is a revival of the beautiful typeface pioneered
in the early 20th century by Bulaq Press in Cairo, also known as Amiria Press,
after which the font is named.  The project aims at the revival of the
aesthetics and traditions of Arabic typesetting, and adapting it to the era of
digital typesetting, in a publicly available form.")
    (license license:silofl1.1)))

(define-public texlive-amiweb2c-guide
  (package
    (name "texlive-amiweb2c-guide")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/amiweb2c-guide/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cxwsx49p3c162ysv0ydyxdncfg8ij9sx2x7c4pvzb0yidvad01c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/amiweb2c-guide")
    (synopsis "How to install AmiWeb2c")
    (description
     "This is a guide for the installation of (La)TeX with the Amiga port of
Web2C named AmiWeb2C in the version 2.1 on an emulated Amiga 4000 computer
running Workbench 3.1.  Furthermore the installation of an ARexx server for
calling LaTeX from an editor is described and some tips for the installation
of new fonts are given.")
    (license license:lppl1.3c)))

(define-public texlive-amsfonts
  (package
    (name "texlive-amsfonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/amsfonts/"
                                     "fonts/afm/public/amsfonts/cm/"
                                     "fonts/afm/public/amsfonts/cmextra/"
                                     "fonts/afm/public/amsfonts/cyrillic/"
                                     "fonts/afm/public/amsfonts/euler/"
                                     "fonts/afm/public/amsfonts/latxfont/"
                                     "fonts/afm/public/amsfonts/symbols/"
                                     "fonts/map/dvips/amsfonts/"
                                     "fonts/source/public/amsfonts/cmextra/"
                                     "fonts/source/public/amsfonts/cyrillic/"
                                     "fonts/source/public/amsfonts/dummy/"
                                     "fonts/source/public/amsfonts/symbols/"
                                     "fonts/tfm/public/amsfonts/cmextra/"
                                     "fonts/tfm/public/amsfonts/cyrillic/"
                                     "fonts/tfm/public/amsfonts/dummy/"
                                     "fonts/tfm/public/amsfonts/euler/"
                                     "fonts/tfm/public/amsfonts/symbols/"
                                     "fonts/type1/public/amsfonts/cm/"
                                     "fonts/type1/public/amsfonts/cmextra/"
                                     "fonts/type1/public/amsfonts/cyrillic/"
                                     "fonts/type1/public/amsfonts/euler/"
                                     "fonts/type1/public/amsfonts/latxfont/"
                                     "fonts/type1/public/amsfonts/symbols/"
                                     "source/latex/amsfonts/"
                                     "tex/latex/amsfonts/"
                                     "tex/plain/amsfonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0phhzcxapa5607pk37agr981rg90zw2p4rqv7sk7i19byr867a1b"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-cm")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-cm texlive-metafont))
    (home-page "https://ctan.org/pkg/amsfonts")
    (synopsis "TeX fonts from the American Mathematical Society")
    (description
     "This package provides an extended set of fonts for use in mathematics,
including: extra mathematical symbols; blackboard bold letters (uppercase
only); fraktur letters; subscript sizes of bold math italic and bold Greek
letters; subscript sizes of large symbols such as sum and product; added sizes
of the Computer Modern small caps font; cyrillic fonts (from the University of
Washington); Euler mathematical fonts.  All fonts are provided as Adobe Type
1 files, and all except the Euler fonts are provided as METAFONT source.  The
distribution also includes the canonical Type 1 versions of the Computer
Modern family of fonts.  The Euler fonts are supported by separate packages;
details can be found in the documentation.")
    (license license:silofl1.1)))

(define-deprecated-package texlive-fonts-amsfonts texlive-amsfonts)
(define-deprecated-package texlive-latex-amsfonts texlive-amsfonts)

(define-public texlive-mkpattern
  (package
    (name "texlive-mkpattern")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/mkpattern/" "tex/plain/mkpattern/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sxnkbcc802jl3fj56x9hvg978bpv15lhrwj0aykb4syq29l47ga"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mkpattern")
    (synopsis "Utility for making hyphenation patterns")
    (description
     "Mkpattern is a general purpose program for the generation of hyphenation
patterns, with definition of letter sets and template-like constructions.  It
also provides an easy way to handle different input and output encodings, and
features generation of clean UTF-8 patterns.")
    (license license:lppl)))

(define-public texlive-ec
  (package
    (name "texlive-ec")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/ec/"
                                     "fonts/source/jknappen/ec/"
                                     "fonts/tfm/jknappen/ec/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cyi0vv9dnp45s0ilsrbkyznj9ji62s5bhkqgh49461mv2f8qj6p"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-cm")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-cm texlive-metafont))
    (home-page "https://ctan.org/pkg/ec")
    (synopsis "Computer modern fonts in T1 and TS1 encodings")
    (description
     "The EC fonts are European Computer Modern Fonts, supporting the complete
LaTeX T1 encoding defined at the 1990 TUG conference hold at Cork/Ireland.
These fonts are intended to be stable with no changes being made to the tfm
files.  The set also contains a Text Companion Symbol font, called @code{tc},
featuring many useful characters needed in text typesetting, for example
oldstyle digits, currency symbols (including the newly created Euro symbol),
the permille sign, copyright, trade mark and servicemark as well as a copyleft
sign, and many others.  The fonts are available in (traced) Adobe Type
1 format, as part of the @code{cm-super} bundle.  The other Computer
Modern-style T1-encoded Type 1 set, Latin Modern, is not actually a direct
development of the EC set, and differs from the EC in a number of
particulars.")
    (license (license:fsf-free "file://doc/fonts/ec/copyrite.txt"))))

(define-deprecated-package texlive-fonts-ec texlive-ec)

;; This provides etex.src which is needed to build various formats, including
;; luatex.fmt and pdflatex.fmt
(define-public texlive-etex
  (package
    (name "texlive-etex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/etex/base/"
                                     "doc/man/man1/etex.1"
                                     "doc/man/man1/etex.man1.pdf"
                                     "fonts/source/public/etex/"
                                     "fonts/tfm/public/etex/"
                                     "tex/plain/etex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15w34g09c0qc76i1aflbzx91pnawz2kvcidg1f7wwsk6a5bz7372"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-cm")))
    (build-system texlive-build-system)
    (arguments (list #:texlive-latex-bin? #f))
    (native-inputs (list texlive-cm texlive-metafont))
    (home-page "https://www.ctan.org/pkg/etex")
    (synopsis "Extended version of TeX")
    (description
     "This package provides an extended version of TeX (which is capable of
running as if it were TeX unmodified).  E-TeX has been specified by the LaTeX
team as the engine for the development of LaTeX2e; as a result, LaTeX
programmers may assume e-TeX functionality.  The pdftex engine directly
incorporates the e-TeX extensions.")
    (license license:knuth)))

(define-public texlive-etex-pkg
  (package
    (name "texlive-etex-pkg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/etex-pkg/" "tex/latex/etex-pkg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10bvvn3s3lmzjscnb2qxkj1ba9qxx0q1w2spcsjpwf20dvym19py"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/etex-pkg")
    (synopsis "E-TeX support package")
    (description
     "The package provides support for LaTeX documents to use many of the
extensions offered by e-TeX; in particular, it modifies LaTeX's register
allocation macros to make use of the extended register range.  The
@code{etextools} package provides macros that make more sophisticated use of
e-TeX's facilities.")
    (license license:lppl1.3+)))

(define-public texlive-eulervm
  (package
    (name "texlive-eulervm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/eulervm/"
                                     "fonts/tfm/public/eulervm/"
                                     "fonts/vf/public/eulervm/"
                                     "source/latex/eulervm/" "tex/latex/eulervm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "118yidwnqw4acap2wdykcdx2cxp8q2ganz67ls6rkg6fid325mkq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eulervm")
    (synopsis "Euler virtual math fonts")
    (description
     "The Euler fonts are suitable for typsetting mathematics in conjunction
with a variety of text fonts that do not provide mathematical character sets
of their own.  Euler-VM is a set of virtual mathematics fonts based on Euler
and CM. This approach has several advantages over immediately using the real
Euler fonts. Most noticeably, less TeX resources are consumed, the quality of
various math symbols is improved and a usable @code{\\hslash} symbol can be
provided.  The virtual fonts are accompanied by a LaTeX package which makes
them easy to use, particularly in conjunction with Type1 PostScript text
fonts.  They are compatible with @code{amsmath}.  A package option allows the
fonts to be loaded at 95% of their nominal size, thus blending better with
certain text fonts, e.g., Minion.")
    (license license:lppl)))

(define-public texlive-plain
  (package
    (name "texlive-plain")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "makeindex/plain/" "tex/plain/base/"
                                     "tex/plain/config/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zwvrfw8z28c9dy8nby5qfwbyrd2a0cdfwyd5jndscjczhw0yi62"))))
    (build-system texlive-build-system)
    (arguments
     (list
      #:tex-engine "tex"
      #:tex-format #f
      #:texlive-latex-bin? #f))
    (home-page "https://ctan.org/pkg/plain")
    (synopsis "Plain TeX format and supporting files")
    (description
     "This package contains files used to build the Plain TeX format, as
described in the TeXbook, together with various supporting files (some also
discussed in the book).")
    (license license:knuth)))

(define-deprecated-package texlive-tex-plain texlive-plain)

(define-public texlive-pxfonts
  (package
    (name "texlive-pxfonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/pxfonts/"
                                     "fonts/afm/public/pxfonts/"
                                     "fonts/map/dvips/pxfonts/"
                                     "fonts/tfm/public/pxfonts/"
                                     "fonts/type1/public/pxfonts/"
                                     "fonts/vf/public/pxfonts/"
                                     "tex/latex/pxfonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0z2ls46x2l79saq4l1d2cqwazhpg79b9hqsf90wzx70676mxcwac"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pxfonts")
    (synopsis "Palatino-like fonts in support of mathematics")
    (description
     "Pxfonts supplies virtual text roman fonts using Adobe Palatino (or
URWPalladioL) with some modified and additional text symbols in the OT1, T1,
and TS1 encodings; maths alphabets using Palatino/Palladio; maths fonts
providing all the symbols of the Computer Modern and AMS fonts, including all
the Greek capital letters from CMR; and additional maths fonts of various
other symbols.  The set is complemented by a sans-serif set of text fonts,
based on Helvetica/NimbusSanL, and a monospace set derived from the parallel
TX font set.  All the fonts are in Type 1 format (AFM and PFB files), and are
supported by TeX metrics (VF and TFM files) and macros for use with LaTeX.")
    (license license:gpl3+)))

(define-public texlive-halloweenmath
  (package
    (name "texlive-halloweenmath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/halloweenmath/"
                                     "source/latex/halloweenmath/"
                                     "tex/latex/halloweenmath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xq72k1p820b5q3haxf936g69p6gv34hr30870l96jnxa3ad7y05"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-cm")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'non-interactive-build
            ;; When it realizes it cannot employ the usedir directive, the
            ;; build process stops and waits for an input before inserting
            ;; generated files in the working directory.  Do not ask for an
            ;; input.
            (lambda _
              (substitute* "source/latex/halloweenmath/halloweenmath.ins"
                (("\\Ask.*") "")
                (("\\(your .*? will be ignored\\).*") "")))))))
    (native-inputs (list texlive-cm))
    (home-page "https://ctan.org/pkg/halloweenmath")
    (synopsis "Scary and creepy math symbols with AMS-LaTeX integration")
    (description
     "The package defines a handful of commands for typesetting mathematical
symbols of various kinds, ranging from large operators to extensible
arrow-like relations and growing arrow-like math accents that all draw from
the classic Halloween-related iconography (pumpkins, witches, ghosts, cats,
and so on) while being, at the same time, seamlessly integrated within the
rest of the mathematics produced by (AmS-)LaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-haranoaji
  (package
    (name "texlive-haranoaji")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/haranoaji/"
                                     "fonts/opentype/public/haranoaji/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zwmb94p6byzij4dxydwvv70iv9y107p7ig0dj94pgxzc4i6vcny"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/haranoaji")
    (synopsis "Harano Aji fonts")
    (description
     "Harano Aji fonts (Harano Aji Mincho and Harano Aji Gothic) are fonts
obtained by replacing Adobe-Identity-0 (AI0) CIDs of Source Han fonts (Source
Han Serif and Source Han Sans) with Adobe-Japan1 (AJ1) CIDs.  There are 14
fonts, 7 weights each for Mincho and Gothic.")
    (license license:silofl1.1)))

(define-public texlive-haranoaji-extra
  (package
    (name "texlive-haranoaji-extra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/haranoaji-extra/"
                                     "fonts/opentype/public/haranoaji-extra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1knw4yw76rdmp0gxx5faszv60rn7b0p6njb3fkpd2dn3jqy45ivi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/haranoaji-extra")
    (synopsis "Extra weights for Harano Aji fonts")
    (description
     "Harano Aji fonts (Harano Aji Mincho and Harano Aji Gothic) are fonts
obtained by replacing Adobe-Identity-0 (AI0) CIDs of Source Han fonts (Source
Han Serif and Source Han Sans) with Adobe-Japan1 (AJ1) CIDs.  This package
provides extra weights for these fonts.")
    (license license:silofl1.1)))

(define-public texlive-hardwrap
  (package
    (name "texlive-hardwrap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hardwrap/" "source/latex/hardwrap/"
                                     "tex/latex/hardwrap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ql3xml1ccll44q945n7w72p6d51y5wcrkawi7cg621gy5d6wzx5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hardwrap")
    (synopsis "Hard wrap text to a certain character length")
    (description
     "The package facilitates wrapping text to a specific character width,
breaking lines by words rather than, as done by TeX, by characters.  The
primary use for these facilities is to aid the generation of messages sent to
the log file or console output to display messages to the user.  Package
authors may also find this useful when writing out arbitrary text to an
external file.")
    (license license:lppl1.3+)))

(define-public texlive-hatching
  (package
    (name "texlive-hatching")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/hatching/"
                                     "metapost/hatching/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rkxx57rpzk8i0msbyrzcgmbvmjjrg295qg508w3v3dsy0f0krjj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hatching")
    (synopsis "MetaPost macros for hatching interior of closed paths")
    (description
     "The file @file{hatching}.mp contains a set of MetaPost macros for
hatching interior of closed paths.")
    (license license:public-domain)))

(define-public texlive-helvetic
  (package
    (name "texlive-helvetic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "dvips/helvetic/"
                                     "fonts/afm/adobe/helvetic/"
                                     "fonts/afm/urw/helvetic/"
                                     "fonts/map/dvips/helvetic/"
                                     "fonts/tfm/adobe/helvetic/"
                                     "fonts/tfm/monotype/helvetic/"
                                     "fonts/tfm/urw35vf/helvetic/"
                                     "fonts/type1/urw/helvetic/"
                                     "fonts/vf/adobe/helvetic/"
                                     "fonts/vf/monotype/helvetic/"
                                     "fonts/vf/urw35vf/helvetic/"
                                     "tex/latex/helvetic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c3f1ly7y6404z0akbfbbfql13sz717v0n0g69qjpr69hi4n0nsl"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/urw-base35")
    (synopsis "Replacement for Adobe's Helvetica font")
    (description
     "This package provides a drop-in replacement for the Helvetica font from
Adobe's basic set.")
    ;; No license version specified.
    (license license:gpl3+)))

(define-public texlive-ieejtran
  (package
    (name "texlive-ieejtran")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/ieejtran/"
                                     "doc/bibtex/ieejtran/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01bcw45v6mbyb1gzykzk5ccwz70s6591994xrj84z9ljgzp06lyg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ieejtran")
    (synopsis
     "Institute of Electrical Engineers of Japan's unofficial bibliography style")
    (description
     "This package provides an unofficial BibTeX style for authors of the
Institute of Electrical Engineers of Japan (IEEJ) transactions journals and
conferences.")
    (license license:expat)))

(define-public texlive-inputenx
  (package
    (name "texlive-inputenx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/inputenx/" "source/latex/inputenx/"
                                     "tex/latex/inputenx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0snjndrcynm4w8m9iq8gmadzhrbwvsdy4y1ak24ia0hpsicdi4aj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/inputenx")
    (synopsis "Enhanced input encoding handling")
    (description
     "This package deals with input encodings.  It provides a wider range of
input encodings using standard mappings, than does @code{inputenc}.  It also
covers nearly all slots.  In this way, it serves as more up to date
replacement for the @code{inputenc} package.")
    (license license:lppl1.3+)))

(define-public texlive-kpathsea
  (package
    (name "texlive-kpathsea")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/info/dir"
                                     "doc/info/kpathsea.info"
                                     "doc/info/web2c.info"
                                     "doc/kpathsea/"
                                     "doc/man/man1/kpseaccess.1"
                                     "doc/man/man1/kpseaccess.man1.pdf"
                                     "doc/man/man1/kpsereadlink.1"
                                     "doc/man/man1/kpsereadlink.man1.pdf"
                                     "doc/man/man1/kpsestat.1"
                                     "doc/man/man1/kpsestat.man1.pdf"
                                     "doc/man/man1/kpsewhich.1"
                                     "doc/man/man1/kpsewhich.man1.pdf"
                                     "doc/web2c/NEWS"
                                     "doc/web2c/web2c.html"
                                     "doc/web2c/web2c.pdf"
                                     "web2c/amiga-pl.tcx"
                                     "web2c/cp1250cs.tcx"
                                     "web2c/cp1250pl.tcx"
                                     "web2c/cp1250t1.tcx"
                                     "web2c/cp227.tcx"
                                     "web2c/cp852-cs.tcx"
                                     "web2c/cp852-pl.tcx"
                                     "web2c/cp8bit.tcx"
                                     "web2c/empty.tcx"
                                     "web2c/fmtutil.cnf"
                                     "web2c/il1-t1.tcx"
                                     "web2c/il2-cs.tcx"
                                     "web2c/il2-pl.tcx"
                                     "web2c/il2-t1.tcx"
                                     "web2c/kam-cs.tcx"
                                     "web2c/kam-t1.tcx"
                                     "web2c/macce-pl.tcx"
                                     "web2c/macce-t1.tcx"
                                     "web2c/maz-pl.tcx"
                                     "web2c/mktex.cnf"
                                     "web2c/mktex.opt"
                                     "web2c/mktexdir"
                                     "web2c/mktexdir.opt"
                                     "web2c/mktexnam"
                                     "web2c/mktexnam.opt"
                                     "web2c/mktexupd"
                                     "web2c/natural.tcx"
                                     "web2c/tcvn-t5.tcx"
                                     "web2c/texmf.cnf"
                                     "web2c/viscii-t5.tcx"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14zi3qydf8hjh2xfn81b54ppq2p78yb8pcgkaz2v2ia9n1r3ga6f"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "gawk" "sed")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:texlive-latex-bin? #f
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'patch-references
            (lambda _
              (let ((dirs (map dirname (list (which "sed")
                                             (which "awk")))))
                (substitute* '("web2c/mktexdir"
                               "web2c/mktexnam"
                               "web2c/mktexupd")
                  (("^version=" m)
                   (format #false "PATH=\"~{~a:~}$PATH\"; export PATH~%~a"
                           dirs m)))))))))
    (inputs (list gawk sed))
    (propagated-inputs (list texlive-libkpathsea)) ;for the executables
    (home-page "https://ctan.org/pkg/kpathsea")
    (synopsis "Files related to the path searching library for TeX")
    (description
     "Kpathsea is a library and utility programs which provide path searching
facilities for TeX file types, including the self-locating feature required
for movable installations, layered on top of a general search mechanism.  This
package provides supporting files.")
    (license license:lgpl3+)))

(define-public texlive-kpfonts
  (package
    (name "texlive-kpfonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/kpfonts/"
                                     "fonts/afm/public/kpfonts/"
                                     "fonts/enc/dvips/kpfonts/"
                                     "fonts/map/dvips/kpfonts/"
                                     "fonts/tfm/public/kpfonts/"
                                     "fonts/type1/public/kpfonts/"
                                     "fonts/vf/public/kpfonts/"
                                     "tex/latex/kpfonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m5waxqrkm1i59i9vbn9ai9zjn7cl0f36iccwn2d73lhrqhbn16q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/kpfonts")
    (synopsis "Complete set of fonts for text and mathematics")
    (description
     "The family contains text fonts in roman, sans-serif and monospaced
shapes, with true small caps and old-style numbers; the package offers full
support of the textcomp package.  The mathematics fonts include all the AMS
fonts, in both normal and bold weights.  Each of the font types is available
in two main versions: default and light.  Each version is available in four
variants: default; oldstyle numbers; oldstyle numbers with old ligatures such
as ct and st, and long-tailed capital Q; and veryoldstyle with long s.  Other
variants include small caps as default or large small caps, and for
mathematics both upright and slanted shapes for Greek letters, as well as
default and narrow versions of multiple integrals.")
    (license license:gpl3+)))

(define-public texlive-kpfonts-otf
  (package
    (name "texlive-kpfonts-otf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/kpfonts-otf/"
                                     "fonts/opentype/public/kpfonts-otf/"
                                     "tex/latex/kpfonts-otf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13i9r4sgw547fwv6zqpbzlzarzfjpgp6ivi29qi47xk1dg8bqq95"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/kpfonts-otf")
    (synopsis "OTF version of the Kp-fonts")
    (description
     "This bundle provides OpenType versions of the Type1 Kp-fonts designed by
Christophe Caignaert.  It is usable with LuaTeX or XeTeX engines only.  It
consists of sixteen Text fonts (eight Serif, four Sans-Serif, four Monotype)
and six Math fonts.  Serif and Sans-Serif families have small caps available
in two sizes (SmallCaps and PetitesCaps), upper and lowercase digits, real
superscripts and subscripts; ancient ligatures (@samp{ct} and @samp{st}),
ancient long-@samp{s} and a long-tailed capital @samp{Q} are available via
font features.  Math fonts cover all usual symbols including AMS'.")
    (license (list license:silofl1.1 license:lppl1.3+))))

(define-public texlive-latexconfig
  (package
    (name "texlive-latexconfig")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/latex/latexconfig/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0254p59z7w4ihplrxknkcy2ls6258yj9k1dh6yc6sx9i538vylbz"))))
    (build-system texlive-build-system)
    (arguments (list #:texlive-latex-bin? #f))
    (home-page "https://ctan.org/pkg/latexconfig")
    (synopsis "Configuration files for LaTeX-related formats")
    (description "The package provides configuration files for LaTeX-related
formats.")
    (license license:lppl)))

(define-public texlive-latex-bin
  (package
    (name "texlive-latex-bin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/dvilualatex.1"
                                     "doc/man/man1/dvilualatex.man1.pdf"
                                     "doc/man/man1/latex.1"
                                     "doc/man/man1/latex.man1.pdf"
                                     "doc/man/man1/lualatex.1"
                                     "doc/man/man1/lualatex.man1.pdf"
                                     "doc/man/man1/pdflatex.1"
                                     "doc/man/man1/pdflatex.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1f73x92hwybkq6gqhps6gnsy8rs12zwxbfnp226d0bm6b2ji31z6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:texlive-latex-bin? #f
      #:create-formats #~(list "dvilualatex" "latex" "lualatex" "pdflatex")
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'install 'symlink-binaries
            ;; Create symbolic links for the latex variants.  We link lualatex
            ;; to luahbtex; see issue #51252 for details.
            (lambda* (#:key inputs #:allow-other-keys)
              (let ((pdftex (search-input-file inputs "bin/pdftex"))
                    (luahbtex (search-input-file inputs "bin/luahbtex"))
                    (bin (string-append #$output "/bin")))
                (mkdir-p bin)
                (with-directory-excursion bin
                  (symlink pdftex "latex")
                  (symlink pdftex "pdflatex")
                  (symlink luahbtex "lualatex"))))))))
    (propagated-inputs
     (list texlive-babel
           texlive-cm
           texlive-firstaid
           texlive-graphics
           texlive-hyphen-complete
           texlive-l3backend
           texlive-l3kernel
           texlive-latex
           texlive-latex-fonts
           texlive-latexconfig
           texlive-lm
           texlive-luahbtex
           texlive-luaotfload
           texlive-luatex
           texlive-pdftex
           texlive-tex-ini-files
           texlive-unicode-data))
    (home-page "https://ctan.org/pkg/latex-bin")
    (synopsis "LaTeX formats and man pages")
    (description
     "This package provides LaTeX format files and man pages along with
several packages that are considered as part of the LaTeX kernel.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-base texlive-latex-bin)

(define-public texlive-atenddvi
  (package
    (name "texlive-atenddvi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/atenddvi/"
                                     "source/latex/atenddvi/"
                                     "tex/latex/atenddvi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fwa5233mdgvixhl2rzn9s06zz52j6ml7hfzd4194bn389n9syhk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/atenddvi")
    (synopsis "Provide the @code{\\AtEndDvi} command for older LaTeX format")
    (description
     "This package is unneeded and does nothing when used with a LaTeX format
2020-10-01 or newer as in this case the format provides the @code{\\AtEndDvi}
command.  For older formats it implements @code{\\AtEndDvi}, a counterpart to
@code{\\AtBeginDvi}.  The execution of its argument is delayed to the end of
the document at the end of the last page.  Thus @code{\\special} and
@code{\\write} remain effective, because they are put into the last page.
This is the main difference to @code{\\AtEndDocument}.")
    (license license:lppl1.3c+)))

(define-public texlive-attachfile
  (package
    (name "texlive-attachfile")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/attachfile/"
                                     "doc/latex/attachfile/"
                                     "source/latex/attachfile/"
                                     "tex/latex/attachfile/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0340c4rvxhhk95wlhf54n9akiwhj6pj0bslys6bkq29x9903zx5h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/attachfile")
    (synopsis "Attach arbitrary files to a PDF document")
    (description
     "Starting with PDF 1.3, PDF files can contain file attachments, i.e.,
arbitrary files that a reader can extract, just like attachments to an e-mail
message.  The @code{attachfile} package brings this functionality to pdfLaTeX
and provides some additional features such as the ability to use arbitrary
LaTeX code for the file icon.  Settings can be made either globally or on
a per-attachment basis.  @code{attachfile} makes it easy to attach files and
customize their appearance in the enclosing document.")
    (license license:lppl1.3+)))

(define-public texlive-attachfile2
  (package
    (name "texlive-attachfile2")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/attachfile2/"
                                     "doc/man/man1/pdfatfi.1"
                                     "doc/man/man1/pdfatfi.man1.pdf"
                                     "scripts/attachfile2/"
                                     "source/latex/attachfile2/"
                                     "tex/latex/attachfile2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y2ygsgx0gjfqkpn1frqg4z59jz6mdp99v9qmz6v4ppflvc1a0zs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "pdfatfi.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/attachfile2")
    (synopsis "Attach files into PDF")
    (description
     "This package can be used to attach files to a PDF document.  It is
a further development of Scott Pakin's package @code{attachfile} for pdfTeX.
Apart from bug fixes, this package adds support for dvips, some new options,
and gets and writes meta information data about the attached files.")
    (license license:lppl1.3c)))

(define-public texlive-atveryend
  (package
    (name "texlive-atveryend")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/atveryend/"
                                     "source/latex/atveryend/"
                                     "tex/latex/atveryend/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rp805h0m99rxs107a798l951lyahlnp7irfklfadn2a2ljzhafn"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-latex"
                                               "texlive-pdftex")))
    (build-system texlive-build-system)
    (arguments (list #:texlive-latex-bin? #f))
    (native-inputs (list texlive-latex texlive-pdftex))
    (home-page "https://ctan.org/pkg/atveryend")
    (synopsis "Hooks at the very end of a document")
    (description
     "This LaTeX packages provides two hooks for @code{\\end{document}} that
are executed after the hook of @code{\\AtEndDocument}:
@code{\\AfterLastShipout} can be used for code that is to be executed right
after the last @code{\\clearpage} before the @file{.aux} file is closed.
@code{\\AtVeryEndDocument} is used for code after closing and final reading of
the @file{.aux} file.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-atveryend texlive-atveryend)

(define-public texlive-automata
  (package
    (name "texlive-automata")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/automata/"
                                     "metapost/automata/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y02wp1w2jkhrxanz7r699kr08bmbfn0h0xaxj3zh4xj9745d7d7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/automata")
    (synopsis "Finite state machines, graphs and trees in MetaPost")
    (description
     "The package offers a collection of macros for MetaPost to make easier to
draw finite-state machines, automata, labelled graphs, etc.  The user defines
nodes, which may be isolated or arranged into matrices or trees; edges connect
pairs of nodes through arbitrary paths.  Parameters, that specify the shapes
of nodes and the styles of edges, may be adjusted.")
    (license license:lppl)))

(define-public texlive-auxhook
  (package
    (name "texlive-auxhook")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/auxhook/" "source/latex/auxhook/"
                                     "tex/latex/auxhook/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qfs7bz8ryp4prr2fw4hwypnfc6yr4rc4wd8qy4rpmab0hab0vdy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/auxhook")
    (synopsis "Hooks for auxiliary files")
    (description
     "This package provides hooks for adding code at the beginning of
@file{.aux} files.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-auxhook texlive-auxhook)

(define-public texlive-epspdf
  (package
    (name "texlive-epspdf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/info/epspdf.info" "doc/support/epspdf/"
                                     "scripts/epspdf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sxn3dff0nxiw68h1kr86rmnc72xkc62fk94j590a4di1lh2firl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts #~(list "epspdf.tlu" "epspdftk.tcl")))
    (inputs (list tcl tk))
    (home-page "https://ctan.org/pkg/epspdf")
    (synopsis "Converter for PostScript, EPS and PDF")
    (description
     "Epspdftk.tcl is a GUI PS/EPS/PDF converter.  Epspdf.tlu, its
command-line backend, can be used by itself.  Options include grayscaling,
cropping margins and single-page selection.  Some conversion options are made
possible by converting in multiple steps.")
    (license license:gpl2)))

(define-public texlive-epstopdf
  (package
    (name "texlive-epstopdf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/epstopdf.1"
                                     "doc/man/man1/epstopdf.man1.pdf"
                                     "doc/man/man1/repstopdf.1"
                                     "doc/man/man1/repstopdf.man1.pdf"
                                     "doc/support/epstopdf/"
                                     "scripts/epstopdf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0brlgj7ywmw95b6bkb3bkvxnvf3a4bfwbgq38lwz4f9klacrs2ys"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "ghostscript")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:link-scripts #~(list "epstopdf.pl")
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'set-gs-location
            (lambda* (#:key inputs #:allow-other-keys)
              (let ((gs (search-input-file inputs "/bin/gs")))
                (substitute* "scripts/epstopdf/epstopdf.pl"
                  (("\"gs\"") (string-append "\"" gs "\""))))))
          (add-after 'link-scripts 'add-repstopdf
            (lambda _
              (with-directory-excursion (string-append #$output "/bin")
                (symlink "epstopdf" "repstopdf")))))))
    (home-page "https://ctan.org/pkg/epstopdf")
    (synopsis "Convert EPS to PDF using Ghostscript")
    (inputs (list ghostscript perl))
    (description
     "Epstopdf is a Perl script that converts an EPS file to an encapsulated
PDF file (a single page file whose media box is the same as the original EPS's
bounding box). The resulting file suitable for inclusion by pdfTeX as an
image.  LaTeX users may make use of the @code{epstopdf} package, which will
run the @code{epstopdf} script on the fly, thus giving the illusion that
pdfLaTeX is accepting EPS graphic files.")
    (license license:bsd-3)))

(define-public texlive-epstopdf-pkg
  (package
    (name "texlive-epstopdf-pkg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/epstopdf-pkg/"
                                     "source/latex/epstopdf-pkg/"
                                     "tex/latex/epstopdf-pkg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ajyc5pkn1niifz5asyf09vbdqvmy05xwl0vxcdl7ik0ll0jcaxp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/epstopdf-pkg")
    (synopsis "Call @command{epstopdf} on the fly")
    (description
     "The package adds support for EPS files in the @code{graphicx} package
when running under pdfTeX.  If an EPS graphic is detected, the package spawns
a process to convert the EPS to PDF, using the script @command{epstopdf}.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-epstopdf-pkg texlive-epstopdf-pkg)

(define-public texlive-filecontents
  (package
    (name "texlive-filecontents")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/filecontents/"
                                     "source/latex/filecontents/"
                                     "tex/latex/filecontents/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hrlwwv8sywd2z6xw3dryf0xbrbbc50k44q8s23727banghg6ham"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/filecontents")
    (synopsis "Create an external file from within a LaTeX document")
    (description
     "LaTeX2e's @code{filecontents} and @code{filecontents*} environments
enable a LaTeX source file to generate external files as it runs through
LaTeX.  However, there are two limitations of these environments: they refuse
to overwrite existing files, and they can only be used in the preamble of
a document.  The filecontents package removes these limitations, letting you
overwrite existing files and letting you use @code{filecontents}
@code{filecontents*} anywhere.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-filecontents texlive-filecontents)

(define-public texlive-filehook
  (package
    (name "texlive-filehook")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/filehook/" "source/latex/filehook/"
                                     "tex/latex/filehook/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zg9svjhrnh52fa04n3pnb0hrijp0lrr939dacf90cjjzwk36sfn"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ydoc")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ydoc))
    (home-page "https://ctan.org/pkg/filehook")
    (synopsis "Hooks for input files")
    (description
     "The package provides several file hooks (@code{AtBegin}, @code{AtEnd},
...) for files read by @code{\\input}, @code{\\include} and
@code{\\InputIfFileExists}.  General hooks for all such files (e.g., all
@code{\\included} ones) and file specific hooks only used for named files are
provided; two hooks are provided for the end of @code{\\included} files ---
one before, and one after the final @code{\\clearpage}.")
    (license license:lppl1.3+)))

(define-public texlive-epsf
  (package
    (name "texlive-epsf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/epsf/" "tex/generic/epsf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03jcf0kqh47is965d2590miwj7d5kif3c4mgsnvkyl664jzjkh92"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/epsf")
    (synopsis "Simple macros for EPS inclusion")
    (description
     "This package provides the original (and now obsolescent) graphics
inclusion macros for use with dvips, still widely used by Plain TeX users (in
particular).  For LaTeX users, the package is nowadays (rather strongly)
deprecated in favour of the more sophisticated standard LaTeX latex-graphics
bundle of packages.  (The latex-graphics bundle is also available to Plain TeX
users, via its Plain TeX version.)")
    (license license:public-domain)))

(define-deprecated-package texlive-generic-epsf texlive-epsf)

(define-public texlive-fancyvrb
  (package
    (name "texlive-fancyvrb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fancyvrb/" "tex/latex/fancyvrb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jpxlzq1v96s2qifzjjh2xfifch47iks7l8zhs9vq7w5cd4y6pyl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fancyvrb")
    (synopsis "Sophisticated verbatim text")
    (description
     "This package provides tools for the flexible handling of verbatim text
including: verbatim commands in footnotes; a variety of verbatim environments
with many parameters; ability to define new customized verbatim environments;
save and restore verbatim text and environments; write and read files in
verbatim mode; build \"example\" environments (showing both result and
verbatim source).")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-fancyvrb texlive-fancyvrb)

(define-public texlive-fandol
  (package
    (name "texlive-fandol")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/fandol/"
                                     "fonts/opentype/public/fandol/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lk91ypsvj2wkqsw8lklkqfsqimjyn0vzbwgqgs5h6kf61m6qsk5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fandol")
    (synopsis "Four basic fonts for Chinese typesetting")
    (description
     "This package provides Fandol fonts designed for Chinese typesetting.
The current version contains four styles: Song, Hei, Kai, Fang.  All fonts are
in OpenType format.")
    (license license:gpl3+)))

(define-public texlive-gentium-tug
  (package
    (name "texlive-gentium-tug")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/gentium-tug/"
                                     "fonts/afm/public/gentium-tug/"
                                     "fonts/enc/dvips/gentium-tug/"
                                     "fonts/map/dvips/gentium-tug/"
                                     "fonts/map/pdftex/gentium-tug/"
                                     "fonts/tfm/public/gentium-tug/"
                                     "fonts/truetype/public/gentium-tug/"
                                     "fonts/type1/public/gentium-tug/"
                                     "source/fonts/gentium-tug/"
                                     "tex/latex/gentium-tug/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0byiqwqxiik3i9cb6lp53vw4yw92frlmmsk05653g9kgmx04x70d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gentium-tug")
    (synopsis "Gentium fonts (in two formats) and support files")
    (description
     "Gentium is a typeface family designed to enable the diverse ethnic
groups around the world who use the Latin, Cyrillic and Greek scripts to
produce readable, high-quality publications.  It supports a wide range of
Latin- and Cyrillic-based alphabets.")
    (license (list license:expat license:silofl1.1))))

(define-public texlive-gincltex
  (package
    (name "texlive-gincltex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gincltex/" "source/latex/gincltex/"
                                     "tex/latex/gincltex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x6bsf445dp8wc5hfgyywlal8vky5w23d69zlpybkp2d9am9a71p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gincltex")
    (synopsis "Include TeX files as graphics")
    (description
     "The package builds on the standard LaTeX packages @code{graphics} and
allows external LaTeX source files to be included, in the same way as graphic
files, by @code{\\includegraphics}.  In effect, then package adds support for
the @file{.tex} extension.")
    (license license:lppl1.3+)))

(define-public texlive-git-latexdiff
  (package
    (name "texlive-git-latexdiff")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/git-latexdiff.1"
                                     "doc/man/man1/git-latexdiff.man1.pdf"
                                     "doc/support/git-latexdiff/"
                                     "scripts/git-latexdiff/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hblgnjad5qm27ijpynz0x1rxgi07y5apgnv5r2wk3ngxj016pvn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "git-latexdiff")))
    (home-page "https://ctan.org/pkg/git-latexdiff")
    (synopsis "Call @command{latexdiff} on two Git revisions of a file")
    (description
     "@command{git-latexdiff} is a tool to graphically visualize differences
between different versions of a LaTeX file.")
    (license license:bsd-2)))

(define-public texlive-glyphlist
  (package
    (name "texlive-glyphlist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "fonts/map/glyphlist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12nmmyh77vr2622lzi11nm1z1k2bxs7jz018yl4rwjlpg0sxg1ja"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/glyphlist")
    (synopsis "Adobe Glyph List and TeX extensions")
    (description
     "This package provides a map between traditional Adobe glyph names and
Unicode points; it is maintained by Adobe.  The additional
@file{texglyphlist.txt} is maintained as part of @code{lcdf-typetools}.")
    (license license:asl2.0)))

(define-public texlive-graphics-def
  (package
    (name "texlive-graphics-def")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/graphics-def/"
                                     "tex/latex/graphics-def/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kp28k3shsiv0a051lp4fcqadac41c942hxwn506yps7h9y4jg23"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:texlive-latex-bin? #f))
    (home-page "https://ctan.org/pkg/graphics-def")
    (synopsis "Colour and graphics option files")
    (description
     "This bundle is a combined distribution consisting of @file{dvips.def},
@file{pdftex.def}, @file{luatex.def}, @file{xetex.def}, @file{dvipdfmx.def},
and @file{dvisvgm.def} driver option files for the LaTeX graphics and color
packages.")
    (license license:lppl1.3c+)))

(define-public texlive-graphics-cfg
  (package
    (name "texlive-graphics-cfg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/graphics-cfg/"
                                     "tex/latex/graphics-cfg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00n63adb2laf43lzix39xl68aq0k5k80mmrw602w99w5n7f96gsf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:texlive-latex-bin? #f))
    (home-page "https://ctan.org/pkg/graphics-cfg")
    (synopsis "Sample configuration files for LaTeX color and graphics")
    (description
     "This bundle includes @file{color.cfg} and @file{graphics.cfg} files that
set default \"driver\" options for the color and graphics packages.")
    (license license:public-domain)))

(define-public texlive-graphics
  (package
    (name "texlive-graphics")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/graphics/"
                                     "source/latex/graphics/"
                                     "tex/latex/graphics/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "024hncahwc07yd2l94znv7v72sbykxdri5lpg3w4ip0nf10ywyma"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-latex"
                                               "texlive-pdftex")))
    (build-system texlive-build-system)
    (arguments (list #:texlive-latex-bin? #f))
    (native-inputs (list texlive-latex texlive-pdftex))
    (propagated-inputs (list texlive-graphics-cfg texlive-graphics-def))
    (home-page "https://ctan.org/macros/latex/required/graphics")
    (synopsis "The LaTeX standard graphics bundle")
    (description
     "This is a collection of LaTeX packages for: producing colour including
graphics (e.g., PostScript) files rotation and scaling of text in LaTeX
documents.  It comprises the packages @code{color}, @code{graphics},
@code{graphicx}, @code{trig}, @code{epsfig}, @code{keyval}, and
@code{lscape}.")
    (license license:lppl1.3c)))

(define-deprecated-package texlive-latex-graphics texlive-graphics)

(define-public texlive-greek-fontenc
  (package
    (name "texlive-greek-fontenc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/greek-fontenc/"
                                     "tex/latex/greek-fontenc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xwg1vnw7z5ik1n106lr1wfq156j1ap8j9z36qdhi5sxqyx9zvm7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/greek-fontenc")
    (synopsis "LICR macros and encoding definition files for Greek")
    (description
     "The package provides Greek LICR macro definitions and encoding
definition files for Greek text font encodings for use with @code{fontenc}.")
    (license license:lppl1.3+)))

(define-public texlive-gsftopk
  (package
    (name "texlive-gsftopk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/gsftopk.1"
                                     "doc/man/man1/gsftopk.man1.pdf"
                                     "dvips/gsftopk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qlac704qbm7kq762z0b887wfncprpcm8zj2lb4nag0wzdrrjdq5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-gsftopk-bin))
    (home-page "https://ctan.org/pkg/gsftopk")
    (synopsis "Convert Ghostscript fonts to PK files")
    (description
     "Designed for use with @command{xdvi} and @command{dvips}, this utility
converts Adobe Type 1 fonts to PK bitmap format.  It should not ordinarily be
much used nowadays, since both its target applications are now capable of
dealing with Type 1 fonts, direct.")
    (license license:gpl3+)))

(define-public texlive-gsftopk-bin
  (package
    (inherit texlive-bin)
    (name "texlive-gsftopk-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("gsftopk"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-gsftopk" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/gsftopk"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/gsftopk"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list texlive-libkpathsea))
    (propagated-inputs '())
    (home-page (package-home-page texlive-gsftopk))
    (synopsis "Binary for @code{texlive-gsftopk}")
    (description
     "This package provides the binary for @code{texlive-gsftopk}.")
    (license (package-license texlive-gsftopk))))

(define-public texlive-hycolor
  (package
    (name "texlive-hycolor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hycolor/" "source/latex/hycolor/"
                                     "tex/latex/hycolor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hmkx37wwmznxjqqnca87shy7qrgqrh2cn5r941ddgivnym31xbh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hycolor")
    (synopsis "Colour for packages @code{hyperref} and @code{bookmark}")
    (description
     "This package provides the code for the color option that is used by
packages @code{hyperref} and @code{bookmark}.  It is not intended as a package
for the user.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-hycolor texlive-hycolor)

(define-public texlive-xcjk2uni
  (package
    (name "texlive-xcjk2uni")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xcjk2uni/"
                                     "source/latex/xcjk2uni/"
                                     "tex/latex/xcjk2uni/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vjp47ngrirrvbnk4vnm5lbysj3qlbwxbfc1szc22gaikm52ggaq"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ttfutils")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          (add-before 'build 'copy-ctxdocstrip.tex
            ;; There's a circular dependency between this package (where
            ;; `ctex' should be a native input) and `ctex' (where this package
            ;; is a propagated input).  To work around this, install the
            ;; specific "ctxdocstrip.tex" file from `ctex' in the build
            ;; directory and set TEXINPUTS variable accordingly so the process
            ;; can find it.
            (lambda* (#:key inputs #:allow-other-keys)
              (install-file (search-input-file inputs
                                               "tex/generic/ctex/ctxdocstrip.tex")
                            "build/")
              (setenv "TEXINPUTS" (string-append (getcwd) "/build:")))))))
    (native-inputs (list (package-source texlive-ctex) texlive-ttfutils))
    (home-page "https://ctan.org/pkg/xcjk2uni")
    (synopsis "Convert CJK characters to Unicode, in pdfTeX")
    (description
     "The package provides commands to convert CJK characters to Unicode in
non-UTF-8 encoding; it provides hooks to support hyperref in producing correct
bookmarks.  The bundle also provides @code{/ToUnicode} mapping file(s) for
a CJK subfont; these can be used with the cmap package, allowing searches of,
and cut-and-paste operations on a PDF file generated by pdfTeX.")
    (license license:lppl1.3c)))

(define-public texlive-xcolor
  (package
    (name "texlive-xcolor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xcolor/" "dvips/xcolor/"
                                     "source/latex/xcolor/" "tex/latex/xcolor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gffdw5klhsyfcnicjw0fpqwgid8qfrfbqwxif7wsbw1q217bmmy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xcolor")
    (synopsis "Driver-independent color extensions for LaTeX and pdfLaTeX")
    (description
     "The package starts from the basic facilities of the colorcolor package,
and provides easy driver-independent access to several kinds of color tints,
shades, tones, and mixes of arbitrary colors.  It allows a user to select
a document-wide target color model and offers complete tools for conversion
between eight color models.  Additionally, there is a command for alternating
row colors plus repeated non-aligned material (like horizontal lines) in
tables.")
    (license license:lppl1.2+)))

(define-deprecated-package texlive-latex-xcolor texlive-xcolor)

(define-public texlive-xltxtra
  (package
    (name "texlive-xltxtra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/xltxtra/"
                                     "source/xelatex/xltxtra/"
                                     "tex/xelatex/xltxtra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dh3nnr4xhb85zp3q4jdzqvfghg8m9zvpsvvrmmp0q3ayf0c1dbj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-metalogo))
    (home-page "https://ctan.org/pkg/xltxtra")
    (synopsis "Extras for LaTeX users of XeTeX")
    (description
     "This package was previously used to provide a number of features that
were useful for typesetting documents with XeLaTeX.  Many of those features
have now been incorporated into the @code{fontspec} package and other
packages, but the package persists for backwards compatibility.  Nowadays,
loading @code{xltxtra} will: load the @code{fontspec}, @code{metalogo}, and
@code{realscripts} packages; redefine @code{\\showhyphens} so it works
correctly; and define two extra commands: @code{\\vfrac} and
@code{\\namedglyph}.")
    (license license:lppl1.3c)))

(define-public texlive-xml2pmx
  (package
    (name "texlive-xml2pmx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/xml2pmx.1"
                                     "doc/man/man1/xml2pmx.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1d3ralqh0b71scd59b4hmm707yfrz1rj28ni2lzkhbb1ql73bvah"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-xml2pmx-bin))
    (home-page "https://ctan.org/pkg/xml2pmx")
    (synopsis "Convert MusicXML to PMX and MusiXTeX")
    (description
     "This program translates MusicXML files to input suitable for PMX and
MusiXTeX processing.")
    (license license:gpl3+)))

(define-public texlive-xml2pmx-bin
  (package
    (inherit texlive-bin)
    (name "texlive-xml2pmx-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '("xml2pmx"))
            (delete-other-directories "texk" '())))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-xml2pmx" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "utils/xml2pmx"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "utils/xml2pmx"
                  (invoke "make" "install"))))))))
    (native-inputs '())
    (inputs '())
    (propagated-inputs '())
    (home-page (package-home-page texlive-xml2pmx))
    (synopsis "Binary for @code{texlive-xml2pmx}")
    (description
     "This package provides the binary for @code{texlive-xml2pmx}.")
    (license (package-license texlive-xml2pmx))))

(define-public texlive-xmltexconfig
  (package
    (name "texlive-xmltexconfig")
    (version "2024.2")
    ;; XXX: The package is actually empty in TeX Live. Treat it as
    ;; a meta-package until it is removed from TeX Live.
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (home-page "https://ctan.org/pkg/xmltexconfig")
    (synopsis "Configuration files for @code{xmltex} and @code{pdfxmltex}")
    (description "This package provides configuration files for @code{xmltex}
and @code{pdfxmltex}.")
    (license license:public-domain)))

(define-public texlive-xmltex
  (package
    (name "texlive-xmltex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/otherformats/xmltex/base/"
                                     "tex/xmltex/base/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rqwsapba8zs2ijjs7lpzksm20jqb8zbmanpw7wmdp2rq26ahylh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:create-formats #~(list "pdfxmltex" "xmltex")
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'install 'install-wrappers
            (lambda* (#:key inputs #:allow-other-keys)
              (let ((pdftex (search-input-file inputs "/bin/pdftex")))
                (mkdir-p (string-append #$output "/bin"))
                (symlink pdftex (string-append #$output "/bin/xmltex"))
                (symlink pdftex (string-append #$output "/bin/pdfxmltex"))))))))
    (propagated-inputs
     (list texlive-babel
           texlive-cm
           texlive-firstaid
           texlive-hyphen-complete
           texlive-l3backend
           texlive-l3kernel
           texlive-latex
           texlive-latex-fonts
           texlive-latexconfig
           texlive-pdftex
           texlive-tex
           texlive-tex-ini-files
           texlive-unicode-data
           texlive-xmltexconfig))
    (home-page "https://ctan.org/pkg/xmltex")
    (synopsis "Support for parsing XML documents")
    (description
     "The package provides an implementation of a parser for documents
matching the XML 1.0 and XML Namespace Recommendations.  Element and attribute
names, as well as character data, may use any characters allowed in XML, using
UTF-8 or a suitable 8-bit encoding.")
    (license license:lppl1.0+)))        ;per xmltex/base/readme.txt

(define-public texlive-xpiano
  (package
    (name "texlive-xpiano")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xpiano/" "source/latex/xpiano/"
                                     "tex/latex/xpiano/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nk8v0d641cr4mg4l2k0fv7pl9b26nyi30k4px5wajwm976f042p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xpiano")
    (synopsis "Extension of the @code{piano} package")
    (description
     "This package provides macros for typesetting virtual keyboards limited
to two octaves for showing notes represented by a colored circle.  Optionally,
the number used for pitch analysis can be shown.  It is an extension of
@file{piano.sty}.  It features extended syntax and several options, like
setting the color, adding numbers for pitch analysis, one or two octaves, and
others.")
    (license license:lppl1.3+)))

(define-public texlive-xpinyin
  (package
    (name "texlive-xpinyin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xpinyin/" "source/latex/xpinyin/"
                                     "tex/latex/xpinyin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fxsnvmkm66rfq08j03sch24maw0wgb8dhl73r2rf6gwxzf4imc5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          ;; FIXME: The build process requires Lua sockets and Unihan to be
          ;; available.  Building it also introduces a circular dependency
          ;; with TEXLIVE-CTEX, and a reproducibility issue with
          ;; "xpinyin-database.def".  Sorry, this is a bit too much.
          (delete 'build))))
    (home-page "https://ctan.org/pkg/xpinyin")
    (synopsis "Automatically add pinyin to Chinese characters")
    (description
     "The package is written to simplify the input of Hanyu Pinyin.  Macros are
provided that automatically add pinyin to Chinese characters.")
    (license license:lppl1.3c)))

(define-public texlive-hyperref
  (package
    (name "texlive-hyperref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hyperref/"
                                     "source/latex/hyperref/"
                                     "tex/latex/hyperref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mb8fm2759mi9gfxbmg97db2g510ay2wmqjkk93xmgkg768rajbc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-atbegshi
           texlive-auxhook
           texlive-bitset
           texlive-etexcmds
           texlive-gettitlestring
           texlive-hycolor
           texlive-intcalc
           texlive-kvdefinekeys
           texlive-kvsetkeys
           texlive-letltxmacro
           texlive-ltxcmds
           texlive-pdfescape
           texlive-refcount
           texlive-rerunfilecheck
           texlive-stringenc
           texlive-url
           texlive-zapfding))
    (home-page "https://www.ctan.org/pkg/hyperref")
    (synopsis "Extensive support for hypertext in LaTeX")
    (description
     "The @code{hyperref} package is used to handle cross-referencing commands
in LaTeX to produce hypertext links in the document.  The package provides
backends for the @code{\\special} set defined for HyperTeX DVI processors; for
embedded @code{pdfmark} commands for processing by Acrobat
Distiller (@code{dvips} and Y&Y's @code{dvipsone}); for Y&Y's @code{dviwindo};
for PDF control within pdfTeX and @code{dvipdfm}; for TeX4ht; and for VTeX's
pdf and HTML backends.  The package is distributed with the @code{backref} and
@code{nameref} packages, which make use of the facilities of
@code{hyperref}.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-hyperref texlive-hyperref)

(define-public texlive-hypdoc
  (package
    (name "texlive-hypdoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hypdoc/" "source/latex/hypdoc/"
                                     "tex/latex/hypdoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "158x0aa6vdvd8l3k1blqf5qjyaqg3mdmixscs1vvqpymdbahqgi6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hypdoc")
    (synopsis "Hyper extensions for @file{doc.sty}")
    (description
     "This package adds hypertext features to the package @code{doc} that is
used in the documentation system of LaTeX2e.  Bookmarks are added and
references are linked as far as possible.")
    (license license:lppl1.3c)))

(define-public texlive-hyperxmp
  (package
    (name "texlive-hyperxmp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hyperxmp/"
                                     "doc/man/man1/hyperxmp-add-bytecount.1"
                                     "doc/man/man1/hyperxmp-add-bytecount.man1.pdf"
                                     "scripts/hyperxmp/"
                                     "source/latex/hyperxmp/"
                                     "tex/latex/hyperxmp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03ipfjyw8wkgmvlaljnaxb2n3imxfs7hzwm9caw78jf6v5ji70ll"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:link-scripts #~(list "hyperxmp-add-bytecount.pl")
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'fix-build
            (lambda _
              (delete-file "source/latex/hyperxmp/hyperxmp-stds.tex"))))))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/hyperxmp")
    (synopsis "Embed XMP metadata within a LaTeX document")
    (description
     "XMP (eXtensible Metadata Platform) is a mechanism proposed by Adobe for
embedding document metadata, within the document itself.  The metadata is
designed to be easy to extract, even by programs that are oblivious to the
document's file format.  The @code{hyperxmp} package makes it trivial for
LaTeX document authors to store XMP metadata in their documents as well.  It
is compatible with pdfLaTeX, XeLaTeX, LaTeX+dvipdfm, and LaTeX+dvips+ps2pdf.")
    (license license:lppl1.3c)))

(define-public texlive-latex-brochure
  (package
    (name "texlive-latex-brochure")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latex-brochure/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xba20sy8q10ac9hxwnz9axh853hrj06vp7mfn12ajax31miznmy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latex-brochure")
    (synopsis "Publicity flyer for LaTeX")
    (description
     "The document is designed as a publicity flyer for LaTeX, but also serves
as an interesting showcase of what LaTeX can do.  The flyer is designed for
printing, double-sided, on A3 paper, which would then be folded once.")
    (license license:lppl)))

(define-public texlive-latex-course
  (package
    (name "texlive-latex-course")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latex-course/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00s521wrc5gqqs5jvd1ljl04nighy8q79r0ama783ic27a3k0qhi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latex-course")
    (synopsis "LaTeX course as a projected presentation")
    (description
     "This package provides a brief Beamer-based slide presentation on LaTeX,
based on Rupprecht's LaTeX 2.09 course, which the author has translated to
English and taken to LaTeX2e and Beamer.  Additional material was taken from
the @emph{Short Introduction to LaTeX}.")
    (license license:gpl3+)))

(define-public texlive-latex-doc-ptr
  (package
    (name "texlive-latex-doc-ptr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latex-doc-ptr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mamlfnxzi4lwh5cpss8zcfr64jdnf6vnj9fp48accrqdj2rpfs2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latex-doc-ptr")
    (synopsis "Direction-finder for LaTeX resources available online")
    (description
     "This package provides a brief set of recommendations for users who need
online documentation of LaTeX.  The document supports the need for
documentation of LaTeX itself, in distributions.")
    (license license:public-domain)))

(define-public texlive-latex-for-undergraduates
  (package
    (name "texlive-latex-for-undergraduates")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latex-for-undergraduates/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03s686vbzpjv71vlp5931vxyx8lckvl5819agh4688h9m98w54s9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latex-for-undergraduates")
    (synopsis "Tutorial aimed at introducing undergraduate students to LaTeX")
    (description
     "This package provides a tutorial aimed at introducing undergraduate
students to LaTeX, including an introduction to LaTeX Workshop in Visual
Studio Code and an example package of user-defined LaTeX commands.")
    (license license:public-domain)))

(define-public texlive-latex-graphics-companion
  (package
    (name "texlive-latex-graphics-companion")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latex-graphics-companion/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01zs32gck1sl9zlbhghyjmjwxyvw0jha5vl2hd10knyrb3z4dhxc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lgc-examples")
    (synopsis "Examples from @emph{The LaTeX Graphics Companion}")
    (description
     "This package contains the source of the examples printed in @emph{The
LaTeX Graphics Companion} book, together with necessary supporting files.")
    (license license:lppl)))

(define-public texlive-latex-refsheet
  (package
    (name "texlive-latex-refsheet")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latex-refsheet/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "169h1syday30qiw032k14fhxikdwszggvqz8b9ga4i9wwxf1vh4m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latex-refsheet")
    (synopsis "LaTeX reference sheet for a thesis with KOMA-Script")
    (description
     "This LaTeX reference sheet is for writing a thesis using the KOMA-Script
document classes (@code{scrartcl}, @code{scrreprt}, @code{scrbook}) and all
the packages needed for a thesis in natural sciences.")
    (license license:lppl1.3c)))

(define-public texlive-latex-veryshortguide
  (package
    (name "texlive-latex-veryshortguide")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latex-veryshortguide/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17i8zmr7mjfrx911psdy9cbn05c5inn4ixqmnjkpr9sbgsninyc4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latex-veryshortguide")
    (synopsis "The Very Short Guide to LaTeX")
    (description
     "This is a 4-page reminder of what LaTeX does.  It is designed for
printing on A4 paper, double-sided, and folding once to A5.  Such an imposed
version of the document is provided in the distribution, as PDF.  An analogous
version is provided in legal format.")
    (license license:lppl1.3+)))

(define-public texlive-latex-web-companion
  (package
    (name "texlive-latex-web-companion")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latex-web-companion/apa/"
                                     "doc/latex/latex-web-companion/apb/"
                                     "doc/latex/latex-web-companion/apc/"
                                     "doc/latex/latex-web-companion/ch2/"
                                     "doc/latex/latex-web-companion/ch3/"
                                     "doc/latex/latex-web-companion/ch4/"
                                     "doc/latex/latex-web-companion/ch6/"
                                     "doc/latex/latex-web-companion/ch7/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0v018lwf88z3qmzyqpyvfql7dbwk5a9r0wj3jfjc9cp2ksl8zf8f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lwc-examples")
    (synopsis "Examples from @emph{The LaTeX Web Companion}")
    (description
     "This package contains the source of the examples printed in @emph{The
LaTeX Web Companion} book, together with necessary supporting files.")
    (license license:lppl)))

(define-public texlive-latex2e-help-texinfo
  (package
    (name "texlive-latex2e-help-texinfo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/info/latex2e.info"
                                     "doc/latex/latex2e-help-texinfo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rk69n89hl67qfbi5mmb4msaibychsk9a83dx593170ayiir6s6g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latex2e-help-texinfo")
    (synopsis "Unofficial reference manual covering LaTeX2e")
    (description
     "This is an unofficial reference manual for LaTeX.  It is provided as
Texinfo source.  This is a collaborative development, and details of getting
involved are to be found on the package home page.")
    (license license:fdl1.1+)))

(define-public texlive-latex4wp
  (package
    (name "texlive-latex4wp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latex4wp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a569y6vss3glz1il4hg2f6718mj24spp4ahdj6v7k6y7ppa1zii"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latex4wp")
    (synopsis "LaTeX guide specifically designed for word processor users")
    (description
     "@emph{LaTeX for Word Processor Users} is a guide that helps converting
knowledge and techniques of word processing into the LaTeX typesetting
environment.  It aims at helping such users use LaTeX instead.")
    (license license:fdl1.3+)))

(define-public texlive-latex4wp-it
  (package
    (name "texlive-latex4wp-it")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latex4wp-it/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14r86fwhb9zafmyv05pqfi9962dpxj7wq94acm43gv8m2rsjp52k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latex4wp-it")
    (synopsis "LaTeX guide for word processor users, in Italian")
    (description
     "The package provides a version of the @emph{LaTeX for Word Processor
Users} document in Italian.")
    (license license:fdl1.3+)))

(define-public texlive-latexcheat
  (package
    (name "texlive-latexcheat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latexcheat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1383rsi21ma0291asi779bjr33m7fii019di8gv8kxwgci692fz0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latexcheat")
    (synopsis "LaTeX cheat sheet")
    (description
     "This package provides a LaTeX reference sheet for writing scientific
papers.  Unlike many other such sheets, this sheet does not focus on
typesetting mathematics, though it does list some symbols.")
    (license license:lppl)))

(define-public texlive-latexcheat-ptbr
  (package
    (name "texlive-latexcheat-ptbr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latexcheat-ptbr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m636j9gdfpm4j1b679z5qw5ygbm6jp8xl9dzy6v5zzy695fcgaf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latexcheat-ptbr")
    (synopsis "LaTeX cheat sheet, in Brazilian Portuguese")
    (description
     "This is a translation to Brazilian Portuguese of Winston Chang's LaTeX
cheat sheet.")
    (license license:lppl)))

(define-public texlive-latexcourse-rug
  (package
    (name "texlive-latexcourse-rug")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latexcourse-rug/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "027siznmshk60flxgra7dgzvwbmgwvckwb6r257b91x3rm77anv5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latexcourse-rug")
    (synopsis "LaTeX course book")
    (description
     "The package provides the book and practice files for a LaTeX course that
the author has give several times at the Rijksuniversiteit
Groningen (Netherlands).")
    (license license:fdl1.1+)))

(define-public texlive-latexfileinfo-pkgs
  (package
    (name "texlive-latexfileinfo-pkgs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latexfileinfo-pkgs/"
                                     "source/latex/latexfileinfo-pkgs/"
                                     "tex/latex/latexfileinfo-pkgs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08afjj6im3bdxv3j0z6kg8yw0pyjl5164fqn0sx084zbdfwdfrqn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latexfileinfo-pkgs")
    (synopsis "Comparison of packages showing LaTeX file information")
    (description
     "The package provides an HTML file that lists and compares CTAN packages
that display LaTeX source file information from @code{\\ProvidesClass},
@code{\\ProvidesFile}, and @code{\\ProvidesPackage} commands in the LaTeX
file.  Five packages of the author's, and several other packages are
discussed; revision control systems are mentioned briefly.")
    (license license:lppl1.3+)))

(define-public texlive-oberdiek
  (package
    (name "texlive-oberdiek")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/oberdiek/" "doc/latex/oberdiek/"
                                     "source/latex/oberdiek/"
                                     "tex/generic/oberdiek/" "tex/latex/oberdiek/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "126fsv65d60ixzyyyx1gpx8a4dd25k5jm599hl31zvdjcrk4p9sx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-auxhook
           texlive-grfext
           texlive-grffile
           texlive-iftex
           texlive-infwarerr
           texlive-kvoptions
           texlive-pdftexcmds))
    (home-page "https://www.ctan.org/pkg/oberdiek")
    (synopsis "Bundle of packages submitted by Heiko Oberdiek")
    (description
     "The bundle comprises various LaTeX packages, providing among others:
better accessibility support for PDF files; extensible chemists reaction
arrows; record information about document class(es) used; and many more.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-oberdiek texlive-oberdiek)

(define-public texlive-regexpatch
  (package
    (name "texlive-regexpatch")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/regexpatch/"
                                     "source/latex/regexpatch/"
                                     "tex/latex/regexpatch/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jv8hvkvq0yvc8mh68ybj8fvhf6kcdzwjin1czs45i26s0dpsngj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/regexpatch")
    (synopsis "High level patching of commands")
    (description
     "The package generalises the macro patching commands provided by
P. Lehmann's @code{etoolbox}.  The difference between this package and its
sibling @code{xpatch} is that this package sports a very powerful
@code{\\regexpatchcmd} based on the @code{l3regex} module of the LaTeX3
experimental packages.")
    (license license:lppl1.3c)))

(define-public texlive-rerunfilecheck
  (package
    (name "texlive-rerunfilecheck")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rerunfilecheck/"
                                     "source/latex/rerunfilecheck/"
                                     "tex/latex/rerunfilecheck/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m3rvjgw0hg3n7db8hpyq55lq7py4scm35bqbawpc5mn5pmh2zg1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-atveryend texlive-uniquecounter))
    (home-page "https://www.ctan.org/pkg/rerunfilecheck")
    (synopsis "Checksum based rerun checks on auxiliary files")
    (description
     "This package provides additional rerun warnings if some auxiliary files
have changed.  It is based on MD5 checksum, provided by pdfTeX.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-rerunfilecheck texlive-rerunfilecheck)

(define-public texlive-onedown
  (package
    (name "texlive-onedown")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/onedown/"
                                     "source/latex/onedown/"
                                     "tex/latex/onedown/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1j4ymb1mz2wa189dy98mwv0550sj38wbridk2fx074dy2lfjxdm5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/onedown")
    (synopsis "Typeset bridge diagrams")
    (description
     "This is a comprehensive package to draw all sorts of bridge diagrams,
including hands, bidding tables, trick tables, and expert quizzes.

It works for all font sizes.  Different fonts for hands, bidding diagrams and
compass are possible.  It also provides annotations to card and bidding
diagrams, automated check on consistency of suit and hands, and multilingual
output of bridge terms.")
    (license license:lppl1.3+)))

(define-public texlive-tools
  (package
    (name "texlive-tools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tools/"
                                     "source/latex/tools/"
                                     "tex/latex/tools/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fkpjgaagf36hq1wxi4a57ijcgdzvlmwlp6alfb05w2ym628zz3h"))))
    (outputs '("out" "doc"))
    (arguments
     (list #:build-targets #~(list "tools.ins")))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tools")
    (synopsis "The LaTeX standard tools bundle")
    (description "This package provides a collection of simple tools that
are part of the LaTeX required tools distribution, comprising the packages:
@code{afterpage}, @code{array}, @code{bm}, @code{calc}, @code{dcolumn},
@code{delarray}, @code{enumerate}, @code{fileerr}, @code{fontsmpl},
@code{ftnright}, @code{hhline}, @code{indentfirst}, @code{layout},
@code{longtable}, @code{multicol}, @code{rawfonts}, @code{showkeys},
@code{somedefs}, @code{tabularx}, @code{theorem}, @code{trace},
@code{varioref}, @code{verbatim}, @code{xr}, and @code{xspace}.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-tools texlive-tools)

(define-public texlive-url
  (package
    (name "texlive-url")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/url/" "tex/latex/url/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "184m40wgnx939ky2hbxnj0v9aak023ldrhgffp0lgyk9wdqpxlqg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/url")
    (synopsis "Verbatim with URL-sensitive line breaks")
    (description "The command @code{\\url} is a form of verbatim command that
allows linebreaks at certain characters or combinations of characters, accepts
reconfiguration, and can usually be used in the argument to another command.
The command is intended for email addresses, hypertext links,
directories/paths, etc., which normally have no spaces, so by default the
package ignores spaces in its argument.  However, a package option allows
spaces, which is useful for operating systems where spaces are a common part
of file names.")
    ;; The license header states that it is under LPPL version 2 or later, but
    ;; the latest version is 1.3c.
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-url texlive-url)

(define-public texlive-l3experimental
  (package
    (name "texlive-l3experimental")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/l3experimental/"
                                     "source/latex/l3experimental/l3benchmark/"
                                     "source/latex/l3experimental/l3draw/"
                                     "source/latex/l3experimental/l3graphics/"
                                     "source/latex/l3experimental/l3opacity/"
                                     "source/latex/l3experimental/l3str/"
                                     "source/latex/l3experimental/l3sys-shell/"
                                     "source/latex/l3experimental/xcoffins/"
                                     "source/latex/l3experimental/xgalley/"
                                     "tex/latex/l3experimental/l3benchmark/"
                                     "tex/latex/l3experimental/l3draw/"
                                     "tex/latex/l3experimental/l3graphics/"
                                     "tex/latex/l3experimental/l3opacity/"
                                     "tex/latex/l3experimental/l3str/"
                                     "tex/latex/l3experimental/l3sys-shell/"
                                     "tex/latex/l3experimental/xcoffins/"
                                     "tex/latex/l3experimental/xgalley/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vrggg8id8fyndzq0vr76vdh4vi8xixjs3b09gq7if48bvjrz3h4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-l3kernel))
    (home-page "https://ctan.org/pkg/l3experimental")
    (synopsis "Experimental LaTeX3 concepts")
    (description
     "The l3experimental packages are a collection of experimental
implementations for aspects of the LaTeX3 kernel, dealing with higher-level
ideas such as the Designer Interface.  Some of them work as stand alone
packages, providing new functionality, and can be used on top of LaTeX2e with
no changes to the existing kernel.  The present release includes:
@itemize @code
@item l3benchmark
for measuring the time taken by TeX to run certain code;
@item l3draw
a code-level interface for constructing drawings;
@item l3graphics
an interface for the inclusion of graphics files;
@item l3opacity
support for opacity in PDF output;
@item l3str
support for string manipulation;
@item l3bitset
support for bit vectors;
@item l3sys-shell
which provides abstractions for common shell functions like file
deletion and copying;
@item xcoffins
which allows the alignment of boxes using a series of handle positions,
supplementing the simple TeX reference point;
@item xgalley
which controls boxes receiving text for typesetting.
@end itemize")
    (license license:lppl1.3c)))

(define-public texlive-l3kernel
  (package
    (name "texlive-l3kernel")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/l3kernel/"
                                     "source/latex/l3kernel/"
                                     "tex/latex/l3kernel/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ajz0h02l8ykpxxqvq8djjnv7fcidfadcyj11mxifhfm6ii589qk"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-latex")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:tex-engine "tex"
      #:tex-format #f
      #:texlive-latex-bin? #f))
    (native-inputs (list texlive-latex))
    (propagated-inputs (list texlive-l3backend))
    (home-page "https://ctan.org/pkg/l3kernel")
    (synopsis "LaTeX3 programming conventions")
    (description
     "The l3kernel bundle provides an implementation of the LaTeX3 programmers
interface, as a set of packages that run under LaTeX2e.  The interface
provides the foundation on which the LaTeX3 kernel and other future code are
built: it is an API for TeX programmers.  The packages are set up so that the
LaTeX3 conventions can be used with regular LaTeX2e packages.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-l3kernel texlive-l3kernel)

(define-public texlive-l3backend
  (package
    (name "texlive-l3backend")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/l3backend/"
                                     "dvips/l3backend/"
                                     "source/latex/l3backend/"
                                     "tex/latex/l3backend/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y0jf1gz37vwp7hvi26y83iy9jgjp2drm6v6wq8yayap293jdfk0"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-latex")))
    (build-system texlive-build-system)
    (arguments
     (list #:tex-engine "tex"
           #:tex-format #f
           #:texlive-latex-bin? #f))
    (native-inputs (list texlive-latex))
    (home-page "https://ctan.org/pkg/l3backend")
    (synopsis "LaTeX3 backend drivers")
    (description
     "This package forms parts of expl3, and contains the code used to
interface with backends (drivers) across the expl3 codebase.  The functions
here are defined differently depending on the engine in use.  As such, these
are distributed separately from l3kernel to allow this code to be updated on
an independent schedule.")
    (license license:lppl1.3c)))

(define-deprecated-package texlive-dvips-l3backend texlive-l3backend)
(define-deprecated-package texlive-latex-l3backend texlive-l3backend)

(define-public texlive-l3packages
  (package
    (name "texlive-l3packages")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/l3packages/"
                                     "source/latex/l3packages/l3keys2e/"
                                     "source/latex/l3packages/xfp/"
                                     "source/latex/l3packages/xparse/"
                                     "source/latex/l3packages/xtemplate/"
                                     "tex/latex/l3packages/l3keys2e/"
                                     "tex/latex/l3packages/xfp/"
                                     "tex/latex/l3packages/xparse/"
                                     "tex/latex/l3packages/xtemplate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "141f5lyybhyg9dncxxsl3npgyysk6ac8wpbagpmqvymfa6sqqrqx"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-latex")))
    (build-system texlive-build-system)
    (arguments
     (list #:build-targets
           '(list "l3keys2e.ins"
                  "xparse.ins"
                  "xfrac.ins"
                  "xfp.ins"
                  "xtemplate.ins")
           #:tex-engine "tex"
           #:tex-format #f
           #:texlive-latex-bin? #f))
    (native-inputs (list texlive-latex))
    (propagated-inputs (list texlive-l3kernel))
    (home-page "https://ctan.org/pkg/l3packages")
    (synopsis "High-level LaTeX3 concepts")
    (description
     "This collection contains implementations for aspects of the LaTeX3
kernel, dealing with higher-level ideas such as the Designer Interface.  The
packages here are considered broadly stable (The LaTeX3 Project does not
expect the interfaces to alter radically).  These packages are built on
LaTeX2e conventions at the interface level, and so may not migrate in the
current form to a stand-alone LaTeX3 format.

Packages provided are @code{xparse}, which provides a high-level interface for
declaring document commands @code{xfp}, an expandable IEEE 754 FPU for LaTeX,
@code{l3keys2e}, which makes the facilities of the kernel module l3keys
available for use by LaTeX 2e packages, @code{xtemplate}, which provides
a means of defining generic functions using a key-value syntax, and
@code{xfrac}, which provides flexible split-level fractions.")
    (license license:lppl1.3c)))

(define-deprecated-package texlive-latex-l3packages texlive-l3packages)

(define-public texlive-fonts-churchslavonic
  (package
    (name "texlive-fonts-churchslavonic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/fonts-churchslavonic/"
                                     "fonts/opentype/public/fonts-churchslavonic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yq641kmsh52gc66h559h6cgcd46dq1q10gnq3g2x77jv2b39a5r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fonts-churchslavonic")
    (synopsis "Fonts for typesetting in Church Slavonic language")
    (description
     "The package provides Unicode-encoded OpenType fonts for Church Slavonic
which are intended for Unicode TeX engines only.")
    (license license:silofl1.1)))

(define-public texlive-fontspec
  (package
    (name "texlive-fontspec")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fontspec/"
                                     "source/latex/fontspec/"
                                     "tex/latex/fontspec/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yz1jkwyybrj3qixmdaxxmi8p4a9kz5zyawl6vcmxys6wlxiyqr2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-euenc
           texlive-iftex
           texlive-l3kernel
           texlive-l3packages
           texlive-lm
           texlive-xunicode))
    (home-page "https://ctan.org/pkg/fontspec")
    (synopsis "Advanced font selection in XeLaTeX and LuaLaTeX")
    (description
     "Fontspec is a package for XeLaTeX and LuaLaTeX.  It provides an
automatic and unified interface to feature-rich AAT and OpenType fonts through
the NFSS in LaTeX running on XeTeX or LuaTeX engines.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-fontspec texlive-fontspec)

(define-public texlive-grffile
  (package
    (name "texlive-grffile")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/grffile/"
                                     "source/latex/grffile/"
                                     "tex/latex/grffile/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01mlvdhqwfwj1l91jfvkdfbn1hj95rlb6xhwikzx1r8qrz5whw7n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/grffile")
    (synopsis "Extended file name support for graphics (legacy package)")
    (description
     "The original @code{grffile} package extended the file name processing
of the @code{graphics} package to support a larger range of file names.  The
base LaTeX code now supports multiple dots and spaces, and this package by
default is a stub that just loads @code{graphicx}.")
    (license license:lppl1.3c+)))

(define-public texlive-sanskrit
  (package
    (name "texlive-sanskrit")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sanskrit/"
                                     "fonts/source/public/sanskrit/"
                                     "fonts/tfm/public/sanskrit/"
                                     "source/latex/sanskrit/"
                                     "tex/latex/sanskrit/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qc0mylgdcc4rnid29was51s6mzil0smrs7kgnnrv8kvlb6mzydl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/sanskrit")
    (synopsis "Sanskrit support")
    (description
     "This package provides a font and pre-processor suitable for the
production of documents written in Sanskrit.  Type 1 versions of the fonts are
available.")
    (license license:lppl)))

(define-public texlive-sanskrit-t1
  (package
    (name "texlive-sanskrit-t1")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/sanskrit-t1/"
                                     "fonts/map/dvips/sanskrit-t1/"
                                     "fonts/type1/public/sanskrit-t1/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mv9ph7999y9shnq25k0w4sgcbvlf2gav5d1fpycjxan3h6rc7vi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sanskrit-t1")
    (synopsis "Type 1 version of @code{skt} fonts for Sanskrit")
    (description
     "The sanskrit-t1 font package provides Type 1 version of Charles Wikner's
@code{skt} font series for the Sanskrit language.")
    (license license:lppl)))

(define-public texlive-sansmath
  (package
    (name "texlive-sansmath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sansmath/" "tex/latex/sansmath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lqxfvmxan0c9s270jp8jw1a5s6ya1i4jlfp2xz2k4w0g0fryjpj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sansmath")
    (synopsis "Maths in a Sans font")
    (description
     "The package defines a new math version Sans, and a command
@code{\\sansmath} that behaves somewhat like @code{\\boldmath}.")
    (license license:public-domain)))

(define-public texlive-sansmathfonts
  (package
    (name "texlive-sansmathfonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/sansmathfonts/"
                                     "fonts/map/dvips/sansmathfonts/"
                                     "fonts/source/public/sansmathfonts/"
                                     "fonts/tfm/public/sansmathfonts/"
                                     "fonts/type1/public/sansmathfonts/"
                                     "fonts/vf/public/sansmathfonts/"
                                     "tex/latex/sansmathfonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13i8sn4v5srcxsq0qw7q5lmw5271lzksc5xsgjrvg98s38zg7pa5"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-amsfonts"
                                               "texlive-cm"
                                               "texlive-ec")))
    (build-system texlive-build-system)
    (native-inputs
     (list texlive-amsfonts texlive-cm texlive-ec texlive-metafont))
    (home-page "https://ctan.org/pkg/sansmathfonts")
    (synopsis "Correct placement of accents in sans-serif maths")
    (description
     "This package provides sans serif small caps and math fonts for use with
Computer Modern.")
    (license license:lppl1.3c)))

(define-public texlive-stringenc
  (package
    (name "texlive-stringenc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/stringenc/"
                                     "source/latex/stringenc/"
                                     "tex/generic/stringenc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pz9fgn3zc1brbpkw2kkphsv8q6vpvbn51n0smmfl1n2m97fni9j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/stringenc")
    (synopsis "Converting a string between different encodings")
    (description
     "This package provides @code{\\StringEncodingConvert} for converting a
string between different encodings.  Both LaTeX and plain-TeX are supported.")
    (license license:lppl1.3c+)))

(define-public texlive-svg-inkscape
  (package
    (name "texlive-svg-inkscape")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/svg-inkscape/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gw3jp7wph0ys6372z2rgjwlpmmawdax7xpgrp4hzg5hxz748pn5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/svg-inkscape")
    (synopsis "How to include an SVG image in LaTeX using Inkscape")
    (description
     "The document demonstrates the use of SVG images in LaTeX documents.
Using the @samp{PDF+LaTeX output} option of Inkscape, it is possible to
include SVG in documents, in which LaTeX typesets the text.  This results in
uniform text style throughout the document, including text in images;
moreover, LaTeX commands may be used in the image's text, providing such
things as mathematics and references.

The document also describes how to automate the conversion from SVG to
@samp{PDF+LaTeX} using Inkscape.")
    (license license:lppl1.3+)))

(define-public texlive-svn-prov
  (package
    (name "texlive-svn-prov")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/svn-prov/" "source/latex/svn-prov/"
                                     "tex/latex/svn-prov/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1w416cf1yb1m2j9y38002zq6rbhbmkafi7w100y9m9lrzya0ws06"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/svn-prov")
    (synopsis "Subversion variants of @code{\\Provides}... macros")
    (description
     "The package introduces Subversion variants of the standard LaTeX macros
@code{\\ProvidesPackage}, @code{\\ProvidesClass} and @code{\\ProvidesFile}
where the file name and date is extracted from Subversion Id keywords.  The
file name may also be given explicitly as an optional argument.")
    (license license:lppl)))

(define-public texlive-l3build
  (package
    (name "texlive-l3build")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/l3build/"
                                     "doc/man/man1/l3build.1"
                                     "doc/man/man1/l3build.man1.pdf"
                                     "scripts/l3build/"
                                     "source/latex/l3build/"
                                     "tex/latex/l3build/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sx4719vvy1jpyq3dwm59pf0acakf21lidmdmjz8sfwp14xbk7sy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "l3build.lua")))
    (propagated-inputs (list texlive-luatex))
    (home-page "https://ctan.org/pkg/l3build")
    (synopsis "Testing and building system for LaTeX")
    (description
     "The @code{l3build} module is designed to support the development of
high-quality LaTeX code by providing: a unit testing system, automated
typesetting of code sources, and a reliable packaging system for CTAN
releases.  The bundle consists of a Lua script to run the tasks and
a @file{.tex} file which provides the testing environment.")
    (license license:lppl1.3c+)))

(define-public texlive-luabidi
  (package
    (name "texlive-luabidi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luabidi/"
                                     "tex/lualatex/luabidi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hapqr3mqbnx1087rbxb4hd7ynj53hhq97rnr9nlwkj19jw6rra3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luabidi")
    (synopsis "Bidi functions for LuaTeX")
    (description
     "The package attempts to emulate the XeTeX @code{bidi} package, in the
context of LuaTeX.")
    (license (list license:lppl1.3c license:expat))))

(define-public texlive-luacode
  (package
    (name "texlive-luacode")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luacode/"
                                     "source/lualatex/luacode/"
                                     "tex/lualatex/luacode/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dyld5yb57p3j7wz591plbgjy7dk7ngn8cxw1lfmvx8iprgk1f8d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luacode")
    (synopsis "Helper for executing Lua code from within TeX")
    (description
     "Executing Lua code from within TeX with directlua can sometimes be
tricky: there is no easy way to use the percent character, counting
backslashes may be hard, and Lua comments don't work the way you expect.  The
package provides the @code{\\luaexec} command and the @code{luacode}
environments to help with these problems.")
    (license license:lppl1.3+)))

(define-public texlive-lualatex-doc-de
  (package
    (name "texlive-lualatex-doc-de")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lualatex-doc-de/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vnmgs475bzbqi14m9sm45cwjfsbvbk45wkb8m73j1bnk7wg7hh4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lualatex-doc-de")
    (synopsis "Guide to LuaLaTeX (German translation)")
    (description
     "The document is a German translation of the map/guide to the world of
LuaLaTeX.  Coverage supports both new users and package developers.  Apart
from the introductory material, the document gathers information from several
sources, and offers links to others.")
    (license license:fdl1.3+)))

(define-public texlive-lualatex-math
  (package
    (name "texlive-lualatex-math")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/lualatex-math/"
                                     "source/lualatex/lualatex-math/"
                                     "tex/lualatex/lualatex-math/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rzzlq6a0c7sj1x83wqn5iwaiz3w9prcpz4lqbjlkgr7my4m052z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-etoolbox texlive-filehook))
    (home-page "https://ctan.org/pkg/lualatex-math")
    (synopsis "Fixes for mathematics-related LuaLaTeX issues")
    (description
     "The package patches a few commands of the LaTeX2e kernel and the
@code{amsmath} and @code{mathtools} packages to be more compatible with the
LuaTeX engine.  It is only meaningful for LuaLaTeX documents containing
mathematical formulas, and does not exhibit any new functionality.  The fixes
are mostly moved from the @code{unicode-math} package to this package since
they are not directly related to Unicode mathematics typesetting.")
    (license license:lppl1.3c)))

(define-public texlive-lualibs
  (package
    (name "texlive-lualibs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/lualibs/" "source/luatex/lualibs/"
                                     "tex/luatex/lualibs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07669vykws1h3q6s3m25rwpsdf4pzq8d90wpqjkvc5zn7lnk27wk"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-latex"
                                               "texlive-pdftex")))
    (build-system texlive-build-system)
    (arguments (list #:texlive-latex-bin? #f))
    (native-inputs (list texlive-latex texlive-pdftex))
    (home-page "https://ctan.org/pkg/lualibs")
    (synopsis "Additional Lua functions for LuaTeX macro programmers")
    (description
     "Lualibs is a collection of Lua modules useful for general programming.
The bundle is based on lua modules shipped with ConTeXt, and made available in
this bundle for use independent of ConTeXt.")
    (license license:gpl2)))

(define-deprecated-package texlive-luatex-lualibs texlive-lualibs)

(define-public texlive-lua-alt-getopt
  (package
    (name "texlive-lua-alt-getopt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/lua-alt-getopt/"
                                     "scripts/lua-alt-getopt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cizxzn33n3pn98xkqnxb8s6vdwkar3xrwhraqrs05pjfdn9d4wz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:texlive-latex-bin? #f))
    (home-page "https://ctan.org/pkg/lua-alt-getopt")
    (synopsis "Process application arguments as @code{getopt_long}")
    (description
     "This package provides a Lua module for processing application arguments
in the same way as BSD/GNU @code{getopt_long(3)} functions do.")
    (license license:expat)))

(define-public texlive-luatex
  (package
    (name "texlive-luatex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/base/"
                                     "doc/man/man1/dviluatex.1"
                                     "doc/man/man1/dviluatex.man1.pdf"
                                     "doc/man/man1/luatex.1"
                                     "doc/man/man1/luatex.man1.pdf"
                                     "doc/man/man1/texlua.1"
                                     "doc/man/man1/texlua.man1.pdf"
                                     "doc/man/man1/texluac.1"
                                     "doc/man/man1/texluac.man1.pdf"
                                     "tex/generic/config/luatex-unicode-letters.tex"
                                     "web2c/texmfcnf.lua"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jcqymq0a2yyn7smbwl0inc6q7ly4x7hraq8wbx3r5qr9q63hlpg"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-kpathsea")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:texlive-latex-bin? #f
      #:create-formats #~(list "dviluatex" "luatex")
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'customize-texmfcnf.lua
            (lambda _
              (substitute* "web2c/texmfcnf.lua"
                (("TEXMFDIST *=.*") "TEXMFDIST = os.getenv(\"GUIX_TEXMF\"),\n")
                (("TEXMFSYSVAR *=.*")
                 "TEXMFSYSVAR = \"$TEXMFDIST/../texmf-var\",\n")
                (("TEXMFSYSCONFIG *=.*")
                 "TEXMFSYSCONFIG = \"$TEXMFDIST/../texmf-config\",\n")
                (("TEXMF *=.*")
                 "TEXMF = \"{$TEXMFCONFIG,$TEXMFVAR,$TEXMFHOME,$TEXMFSYSCONFIG,$TEXMFSYSVAR,$TEXMFDIST}\",\n")))))))
    (native-inputs (list texlive-kpathsea))
    (propagated-inputs
     (list texlive-cm
           texlive-etex
           texlive-hyphen-complete
           texlive-knuth-lib
           texlive-plain
           texlive-tex-ini-files
           texlive-unicode-data))
    (home-page "https://ctan.org/pkg/luatex")
    (synopsis "Extended version of pdfTeX using Lua")
    (description
     "LuaTeX is an extended version of pdfTeX using Lua as an embedded
scripting language.  The LuaTeX project's main objective is to provide an open
and configurable variant of TeX while at the same time offering downward
compatibility.  LuaTeX uses Unicode (as UTF-8) as its default input encoding,
and is able to use modern (OpenType) fonts (for both text and mathematics).
It should be noted that LuaTeX is still under development; its specification
has been declared stable, but absolute stability may not in practice be
assumed.")
    (license license:gpl2)))

(define-public texlive-luatexbase
  (package
    (name "texlive-luatexbase")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/luatexbase/"
                                     "source/luatex/luatexbase/"
                                     "tex/luatex/luatexbase/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nz2k9czqdmn08v75qa2bwanvcvyp9jmqcgwaxcy4fy4mpbrn8ra"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-ctablestack))
    (home-page "https://ctan.org/pkg/luatexbase")
    (synopsis "Basic resource management for LuaTeX code")
    (description
     "The LaTeX kernel builds in support for LuaTeX functionality, also
available as @file{ltluatex.tex} for users of plain TeX and those with older
LaTeX kernel implementations.  This support is based on ideas taken from the
original @code{luatexbase} package, but there are interface differences.  This
stub package provides a compatibility layer to allow existing packages to
upgrade smoothly to the new support structure.")
    (license license:lppl1.3+)))

(define-public texlive-luatex85
  (package
    (name "texlive-luatex85")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/luatex85/"
                                     "source/generic/luatex85/"
                                     "tex/generic/luatex85/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02j42g9c5smgbrk898fpvrgqlxqcqi8xch23awvnbvg6y54cs573"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luatex85")
    (synopsis "pdfTeX aliases for LuaTeX")
    (description
     "The package provides emulation of pdfTeX primitives for LuaTeX v0.85+.")
    (license license:lppl1.3+)))

(define-public texlive-luatexja
  (package
    (name "texlive-luatexja")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/luatexja/"
                                     "source/luatex/luatexja/"
                                     "tex/luatex/luatexja/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h03dzbi2lqrfsrhdcbfihnn3hni8wxzknam3hhqpdsql39i0drw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-luatexbase))
    (home-page "https://ctan.org/pkg/luatexja")
    (synopsis "Typeset Japanese with Lua(La)TeX")
    (description
     "The package offers support for typesetting Japanese documents with LuaTeX.
Either of the Plain and LaTeX2e formats may be used with the package.")
    (license license:bsd-3)))

(define-public texlive-luahbtex
  (package
    (name "texlive-luahbtex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/luahbtex.1"
                                     "doc/man/man1/luahbtex.man1.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y47q58jggwzy5hk9n2arh0g4a92pqcavadzxa38lpadf16zxbck"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:texlive-latex-bin? #f
      #:create-formats #~(list "luahbtex")))
    (propagated-inputs
     (list texlive-cm
           texlive-etex
           texlive-hyphen-complete
           texlive-knuth-lib
           texlive-luatex
           texlive-plain
           texlive-tex-ini-files
           texlive-unicode-data))
    (home-page "https://ctan.org/pkg/luahbtex")
    (synopsis "LuaTeX with HarfBuzz library for glyph shaping")
    (description
     "LuaHBTeX is a LuaTeX variant that can use the HarfBuzz engine for glyph
shaping, instead of LuaTeX's built-in shaper.")
    (license (package-license texlive-luatex))))

(define-public texlive-lua-uni-algos
  (package
    (name "texlive-lua-uni-algos")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/lua-uni-algos/"
                                     "tex/luatex/lua-uni-algos/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dx70msqkj101mgj88b7fmb28bghlrrrcy5v66m74gqb5i41dnc2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:texlive-latex-bin? #f))
    (home-page "https://ctan.org/pkg/lua-uni-algos")
    (synopsis "Unicode algorithms for LuaTeX")
    (description
     "Lua code working with Unicode data has to deal with quite some
challenges.  For example there are many canonically equivalent sequences which
should be treated in the same way, and even identifying a single character
becomes quite different once you have to deal with all kinds of combining
characters, emoji sequences and syllables in different scripts.  Therefore
@code{lua-uni-algos} wants to build a collection of small libraries
implementing algorithms to deal with lots of the details in Unicode, such that
authors of LuaTeX packages can focus on their actual functionality instead of
having to fight against the peculiarities of Unicode.  Given that this package
provides Lua modules, it is only useful in Lua(HB)TeX.  Additionally, it
expects an up-to-date version of the unicode-data package to be present.  This
package is intended for package authors only; no user-level functionality
provided.")
    (license license:lppl1.3+)))

(define-public texlive-luaotfload
  (package
    (name "texlive-luaotfload")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/luaotfload/"
                                     "doc/man/man1/luaotfload-tool.1"
                                     "doc/man/man1/luaotfload-tool.man1.pdf"
                                     "doc/man/man5/luaotfload.conf.5"
                                     "doc/man/man5/luaotfload.conf.man5.pdf"
                                     "scripts/luaotfload/"
                                     "source/luatex/luaotfload/"
                                     "tex/luatex/luaotfload/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rbf7m27r7nz5raj2gcm1y0hsrg3fxx5l7di15rl4vsz73ij38mk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:texlive-latex-bin? #f
           #:link-scripts #~(list "luaotfload-tool.lua")))
    (propagated-inputs
     (list texlive-lm
           texlive-lua-alt-getopt
           texlive-lua-uni-algos
           texlive-lualibs))
    (home-page "https://ctan.org/pkg/luaotfload")
    (synopsis "OpenType font loader for LuaTeX")
    (description
     "Luaotfload is an adaptation of the ConTeXt font loading system for the
Plain and LaTeX formats.  It allows OpenType fonts to be loaded with font
features accessible using an extended font request syntax while providing
compatibilitywith XeTeX.  By indexing metadata in a database it facilitates
loading fonts by their proper names instead of file names.")
    (license license:gpl2)))

(define-deprecated-package texlive-luatex-luaotfload texlive-luaotfload)

(define-public texlive-amsmath
  (package
    (name "texlive-amsmath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/amsmath/" "source/latex/amsmath/"
                                     "tex/latex/amsmath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a8cbi5pdd4l4mwdb0vhmclqvlihh7a6gmpls6vn4jgcs15sjfw3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/amsmath")
    (synopsis "AMS mathematical facilities for LaTeX")
    (description
     "This is the principal package in the AMS-LaTeX distribution.  It adapts
for use in LaTeX most of the mathematical features found in AMS-TeX; it is
highly recommended as an adjunct to serious mathematical typesetting in LaTeX.
When amsmath is loaded, AMS-LaTeX packages @code{amsbsy} (for bold symbols),
@code{amsopn} (for operator names) and @code{amstext} (for text embedded in
mathematics) are also loaded.  This package is part of the LaTeX required
distribution; however, several contributed packages add still further to its
appeal; examples are @code{empheq}, which provides functions for decorating
and highlighting mathematics, and @code{ntheorem}, for specifying theorem (and
similar) definitions.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-amsmath texlive-amsmath)

(define-public texlive-amsmath-it
  (package
    (name "texlive-amsmath-it")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/amsmath-it/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xcwsk8q9q3nsz8wbklgpbw0vzjw7iw0chffzcbp2zsk6rypqf7w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/amsmath-it")
    (synopsis "Italian translations of some old @code{amsmath} documents")
    (description
     "This package provides an Italian translation for some old @code{amsmath}
documents.  The documents are: @file{diffs-m.txt} of December 1999, and
@file{amsmath.faq} of March 2000.")
    (license license:lppl)))

(define-public texlive-manfnt
  (package
    (name "texlive-manfnt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/manfnt/" "source/latex/manfnt/"
                                     "tex/latex/manfnt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0iwka406hkxb85yqg4kwr81483s3h250way1pmbfb67vl3x4p60x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/manfnt")
    (synopsis "LaTeX support for the TeX book symbols")
    (description
     "This package provides a LaTeX package for easy access to the symbols of
the Knuth's manual font, such as the Dangerous Bend and Manual-errata Arrow.")
    (license license:lppl)))

(define-public texlive-manfnt-font
  (package
    (name "texlive-manfnt-font")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "fonts/afm/hoekwater/manfnt-font/"
                                     "fonts/map/dvips/manfnt-font/"
                                     "fonts/type1/hoekwater/manfnt-font/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cdd2a3xj00bwsby9z5iz5f2iy2iwsjl35gcack9q83hacbf3ssb"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/manual")
    (synopsis "Knuth's manual fonts")
    (description
     "This package provides Metafont (by Donald Knuth) and Adobe Type 1 (by
Taco Hoekwater) versions of the font containing the odd symbols Knuth uses in
his books.  LaTeX support is available using the @code{manfnt} package.")
    (license license:knuth)))

(define-public texlive-mathdots
  (package
    (name "texlive-mathdots")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/mathdots/"
                                     "source/generic/mathdots/"
                                     "tex/generic/mathdots/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jaffj343p1chdxs2g7s6lpckvihk0jfw22nw0vmijyjxfiy9yg0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mathdots")
    (synopsis "Commands to produce dots in math that respect font size")
    (description
     "Mathdots redefines @code{\\ddots} and @code{\\vdots}, and defines
@code{\\iddots}.  The dots produced by @code{\\iddots} slant in the opposite
direction to @code{\\ddots}.  All the commands are designed to change size
appropriately in scripts, as well as in response to LaTeX size changing
commands.  The commands may also be used in plain TeX.")
    (license license:lppl)))

(define-public texlive-amscls
  (package
    (name "texlive-amscls")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/amscls/" "doc/latex/amscls/"
                                     "source/latex/amscls/" "tex/latex/amscls/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1chy1rqwici66p9brphb3gsprmcyhia9cvm5fn9wb5a9cchxqa08"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/amscls")
    (synopsis "AMS document classes for LaTeX")
    (description
     "This bundle contains three AMS classes: @code{amsart} (for writing
articles for the AMS), @code{amsbook} (for books) and @code{amsproc} (for
proceedings), together with some supporting material.  The material is made
available as part of the AMS-LaTeX distribution.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-amscls texlive-amscls)

(define-public texlive-babel
  (package
    (name "texlive-babel")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/babel/"
                                     "makeindex/babel/"
                                     "source/latex/babel/"
                                     "tex/generic/babel/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ijfnjsgg509gqqv7kqkw1ql2vsli9bpjh4bx9155xk61dcdm8nc"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-latex"
                                               "texlive-pdftex"
                                               "unzip")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:texlive-latex-bin? #f
      #:phases
      #~(modify-phases %standard-phases
          ;; This package tries to produce babel.aux twice but refuses to
          ;; overwrite the first one.
          (add-before 'build 'fix-ins
            (lambda _
              (substitute* "source/latex/babel/babel.ins"
                (("askonceonly") "askforoverwritefalse"))))
          (add-before 'build 'generate-locales
            (lambda _
              (let ((locale-directory (string-append (getcwd) "/build/locale")))
                (mkdir-p locale-directory)
                (with-directory-excursion "source/latex/babel/"
                  (invoke "unzip" "locale.zip" "-d" locale-directory))))))))
    (native-inputs (list texlive-latex texlive-pdftex unzip))
    (home-page "https://www.ctan.org/pkg/babel")
    (synopsis "Multilingual support for Plain TeX or LaTeX")
    (description
     "The package manages culturally-determined typographical (and other)
rules, and hyphenation patterns for a wide range of languages.  A document may
select a single language to be supported, or it may select several, in which
case the document may switch from one language to another in a variety of
ways.  Babel uses contributed configuration files that provide the detail of
what has to be done for each language.  Users of XeTeX are advised to use the
polyglossia package rather than Babel.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-babel texlive-babel)

(define-public texlive-babelbib
  (package
    (name "texlive-babelbib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/babelbib/"
                                     "doc/bibtex/babelbib/" "tex/latex/babelbib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q65qy0jmy98zfaha26b09hzr7v02jn8i6942y51hfaphbgh8kpx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babelbib")
    (synopsis "Multilingual bibliographies")
    (description
     "This package enables the user to generate multilingual bibliographies in
cooperation with @code{babel}.  Two approaches are possible: each citation may
be written in another language, or the whole bibliography can be typeset in
a language chosen by the user.  In addition, the package supports commands to
change the typography of the bibliographies.")
    (license license:lppl1.0+)))

(define-public texlive-barcodes
  (package
    (name "texlive-barcodes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/barcodes/"
                                     "fonts/source/public/barcodes/"
                                     "fonts/tfm/public/barcodes/"
                                     "source/latex/barcodes/"
                                     "tex/latex/barcodes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bxvmmmb4x0zpdkqa399rwdhz6yamfzx2kn2i7a8vz172q0b2msc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/barcodes")
    (synopsis "Fonts for making barcodes")
    (description
     "The package deals with EAN barcodes; Metafont sources for fonts are
provided, and a set of examples; for some codes, a small Perl script is
needed.")
    (license license:lppl)))

(define-public texlive-bbcard
  (package
    (name "texlive-bbcard")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/bbcard/" "metapost/bbcard/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1f1d3l85d0308izqpydmqmb4vpw47lqx1pwjiq14npjs8zfzkp18"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bbcard")
    (synopsis "Bullshit bingo, calendar and baseball-score cards")
    (description
     "This set contains three jiffy packages for creating cards of various
sorts with MetaPost.")
    (license license:public-domain)))

(define-public texlive-bbm
  (package
    (name "texlive-bbm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/bbm/" "fonts/source/public/bbm/"
                                     "fonts/tfm/public/bbm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fyzr8zfcv3i1ymzvpifbkmfxqvrva029vh4v0siia63sl36lvq3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:phases
           #~(modify-phases %standard-phases
               ;; FIXME: Font metrics cannot be generated due to "bad pos"
               ;; errors with "bbmitt" fonts.
               (delete 'generate-font-metrics))))
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/bbm")
    (synopsis "Blackboard-style CM fonts")
    (description
     "This package provides blackboard variants of Computer Modern fonts.  The
fonts are distributed as Metafont source (only); LaTeX support is available
with the @code{bbm-macros} package.  A sample of these fonts appears in the
blackboard bold sampler.")
    ;; The package states "You may freely use, modify and/or distribute this
    ;; file." everywhere, notably in the file below.
    (license (license:fsf-free "file://doc/fonts/bbm/README"))))

(define-public texlive-bbm-macros
  (package
    (name "texlive-bbm-macros")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bbm-macros/"
                                     "source/latex/bbm-macros/"
                                     "tex/latex/bbm-macros/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11klh7hwi06yr2wx5bpk230hn7rpfspk6sd55j6rmw8kz2wa3lr7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bbm-macros")
    (synopsis "LaTeX support for blackboard-style CM fonts")
    (description
     "This package provides LaTeX support for Blackboard variants of Computer
Modern fonts.  It declares a font family @code{bbm} so you can in principle
write running text in blackboard bold, and lots of math alphabets for using
the fonts within maths.")
    (license license:lppl)))

(define-public texlive-bbold
  (package
    (name "texlive-bbold")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bbold/"
                                     "fonts/source/public/bbold/"
                                     "fonts/tfm/public/bbold/"
                                     "source/latex/bbold/" "tex/latex/bbold/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0x3fhz582xcv33s9yiwka82j8bz3nxribgmni3j8j03r6dih8d8r"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments
     (list #:build-targets #~(list "bbold.dtx")
           #:tex-format "latex"
           #:phases
           #~(modify-phases %standard-phases
               ;; Building documentation, automatic when generating
               ;; runfiles, fails.  Skip building it.
               (add-after 'unpack 'skip-documentation
                 (lambda _
                   (substitute* "source/latex/bbold/bbold.dtx"
                     (("\\\\DocInput\\{bbold\\.dtx\\}") "")))))))
    (native-inputs
     (list texlive-metafont
           (texlive-updmap.cfg
            (list texlive-etoolbox texlive-hypdoc))))
    (home-page "https://ctan.org/pkg/bbold")
    (synopsis "Sans serif blackboard bold")
    (description
     "This package provides a geometric sans serif blackboard bold font, for
use in mathematics; Metafont sources are provided, as well as macros for use
with LaTeX.")
    (license license:bsd-3)))

(define-public texlive-blockdraw-mp
  (package
    (name "texlive-blockdraw-mp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/blockdraw_mp/"
                                     "metapost/blockdraw_mp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z0cgjslx4kx8fspf3i5h4idxlzhgpm14i16vq88c96z8cdjb2xy"))))
    (outputs '("out" "doc"))
    (properties '((upstream-name . "blockdraw_mp")))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/blockdraw_mp")
    (synopsis "Block diagrams and bond graphs, with MetaPost")
    (description
     "This package provides a set of simple MetaPost macros to draw block
diagrams and bond graphs. While the task is not itself difficult to program,
it is felt that many users will be happy to have a library for the job.")
    (license license:lppl)))

(define-public texlive-blopentype
  (package
    (name "texlive-blopentype")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/blopentype/"
                                     "tex/luatex/blopentype/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bancizncwjyy15pk06kaln8kpzzh7777zwabjrzlj58a0hbm0q6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-gates texlive-texapi texlive-yax))
    (home-page "https://ctan.org/pkg/blopentype")
    (synopsis "Basic LuaTeX OpenType handler")
    (description
     "This is a basic LuaTeX OpenType handler, based on Paul Isambert's PiTeX
code.")
    (license (list license:lppl1.3c license:expat))))

(define-public texlive-bookcover
  (package
    (name "texlive-bookcover")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bookcover/"
                                     "source/latex/bookcover/"
                                     "tex/latex/bookcover/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m5km26diwv7xij4r64c3gk2hl8xc22lrbcccqlrk1fhdlz3i8zb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bookcover")
    (synopsis "Class for book covers and dust jackets")
    (description "This class helps typesetting book covers and dust jackets.")
    (license license:lppl1.2+)))

(define-public texlive-bpolynomial
  (package
    (name "texlive-bpolynomial")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/bpolynomial/"
                                     "metapost/bpolynomial/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p4c3xc55zij85yy1jhmj7jrkxss935qx5zdxbm79mjlxx1aq1q0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bpolynomial")
    (synopsis "Drawing polynomial functions of up to order 3")
    (description
     "This MetaPost package helps plotting polynomial and root functions up to
order three.  The package provides macros to calculate Bezier curves exactly
matching a given constant, linear, quadratic or cubic polynomial, or square or
cubic root function.  In addition, tangents on all functions and derivatives
of polynomials can be calculated.")
    (license license:lppl)))

(define-public texlive-businesscard-qrcode
  (package
    (name "texlive-businesscard-qrcode")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/businesscard-qrcode/"
                                     "tex/xelatex/businesscard-qrcode/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0r942lv7mymi9wmmshjgf3vnz2n38m91dzqzrg0dg6bckb09dhmf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/businesscard-qrcode")
    (synopsis "Business cards with QR-Code")
    (description
     "This package generates a configurable business card or visiting card
with full vcard as QR-Code, ready to send to online printers.  You can specify
the exact size of the paper and the content within the paper, including
generation of crop marks.")
    (license license:lgpl3)))

(define-public texlive-cmarrows
  (package
    (name "texlive-cmarrows")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/cmarrows/"
                                     "metapost/cmarrows/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1awyf474n4f6fivb7ih9mpmz6641f815in8qrg2biagys3czsq96"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cmarrows")
    (synopsis "MetaPost arrows and braces in the Computer Modern style")
    (description
     "This MetaPost package contains macros to draw arrows and braces in the
Computer Modern style.")
    (license license:lppl)))

(define-public texlive-cmexb
  (package
    (name "texlive-cmexb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cmexb/" "fonts/map/dvips/cmexb/"
                                     "fonts/tfm/public/cmexb/"
                                     "fonts/type1/public/cmexb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fwnxzlkcf58n1f91vz8xbcp8nmhqmhjqhswgkzvyrd6lnp5gzdk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cmexb")
    (synopsis "@code{cmexb10} metrics and Type 1")
    (description
     "This package provides Computer Modern Math Extension bold, metrics and
@file{.pfb} file.")
    (license license:public-domain)))   ;see "README-cmexb"

(define-public texlive-cqubeamer
  (package
    (name "texlive-cqubeamer")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/cqubeamer/"
                                     "tex/xelatex/cqubeamer/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13ma7i3z64w59m2hkrh68j3vqa2k93hhb2lmarqb4pkhr72vk4s7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cqubeamer")
    (synopsis "LaTeX Beamer Template for Chongqing University")
    (description
     "This package provides a LaTeX beamer template designed for researchers
of Chongqing University.  It can be used for academic reports, conferences, or
thesis defense, and can be helpful for delivering a speech.  It should be used
with the XeTeX engine.")
    (license (list license:expat license:cc-by4.0))))

(define-public texlive-cs
  (package
    (name "texlive-cs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "fonts/enc/dvips/cs/"
                                     "fonts/map/dvips/cs/"
                                     "fonts/source/public/cs/"
                                     "fonts/tfm/cs/cs-a35/"
                                     "fonts/tfm/cs/cs-charter/"
                                     "fonts/tfm/public/cs/"
                                     "fonts/type1/public/cs/"
                                     "fonts/vf/cs/cs-a35/"
                                     "fonts/vf/cs/cs-charter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nzzcg1yvbslhqm5lsfcpqh6sbzkmnmmgyakg9l8855qpa8g9bf3"))))
    (properties '((updater-extra-native-inputs "texlive-sauter")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont texlive-sauter))
    (propagated-inputs (list texlive-cmexb))
    (home-page "https://ctan.org/pkg/csfonts")
    (synopsis "Czech/Slovak-tuned Computer Modern fonts")
    (description "This package provides Czech/Slovak-tuned Computer Modern
fonts in the Metafont format; Type 1 format versions (csfonts-t1) are also
available.")
    (license license:gpl2+)))           ;see fonts/source/public/cs/cscode.mf

;;; Note: if this package is modified, its name must be changed to comply with
;;; its license.
(define-public texlive-csplain
  (package
    (name "texlive-csplain")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/csplain/base/"
                                     "tex/csplain/fonts/"
                                     "tex/csplain/opmac/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14z479gkiwgw17pdghrxh5q0rlxnij7ccj49kgf3macwgmh5lm0r"))))
    (properties '((updater-extra-native-inputs "texlive-xetex")))
    (build-system texlive-build-system)
    (arguments
     (list #:create-formats #~(list "csplain" "luacsplain" "pdfcsplain")
           #:phases
           #~(modify-phases %standard-phases
               (add-after 'install 'symlink-binaries
                 (lambda* (#:key inputs #:allow-other-keys)
                   (let ((pdftex (search-input-file inputs "bin/pdftex"))
                         (luatex (search-input-file inputs "bin/luatex"))
                         (bin (string-append #$output "/bin")))
                     (mkdir-p bin)
                     (with-directory-excursion bin
                       (symlink pdftex "csplain")
                       (symlink pdftex "pdfcsplain")
                       (symlink luatex "luacsplain"))))))))
    (native-inputs (list texlive-xetex))
    (propagated-inputs
     (list texlive-cm
           texlive-cs
           texlive-enctex
           texlive-hyphen-complete
           texlive-luatex
           texlive-luatex85
           texlive-pdftex
           texlive-plain
           texlive-tex
           texlive-tex-ini-files
           texlive-xetex))
    (home-page "https://petr.olsak.net/csplain-e.html")
    (synopsis "Plain TeX multilanguage support")
    (description
     "CSplain is a small extension of basic Plain TeX macros from which the
formats @code{csplain} and @code{pdfcsplain} can be generated.  It supports:
hyphenation of words for 50+ languages, simple and powerful font loading
system (various sizes of fonts), TeX, pdfTeX, XeTeX and LuaTeX engines, math
fonts simply loaded with full amstex-like features, three internal
encodings (IL2 for Czech/Slovak languages, T1 for many languages with latin
alphabet and Unicode in new TeX engines), natural UTF-8 input in pdfTeX using
encTeX without any active characters, Czech and Slovak special typesetting
features.  An important part of the package is OPmac, which implements most of
LaTeX's features (sectioning, font selection, color, hyper reference and URLs,
bibliography, index, table of contents, tables, etc.) by Plain TeX macros.
The OPmac macros can generate a bibliography without any external program.")
    ;; This custom permissive license includes as a redistribution condition
    ;; that says the package must be renamed from 'csplain' if it is modified.
    (license (license:non-copyleft "file:///tex/csplain/base/csplain.ini"))))

(define-public texlive-ctable
  (package
    (name "texlive-ctable")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ctable/" "source/latex/ctable/"
                                     "tex/latex/ctable/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x624vz1gv8bsdafwhx89zaic7f2mz9vlvwjpv8fwzjhjwx4lxmv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ctable")
    (synopsis "Flexible typesetting of table and figure floats")
    (description
     "This package provides commands to typeset centered, left- or
right-aligned table and (multiple-)figure floats, with footnotes.")
    (license license:lppl)))

(define-public texlive-babel-albanian
  (package
    (name "texlive-babel-albanian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-albanian/"
                                     "source/generic/babel-albanian/"
                                     "tex/generic/babel-albanian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sgyxj2f2w5fb22ys0idcfy10m1wbz3mk3rkpvv7cwa0v3a0arhl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-albanian")
    (synopsis "Support for Albanian within Babel")
    (description
     "The package provides support for typesetting Albanian (as part of the
Babel system).")
    (license license:lppl1.3+)))

(define-public texlive-babel-azerbaijani
  (package
    (name "texlive-babel-azerbaijani")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-azerbaijani/"
                                     "source/generic/babel-azerbaijani/"
                                     "tex/generic/babel-azerbaijani/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vpgx76316gfhxp9maiqnd3z1hjavzlnjibxi4yhalbby0dnswi1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-azerbaijani")
    (synopsis "Support for Azerbaijani within Babel")
    (description
     "This is the Babel style for Azerbaijani.  This language poses special
challenges because no traditional font encoding contains the full character
set, and therefore a mixture must be used (e.g., T2A and T1).  This package is
compatible with Unicode engines LuaTeX and XeTeX, which are very likely the
most convenient way to write Azerbaijani documents.")
    (license license:lppl1.3+)))

(define-public texlive-babel-basque
  (package
    (name "texlive-babel-basque")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-basque/"
                                     "source/generic/babel-basque/"
                                     "tex/generic/babel-basque/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16bcy5wlkwh8cwvcff1sc3m4rq4a7fzzawpl158kscp7fmw7i7k4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-basque")
    (synopsis "Babel contributed support for Basque")
    (description "The package establishes Basque conventions in a document.")
    (license license:lppl1.3+)))

(define-public texlive-babel-belarusian
  (package
    (name "texlive-babel-belarusian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-belarusian/"
                                     "source/generic/babel-belarusian/"
                                     "tex/generic/babel-belarusian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1055gyy9hab9whnr5c2p4i4yczkn5pwm0n54ylnnsl8wg8q58w1z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-belarusian")
    (synopsis "Babel support for Belarusian")
    (description
     "The package provides support for use of Babel in documents written in
Belarusian.")
    (license license:lppl1.3c)))

(define-public texlive-babel-bosnian
  (package
    (name "texlive-babel-bosnian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-bosnian/"
                                     "source/generic/babel-bosnian/"
                                     "tex/generic/babel-bosnian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "097j3cwq29x17hc6wbdj2m4h7m2yv47i1m2irqxkrjvywq0b5bqd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-bosnian")
    (synopsis "Babel contrib support for Bosnian")
    (description
     "The package provides a language definition file that enables support of
Bosnian with Babel.")
    (license license:lppl1.3+)))

(define-public texlive-babel-breton
  (package
    (name "texlive-babel-breton")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-breton/"
                                     "source/generic/babel-breton/"
                                     "tex/generic/babel-breton/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hvb2qjin8jx4lmw3w2y04jnnnc6w0033kjhgflfyp309dmvhzhl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-breton")
    (synopsis "Babel contributed support for Breton")
    (description
     "Breton (being, principally, a spoken language) does not have typographic
rules of its own; this package provides an appropriate selection of French and
British typographic rules.")
    (license license:lppl1.3+)))

(define-public texlive-babel-bulgarian
  (package
    (name "texlive-babel-bulgarian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-bulgarian/"
                                     "source/generic/babel-bulgarian/"
                                     "tex/generic/babel-bulgarian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "065j31rl7r4x8krkwxhq0lwdkmbq90jr8666if4br36kw0g3kzv3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-bulgarian")
    (synopsis "Babel contributed support for Bulgarian")
    (description
     "The package provides support for documents in Bulgarian (or simply
containing some Bulgarian text).")
    (license license:lppl1.3+)))

(define-public texlive-babel-catalan
  (package
    (name "texlive-babel-catalan")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-catalan/"
                                     "source/generic/babel-catalan/"
                                     "tex/generic/babel-catalan/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "162ih5948z2kbxqxf7bp94ffg7f2b5l8ffa9w304868hj9ik6jfk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-catalan")
    (synopsis "Babel contributed support for Catalan")
    (description
     "The package establishes Catalan conventions in a document (or a subset
of the conventions, if Catalan is not the main language of the document).")
    (license license:lppl1.3+)))

(define-public texlive-babel-croatian
  (package
    (name "texlive-babel-croatian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-croatian/"
                                     "source/generic/babel-croatian/"
                                     "tex/generic/babel-croatian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r3cccrc2i57sza8qc24hxm2p6igvhbkr8a6lnsrcrhbji2smi07"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-croatian")
    (synopsis "Babel contributed support for Croatian")
    (description
     "The package establishes Croatian conventions in a document (or a subset
of the conventions, if Croatian is not the main language of the document).")
    (license license:lppl1.3+)))

(define-public texlive-babel-english
  (package
    (name "texlive-babel-english")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-english/"
                                     "source/generic/babel-english/"
                                     "tex/generic/babel-english/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fh8xxxh79za80yvgypf8clzj0lk237lfyqfkl233id9rlias08d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-english")
    (synopsis "Babel support for English")
    (description
     "The package provides the language definition file for support of
English in @code{babel}.  Care is taken to select british hyphenation patterns
for British English and Australian text, and default (american) patterns for
Canadian and USA text.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-generic-babel-english texlive-babel-english)

(define-public texlive-babel-esperanto
  (package
    (name "texlive-babel-esperanto")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-esperanto/"
                                     "source/generic/babel-esperanto/"
                                     "tex/generic/babel-esperanto/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1av9x9d5rff6hsssssbn1jnyrqnj1c2n5fa4kgxlla95xn7zs65m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-esperanto")
    (synopsis "Babel support for Esperanto")
    (description
     "The package provides the language definition file for support of
Esperanto in Babel.  Some shortcuts are defined, as well as translations to
Esperanto of standard LaTeX names.")
    (license license:lppl1.3+)))

(define-public texlive-babel-estonian
  (package
    (name "texlive-babel-estonian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-estonian/"
                                     "source/generic/babel-estonian/"
                                     "tex/generic/babel-estonian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pi4rmbwjg8mrxi9y6jhczfv6nbrb25n025sx56yn36f579rwwiy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-estonian")
    (synopsis "Babel support for Estonian")
    (description
     "The package provides the language definition file for support of
Estonian in Babel.  Some shortcuts are defined, as well as translations to
Estonian of standard LaTeX names.")
    (license license:lppl1.3+)))

(define-public texlive-babel-french
  (package
    (name "texlive-babel-french")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-french/"
                                     "source/generic/babel-french/"
                                     "tex/generic/babel-french/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04jbg7dfk9wsyls5vk6a5v2kd5ni8jf4ixj0piy1a0z75s01my1r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-french")
    (synopsis "Babel contributed support for French")
    (description
     "The package establishes French conventions in a document (or a subset of
the conventions, if French is not the main language of the document).")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-generic-babel-french texlive-babel-french)

(define-public texlive-babel-friulan
  (package
    (name "texlive-babel-friulan")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-friulan/"
                                     "source/generic/babel-friulan/"
                                     "tex/generic/babel-friulan/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "082xhr083hcbp0lqvkfj48hnqj4fa7x30vn6sk6v2f1g57zq9v69"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-friulan")
    (synopsis "Babel and Polyglossia support for Friulan(Furlan)")
    (description
     "The package provides a language description file that enables support of
Friulan either with Babel or with Polyglossia.")
    (license license:lppl1.3+)))

(define-public texlive-babel-galician
  (package
    (name "texlive-babel-galician")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-galician/"
                                     "source/generic/babel-galician/"
                                     "tex/generic/babel-galician/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13giby8mzyxjccyvhb9dsnyqc2h17k70fch84z5mi8si3jnm9sq4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-galician")
    (synopsis "Babel and Polyglossia support for Galician")
    (description
     "The package provides a language description file that enables support of
Galician either with Babel or with Polyglossia.")
    (license license:lppl1.3+)))

(define-public texlive-babel-georgian
  (package
    (name "texlive-babel-georgian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-georgian/"
                                     "tex/generic/babel-georgian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qjpaxzgm0qh88j6x1zvnjb1n994prxqnzchrp05pgsbyjcf410p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-georgian")
    (synopsis "Babel support for Georgian")
    (description
     "The package provides support for use of Babel in documents written in
Georgian.  The package is adapted for use both under traditional TeX engines,
and under XeTeX and LuaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-babel-german
  (package
    (name "texlive-babel-german")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-german/"
                                     "source/generic/babel-german/"
                                     "tex/generic/babel-german/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k5m77nfvazfb2s9bdjchzhiyrs63mk5n8g1da5xcwrbl1pldclw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-german")
    (synopsis "Babel support for documents written in German")
    (description
     "This bundle is an extension to the babel package for multilingual typesetting.
It provides all the necessary macros, definitions and settings to typeset
German documents.  The bundle includes support for the traditional and
reformed German orthography as well as for the Austrian and Swiss varieties of
German.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-generic-babel-german texlive-babel-german)

(define-public texlive-babel-greek
  (package
    (name "texlive-babel-greek")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-greek/"
                                     "source/generic/babel-greek/"
                                     "tex/generic/babel-greek/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00yk4kx7078q6dkx43rifgpcplhbg8b98m39zsw0vgpd91vzr93p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-greek")
    (synopsis "Babel support for documents written in Greek")
    (description
     "The file provides modes for monotonic (single-diacritic) and polytonic
(multiple-diacritic) modes of writing.  Provision is made for Greek function
names in mathematics, and for classical-era symbols.")
    (license license:lppl1.3+)))

(define-public texlive-babel-hebrew
  (package
    (name "texlive-babel-hebrew")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-hebrew/"
                                     "source/generic/babel-hebrew/"
                                     "tex/generic/babel-hebrew/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0n0w7jmjf71fw96ycrqwxxh6s4knw3fj4i83n63y4xv2x5w40f7y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-hebrew")
    (synopsis "Babel support for Hebrew")
    (description
     "The package provides the language definition file for support of Hebrew
in babel.  Macros to control the use of text direction control of TeX--XeT and
e-TeX are provided (and may be used elsewhere).  Some shortcuts are defined,
as well as translations to Hebrew of standard LaTeX names.")
    (license license:lppl1.3+)))

(define-public texlive-babel-hungarian
  (package
    (name "texlive-babel-hungarian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-hungarian/"
                                     "tex/generic/babel-hungarian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x54clczgvkq9slq5331hvp1rzlv4jm4g9gnpflz8y72jbqmcm24"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-hungarian")
    (synopsis "Babel support for Hungarian (Magyar)")
    (description
     "The package provides a language definition file that enables support of
Magyar (Hungarian) with Babel.")
    (license license:lppl)))

(define-public texlive-babel-icelandic
  (package
    (name "texlive-babel-icelandic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-icelandic/"
                                     "source/generic/babel-icelandic/"
                                     "tex/generic/babel-icelandic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cz6q6mn34h19k1rd2c5pfw3s6allqcbsvm0pyriinnylpx9i44d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-icelandic")
    (synopsis "Babel support for Icelandic")
    (description
     "The package provides the language definition file for support of
Icelandic in Babel.  Some shortcuts are defined, as well as translations to
Icelandic of standard LaTeX names.")
    (license license:lppl1.3+)))

(define-public texlive-babel-indonesian
  (package
    (name "texlive-babel-indonesian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-indonesian/"
                                     "source/generic/babel-indonesian/"
                                     "tex/generic/babel-indonesian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ilkl7s5dh8cs6z211p4imyzg3d2axfa5vkmrxn4d3lbx1g3chs1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-indonesian")
    (synopsis "Support for Indonesian within Babel")
    (description "This is the Babel style for Indonesian.")
    (license license:lppl1.3+)))

(define-public texlive-babel-interlingua
  (package
    (name "texlive-babel-interlingua")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-interlingua/"
                                     "source/generic/babel-interlingua/"
                                     "tex/generic/babel-interlingua/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mxyfa6rsaxwazliblg9p4cbr0vip12c00mkvnz4dak2adnhzvbg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-interlingua")
    (synopsis "Babel support for Interlingua")
    (description
     "The package provides the language definition file for support of
Interlingua in Babel.  This includes translations to Interlingua of standard
LaTeX names (no shortcuts are provided).  Interlingua itself is an auxiliary
language, built from the common vocabulary of Spanish/Portuguese, English,
Italian and French, with some normalisation of spelling.")
    (license license:lppl1.3+)))

(define-public texlive-babel-irish
  (package
    (name "texlive-babel-irish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-irish/"
                                     "source/generic/babel-irish/"
                                     "tex/generic/babel-irish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0j78inzjbv653gla11g3rzmn0b5fvzbkmppmhbgq9qi8102p7k55"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-irish")
    (synopsis "Babel support for Irish")
    (description
     "The package provides the language definition file for support of Irish
Gaelic in Babel.  The principal content is translations to Irish of standard
LaTeX names.")
    (license license:lppl1.3+)))

(define-public texlive-babel-italian
  (package
    (name "texlive-babel-italian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-italian/"
                                     "source/generic/babel-italian/"
                                     "tex/generic/babel-italian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zb2cm5b0pbpvxpcm1mmp1mwxaighf6grlh5ijcq1m36iycpgm0p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-italian")
    (synopsis "Babel support for Italian text")
    (description "The package provides language definitions for use in
Babel.")
    (license license:lppl1.3c)))

(define-public texlive-babel-japanese
  (package
    (name "texlive-babel-japanese")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-japanese/"
                                     "source/generic/babel-japanese/"
                                     "tex/generic/babel-japanese/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jn2pl080c0dd6ryj6y5b87h6ijg3lcd2hw7g5kyw7p9r7a6b8i0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-japanese")
    (synopsis "Babel support for Japanese")
    (description
     "This package provides a japanese option for the Babel package.  It
defines all the language definition macros in Japanese.  Currently this
package works with pLaTeX, upLaTeX, XeLaTeX and LuaLaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-babel-kurmanji
  (package
    (name "texlive-babel-kurmanji")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-kurmanji/"
                                     "source/generic/babel-kurmanji/"
                                     "tex/generic/babel-kurmanji/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "021dzdjhiymsvqxc1cq409vkm7390lrr691snydr9xr35x0k3wr1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-kurmanji")
    (synopsis "Babel support for Kurmanji")
    (description
     "The package provides the language definition file for support of
Kurmanji in Babel.  Kurmanji belongs to the family of Kurdish languages.  Some
shortcuts are defined, as well as translations to Kurmanji of standard LaTeX
names.  Note that the package is dealing with Northern Kurdish, written using
a Latin-based alphabet.  The @code{arabxetex} package offers support for
Kurdish written in Arabic script.")
    (license license:lppl1.3+)))

(define-public texlive-babel-latin
  (package
    (name "texlive-babel-latin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-latin/"
                                     "source/generic/babel-latin/"
                                     "tex/generic/babel-latin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ykiny7rcz5czsadxfxl53403ixkyxi67dqlphqaxkvvm2k61kpb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-latin")
    (synopsis "Babel support for Latin")
    (description
     "The Babel-latin package provides the Babel languages @code{latin},
 @code{classiclatin}, @code{medievallatin}, and @code{ecclesiasticlatin}.  It
also defines several useful shorthands as well as some modifiers for
typographical fine-tuning.")
    (license license:lppl1.3+)))

(define-public texlive-babel-latvian
  (package
    (name "texlive-babel-latvian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-latvian/"
                                     "source/generic/babel-latvian/"
                                     "tex/generic/babel-latvian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a605a9ksibxf8kbrqa2bmk24j9wmgzpz5f12jwcym02jm66sw82"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-latvian")
    (synopsis "Babel support for Latvian")
    (description
     "The package provides the language definition file for support of Latvian
in Babel.")
    (license license:lppl1.3+)))

(define-public texlive-babel-lithuanian
  (package
    (name "texlive-babel-lithuanian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-lithuanian/"
                                     "source/generic/babel-lithuanian/"
                                     "tex/generic/babel-lithuanian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08ifkjb61m9nx3wn8hvca9vfrzlmxpwvrh21hq1rh6dwmqli11j6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-lithuanian")
    (synopsis "Babel support for documents written in Lithuanian")
    (description
     "Babel support material for documents written in Lithuanian moved from
the @code{lithuanian} package into a new package @code{babel-lithuanian} to
match Babel support for other languages.")
    (license license:lppl1.3+)))

(define-public texlive-babel-macedonian
  (package
    (name "texlive-babel-macedonian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-macedonian/"
                                     "source/generic/babel-macedonian/"
                                     "tex/generic/babel-macedonian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fps3nlbr4j2vy8pww4xkp2xsxiclzal4ifcpc1a0dsc4blll5nr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-macedonian")
    (synopsis "Babel module to support Macedonian Cyrillic")
    (description
     "The package provides support for Macedonian documents written in
Cyrillic, in Babel.")
    (license license:lppl1.3+)))

(define-public texlive-babel-malay
  (package
    (name "texlive-babel-malay")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-malay/"
                                     "source/generic/babel-malay/"
                                     "tex/generic/babel-malay/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gbjrsf4drmrplhwl0avpzv5yfyb30znhza4pxk704i1khabnwzk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-malay")
    (synopsis "Support for Malay within Babel")
    (description "This is the Babel style for Malay.")
    (license license:lppl1.3+)))

(define-public texlive-babel-occitan
  (package
    (name "texlive-babel-occitan")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-occitan/"
                                     "source/generic/babel-occitan/"
                                     "tex/generic/babel-occitan/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0apg6i95lhhlwwci3mm8gqrs5x5qchxkc9w615cj083bvsri8vnk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-occitan")
    (synopsis "Babel support for Occitan")
    (description "This package provides Occitan language description file for
Babel, with usage instructions.")
    (license license:lppl1.3+)))

(define-public texlive-babel-piedmontese
  (package
    (name "texlive-babel-piedmontese")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-piedmontese/"
                                     "source/generic/babel-piedmontese/"
                                     "tex/generic/babel-piedmontese/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04hig8rd6nxwwz1zjskpmap00gixmb63qh08p5fxqc6mb4bdh78b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-piedmontese")
    (synopsis "Babel support for Piedmontese")
    (description
     "The package provides the language definition file for support of
Piedmontese in Babel.  Some shortcuts are defined, as well as translations to
Piedmontese of standard LaTeX names.")
    (license license:lppl1.3+)))

(define-public texlive-babel-portuges
  (package
    (name "texlive-babel-portuges")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-portuges/"
                                     "source/generic/babel-portuges/"
                                     "tex/generic/babel-portuges/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0619ygyjz5vz3a6khx7yvsa059x59r54fgyxb0p8k196lss07lq2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-portuges")
    (synopsis "Babel support for Portuges")
    (description
     "The package provides the language definition file for support of
Portuguese and Brazilian Portuguese in Babel.  Some shortcuts are defined, as
well as translations to Portuguese of standard LaTeX names.")
    (license license:lppl1.3+)))

(define-public texlive-babel-romanian
  (package
    (name "texlive-babel-romanian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-romanian/"
                                     "source/generic/babel-romanian/"
                                     "tex/generic/babel-romanian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yyzcw7pm0b7fmxwn3j677g066dlmkmpa1flrivkqzbcn4mykwir"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-romanian")
    (synopsis "Babel support for Romanian")
    (description
     "The package provides the language definition file for support of
Romanian in Babel.  Translations to Romanian of standard LaTeX names are
provided.")
    (license license:lppl1.3+)))

(define-public texlive-babel-romansh
  (package
    (name "texlive-babel-romansh")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-romansh/"
                                     "source/generic/babel-romansh/"
                                     "tex/generic/babel-romansh/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08lc76yglblidg24s5ap9j0xmzbxgsfwcf9f6g1m4bwbqwkh089x"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs (list (texlive-updmap.cfg
                          (list texlive-etoolbox
                                texlive-hypdoc))))
    (home-page "https://ctan.org/pkg/babel-romansh")
    (synopsis "Babel and Polyglossia support for the Romansh language")
    (description
     "The package provides a language description file that enables support of
Romansh either with Babel or with Polyglossia.")
    (license license:lppl1.3+)))

(define-public texlive-babel-russian
  (package
    (name "texlive-babel-russian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-russian/"
                                     "source/generic/babel-russian/"
                                     "tex/generic/babel-russian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sy3b7qx5l6smpixa9896zqqrh6ymrz31pd4026f815jy78k3cfb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-russian")
    (synopsis "Russian language module for Babel")
    (description
     "The package provides support for use of Babel in documents written in
Russian (in both traditional and modern forms).  The support is adapted for
use both under traditional TeX engines, and under XeTeX and LuaTeX.")
    (license license:lppl1.3c)))

(define-public texlive-babel-samin
  (package
    (name "texlive-babel-samin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-samin/"
                                     "source/generic/babel-samin/"
                                     "tex/generic/babel-samin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1izvs1xz9g838ygxwnm8v7rcc8fzn68xd1dbah13wcc0p9nq736x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-samin")
    (synopsis "Babel support for Samin")
    (description
     "The package provides the language definition file for support of North
Sami in Babel.  Several Sami dialects/languages are spoken in Finland, Norway,
Sweden and on the Kola Peninsula of Russia.  Not all use the same alphabet,
and no attempt is made to support any other than North Sami here.  Some
shortcuts are defined, as well as translations to Norsk of standard LaTeX
names.")
    (license license:lppl1.3+)))

(define-public texlive-babel-scottish
  (package
    (name "texlive-babel-scottish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-scottish/"
                                     "source/generic/babel-scottish/"
                                     "tex/generic/babel-scottish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lcnf84ri330z8qvxlqxyhfm50ylxh9wb3sn2pjjhfg7zadg9zvv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-scottish")
    (synopsis "Babel support for Scottish Gaelic")
    (description
     "The package provides the language definition file for support of Gaidhlig
(Scottish Gaelic) in Babel.  Some shortcuts are defined, as well as
translations of standard LaTeX names.")
    (license license:lppl1.3+)))

(define-public texlive-babel-serbian
  (package
    (name "texlive-babel-serbian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-serbian/"
                                     "source/generic/babel-serbian/"
                                     "tex/generic/babel-serbian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "089w8phd1pyzh8dmn4v2bspnmx4hqi63mby1yn7xk596qxi3nqrz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-serbian")
    (synopsis "Babel and Polyglossia support for Serbian")
    (description
     "The package provides support for Serbian documents written in Latin, in
Babel.")
    (license license:lppl1.3+)))

(define-public texlive-babel-serbianc
  (package
    (name "texlive-babel-serbianc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-serbianc/"
                                     "source/generic/babel-serbianc/"
                                     "tex/generic/babel-serbianc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ji77vlb10vxdka5bsnqkrlf34c4qhpl162xizrzxf11z6099wng"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-serbianc")
    (synopsis "Babel module to support Serbian Cyrillic")
    (description
     "The package provides support for Serbian documents written in Cyrillic,
in Babel.")
    (license license:lppl1.3+)))

(define-public texlive-babel-slovak
  (package
    (name "texlive-babel-slovak")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-slovak/"
                                     "source/generic/babel-slovak/"
                                     "tex/generic/babel-slovak/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16w95j3ckvjvmwccx2qvf7lq3b3zvnlf7ygm35i8xq22f3lm2a9k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-slovak")
    (synopsis "Babel support for typesetting Slovak")
    (description
     "The package provides the language definition file for support of Slovak
in Babel, including Slovak variants of LaTeX built-in-names.  Shortcuts are
also defined.")
    (license license:lppl1.3+)))

(define-public texlive-babel-slovenian
  (package
    (name "texlive-babel-slovenian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-slovenian/"
                                     "source/generic/babel-slovenian/"
                                     "tex/generic/babel-slovenian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08bf1732vsa148km0vkfj6k1cg3j3yrhkzsvnhv283bbr1wqprz6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-slovenian")
    (synopsis "Babel support for typesetting Slovenian")
    (description
     "The package provides the language definition file for support of
Slovenian in Babel.  Several shortcuts are defined, as well as translations to
Slovenian of standard LaTeX names.")
    (license license:lppl1.3+)))

(define-public texlive-babel-sorbian
  (package
    (name "texlive-babel-sorbian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-sorbian/"
                                     "source/generic/babel-sorbian/"
                                     "tex/generic/babel-sorbian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b6qqk0qik294z8sirvf58cf5v8mhsz4hj91gw7zg8b4j362lp8y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-sorbian")
    (synopsis "Babel support for Upper and Lower Sorbian")
    (description
     "The package provides language definitions file for support of both Upper
and Lower Sorbian, in Babel.  Some shortcuts are defined, as well as
translations to the relevant language of standard LaTeX names.")
    (license license:lppl1.3+)))

(define-public texlive-babel-spanish
  (package
    (name "texlive-babel-spanish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-spanish/"
                                     "source/generic/babel-spanish/"
                                     "tex/generic/babel-spanish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nzc4hs91a901cjy2vhpamdw3gyxp7k2lmag9ni8zmy180zncm5g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-spanish")
    (synopsis "Babel support for Spanish")
    (description
     "This bundle provides the means to typeset Spanish text, with the support
provided by the LaTeX standard package Babel.  Note that separate support is
provided for those who wish to typeset Spanish as written in Mexico.")
    (license license:lppl1.3+)))

(define-public texlive-babel-swedish
  (package
    (name "texlive-babel-swedish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-swedish/"
                                     "source/generic/babel-swedish/"
                                     "tex/generic/babel-swedish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qi2rzhlxikabrk9n0096inbczgp5hwghvy5zn0mph8zmsxlfbdf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-swedish")
    (synopsis "Babel support for typesetting Swedish")
    (description
     "The package provides the language definition file for Swedish.")
    (license license:lppl1.3+)))

(define-public texlive-babel-thai
  (package
    (name "texlive-babel-thai")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-thai/"
                                     "source/generic/babel-thai/"
                                     "tex/generic/babel-thai/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wgprys500a1fn56bnsmq8fhmb9y8cfwsqn5hginfb36d3gym4p6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-thai")
    (synopsis "Support for Thai within babel")
    (description
     "The package provides support for typesetting Thai text within the Babel
system.")
    (license license:lppl1.3+)))

(define-public texlive-babel-turkish
  (package
    (name "texlive-babel-turkish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-turkish/"
                                     "source/generic/babel-turkish/"
                                     "tex/generic/babel-turkish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q88q0kfa4jjd4m51mvj798scxr5c5l7bjp9sfv8s5pq3ym19bq0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-turkish")
    (synopsis "Babel support for Turkish documents")
    (description
     "The package provides support, within Babel, of the Turkish language.")
    (license license:lppl1.3+)))

(define-public texlive-babel-ukrainian
  (package
    (name "texlive-babel-ukrainian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-ukrainian/"
                                     "source/generic/babel-ukrainian/"
                                     "tex/generic/babel-ukrainian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nz8yzpc5khyv6wgm5ndwfdxx591wqlg311crzxk08ardg8zwvgs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-ukrainian")
    (synopsis "Babel support for Ukrainian")
    (description
     "The package provides support for use of babel in documents written in
Ukrainian.  The support is adapted for use under legacy TeX engines as well as
XeTeX and LuaTeX.")
    (license license:lppl1.3c)))

(define-public texlive-babel-vietnamese
  (package
    (name "texlive-babel-vietnamese")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-vietnamese/"
                                     "source/generic/babel-vietnamese/"
                                     "tex/generic/babel-vietnamese/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12nnrdk0k2xfab33249s3gzs1815p7j197bv4zisndxvrmiv6hdf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-vietnamese")
    (synopsis "Babel support for typesetting Vietnamese")
    (description
     "The package provides the language definition file for support of
Vietnamese in Babel.")
    (license license:lppl1.3+)))

(define-public texlive-babel-welsh
  (package
    (name "texlive-babel-welsh")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-welsh/"
                                     "source/generic/babel-welsh/"
                                     "tex/generic/babel-welsh/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qba526ralldh4y6w0pzdw2vb2ng31mw416qzn0zzjp8sppc3hyw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-welsh")
    (synopsis "Babel support for Welsh")
    (description
     "The package provides the language definition file for Welsh.")
    (license license:lppl1.3+)))

(define-public texlive-cyklop
  (package
    (name "texlive-cyklop")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cyklop/"
                                     "fonts/afm/public/cyklop/"
                                     "fonts/enc/dvips/cyklop/"
                                     "fonts/map/dvips/cyklop/"
                                     "fonts/opentype/public/cyklop/"
                                     "fonts/tfm/public/cyklop/"
                                     "fonts/type1/public/cyklop/"
                                     "tex/latex/cyklop/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jfri15l1jycqzjac8s5bz6izypdwfjagfz6jhw95ixj1s9brnpl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cyklop")
    (synopsis "The Cyclop typeface")
    (description
     "The Cyclop typeface was designed in the 1920s at the workshop of Warsaw
type foundry @emph{Odlewnia Czcionek J. Idzkowski i S-ka}.  This sans serif
typeface has a highly modulated stroke so it has high typographic contrast.
The vertical stems are much heavier then horizontal ones.  Most characters
have thin rectangles as additional counters giving the unique shape of the
characters.  The lead types of Cyclop typeface were produced in slanted
variant at sizes 8-48 pt.  It was heavily used for heads in newspapers and
accidents prints.  Typesetters used Cyclop in the inter-war period, during the
occupation in the underground press.  The typeface was used until the
beginnings of the offset print and computer typesetting era.  Nowadays it is
hard to find the metal types of this typeface.

The fonts are distributed in the Type1 and OpenType formats along with the
files necessary for use these fonts in TeX and LaTeX including encoding
definition files: T1 (ec), T5 (Vietnamese), OT4, QX, texnansi and nonstandard
ones (IL2 for Czech fonts).")
    (license license:gfl1.0)))

(define-public texlive-cyrillic-bin
  (package
    (name "texlive-cyrillic-bin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/rubibtex.1"
                                     "doc/man/man1/rubibtex.man1.pdf"
                                     "doc/man/man1/rumakeindex.1"
                                     "doc/man/man1/rumakeindex.man1.pdf"
                                     "scripts/texlive-extra/rubibtex.sh"
                                     "scripts/texlive-extra/rumakeindex.sh"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09l5f7l91ph6sqfp2ia3yn23pa3s4cyfgyn020ncqvapg00s0mmg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:link-scripts #~(list "rubibtex.sh" "rumakeindex.sh")
      #:phases
      #~(modify-phases %standard-phases
          (replace 'patch-shell-scripts
            (lambda _
              (with-directory-excursion "scripts/texlive-extra/"
                (with-fluids ((%default-port-encoding "ISO-8859-1"))
                  (substitute* (list "rubibtex.sh" "rumakeindex.sh")
                    (("\\b(basename|cat|mkdir|rm|sed)\\b" _ command)
                     (which command))))))))))
    (home-page "https://ctan.org/pkg/cyrillic-bin")
    (synopsis "Cyrillic BibTeX and MakeIndex")
    (description
     "This package provides scripts for Cyrillic versions of BibTeX and
MakeIndex.")
    (license license:public-domain)))

(define-public texlive-cyrillic
  (package
    (name "texlive-cyrillic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cyrillic/"
                                     "source/latex/cyrillic/"
                                     "tex/latex/cyrillic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08v670f7s74klnac7pzqsad9m4jsxfkckzkswxb94xxd61kanzdx"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-latex")))
    (build-system texlive-build-system)
    (arguments
     (list #:tex-engine "tex"
           #:tex-format #f))
    (native-inputs (list texlive-latex))
    (propagated-inputs (list texlive-cyrillic-bin))
    (home-page "https://ctan.org/pkg/cyrillic")
    (synopsis "Support for Cyrillic fonts in LaTeX")
    (description
     "This bundle of macros files provides macro support (including font
encoding macros) for the use of Cyrillic characters in fonts encoded under the
T2* and X2 encodings.  These encodings cover (between them) pretty much every
language that is written in a Cyrillic alphabet.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-cyrillic texlive-cyrillic)

(define-public texlive-passivetex
  (package
    (name "texlive-passivetex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/xmltex/passivetex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1h49v6sqbm27isfwwcql9dzxn4vmcn2algkqh7f1pzj860xw3ygn"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/passivetex")
    (synopsis "Support package for XML/SGML typesetting")
    (description
     "This is a set of packages providing XML parsing, UTF-8 parsing,
Unicode entities, and common formatting object definitions for JadeTeX.")
    ;; License given in "tex/xmltex/passivetex/mlnames.sty".
    (license license:lppl1.0+)))

(define-public texlive-pict2e
  (package
    (name "texlive-pict2e")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pict2e/"
                                     "source/latex/pict2e/"
                                     "tex/latex/pict2e/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pazv1khsgjhxc673qrhjrbzlkgmcj53qccb9hw7ygdajxrjc2ba"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pict2e")
    (synopsis "New implementation of @code{picture} commands")
    (description
     "This package extends the existing LaTeX @code{picture} environment,
using the familiar technique (the @code{graphics} and @code{color} packages)
of driver files (at present, drivers for dvips, pdfTeX, LuaTeX, XeTeX, VTeX,
dvipdfm, and dvipdfmx are available).  The package documentation has a fair
number of examples of use, showing where things are improved by comparison
with the LaTeX @code{picture} environment.")
    (license license:lppl1.3+)))

(define-public texlive-psnfss
  (package
    (name "texlive-psnfss")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/psnfss/"
                                     "fonts/map/dvips/psnfss/"
                                     "source/latex/psnfss/"
                                     "tex/latex/psnfss/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17zxqz32ky99z22yaqayg9ih8lyaswi97d34jykc0s12w4k4i97c"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-cm")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-cm))
    (propagated-inputs
     (list texlive-graphics texlive-symbol texlive-zapfding))
    (home-page "https://www.ctan.org/pkg/psnfss")
    (synopsis "Font support for common PostScript fonts")
    (description
     "The PSNFSS collection includes a set of files that provide a complete
working setup of the LaTeX font selection scheme (NFSS2) for use with common
PostScript fonts.  The base set of text fonts covered by PSNFSS includes the
AvantGarde, Bookman, Courier, Helvetica, New Century Schoolbook, Palatino,
Symbol, Times Roman and Zapf Dingbats fonts.  In addition, the fonts Bitstream
Charter and Adobe Utopia are covered.  Separate packages are provided to load
each font for use as the main text font.  The package @code{helvet} allows
Helvetica to be loaded with its size scaled to something more appropriate for
use as a Sans-Serif font to match Times, while @code{pifont} provides the
means to select single glyphs from symbol fonts.  The bundle as a whole is
part of the LaTeX required set of packages.")
    (license license:lppl1.2+)))

(define-deprecated-package texlive-latex-psnfss texlive-psnfss)

(define-public texlive-ifplatform
  (package
    (name "texlive-ifplatform")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ifplatform/"
                                     "source/latex/ifplatform/"
                                     "tex/latex/ifplatform/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1llas0xwq3y9nk7gblg40l99cgmkl9r7rbfazrhpnbaz5cshl8pl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ifplatform")
    (synopsis "Conditionals to test which platform is being used")
    (description
     "This package uses the (La)TeX extension @samp{-shell-escape} to
establish whether the document is being processed on a Windows or on
a Unix-like system, or on Cygwin.

Booleans provided are: @code{\\ifwindows}, @code{\\iflinux}, @code{\\ifmacosx}
and @code{\\ifcygwin}.  The package also preserves the output of
@command{uname} on a Unix-like system, which may be used to distinguish
between various classes of Unix systems.")
    (license license:lppl1.3c)))

(define-deprecated-package texlive-latex-ifplatform texlive-ifplatform)

(define-public texlive-ifptex
  (package
    (name "texlive-ifptex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/ifptex/" "tex/generic/ifptex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mf4rwy1g0l2qsz571h5g3kinciy17vqgm42gvhbhffm5xyxhvx8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ifptex")
    (synopsis "Check if the engine is pTeX or one of its derivatives")
    (description
     "The @code{ifptex} package is a counterpart of @code{ifxetex},
@code{ifluatex}, etc.@: for the pTeX engine.  The @code{ifuptex} package is an
alias to @code{ifptex} provided for backward compatibility.")
    (license license:expat)))

(define-public texlive-iftex
  (package
    (name "texlive-iftex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/iftex/" "tex/generic/iftex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05p8iw8c8vjs59zb8pgilwpvlzrlb8zxyf34fhyr67y6bwm8phnf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "http://www.ctan.org/pkg/iftex")
    (synopsis "Determine the currently used TeX engine")
    (description
     "This package, which works both for Plain TeX and for LaTeX, defines the
@code{\\ifPDFTeX}, @code{\\ifXeTeX}, and @code{\\ifLuaTeX} conditionals for
testing which engine is being used for typesetting.  The package also provides
the @code{\\RequirePDFTeX}, @code{\\RequireXeTeX}, and @code{\\RequireLuaTeX}
commands which throw an error if pdfTeX, XeTeX or LuaTeX (respectively) is not
the engine in use.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-generic-iftex texlive-iftex)
(define-deprecated-package texlive-generic-ifxetex texlive-iftex)

(define-public texlive-ifxptex
  (package
    (name "texlive-ifxptex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/ifxptex/"
                                     "tex/generic/ifxptex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0r77j010a9fcn47kjy6vwv72i8fynb8jsilas6hs9c9lgk5bal1g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ifxptex")
    (synopsis "Detect pTeX and its derivatives")
    (description
     "The package provides commands for detecting pTeX and its derivatives
(e-pTeX, upTeX, e-upTeX, and ApTeX).  Both LaTeX and plain TeX are
supported.")
    (license license:knuth)))

(define-public texlive-tipa
  (package
    (name "texlive-tipa")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/tipa/"
                                     "fonts/map/dvips/tipa/"
                                     "fonts/source/public/tipa/"
                                     "fonts/tfm/public/tipa/"
                                     "fonts/type1/public/tipa/"
                                     "tex/latex/tipa/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11gi7yhq2lnfgvqa29i0sidi5mwkzpja5ggdcpvqwv4xljf4vpvh"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-cm")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-cm texlive-metafont))
    (home-page "https://ctan.org/pkg/tipa")
    (synopsis "Fonts and macros for IPA phonetics characters")
    (description
     "These fonts are considered the ultimate answer to IPA typesetting.  The
encoding of these 8-bit fonts has been registered as LaTeX standard encoding
T3, and the set of addendum symbols as encoding TS3.  Times-like Adobe Type
1 versions are provided for both the T3 and the TS3 fonts.")
    (license license:lppl)))

(define-public texlive-tipa-de
  (package
    (name "texlive-tipa-de")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tipa-de/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16gwc0dpdls6s2vdl3hmd6307d88gfzsa3kbw3vhl0z5iawvwj4h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tipa-de")
    (synopsis "German translation of @code{tipa} documentation")
    (description
     "This is a German translation of Fukui Rei's @code{tipaman} from the
@code{tipa} bundle.")
    (license license:lppl)))

(define-public texlive-amsrefs
  (package
    (name "texlive-amsrefs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/amsrefs/" "bibtex/bst/amsrefs/"
                                     "doc/latex/amsrefs/" "source/latex/amsrefs/"
                                     "tex/latex/amsrefs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12la66vz5ic6jc1cy96b2zh2fxsbaii9kbs4wrz1ii8v508wdkhv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/amsrefs")
    (synopsis "LaTeX-based replacement for BibTeX")
    (description
     "Amsrefs is a LaTeX package for bibliographies that provides an
archival data format similar to the format of BibTeX database files, but
adapted to make direct processing by LaTeX easier.  The package can be used
either in conjunction with BibTeX or as a replacement for BibTeX.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-amsrefs texlive-amsrefs)

(define-public texlive-bigfoot
  (package
    (name "texlive-bigfoot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bigfoot/"
                                     "source/latex/bigfoot/"
                                     "tex/latex/bigfoot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "140b4bbjcgajd1flznmi3ga6lx5pna2nxybr2dqm9515lny8gwf0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bigfoot")
    (synopsis "Footnotes for critical editions")
    (description
     "The package aims to provide a one-stop solution to requirements for
footnotes.  It offers multiple footnote apparatus superior to that of
@code{manyfoot}.  Footnotes can be formatted in separate paragraphs, or be run
into a single paragraph.  Note that the majority of the @code{bigfoot}
package's interface is identical to that of @code{manyfoot}; users should seek
information from that package's documentation.

The @code{bigfoot} bundle also provides the @code{perpage} and @code{suffix}
packages.")
    (license license:gpl2+)))

(define-deprecated-package texlive-latex-bigfoot texlive-bigfoot)

(define-public texlive-blindtext
  (package
    (name "texlive-blindtext")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/blindtext/"
                                     "source/latex/blindtext/"
                                     "tex/latex/blindtext/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gakawih3mzm5jh01kb44sjpsa4r8c3zwzig5bac37g4ha2vqska"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/blindtext")
    (synopsis "Producing blind text for testing")
    (description
     "The package provides the commands @code{\\blindtext} and
@code{\\Blindtext} for creating \"blind\" text useful in testing new classes
and packages, and @code{\\blinddocument}, @code{\\Blinddocument} for creating
an entire random document with sections, lists, mathematics, etc.  The package
supports three languages, @code{english}, @code{(n)german} and @code{latin};
the @code{latin} option provides a short \"lorem ipsum\" (for a fuller \"lorem
ipsum\" text, see the @code{lipsum} package).")
    (license license:lppl)))

(define-deprecated-package texlive-latex-blindtext texlive-blindtext)

(define-public texlive-dinbrief
  (package
    (name "texlive-dinbrief")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dinbrief/"
                                     "source/latex/dinbrief/"
                                     "tex/latex/dinbrief/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l6mmn3y07xglmh3h5f7pnpmyacqb2g6nqgq3q1p6k97kf708c5s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'fix-build
            (lambda _
              (with-fluids ((%default-port-encoding "ISO-8859-1"))
                (with-directory-excursion "source/latex/dinbrief"
                  (delete-file "dinbrief.drv")
                  (substitute* "dinbrief.dtx"
                    (("zur Verf.+ung. In der Pr\"aambel")
                     "zur Verf\"ung. In der Pr\"aambel")))))))))
    (home-page "https://ctan.org/pkg/dinbrief")
    (synopsis "German letter DIN style")
    (description
     "This package implements a document layout for writing letters according
to the rules of DIN (Deutsches Institut für Normung, German standardisation
institute).  A style file for LaTeX 2.09 (with limited support of the
features) is part of the package.  Since the letter layout is based on a
German standard, the user guide is written in German, but most macros have
English names from which the user can recognize what they are used for.  In
addition there are example files showing how letters may be created with the
package.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-dinbrief texlive-dinbrief)

(define-public texlive-draftwatermark
  (package
    (name "texlive-draftwatermark")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/draftwatermark/"
                                     "source/latex/draftwatermark/"
                                     "tex/latex/draftwatermark/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hanv3972wm2wdy8f8ygljl9rnbf04vn5yx2pqz3jdic8dhwp0j0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/draftwatermark")
    (synopsis "Put a grey textual watermark on document pages")
    (description
     "This package provides a means to add a textual, light grey watermark
on every page or on the first page of a document.  Typical usage may consist
in writing words such as DRAFT or CONFIDENTIAL across document pages.  The
package performs a similar function to that of @code{draftcopy}, but its
implementation is output device independent, and made very simple by relying
on @code{everypage}.")
    (license license:lppl1.3+)))

(define-public texlive-drv
  (package
    (name "texlive-drv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/drv/" "metapost/drv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vjc9x9xa50zzzc3m2csj9x0gqwcamhyqz1xkdbkqwkcy8rfpnlh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/drv")
    (synopsis "Derivation trees with MetaPost")
    (description
     "This package provides a set of MetaPost macros for typesetting
derivation trees (such as used in sequent calculus, type inference,
programming language semantics...).")
    (license license:lppl)))

(define-public texlive-dviincl
  (package
    (name "texlive-dviincl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/dviincl/" "metapost/dviincl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05f6ll7cq4ad4i4nkzrjnlqg1456is06fbmjiinadahf7yrqk3lw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dviincl")
    (synopsis "Include a DVI page into MetaPost output")
    (description
     "DVItoMP is one of the auxiliary programs available to any MetaPost
package; it converts a DVI file into a MetaPost file.  Using it, one can
envisage including a DVI page into an EPS files generated by MetaPost.  Such
files allow pages to include other pages.")
    (license license:public-domain)))

(define-public texlive-emp
  (package
    (name "texlive-emp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/emp/" "source/latex/emp/"
                                     "tex/latex/emp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "183qwxxjws4l0jrn92dj4qd8avnv9gq2rk1zqak0h48wxlp0fpyq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/emp")
    (synopsis "Encapsulate MetaPost figures in a document")
    (description
     "Emp is a package for encapsulating MetaPost figures in LaTeX: the
package provides environments where you can place MetaPost commands, and means
of using that code as fragments for building up figures to include in your
document.  So, with Emp, the procedure is to run your document with LaTeX, run
MetaPost, and then complete running your document in the normal way.  Emp is
therefore useful for keeping illustrations in synchrony with the text.  It
also frees you from inventing descriptive names for PostScript files that fit
into the confines of file system conventions.")
    (license license:gpl3+)))

(define-public texlive-enctex
  (package
    (name "texlive-enctex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/enctex/"
                                     "tex/generic/enctex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1j8ji1ka8vhskm5kn0iwmkhjfp88ly6rva30pr1c9llsmsac5sf2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/enctex")
    (synopsis "TeX extension that translates input on its way into TeX")
    (description
     "EncTeX is (another) TeX extension, written at the change-file level.  It
provides means of translating input on the way into TeX.  It allows, for
example, translation of multibyte sequences, such as utf-8 encoding.")
    (license license:gpl3+)))

(define-public texlive-environ
  (package
    (name "texlive-environ")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/environ/"
                                     "source/latex/environ/"
                                     "tex/latex/environ/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08a3vhyzc647b9zp3yifdklj0vch9cv2vajh7ig3y01jcdqhjy41"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-trimspaces))
    (home-page "https://ctan.org/pkg/environ")
    (synopsis "New interface for environments in LaTeX")
    (description
     "This package provides the @code{\\collect@@body} command (as in
@code{amsmath}), as well as a @code{\\long} version @code{\\Collect@@Body},
for collecting the body text of an environment.  These commands are used to
define a new author interface to creating new environments.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-environ texlive-environ)

(define-public texlive-epsincl
  (package
    (name "texlive-epsincl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/epsincl/" "metapost/epsincl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pjnfqayh42gavlbd9wqn86qyqhw1bxrbmwgsv39ycj4s63xjxqr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/epsincl")
    (synopsis "Include EPS in MetaPost figures")
    (description
     "The package facilitates including EPS files in MetaPost figures.")
    (license license:public-domain)))

(define-public texlive-eqparbox
  (package
    (name "texlive-eqparbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/eqparbox/"
                                     "source/latex/eqparbox/"
                                     "tex/latex/eqparbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16c5dyd4bz45a2c1ppbq05h9ixg15srk5az5pld5gpv4j0zwzrqw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eqparbox")
    (synopsis "Create equal-widthed parboxes")
    (description
     "LaTeX users sometimes need to ensure that two or more blocks of text
occupy the same amount of horizontal space on the page.  To that end, the
@code{eqparbox} package defines a new command, @code{\\eqparbox}, which works
just like @code{\\parbox}, except that instead of specifying a width, one
specifies a tag.  All @code{eqparbox}es with the same tag---regardless of
where they are in the document---will stretch to fit the widest
@code{eqparbox} with that tag.  This simple, equal-width mechanism can be used
for a variety of alignment purposes, as is evidenced by the examples in
@code{eqparbox}'s documentation.  Various derivatives of @code{\\eqparbox} are
also provided.")
    (license license:lppl1.3c)))

(define-deprecated-package texlive-latex-eqparbox texlive-eqparbox)

(define-public texlive-etoc
  (package
    (name "texlive-etoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/etoc/" "source/latex/etoc/"
                                     "tex/latex/etoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "008j03lplb5a12ha8vdsl2m8jqjm5vr753x40nahbpr96397k2b2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/etoc")
    (synopsis "Customisable table of contents")
    (description
     "This package gives the user complete control of how the entries of the
table of contents should be constituted from the name, number, and page number
of each sectioning unit.  The layout is controlled by the definition of line
styles for each sectioning level used in the document.

The package provides its own custom line styles (which may be used as
examples), and continues to support the standard formatting inherited from the
LaTeX document classes, but the package can also allow the user to delegate
the details to packages dealing with list making environments (such as
@code{enumitem}).  The package's default global style typesets tables of
contents in a multi-column format, with either a standard heading, or a ruled
title (optionally with a frame around the table).

The @code{\\tableofcontents} command may be used arbitrarily many times in the
same document, while @code{\\localtableofcontents} provides a local table of
contents.")
    (license license:lppl1.3c)))

(define-deprecated-package texlive-latex-etoc texlive-etoc)

(define-public texlive-expdlist
  (package
    (name "texlive-expdlist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/expdlist/"
                                     "source/latex/expdlist/"
                                     "tex/latex/expdlist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kylmj615hmbmjbynn5bfzhfz0wk1drxmg0kjqljnglffkb6irv6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/expdlist")
    (synopsis "Expanded description environments")
    (description
     "The package provides additional features for the LaTeX @code{description} environment,
including adjustable left margin.  The package also allows the user to break
a list (for example, to interpose a comment) without affecting the structure
of the list (this works for itemize and eumerate lists and numbered lists
remain in sequence).")
    (license license:lppl)))

(define-deprecated-package texlive-latex-expdlist texlive-expdlist)

(define-public texlive-expressg
  (package
    (name "texlive-expressg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/expressg/"
                                     "metapost/expressg/"
                                     "source/metapost/expressg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08f6lxxxmhfld6g2iy2kn68llalz3wayxqka7nd48s1ahm33kmdd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/expressg")
    (synopsis "Diagrams consisting of boxes, lines, and annotations")
    (description
     "This package provides a MetaPost package providing facilities to assist
in drawing diagrams that consist of boxes, lines, and annotations.  Particular
support is provided for creating EXPRESS-G diagrams, for example IDEF1X, OMT,
Shlaer-Mellor, and NIAM diagrams.  The package may also be used to create UML
and most other Box-Line-Annotation charts, but not Gantt charts directly.")
    (license license:lppl)))

(define-public texlive-exteps
  (package
    (name "texlive-exteps")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/exteps/" "metapost/exteps/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mmlmcjn8fk16y14p3q6xfmkcc75vcykblgcyzapzxd1nzy51ak7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/exteps")
    (synopsis "Include EPS figures in MetaPost")
    (description
     "Exteps is a module for including external EPS figures into MetaPost
figures.  It is written entirely in MetaPost, and does not therefore require
any post processing of the MetaPost output.")
    (license license:gpl3+)))

(define-public texlive-featpost
  (package
    (name "texlive-featpost")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/featpost/"
                                     "metapost/featpost/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a97syvr3vwpayhasb98ssvgwr99p13plrjnqb9ad24jd6srmmdg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/featpost")
    (synopsis "MetaPost macros for 3D")
    (description
     "These macros allow the production of three-dimensional schemes
containing angles, circles, cylinders, cones and spheres, among other
things.")
    (license license:gpl3+)))

(define-public texlive-feynmf
  (package
    (name "texlive-feynmf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/feynmf/" "metafont/feynmf/"
                                     "metapost/feynmf/" "source/latex/feynmf/"
                                     "tex/latex/feynmf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a6zhs4x6rkjl7vapc3y59hmrvmi570ji2bszpsk88w3fi8klckb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/feynmf")
    (synopsis "Macros and fonts for creating Feynman (and other) diagrams")
    (description
     "The @code{feynmf} package provides an interface to Metafont to use
simple structure specifications to produce relatively complex diagrams. While
the package was designed for Feynman diagrams, it could in principle be used
for diagrams in graph and similar theories, where the structure is
semi-algorithmically determined.")
    (license license:gpl3+)))

(define-public texlive-feynmp-auto
  (package
    (name "texlive-feynmp-auto")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/feynmp-auto/"
                                     "source/latex/feynmp-auto/"
                                     "tex/latex/feynmp-auto/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19ghfblv641ghak049v42wbqmh7pfadz0mrbkfbx2jr4bvf57rv2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/feynmp-auto")
    (synopsis "Automatic processing of @code{feynmp} graphics")
    (description
     "The package takes care of running Metapost on the output files produced
by the @code{feynmp} package, so that the compiled pictures will be available
in the next run of LaTeX. The package honours options that apply to
@code{feynmp}.")
    (license license:lppl1.3+)))

(define-public texlive-filemod
  (package
    (name "texlive-filemod")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/filemod/" "tex/generic/filemod/"
                                     "tex/latex/filemod/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1snsj7kblkj1ig3x3845lsypz7ab04lf0dcpdh946xakgjnz4fb5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/filemod")
    (synopsis "Provide file modification times, and compare them")
    (description
     "This package provides macros to read and compare the modification dates
of files.  The files may be @code{.tex} files, images or other files (as long
as they can be found by LaTeX).  It uses the @code{\\pdffilemoddate} primitive
of pdfLaTeX to find the file modification date as PDF date string, parses the
string and returns the value to the user.  The package will also work for DVI
output with recent versions of the LaTeX compiler which uses pdfLaTeX in DVI
mode.  The functionality is provided by purely expandable macros or by faster
but non-expandable ones.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-filemod texlive-filemod)

(define-public texlive-fix2col
  (package
    (name "texlive-fix2col")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fix2col/" "source/latex/fix2col/"
                                     "tex/latex/fix2col/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04mzs1qn9ish5sdp1v9adqvl92ljbs9rjxxfsqskalm4g9ckn8dy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fix2col")
    (synopsis "Fix miscellaneous two column mode features")
    (description
     "This package is obsolete; do not use in new documents.  It will do
nothing in LaTeX formats after 2015/01/01 as the fixes that it implements were
incorporated into the @code{fixltx2e} package, which is itself obsolete as
since the 2015/01/01 release these fixes are in the LaTeX format itself.

Fix mark handling so that @code{\\firstmark} is taken from the first column if
that column has any marks at all; keep two column floats like @code{figure*}
in sequence with single column floats like figure.")
    (license license:lppl)))

(define-public texlive-fixlatvian
  (package
    (name "texlive-fixlatvian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/fixlatvian/"
                                     "makeindex/fixlatvian/"
                                     "source/xelatex/fixlatvian/"
                                     "tex/xelatex/fixlatvian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09bivnc287z57k9rhwfl16w66dkvb55shnwpqv972n6dsjdcrh7j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fixlatvian")
    (synopsis "Improve Latvian language support in XeLaTeX")
    (description
     "The package offers improvement of the Latvian language support in
@code{polyglossia}, in particular in the area of the standard classes.")
    (license license:lppl1.3+)))

(define-public texlive-fiziko
  (package
    (name "texlive-fiziko")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/fiziko/" "metapost/fiziko/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "160iqgm4f7imnj89gj4822xv5wnnxf336k261v52h6sd0lhnhany"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fiziko")
    (synopsis "MetaPost library for physics textbook illustrations")
    (description
     "This MetaPost library was initially written to automate some elements of
black and white illustrations for a physics textbook.  It provides functions
to draw things like lines of variable width, shaded spheres, and tubes of
different kinds, which can be used to produce images of a variety of objects.
The library also contains functions to draw some objects constructed from
these primitives.")
    (license (list license:gpl3+ license:cc-by-sa4.0))))

(define-public texlive-font-change-xetex
  (package
    (name "texlive-font-change-xetex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xetex/font-change-xetex/"
                                     "tex/xetex/font-change-xetex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qhkxsk3wl6a8isik4ln1jq7ifhk7hbidq2i1lfy18c1py87xw5k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/font-change-xetex")
    (synopsis "Macros to change text and mathematics fonts in plain XeTeX")
    (description
     "This package consists of macros that can be used to typeset plain XeTeX
documents using any OpenType or TrueType font installed on the computer
system.  The macros allow the user to change the text mode fonts and some math
mode fonts.  For any declared font family, various font style, weight, and
size variants like bold, italics, small caps, etc., are available through
standard and custom TeX control statements.  Using the optional argument of
the macros, the available XeTeX font features and OpenType tags can be
accessed.  Other features of the package include activating and deactivating
hanging punctuation, and support for special Unicode characters.")
    (license license:cc-by-sa4.0)))

(define-public texlive-fontbook
  (package
    (name "texlive-fontbook")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/fontbook/"
                                     "source/xelatex/fontbook/"
                                     "tex/xelatex/fontbook/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n5yn6rgndk0yr91bhglby9nr5mifgfi895klvsixmxc0k5bqp97"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fontbook")
    (synopsis "Generate a font book")
    (description
     "The package provides a means of producing a book of font samples (for
evaluation, etc.).")
    (license license:lppl1.3+)))

(define-public texlive-fontwrap
  (package
    (name "texlive-fontwrap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/fontwrap/"
                                     "tex/xelatex/fontwrap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nzphhwgm9387mn2rfhmsandyvcwv99lxm5978jg6pycs43dggs7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fontwrap")
    (synopsis "Bind fonts to specific Unicode blocks")
    (description
     "The package (which runs under XeLaTeX) lets you bind fonts to specific
Unicode blocks, for automatic font tagging of multilingual text.")
    (license license:gpl3+)))

(define-public texlive-garrigues
  (package
    (name "texlive-garrigues")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/garrigues/"
                                     "metapost/garrigues/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vg1j0r4mkp057v7kjr8yza1danc3zj7k590x5531yi0gzp7hgq2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/garrigues")
    (synopsis "MetaPost macros for the reproduction of Garrigues' Easter nomogram")
    (description
     "This library provides MetaPost macros for the reproduction of Garrigues
Easter nomogram.")
    (license license:lppl)))

(define-public texlive-garuda-c90
  (package
    (name "texlive-garuda-c90")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "dvips/garuda-c90/"
                                     "fonts/map/dvips/garuda-c90/"
                                     "fonts/tfm/public/garuda-c90/"
                                     "source/fonts/garuda-c90/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1f6rlfxq3ccv9wdf7pzfgs1081yflxd3fzhkzi23mpyl777l7q9y"))))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-fonts-tlwg))
    (home-page "https://ctan.org/pkg/garuda-c90")
    (synopsis "TeX support (from CJK) for the Garuda font")
    (description
     "This package provides TeX support (from CJK) for the Garuda font.")
    (license license:gpl2+)))

(define-public texlive-hanging
  (package
    (name "texlive-hanging")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hanging/" "source/latex/hanging/"
                                     "tex/latex/hanging/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18ichpmmghz0nmv6m646r64y5jvyp52qz9hj7hadrf34xj1ijmlk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/hanging")
    (synopsis "Typeset hanging paragraphs")
    (description
     "The @code{hanging} package facilitates the typesetting of hanging
paragraphs.  The package also enables typesetting with hanging punctuation,
by making punctuation characters active.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-hanging texlive-hanging)

(define-public texlive-fira
  (package
    (name "texlive-fira")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/fira/"
                                     "fonts/enc/dvips/fira/"
                                     "fonts/map/dvips/fira/"
                                     "fonts/opentype/public/fira/"
                                     "fonts/tfm/public/fira/"
                                     "fonts/type1/public/fira/"
                                     "fonts/vf/public/fira/"
                                     "tex/latex/fira/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19sb6c1h1crhs1597i3nlvr2ahl20hxj7a1a5xkpfr5vj4n3x5kv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fira")
    (synopsis "Fira fonts with LaTeX support")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the Fira Sans family of fonts designed by Erik Spiekermann and Ralph du
Carrois of Carrois Type Design.  Fira Sans is available in eleven weights with
corresponding italics: light, regular, medium, bold, ...")
    (license (list license:lppl
                   license:silofl1.1))))

(define-public texlive-firstaid
  (package
    (name "texlive-firstaid")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/firstaid/" "source/latex/firstaid/"
                                     "tex/latex/firstaid/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kzf4siq18mp5wfp9mkc96vk45k85wcgphpv51vsa312fqdylzcb"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-latex"
                                               "texlive-pdftex")))
    (build-system texlive-build-system)
    (arguments (list #:texlive-latex-bin? #f))
    (native-inputs (list texlive-latex texlive-pdftex))
    (home-page "https://ctan.org/pkg/firstaid")
    (synopsis
     "First aid for external LaTeX files and packages that need updating")
    (description
     "This package contains some first aid for LaTeX packages or classes that
require updates because of internal changes to the LaTeX kernel that are not
yet reflected in the package's or class's code.  The file
@file{latex2e-first-aid-for-external-files.ltx} provided by this package is
meant to be loaded during format generation and not by the user.")
    (license license:lppl1.3c)))

(define-public texlive-gmp
  (package
    (name "texlive-gmp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gmp/" "source/latex/gmp/"
                                     "tex/latex/gmp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zvl80wjg4xsika0p0v6jskrwdpy3n7qbfvbg76qbzzpc03n6x6a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gmp")
    (synopsis "Enable integration between MetaPost pictures and LaTeX")
    (description
     "The package allows integration between MetaPost pictures and LaTeX.
The main feature is that passing parameters to the MetaPost pictures is
possible and the picture code can be put inside arguments to commands,
including @code{\\newcommand}.")
    (license license:lppl1.3+)))

(define-public texlive-hershey-mp
  (package
    (name "texlive-hershey-mp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/hershey-mp/"
                                     "metapost/hershey-mp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pbybiqh5qgj9zh0yifxm2hn25h73kz1glrv1cz9sw38h6iydlzw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hershey-mp")
    (synopsis "MetaPost support for the Hershey font file format")
    (description
     "This package provides MetaPost support for reading jhf vector font
files, used by (mostly? only?) the so-called Hershey Fonts of the late 1960s.
The package does not include the actual font files, which you can probably
find in the software repository of your operating system.")
    (license license:eupl1.2)))

(define-public texlive-interchar
  (package
    (name "texlive-interchar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/interchar/"
                                     "tex/xelatex/interchar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06pvpaph1gi3rjvwzpvzc2rlx0wb8fqmidbfh8dw2qazzbirdlnz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/interchar")
    (synopsis "Managing character class schemes in XeTeX")
    (description
     "The package manages character class schemes of XeTeX.  Using this
package, you may switch among different character class schemes.  Migration
commands are provided for make packages using this mechanism compatible with
each others.")
    (license license:lppl1.3+)))

(define-public texlive-latexmk
  (package
    (name "texlive-latexmk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/latexmk.1"
                                     "doc/man/man1/latexmk.man1.pdf"
                                     "doc/support/latexmk/" "scripts/latexmk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yqll020pp0ajyq9i1ifim0mqvb9dk97y1gjkgi8r4n0d1bvkx9d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "latexmk.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/latexmk")
    (synopsis "Fully automated LaTeX document generation")
    (description
     "Latexmk completely automates the process of generating a LaTeX document.
Given the source files for a document, @command{latexmk} issues the
appropriate sequence of commands to generate a @file{.dvi}, @file{.ps},
@file{.pdf} or hardcopy version of the document.  An important feature is the
preview continuous mode, where the script watches all of the source files and
reruns LaTeX, etc., whenever a source file has changed.  Thus a previewer can
offer a display of the document's latest state.")
    (license license:gpl2)))

(define-public texlive-latexmp
  (package
    (name "texlive-latexmp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/latexmp/" "metapost/latexmp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zxwxss5sl16laaqalr8043wmyk2bhlja3al5xlxkizvlnflqy0f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latexmp")
    (synopsis "Interface for LaTeX-based typesetting in MetaPost")
    (description
     "The MetaPost package @code{latexMP} implements a user-friendly interface
to access LaTeX-based typesetting capabilities in MetaPost.  The text to be
typeset is given as string.  This allows even dynamic text elements, for
example counters, to be used in labels.  Compared to other implementations it
is much more flexible, since it can be used as direct replacement for
@code{btex.etex}, and much faster, compared for example to the solution
provided by @code{tex.mp}.")
    (license license:public-domain)))

(define-public texlive-marathi
  (package
    (name "texlive-marathi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/marathi/" "source/latex/marathi/"
                                     "tex/latex/marathi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xlyvdb6dadg4x2xixcxr1ixqsz69ssifpbh5p46lzsz080pwd58"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/marathi")
    (synopsis "Typeset Marathi language using XeLaTeX or LuaLaTeX")
    (description
     "This package is used to typeset Marathi language with LuaLaTeX and XeLaTeX.
It will provide localizations needed for the Marathi language.  Currently the
package localizes package @code{blindtext} and package @code{expex}.")
    (license (list license:gpl3+ license:fdl1.3+))))

(define-public texlive-markdown
  (package
    (name "texlive-markdown")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/context/third/markdown/examples/"
                                     "doc/generic/markdown/"
                                     "doc/latex/markdown/examples/"
                                     "doc/optex/markdown/examples/"
                                     "scripts/markdown/"
                                     "source/generic/markdown/"
                                     "tex/context/third/markdown/"
                                     "tex/generic/markdown/"
                                     "tex/latex/markdown/"
                                     "tex/luatex/markdown/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1202x2l22sq2252b7bnywm58b2sj7syvk9ayldd3fgxb0lr3a063"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/markdown")
    (synopsis "Converting and rendering Markdown documents inside TeX")
    (description
     "The package provides facilities for the conversion of Markdown markup to
plain TeX.  These are provided both in form of a Lua module and in form of
plain TeX, LaTeX, and ConTeXt macro packages that enable the direct inclusion
of Markdown documents inside TeX documents.")
    (license license:lppl1.3c)))

(define-public texlive-mcf2graph
  (package
    (name "texlive-mcf2graph")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/mcf2graph/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xy1f4cmf2w9p0wpdapig6jc4bwwmqqiy7981ja3kcx6g6id1r95"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mcf2graph")
    (synopsis "Draw chemical structure diagrams with MetaPost")
    (description
     "The Molecular Coding Format (MCF) is a linear notation for describing
chemical structure diagrams.  This package converts MCF to graphic files using
MetaPost.")
    (license license:expat)))

(define-public texlive-metago
  (package
    (name "texlive-metago")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/metago/" "metapost/metago/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13m61ml8wfs5888nifilgzi503m3gz1f2fa44408jdhlr6zk6fa0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/metago")
    (synopsis "MetaPost output of Go positions")
    (description
     "The package allows you to draw Go game positions with MetaPost.  Two
methods of usage are provided, either using the package programmatically, or
using the package via a script (which may produce several images).")
    (license license:lppl)))

(define-public texlive-metaobj
  (package
    (name "texlive-metaobj")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/metaobj/" "metapost/metaobj/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ir6p14h79x5iqbxmj2893x8j1d490bnhs83jwnrbcjxn0yxky6w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/metaobj")
    (synopsis "MetaPost package providing high-level objects")
    (description
     "METAOBJ is a large MetaPost package providing high-level objects.  It
implements many of PSTricks features for node connections, but also trees,
matrices, and many other things.  It more or less contains @code{boxes.mp} and
@code{rboxes.mp}.  It is easily extensible with new objects.")
    (license license:lppl)))

(define-public texlive-metaplot
  (package
    (name "texlive-metaplot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/metaplot/" "metapost/metaplot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19y8lj28gvky7f7g2i562ixwvmnxnflnfc8l8r0x7zg384hg8835"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/metaplot")
    (synopsis "Plot-manipulation macros for use in MetaPost")
    (description
     "MetaPlot is a set of MetaPost macros for manipulating pre-generated
plots (and similar objects), and formatting them for inclusion in a MetaPost
figure.  The intent is that the plots can be generated by some outside
program, in an abstract manner that does not require making decisions about
on-page sizing and layout, and then they can be imported into MetaPlot and
arranged using the full capabilities of MetaPost.  Metaplot also includes
a very flexible set of macros for generating plot axes, which may be useful in
other contexts as well.")
    (license license:lppl)))

(define-public texlive-metapost-colorbrewer
  (package
    (name "texlive-metapost-colorbrewer")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/metapost-colorbrewer/"
                                     "metapost/metapost-colorbrewer/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00bpdz2k849k1sfrlflxhdbylncb5y2bixgmylyh0i8rbb467q7l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/metapost-colorbrewer")
    (synopsis
     "Implementation of the @code{colorbrewer2.org} colours for MetaPost")
    (description
     "This package provides two MetaPost include files that define all the
@code{colorbrewer2.org} colours: @code{colorbrewer-cmyk.mp} and
@code{colorbrewer-rgb.mp}. The first defines all the colours as CMYK, the
second as RGB.")
    (license license:gpl3+)))

(define-public texlive-metauml
  (package
    (name "texlive-metauml")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/metauml/" "metapost/metauml/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01hs234mjqnr39zm7jl6dpbm5w0k4p73pr0aj35ii0dhakln2jsy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/metauml")
    (synopsis "MetaPost library for typesetting UML diagrams")
    (description
     "MetaUML is a MetaPost library for typesetting UML diagrams, which
provides a usable, human-friendly textual notation for UML, offering now
support for class, package, activity, state, and use case diagrams.")
    (license license:gpl3+)))

(define-public texlive-mfpic
  (package
    (name "texlive-mfpic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/mfpic/" "metafont/mfpic/"
                                     "metapost/mfpic/" "source/generic/mfpic/"
                                     "tex/generic/mfpic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1s3z31mglmij7qc1f0681vv2a6md9wz9zbi6zlh7zvmhy5hzkjkv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mfpic")
    (synopsis "Draw Metafont/post pictures from (La)TeX commands")
    (description
     "Mfpic is a scheme for producing pictures from (La)TeX commands.
Commands @code{\\mfpic} and @code{\\endmfpic} (in LaTeX, the @code{mfpic}
environment) enclose a group in which drawing commands may be placed.  The
commands generate a Meta-language file, which may be processed by MetaPost (or
even Metafont).  The resulting image file will be read back in to the document
to place the picture at the point where the original (La)TeX commands
appeared.")
    (license license:lppl1.3+)))

(define-public texlive-mfpic4ode
  (package
    (name "texlive-mfpic4ode")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mfpic4ode/"
                                     "source/latex/mfpic4ode/"
                                     "tex/latex/mfpic4ode/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ssmpvp1apxvinidq42pfpvjimpvd250har85n6rl7dj5fws9j8m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mfpic4ode")
    (synopsis "Macros to draw direction fields and solutions of ODEs")
    (description
     "The package is a small set of macros for drawing direction fields, phase
portraits and trajectories of differential equations and two dimensional
autonomous systems.  The Euler, Runge-Kutta and fourth order Runge-Kutta
algorithms are available to solve the ODEs.  The picture is translated into
@code{mfpic} macros and MetaPost is used to create the final drawing.")
    (license license:lppl)))

(define-public texlive-minim-hatching
  (package
    (name "texlive-minim-hatching")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/minim-hatching/"
                                     "metapost/minim-hatching/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qcd5zvhj9hrdhb7il1hbfdh5sgccl6mvwwmpw9fymbwdri9224f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/minim-hatching")
    (synopsis "Create tiling patterns with @code{minim-mp} MetaPost processor")
    (description
     "This is a small proof-of-concept library of tiling patterns for use with
the @code{minim-mp} MetaPost processor.")
    (license license:eupl1.2)))

(define-public texlive-mp3d
  (package
    (name "texlive-mp3d")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/mp3d/" "metapost/mp3d/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qfg4ifm5z72sr8vimibmpmqh0cxzipiy4jr8rbq5qsj2mfqzphd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mp3d")
    (synopsis "3D animations")
    (description
     "This library creates animations of 3-dimensional objects (such as
polyhedra) in MetaPost.")
    (license license:lppl)))

(define-public texlive-mparrows
  (package
    (name "texlive-mparrows")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/mparrows/"
                                     "metapost/mparrows/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pc9w5g6qasfpv4dxf0aahahbxk6kjwirdmx8l4i27syjb1lgzw9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mparrows")
    (synopsis "MetaPost module with different types of arrow heads")
    (description
     "This package provides a package to provide different types of arrow
heads to be used with MetaPost commands")
    (license license:public-domain)))

(define-public texlive-mpattern
  (package
    (name "texlive-mpattern")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/mpattern/"
                                     "metapost/mpattern/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00g250vl6gnvwx6zgmfqcw3nwkh546i1vjz4zjp3dc5n5yj5y6ls"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mpattern")
    (synopsis "Patterns in MetaPost")
    (description
     "This package provides a package for defining and using patterns in MetaPost,
using the Pattern Color Space available in PostScript Level 2.")
    (license license:public-domain)))

(define-public texlive-mpcolornames
  (package
    (name "texlive-mpcolornames")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/mpcolornames/"
                                     "metapost/mpcolornames/"
                                     "source/metapost/mpcolornames/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1s5yb57yamg1fd7w5hmkmfyxyqj3mivhkvrkqzm31dzh4y22qg3k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mpcolornames")
    (synopsis "Extend list of predefined colour names for MetaPost")
    (description
     "The MetaPost format @code{plain.mp} provides only five built-in colour names
(variables), all of which are defined in the RGB model: red, green and blue
for the primary colours and black and white.  The package makes more than 500
colour names from different colour sets in different colour models available
to MetaPost.")
    (license license:lppl)))

(define-public texlive-mpgraphics
  (package
    (name "texlive-mpgraphics")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mpgraphics/"
                                     "source/latex/mpgraphics/"
                                     "tex/latex/mpgraphics/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0z51scc8vimwihdyxv3g1cb7bjbj8w2a2ck1ygjyf8xzz4hcic2s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mpgraphics")
    (synopsis "Process and display MetaPost figures inline")
    (description
     "The package allows LaTeX users to typeset MetaPost code inline and
display figures in their documents with only and only one run of LaTeX,
pdfLaTeX or XeLaTeX (no separate runs of @command{mpost}).  Mpgraphics
achieves this by using the shell escape (@samp{\\write 18}) feature of current
TeX distributions, so that the whole process is automatic and the end user is
saved the tiresome processing.")
    (license license:lppl1.3+)))

(define-public texlive-mptrees
  (package
    (name "texlive-mptrees")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/mptrees/" "metapost/mptrees/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zbrbyvih6cp46y2ilr10g4a7ijfwpj0x9cipl5rl62r60qwydfx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mptrees")
    (synopsis "Probability trees with MetaPost")
    (description
     "This package provides MetaPost tools for drawing simple probability
trees.  One command and several parameters to control the output are
provided.")
    (license license:lppl1.3+)))

(define-public texlive-na-position
  (package
    (name "texlive-na-position")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/na-position/"
                                     "tex/xelatex/na-position/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rp1css44sl6j762kfwzq53k6690djgag6yc85dd9134i837gvqr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/na-position")
    (synopsis
     "Tables of relative positions of curves, asymptotes, tangents in Arabic
documents")
    (description
     "This package facilitates, in most cases, the creation of tables of
relative positions of a curve and its asymptote, or a curve and a tangent in
one of its points.  This package has to be used with @code{polyglossia} and
XeLaTeX to produce documents in Arabic.")
    (license license:lppl)))

(define-public texlive-natbib
  (package
    (name "texlive-natbib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/natbib/" "doc/latex/natbib/"
                                     "source/latex/natbib/" "tex/latex/natbib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17hyba6v24wrbjvakgjxkndjb418mmi2wmnhrm7zmfwb0bvy6f2j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/natbib")
    (synopsis "Flexible bibliography support")
    (description
     "The bundle provides a package that implements both author-year and
numbered references, as well as much detailed of support for other
bibliography use.  Also Provided are versions of the standard BibTeX styles
that are compatible with natbib--plainnat, unsrtnat, abbrnat.  The
bibliography styles produced by custom-bib are designed from the start to be
compatible with @code{natbib}.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-natbib texlive-natbib)

(define-public texlive-newfloat
  (package
    (name "texlive-newfloat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/newfloat/" "source/latex/newfloat/"
                                     "tex/latex/newfloat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "056vy6vwhp7mn9gwrb6ib1ymmrqd26ysjw7bv34v812xc0z9gfck"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/newfloat")
    (synopsis "Define new floating environments")
    (description
     "This package offers the command @code{\\DeclareFloatingEnvironment},
which the user may use to define new floating environments which behave like
the LaTeX standard foating environments @code{figure} and @code{table}.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-newfloat texlive-newfloat)

(define-public texlive-newpax
  (package
    (name "texlive-newpax")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/newpax/" "source/latex/newpax/"
                                     "tex/latex/newpax/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qrlii2hkkmj60w1qklx3rbagiy1y4x1dfv56lz6bc6kzs6qk5hm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/newpax")
    (synopsis "Experimental package to extract and reinsert PDF annotations")
    (description
     "The package is based on the @code{pax} package from Heiko Oberdiek.  It
offers a Lua-based alternative to the java based @file{pax.jar} to extract the
annotations from a PDF.  The resulting file can then be used together with
@file{pax.sty}.  It also offers an extended style which works with all three
major engines.")
    (license license:lppl1.3c)))

(define-public texlive-newunicodechar
  (package
    (name "texlive-newunicodechar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/newunicodechar/"
                                     "source/latex/newunicodechar/"
                                     "tex/latex/newunicodechar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b3n5mdfw9csp0ri1vw4jh1ibnpsllb5n6pwfkg1jad10ml9wavz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/newunicodechar")
    (synopsis "Definitions of the meaning of Unicode characters")
    (description
     "This package provides a friendly interface for defining the meaning of
Unicode characters.  The document should be processed by (pdf)LaTeX with the
Unicode option of @code{inputenc} or @code{inputenx}, or by XeLaTeX/LuaLaTeX.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-newunicodechar texlive-newunicodechar)

(define-public texlive-newverbs
  (package
    (name "texlive-newverbs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/newverbs/" "source/latex/newverbs/"
                                     "tex/latex/newverbs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02mhqgsfd13i1llhm0rgq3f9qs067jih2s15q1zvsfd5bhzls1pq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          (add-before 'build 'copy-ydocstrip.tex
            ;; There's a circular dependency between `newverbs' (where `ydoc'
            ;; should be a native input) and `ydoc' (where `newverbs' is
            ;; a propagated input).  To work around this, install the specific
            ;; "ydocstrip.tex" file from `ydoc' in the build directory and set
            ;; TEXINPUTS variable accordingly so the process can find it.
            (lambda* (#:key inputs native-inputs #:allow-other-keys)
              (install-file (search-input-file (or native-inputs inputs)
                                               "tex/generic/ydoc/ydocstrip.tex")
                            "build/")
              (setenv "TEXINPUTS" (string-append (getcwd) "/build:")))))))
    (native-inputs
     ;; TODO: Remove input label on next rebuild cycle.
     `(("_" ,(package-source texlive-ydoc))))
    (home-page "https://ctan.org/pkg/newverbs")
    (synopsis "Define new versions of @code{\\verb}")
    (description
     "The package allows the definition of @code{\\verb} variants which add
TeX code before and after the verbatim text (e.g., quotes or surrounding
@code{\\fbox@{@}}).  When used together with the @code{shortvrb} package it
allows the definition of short verbatim characters which use this package's
variant instead of the normal @code{\\verb}.  In addition, it is possible to
collect an argument verbatim to either typeset or write it into a file.  The
@code{\\Verbdef} command defines verbatim text to a macro which can later be
used to write the verbatim text to a file.")
    (license license:lppl1.3+)))

(define-public texlive-nodetree
  (package
    (name "texlive-nodetree")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/nodetree/"
                                     "source/luatex/nodetree/"
                                     "tex/luatex/nodetree/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qjf59xsp1bpjflfwgps7xq47l3jrlm644xvkqwcjxhr6gk21cb2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nodetree")
    (synopsis "Visualize node lists in a tree view")
    (description
     "@code{nodetree} is a development package that visualizes the structure
of node lists.  It uses a similar visual representation for node lists as the
UNIX @command{tree} command for a folder structure.")
    (license license:lppl1.3+)))

(define-public texlive-nomencl
  (package
    (name "texlive-nomencl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nomencl/" "makeindex/nomencl/"
                                     "source/latex/nomencl/" "tex/latex/nomencl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "176lqab9ypsym7x7mk9d0pbqf3fl9iwi539zjqv3l6nbmxj9ga88"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nomencl")
    (synopsis "Produce lists of symbols as in nomenclature")
    (description
     "This package produces lists of symbols using the capabilities of the
MakeIndex program.")
    (license license:lppl)))

(define-public texlive-norasi-c90
  (package
    (name "texlive-norasi-c90")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "dvips/norasi-c90/"
                                     "fonts/map/dvips/norasi-c90/"
                                     "fonts/tfm/public/norasi-c90/"
                                     "source/fonts/norasi-c90/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19ynw46dbk71sbzx6rna359gdddjmwl57gw3kfz3f9ywvhq01m1k"))))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-fonts-tlwg))
    (home-page "https://ctan.org/pkg/norasi-c90")
    (synopsis  "TeX support (from CJK) for the Norasi font")
    (description
     "This package provides TeX support (from CJK) for the Norasi font.")
    (license license:gpl2+)))

(define-public texlive-noto
  (package
    (name "texlive-noto")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/noto/"
                                     "fonts/enc/dvips/noto/"
                                     "fonts/map/dvips/noto/"
                                     "fonts/tfm/google/noto/"
                                     "fonts/truetype/google/noto/"
                                     "fonts/type1/google/noto/"
                                     "fonts/vf/google/noto/"
                                     "tex/latex/noto/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14nf6xd85cb5s9f1sk8zzshgfhjda0r712dp592j8cb4s5v2hf7p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/noto")
    (synopsis "Support for Noto fonts")
    (description
     "This package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX support for
the NotoSerif, NotoSans and NotoSansMono families of fonts, designed by Steve
Matteson for Google.")
    (license (list license:lppl license:silofl1.1))))

(define-public texlive-novel
  (package
    (name "texlive-novel")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/novel/"
                                     "fonts/opentype/public/novel/"
                                     "tex/lualatex/novel/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jglb0i5p1s80wbx03z37ps5mzdwdlrfkd8fxf607c7v1sbhhabc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/novel")
    (synopsis "Class for printing fiction, such as novels")
    (description
     "This LuaLaTeX document class is specifically written to meet the needs
of original fiction writers, who are typesetting their own novels for
non-color print-on-demand technology.  The package is well suited for
detective novels, science fiction, and short stories.  It is however not
recommended for creating color picture books or dissertations.")
    (license (list license:lppl1.3c license:silofl1.1))))

(define-public texlive-octavo
  (package
    (name "texlive-octavo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/octavo/" "source/latex/octavo/"
                                     "tex/latex/octavo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10ycj2xg2v7cq4my51dcc749hrrkg2gd41xyrwv1dg1lp9vh7j4z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/octavo")
    (synopsis "Typeset books following classical design and layout")
    (description
     "The @code{octavo} class is a modification of the standard LaTeX
@code{book} class.  Its purpose is to typeset books following classical design
and layout principles, with the express intention of encouraging the making of
beautiful books by anyone with access to a good printer and with an
inclination towards venerable crafts, e.g., bookbinding.  The @code{octavo}
class differs from the book class by implementing many of the proposals and
insights of respected experts, especially Jan Tschichold and Hugh Williamson.
The documentation discusses methods to organise and print out any text into
signatures, which can then be gathered, folded and sewn into a book.")
    (license license:lppl)))

(define-public texlive-odsfile
  (package
    (name "texlive-odsfile")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/odsfile/"
                                     "tex/lualatex/odsfile/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wkl7mj7adqwdw6g8hrmh6yq834rkk60fd2vpyrqq9l5az703cj6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/odsfile")
    (synopsis "Read OpenDocument Spreadsheet documents as LaTeX tables")
    (description
     "The distribution includes a package and a Lua library that can together
read OpenDocument spreadsheet documents as LaTeX tables.  Cells in the tables
may be processed by LaTeX macros, so that, for example, the package may be
used for drawing some plots.  The package uses Lua's @code{zip} library.")
    (license license:lppl1.3c)))

(define-public texlive-pdftexcmds
  (package
    (name "texlive-pdftexcmds")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pdftexcmds/"
                                     "source/generic/pdftexcmds/"
                                     "tex/generic/pdftexcmds/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gad1vi0r5xw7gyj1cb2cp58j4dqrw4awcfxmfrna9xbz91g4sn9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/pdftexcmds")
    (synopsis "LuaTeX support for pdfTeX utility functions")
    (description
     "This package makes a number of utility functions from pdfTeX
available for LuaTeX by reimplementing them using Lua.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-pdftexcmds texlive-pdftexcmds)

(define-public texlive-philokalia
  (package
    (name "texlive-philokalia")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/philokalia/"
                                     "fonts/opentype/public/philokalia/"
                                     "source/xelatex/philokalia/"
                                     "tex/xelatex/philokalia/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pcszddyyc4caqd1ahcl10rf1mn0m1lrdgn1gldv94cpa89653kg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/philokalia")
    (synopsis "Font to typeset the Philokalia Books")
    (description
     "The @code{philokalia} package has been designed to ease the use of the
Philokalia-Regular OpenType font with XeLaTeX.  The font started as a project
to digitize the typeface used to typeset the Philokalia books.")
    (license license:lppl1.3c)))

(define-public texlive-piechartmp
  (package
    (name "texlive-piechartmp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/piechartmp/"
                                     "metapost/piechartmp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xf83k85bwbdy4d1m23zyk5zjg9qw960q4rkgf2i1449w30gf3hp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/piechartmp")
    (synopsis "Draw pie-charts using MetaPost")
    (description
     "The @code{piechartmp} package is an easy way to draw pie-charts with
MetaPost.  The package implements an interface that enables users with little
MetaPost experience to draw charts.  A highlight of the package is the
possibility of suppressing some segments of the chart, thus creating the
possibility of several charts from the same data.")
    (license license:lppl)))

(define-public texlive-placeins
  (package
    (name "texlive-placeins")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/placeins/" "tex/latex/placeins/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0785ppjhf4x3by61mskwz289nzvbbw6iw7n0fq2dckgywjw3p2mz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/placeins")
    (synopsis "Control float placement")
    (description
     "This package defines a @code{\\FloatBarrier} command, beyond which
floats may not pass; useful, for example, to ensure all floats for a section
appear before the next @code{\\section} command.")
    (license license:public-domain)))

(define-public texlive-psfrag
  (package
    (name "texlive-psfrag")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/psfrag/"
                                     "dvips/psfrag/"
                                     "source/latex/psfrag/"
                                     "tex/latex/psfrag/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06vp5x6rnl4gqwxzzynbl169q23k8pmaxjhb0lbzdcm3ihvzp47z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/psfrag")
    (synopsis "Replace strings in encapsulated PostScript figures")
    (description
     "This package allows LaTeX constructions (equations, picture
environments, etc.) to be precisely superimposed over Encapsulated PostScript
figures, using your own favorite drawing tool to create an EPS figure and
placing simple text tags where each replacement is to be placed, with PSfrag
automatically removing these tags from the figure and replacing them with
a user specified LaTeX construction, properly aligned, scaled, and/or
rotated.")
    (license (license:fsf-free "file://psfrag.dtx"))))

(define-deprecated-package texlive-latex-psfrag texlive-psfrag)

(define-public texlive-psfrag-italian
  (package
    (name "texlive-psfrag-italian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/psfrag-italian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ssx8rw7fwln02zzscywivnhizgrb6w05awscvv9gf9n1qj6avsf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/psfrag-italian")
    (synopsis "PSfrag documentation in Italian")
    (description
     "This is a translation of the documentation that comes with the
@code{psfrag} package.")
    (license license:gpl3+)))

(define-public texlive-pstool
  (package
    (name "texlive-pstool")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pstool/" "tex/latex/pstool/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12clzcw2cl7g2chr2phgmmiwxw4859cln1gbx1wgp8bl9iw590nc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pstool")
    (synopsis "Support for @code{psfrag} within pdfLaTeX")
    (description
     "This is a package for processing PostScript graphics with @code{psfrag}
labels within pdfLaTeX documents.  Every graphic is compiled individually,
drastically speeding up compilation time when only a single figure needs
re-processing.")
    (license license:lppl1.3c)))

(define-deprecated-package texlive-latex-pstool texlive-pstool)

(define-public texlive-ptext
  (package
    (name "texlive-ptext")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/ptext/" "tex/xelatex/ptext/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ipb1mlg266rziznskdxi3iwi0s6374lp8ky0hhbi5llryg505p9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ptext")
    (synopsis "Lipsum for Persian")
    (description
     "The package provides lipsum-like facilities for the Persian language.
The source of the filling text is the Persian epic @emph{the Shanameh} (100
paragraphs are used).")
    (license license:lppl1.2+)))

(define-public texlive-realscripts
  (package
    (name "texlive-realscripts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/realscripts/"
                                     "source/latex/realscripts/"
                                     "tex/latex/realscripts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yk1v1ybd1zv1x6rc8qd2mbbwc5h91i44scnih6v2n5nrh61jfxb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/realscripts")
    (synopsis "Access OpenType subscript and superscript glyphs")
    (description
     "This package replaces @code{\\textsuperscript} and
@code{\\textsubscript} commands by equivalent commands that use OpenType font
features to access appropriate glyphs if possible.  It also patches LaTeX's
default footnote command to use this new @code{\\textsuperscript} for footnote
symbols.")
    (license license:lppl1.3+)))

(define-public texlive-refcount
  (package
    (name "texlive-refcount")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/refcount/" "source/latex/refcount/"
                                     "tex/latex/refcount/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "128cvwdl4wcdshvs59yn5iljdxxdrc5jircbxav77y7kc3l33z7z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/refcount")
    (synopsis "Counter operations with label references")
    (description
     "This package provides the @code{\\setcounterref} and
@code{\\addtocounterref} commands which use the section (or other) number
from the reference as the value to put into the counter.  It also provides
@code{\\setcounterpageref} and @code{\\addtocounterpageref} that do the
corresponding thing with the page reference of the label.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-refcount texlive-refcount)

(define-public texlive-repere
  (package
    (name "texlive-repere")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/repere/" "metapost/repere/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bxhx0vfmsb6yzx19a4b7hwwxkwkxj36iyr6zvw1f1wra6aqky7y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/repere")
    (synopsis "MetaPost macros for secondary school mathematics teachers")
    (description
     "This package provides MetaPost macros for drawing secondary school
mathematics figures in a coordinate system: axis, grids points, vectors
functions (curves, tangents, integrals, sequences) statistic diagrams plane
geometry (polygons, circles), arrays and game boards.")
    (license license:lppl1.3c)))

(define-public texlive-revtex
  (package
    (name "texlive-revtex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/revtex/" "doc/latex/revtex/"
                                     "source/latex/revtex/" "tex/latex/revtex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12s8cm8717h0a6dx14zcnghxvlqiag9v5y42hdvhm2rcvjipspjx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/revtex")
    (synopsis "Styles for various Physics Journals")
    (description
     "This package includes styles for American Physical Society, American
Institute of Physics, and Optical Society of America.  The distribution
consists of the RevTeX class itself, and several support packages.")
    (license license:lppl1.3c)))

(define-public texlive-roex
  (package
    (name "texlive-roex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "metafont/roex/" "source/metafont/roex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12w5wrrlk8rd4gx57646r01rb49ckmgnzhmx9385ll0sag8c9s2v"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mf-ps")
    (synopsis "Metafont-PostScript conversions")
    (description
     "This package provides a Metafont support package including: @code{epstomf},
a tiny AWK script for converting EPS files into Metafont; @code{mftoeps} for
generating (encapsulated) PostScript files readable, e.g., by CorelDRAW, Adobe
Illustrator and Fontographer; a collection of routines (in folder progs) for
converting Metafont-coded graphics into encapsulated PostScript; and
@code{roex.mf}, which provides Metafont macros for removing overlaps and
expanding strokes.  In @code{mftoeps}, Metafont writes PostScript code to
a log-file, from which it may be extracted by either TeX or AWK.")
    (license license:public-domain)))

(define-public texlive-roundrect
  (package
    (name "texlive-roundrect")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/roundrect/"
                                     "metapost/roundrect/"
                                     "source/metapost/roundrect/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bx6xfr49rrcrnbyw917fab2qi0x29h66ip4nyhw6477815ic0wq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/roundrect")
    (synopsis "MetaPost macros for configurable rounded rectangles")
    (description
     "The @code{roundrect} macros for MetaPost provide ways to produce rounded
rectangles, which may or may not contain a title bar or text (the title bar
may itself contain text).")
    (license license:lppl1.3+)))

(define-public texlive-sauerj
  (package
    (name "texlive-sauerj")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sauerj/" "source/latex/sauerj/"
                                     "tex/latex/sauerj/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03dmw150qcravzndikijhq2a89sjdplxgi93fx0zxln2l4flvz5k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sauerj")
    (synopsis "Bundle of utilities by Jonathan Sauer")
    (description
     "The bundle consists of:
@itemize
@item a tool for collecting text for later re-use,
@item a tool for typesetting the meta-information within a text,
@item a tool for use in constructing macros with multiple optional parameters,
@item a package for multiple column parallel texts,
@item a tool for processing key-value structured lists,
@item macros for typesetting a number as a German-language string.
@end itemize")
    (license license:lppl)))

(define-public texlive-sauter
  (package
    (name "texlive-sauter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "fonts/source/public/sauter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "037skfr46198y0vczwcy6dzq9ry8w5imj1ih9nfy9mrb0hmj8caq"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sauter")
    (synopsis "Wide range of design sizes for CM fonts")
    (description
     "This package includes extensions, originally to the CM fonts, providing
a parameterization scheme to build Metafont fonts at true design sizes, for
a large range of sizes.  The scheme has now been extended to a range of other
fonts, including the AMS fonts, @code{bbm}, @code{bbold}, @code{rsfs} and
@code{wasy} fonts.")
    (license license:gpl3+)))

(define-public texlive-selinput
  (package
    (name "texlive-selinput")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/selinput/" "source/latex/selinput/"
                                     "tex/latex/selinput/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0x8l98r6xzyi4lc909bv7ii2nbpff8j7j3q4z86l7rrjk1jkx9qi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/selinput")
    (synopsis "Semi-automatic detection of input encoding")
    (description
     "This package selects the input encoding by specifying pairs of input
characters and their glyph names.")
    (license license:lppl1.3+)))

(define-public texlive-semaphor
  (package
    (name "texlive-semaphor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/semaphor/"
                                     "fonts/afm/public/semaphor/"
                                     "fonts/enc/dvips/semaphor/"
                                     "fonts/map/dvips/semaphor/"
                                     "fonts/opentype/public/semaphor/"
                                     "fonts/source/public/semaphor/"
                                     "fonts/tfm/public/semaphor/"
                                     "fonts/type1/public/semaphor/"
                                     "tex/context/third/semaphor/"
                                     "tex/latex/semaphor/"
                                     "tex/plain/semaphor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yigah8x75fd13x0f6ncpp21ly75nyfz6h5y5sfc590n7wcm0gvr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/semaphor")
    (synopsis "Semaphore alphabet font")
    (description
     "These fonts represent semaphore in a highly schematic, but very clear,
fashion.  The fonts are provided as Metafont source, and in both OpenType and
Adobe Type 1 formats.")
    (license license:gpl3+)))

(define-public texlive-seminar
  (package
    (name "texlive-seminar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/seminar/" "tex/latex/seminar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xm78f9qsy3zr1vllb8mgp1azhn7a2jaqkj2lkrsgc3m7ag9w9hh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/seminar")
    (synopsis "Make overhead slides")
    (description
     "This package provides a class that produces overhead
slides (transparencies), with many facilities.  Seminar is not nowadays
reckoned a good basis for a presentation — users are advised to use more
recent classes such as @code{powerdot} or @code{beamer}, both of which are
tuned to 21st-century presentation styles.")
    (license license:lppl1.2+)))

(define-deprecated-package texlive-latex-seminar texlive-seminar)

(define-public texlive-sepnum
  (package
    (name "texlive-sepnum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sepnum/" "tex/latex/sepnum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vzjhb470imd1f5wlj32jysn825vyygq9xkscqdjaa9jby70a26x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sepnum")
    (synopsis "Print numbers in a friendly format")
    (description
     "This package provides a command to print a number with (potentially
different) separators every three digits in the parts either side of the
decimal point (the point itself is also configurable).  The macro is fully
expandable and not fragile (unless one of the separators is).  There is also
a command @code{\\sepnumform}, that may be used when defining
@samp{\\the<counter> macros}.")
    (license license:lppl)))

(define-public texlive-seqsplit
  (package
    (name "texlive-seqsplit")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/seqsplit/"
                                     "source/latex/seqsplit/"
                                     "tex/latex/seqsplit/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0x6xcism9s9mhpr278xi4c1gimz3mlqnrpr40vkx5abglr0gzm0j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/seqsplit")
    (synopsis "Split long sequences of characters in a neutral way")
    (description
     "@code{seqsplit} provides a command @code{\\seqsplit}, which makes its
argument splittable anywhere, and then leaves the TeX paragraph-maker to do the
splitting.  The package is suitable for situations when one needs to type long
sequences of letters or of numbers in which there is no obvious break points to
be found, such as in base-sequences in genes or calculations of transcendental
numbers.  While the package may obviously be used to typeset DNA sequences, the
user may consider the @code{dnaseq} as a rather more powerful alternative.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-seqsplit texlive-seqsplit)

(define-public texlive-shapes
  (package
    (name "texlive-shapes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/shapes/" "metapost/shapes/"
                                     "source/metapost/shapes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q93ycxjzmvp73z92rc7vlzvmijbj2w1ldq709r9jflk044lsrh2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/shapes")
    (synopsis "Draw polygons, reentrant stars, and fractions in circles")
    (description
     "The shapes set of macros allows drawing regular polygons; their
corresponding reentrant stars in all their variations; and fractionally filled
circles (useful for visually demonstrating the nature of fractions) in
MetaPost.")
    (license license:lppl1.3+)))

(define-public texlive-short-math-guide
  (package
    (name "texlive-short-math-guide")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/short-math-guide/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wjcjgw0xk4zx57f364cpl57qpxj3lq4lahlkbk6iiin1h9v2prf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/short-math-guide")
    (synopsis "Guide to typeset mathematical notation with LaTeX")
    (description
     "@emph{The Short Math Guide} is intended to be a concise introduction to
the use of the facilities provided by @code{amsmath} and various other LaTeX
packages for typesetting mathematical notation.  Originally created by Michael
Downes of the American Mathematical Society based only on @code{amsmath}, it
has been brought up to date with references to related packages and other
useful information.")
    (license license:lppl1.3c)))

(define-public texlive-showexpl
  (package
    (name "texlive-showexpl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/showexpl/" "source/latex/showexpl/"
                                     "tex/latex/showexpl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vff1yk7a3f4csxibfk6r37s3h6n4wdpnk3qj4dsx7kh5zrcysha"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/showexpl")
    (synopsis "Typesetting LaTeX source code")
    (description
     "This package provides a way to typeset LaTeX source code and the related
result in the same document.")
    (license license:lppl1.2+)))

(define-public texlive-simple-resume-cv
  (package
    (name "texlive-simple-resume-cv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/simple-resume-cv/"
                                     "tex/xelatex/simple-resume-cv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07lqmjfjr58q7jgl59syv67hsy54rsig9f002wkwr1297z02k862"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/simple-resume-cv")
    (synopsis "Template for a simple resume or curriculum vitae (CV)")
    (description
     "This package provides a template for a simple resume or curriculum
vitae (CV), in XeLaTeX.  This simple template can be further customized or
extended, with numerous examples.")
    (license license:public-domain)))

(define-public texlive-simple-thesis-dissertation
  (package
    (name "texlive-simple-thesis-dissertation")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list
                                "doc/xelatex/simple-thesis-dissertation/"
                                "tex/xelatex/simple-thesis-dissertation/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ikxsh8br03lz17z6pd6y5gw9y7bw9zyhnh646cmd28i6p1ryi4i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/simple-thesis-dissertation")
    (synopsis "Template for a simple thesis, dissertation, or technical report")
    (description
     "This package provides a template for a simple thesis or dissertation or
technical report, in XeLaTeX.  This simple template that can be further
customized or extended, with numerous examples.")
    (license license:public-domain)))

(define-public texlive-simplified-latex
  (package
    (name "texlive-simplified-latex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/simplified-latex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cgf1p7p2ikda1nb0c2vhhx7ai6rd973pz6a00pr9yanxsvghp6d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/simplified-latex")
    (synopsis "Simplified introduction to LaTeX")
    (description
     "This package provides an accessible introduction to LaTeX for the
beginner.")
    (license license:lppl)))

(define-public texlive-slideshow
  (package
    (name "texlive-slideshow")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/slideshow/"
                                     "metapost/slideshow/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07r58whn61nyxj0cldzf9bbwhh0kc72d6708ldf03q7sbf5zi37s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/slideshow")
    (synopsis "Generate slideshow with MetaPost")
    (description
     "The package provides a means of creating presentations in MetaPost,
without intervention from other utilities (except a distiller).")
    (license (license:fsf-free "file://metapost/slideshow/slideshow.mp"))))

(define-public texlive-splines
  (package
    (name "texlive-splines")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/splines/" "metapost/splines/"
                                     "source/metapost/splines/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15pvr4vl5whcrij6gq3al5jaqrshvm2qybvxq7qx0gdxzfsli38z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/splines")
    (synopsis "MetaPost macros for drawing cubic spline interpolants")
    (description
     "This is a small package of macros for creating cubic spline interpolants
in MetaPost or Metafont.  Given a list of points the macros can produce
a closed or a relaxed spline joining them.")
    (license license:lppl1.3+)))

(define-public texlive-stackengine
  (package
    (name "texlive-stackengine")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/stackengine/"
                                     "tex/latex/stackengine/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c12ygqxdb6vn1y03jzcjpmdp53r076hq3hgjzwy2ch1dw81cnpd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-listofitems))
    (home-page "https://ctan.org/pkg/stackengine")
    (synopsis "Customised stacking of objects")
    (description
     "The package provides a versatile way to stack objects vertically in a
variety of customizable ways.  A number of useful macros are provided, all
of which make use of the @code{stackengine} core.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-stackengine texlive-stackengine)

(define-public texlive-suanpan
  (package
    (name "texlive-suanpan")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/suanpan/" "metapost/suanpan/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ddhk8d98bc4l2xbx5w6kaynl4n125nnv4hadfp5s19vwcc6slqv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/suanpan")
    (synopsis "MetaPost macros for drawing Chinese and Japanese abaci")
    (description
     "The package provides macros for drawing Chinese and Japanese abaci.")
    (license license:lppl)))

(define-public texlive-synctex
  (package
    (name "texlive-synctex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/synctex.1"
                                     "doc/man/man1/synctex.man1.pdf"
                                     "doc/man/man5/synctex.5"
                                     "doc/man/man5/synctex.man5.pdf"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a2nlmbib8723jjhf6xxh5rpmnd5jv3cd69br4ihchbq5ipzircp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/synctex")
    (synopsis "Engine-level feature synchronizing output and source")
    (description
     "SyncTeX allows navigating between the TeX source and (usually PDF)
output, in both directions, given a SyncTeX-aware front end.  It is compiled
into most engines and can be enabled with the @samp{--synctex=1} option.")
    (license license:expat)))

(define-public texlive-tetragonos
  (package
    (name "texlive-tetragonos")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/tetragonos/"
                                     "tex/xelatex/tetragonos/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "191727d2craai25847i2xfzlm04852afvrwdjsk3jjss46a43ixn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tetragonos")
    (synopsis "Four-Corner codes of Chinese characters")
    (description
     "This is a XeLaTeX package for mapping Chinese characters to their codes
in the Four-Corner method.")
    (license license:lppl1.3c)))

(define-public texlive-threeddice
  (package
    (name "texlive-threeddice")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/threeddice/"
                                     "metapost/threeddice/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sj4f3bbxjzwbncxlvlbmsnfi7jkf5625gwhbqfh399vlh0nb56j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/threeddice")
    (synopsis "Create images of dice with one, two, or three faces showing")
    (description
     "The package provides MetaPost code to create all possible symmetrical
views (up to rotation) of a right-handed die.")
    (license license:lppl)))

(define-public texlive-textpath
  (package
    (name "texlive-textpath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/textpath/"
                                     "metapost/textpath/" "tex/latex/textpath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07g7n0hjsvsk0cibprpqid43vvljjzagap07zbp2kirkiv7yq3k0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/textpath")
    (synopsis "Setting text along a path with MetaPost")
    (description
     "This MetaPost package provides macros to typeset text along a free path
with the help of LaTeX, thereby preserving kerning and allowing for 8-bit
input (accented characters).")
    (license license:lppl)))

(define-public texlive-tocloft
  (package
    (name "texlive-tocloft")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tocloft/"
                                     "source/latex/tocloft/"
                                     "tex/latex/tocloft/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1s09g02pq2zi5ywm3yhyp4lpzq77n9aahr6wnm1c0wb9zawq2mpk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/tocloft")
    (synopsis "Control table of contents")
    (description
     "This package provides control over the typography of the @dfn{Table of
Contents}, @dfn{List of Figures} and @dfn{List of Tables}, and the ability to
create new @samp{List of ...}.  The ToC @code{\\parskip} may be changed.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-tocloft texlive-tocloft)

(define-public texlive-tocvsec2
  (package
    (name "texlive-tocvsec2")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tocvsec2/"
                                     "source/latex/tocvsec2/"
                                     "tex/latex/tocvsec2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ybw8dra074pbl9l0ilp13naz73mgb57agy79bvmrb7v2r8a6zm7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tocvsec2")
    (synopsis "Section numbering and table of contents control")
    (description
     "This package provides control over section numbering (without recourse
to starred sectional commands) and the entries in the table of contents on
a section by section basis.")
    (license license:lppl1.3+)))

(define-public texlive-transparent
  (package
    (name "texlive-transparent")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/transparent/"
                                     "source/latex/transparent/"
                                     "tex/latex/transparent/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "161lfx6yv8qgk76lz0j375swrk6012djay3sjxggrsx7l92qjvhd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/transparent")
    (synopsis "Using a color stack for transparency with pdfTeX")
    (description
     "This package shows how a separate color stack can be used for
transparency, a property besides color that works across page breaks.  If the
PDF management is used it can also be used with other engines, but without
support for page breaks.")
    (license license:lppl1.3c)))

(define-public texlive-trimspaces
  (package
    (name "texlive-trimspaces")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/trimspaces/"
                                     "source/latex/trimspaces/"
                                     "tex/latex/trimspaces/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0if7pqaib533fbrj9r62mmr4h012hrpszdxs759rwhmyycikg6dk"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-filecontents")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:tex-format "latex"
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'fix-bug
            (lambda _
              ;; The "ins" file refers to the wrong source file.
              (substitute* "source/latex/trimspaces/trimspaces.ins"
                (("pstool\\.tex") "trimspaces.tex")))))))
    (native-inputs (list texlive-filecontents))
    (home-page "https://ctan.org/pkg/trimspaces")
    (synopsis "Trim spaces around an argument or within a macro")
    (description
     "This package provides a very short package that allows you to expandably
remove spaces around a token list (commands are provided to remove spaces
before, spaces after, or both); or to remove surrounding spaces within a macro
definition, or to define space-stripped macros.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-trimspaces texlive-trimspaces)

(define-public texlive-tufte-latex
  (package
    (name "texlive-tufte-latex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/tufte-latex/"
                                     "doc/latex/tufte-latex/"
                                     "tex/latex/tufte-latex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16jqf8assirdj769rajrdb70w8rc0kyj0q07bs6v13kfil5h0bdp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-changepage
           texlive-ifmtarg
           texlive-paralist
           texlive-placeins
           texlive-sauerj
           texlive-xifthen))
    (home-page "https://ctan.org/pkg/tufte-latex")
    (synopsis "Document classes inspired by the work of Edward Tufte")
    (description
     "This package provides two classes inspired, respectively, by handouts
and books created by Edward Tufte.")
    (license license:asl2.0)))

(define-public texlive-turkmen
  (package
    (name "texlive-turkmen")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/turkmen/" "source/latex/turkmen/"
                                     "tex/latex/turkmen/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jgz9vkqpp853pxvhknafrwpl41h04j7fr1gfjrzqzcrdq7d855i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/turkmen")
    (synopsis "Babel support for Turkmen")
    (description
     "The package provides support for Turkmen in Babel, but integration with
Babel is not available.")
    (license license:lppl)))

(define-public texlive-ucharclasses
  (package
    (name "texlive-ucharclasses")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/ucharclasses/"
                                     "tex/xelatex/ucharclasses/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pgzs730zqmcck693i7fq771p7szq6nqdxb9w8dy6l2b4zdql14m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ucharclasses")
    (synopsis "Font actions in XeTeX according to what is being processed")
    (description
     "The package takes care of switching fonts when you switch from one
Unicode block to another in the text of a document.  This way, you can write
a document with no explicit font selection, but a series of rules of the form
``when entering block ..., switch font to use ...''.")
    (license license:public-domain)))

(define-public texlive-undolabl
  (package
    (name "texlive-undolabl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/undolabl/"
                                     "source/latex/undolabl/"
                                     "tex/latex/undolabl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pa1m610j46623wm59inxmaqpjhd9cfmbwmyh02pbmpqid47p9l1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/undolabl")
    (synopsis "Override existing labels")
    (description
     "The package allows the user to override existing labels (for example,
those generated automatically).")
    (license license:lppl1.3+)))

(define-public texlive-unicode-bidi
  (package
    (name "texlive-unicode-bidi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/unicode-bidi/"
                                     "tex/xelatex/unicode-bidi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0anwaaf21qcdgni9z85hqap1wb4y9pv13p96x13w29hbqizmf69l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/unicode-bidi")
    (synopsis "Experimental Unicode Bidi package for XeTeX")
    (description
     "The experimental Unicode-Bidi package allows mixing non-RTL script with
RTL script without any markup.")
    (license license:lppl1.3+)))

(define-public texlive-unimath-plain-xetex
  (package
    (name "texlive-unimath-plain-xetex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xetex/unimath-plain-xetex/"
                                     "fonts/misc/xetex/fontmapping/unimath-plain-xetex/"
                                     "tex/xetex/unimath-plain-xetex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vqnqfklg1mj7mipgrfng0qq1i9psiqri0yh30ixrz8j6mkaqb35"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/unimath-plain-xetex")
    (synopsis "OpenType math support in (plain) XeTeX")
    (description
     "This package provides OpenType math font support in plain TeX format.
It only works with the XeTeX engine.")
    (license license:lppl1.3c)))

(define-public texlive-unisugar
  (package
    (name "texlive-unisugar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/unisugar/"
                                     "tex/xelatex/unisugar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bn88ghfn14am1grph1pjw9k0xy1rz8swzhsbxsxyzz6cqk9s161"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/unisugar")
    (synopsis "Define syntactic sugar for Unicode LaTeX")
    (description
     "The package allows the user to define shorthand aliases for single
Unicode characters, and also provides support for such aliases in RTL-text.
The package requires an TeX-alike system that uses Unicode input in a native
way: current examples are XeTeX and LuaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-xebaposter
  (package
    (name "texlive-xebaposter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xebaposter/"
                                     "tex/latex/xebaposter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18fnwfhfk3jzkp4yd0dfi49jnf8njccbhhd6k15pvghs4brd9hba"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xebaposter")
    (synopsis "Create scientific Persian/Latin posters using TikZ")
    (description
     "This package is designed for making scientific Persian/Latin posters.
It is a fork of @code{baposter} by Brian Amberg and Reinhold Kainhofer.")
    (license license:lppl1.3+)))

(define-public texlive-xechangebar
  (package
    (name "texlive-xechangebar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/xechangebar/"
                                     "tex/xelatex/xechangebar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a7b9bffh5b435gw4qxydmfrpizly79cjgjhhlgywwg6gibvxn4s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xechangebar")
    (synopsis "Extension of package @code{changebar} for use with XeLaTeX")
    (description
     "The package extends package @code{changebar} so it can be used with
XeLaTeX.  It introduces the new option @code{xetex} for use with XeLaTeX.
Everything else remains the same and users should consult the original
documentation for usage information.")
    (license license:lppl1.3+)))

(define-public texlive-xecolor
  (package
    (name "texlive-xecolor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/xecolor/"
                                     "tex/xelatex/xecolor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0adzg2j1lmclr5zcs8da3m1b9q5xs50rxga6k2pzzxy2x0nh1xpi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xecolor")
    (synopsis "Support for color in XeLaTeX")
    (description
     "This is a simple package which defines about 140 different colours using
XeTeX's colour feature.  The colours can be used in bidirectional texts
without any problem.")
    (license license:lppl1.3+)))

(define-public texlive-xecyr
  (package
    (name "texlive-xecyr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/xecyr/" "tex/xelatex/xecyr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07qvxfnwha6iqzcv84ws074jdi8jn60h42l93jn037n3zj2qxkg8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xecyr")
    (synopsis "Using Cyrillic languages in XeTeX")
    (description
     "This package provides helper tools for using Cyrillic languages with
XeLaTeX and @code{babel}.")
    (license license:lppl1.3+)))

(define-public texlive-xeindex
  (package
    (name "texlive-xeindex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/xeindex/"
                                     "tex/xelatex/xeindex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sps9lrzm9y2rrin5pkgzyk56c77xnydvp21ljmvsimqgafr5aqb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xeindex")
    (synopsis "Automatic index generation for XeLaTeX")
    (description
     "The package is based on XeSearch, and will automatically index words or
phrases in an XeLaTeX document.  Words are declared in a list, and every
occurrence then creates an index entry whose content can be fully specified
beforehand.")
    (license license:lppl)))

(define-public texlive-xesearch
  (package
    (name "texlive-xesearch")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xetex/xesearch/" "tex/xetex/xesearch/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13fdllqswyyvvyjqn0a4ld18dixxnn7zlpagsdaq8cl1svpaxpk5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xesearch")
    (synopsis "String finder for XeTeX")
    (description
     "The package finds strings (e.g., parts of words or phrases) and
manipulates them, thus turning each word or phrase into a possible command.
It is written in plain XeTeX and should thus work with any format.  The main
application for the moment is XeIndex, an automatic index for XeLaTeX, but
examples are given of simple use to check spelling, count words, and highlight
syntax of programming languages.")
    (license license:lppl)))

(define-public texlive-xespotcolor
  (package
    (name "texlive-xespotcolor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/xespotcolor/"
                                     "source/xelatex/xespotcolor/"
                                     "tex/xelatex/xespotcolor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pqv4y2idcazwdy94ryyrk5s2g66sb7liy9hypqaq69symn8myf7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xespotcolor")
    (synopsis "Spot colours support for XeLaTeX")
    (description
     "The package provides macros for using spot colours in LaTeX documents.
The package is a reimplementation of the @code{spotcolor} package for use with
XeLaTeX.  As such, it has the same user interface and the same capabilities.")
    (license license:lppl1.3c)))

(define-public texlive-xetex-devanagari
  (package
    (name "texlive-xetex-devanagari")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xetex/xetex-devanagari/"
                                     "fonts/misc/xetex/fontmapping/xetex-devanagari/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17br9aq1af36wadq2cmndbb0z2jdhr1mn7jdb3cq642wwngcfi13"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xetex-devanagari")
    (synopsis "XeTeX input map for Unicode Devanagari")
    (description
     "The package provides a map for use with Jonathan Kew's TECkit, to
translate Devanagari (encoded according to the Harvard/Kyoto convention) to
Unicode (range 0900-097F).")
    (license license:lppl)))

(define-public texlive-xetex-itrans
  (package
    (name "texlive-xetex-itrans")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/xetex-itrans/"
                                     "fonts/misc/xetex/fontmapping/xetex-itrans/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1chx2s0p6y5p767cr23jh9x61axjrdnyc5lcvf7kyrg74cszsmql"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xetex-itrans")
    (synopsis "Itrans input maps for use with XeLaTeX")
    (description
     "The package provides maps for use with XeLaTeX with coding done using
@code{itrans}.  Fontspec maps are provided for Devanagari (Sanskrit), for
Sanskrit in Kannada and for Kannada itself.")
    (license license:lppl1.3+)))

(define-public texlive-xetex-pstricks
  (package
    (name "texlive-xetex-pstricks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xetex/xetex-pstricks/"
                                     "tex/xelatex/xetex-pstricks/"
                                     "tex/xetex/xetex-pstricks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "195zjdxddlwl69gnp2x3jg3l8gn36mxsdbz03qs0r940frx533ls"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xetex-pstricks")
    (synopsis "Running PSTricks under XeTeX")
    (description
     "The package provides an indirection scheme for XeTeX to use the PSTricks
@file{xdvipdfmx.cfg} configuration file, so that XeTeX documents will load it
in preference to the standard pstricks.con configuration file.  With this
configuration, many PSTricks features can be used in XeLaTeX or plain XeTeX
documents.")
    (license license:public-domain)))

(define-public texlive-xetex-tibetan
  (package
    (name "texlive-xetex-tibetan")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xetex/xetex-tibetan/"
                                     "fonts/misc/xetex/fontmapping/xetex-tibetan/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02z3jzf16hi9zj50lpf9map5f6ydvxw66f0k4n5ry88s7frbxwmw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xetex-tibetan")
    (synopsis "XeTeX input maps for Unicode Tibetan")
    (description
     "The package provides a map for use with Jonathan Kew's TECkit, to
translate Tibetan to Unicode (range 0F00-0FFF).")
    (license license:lppl)))

(define-public texlive-xetexfontinfo
  (package
    (name "texlive-xetexfontinfo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xetex/xetexfontinfo/"
                                     "tex/xetex/xetexfontinfo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0x1llikcvwlf74anmvaks73gvd99xha9dg49zh75dwki0nwisn2j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xetexfontinfo")
    (synopsis "Report font features in XeTeX")
    (description
     "This package provides a pair of documents to reveal the font features
supported by fonts usable in XeTeX.")
    (license license:asl2.0)))

(define-public texlive-xetexko
  (package
    (name "texlive-xetexko")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xetex/xetexko/" "tex/xetex/xetexko/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1d3jmk40a05yah0viyi2xnqjwjmmfyhv9i1a0xcly2wjyr9c6dzx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xetexko")
    (synopsis "Typeset Korean with Xe(La)TeX")
    (description
     "The package supports typesetting Korean documents (including old Hangul
texts), using XeTeX.  It enhances the existing support, in XeTeX, providing
features that provide quality typesetting.")
    (license license:lppl1.3c)))

(define-public texlive-xetexref
  (package
    (name "texlive-xetexref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xetex/xetexref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m2cf5l7q8djsifz3xj4s99ad6j7xxfndvm9v7h6cg3jxv083yrg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xetexref")
    (synopsis "Reference documentation of XeTeX")
    (description
     "The package comprises reference documentation for XeTeX detailing its
extended features.")
    (license license:lppl1.3c)))

(define-public texlive-xevlna
  (package
    (name "texlive-xevlna")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/xevlna/" "tex/xelatex/xevlna/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gwh1rd5s01rnb11nxk6nxwyqj32bi739p10hwqz3sw1hfy8mnfi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xevlna")
    (synopsis "Insert non-breakable spaces using XeTeX")
    (description
     "The package will directly insert nonbreakable spaces (in Czech, vlna or
vlnka), after nonsyllabic prepositions and single letter conjuctions, while
the document is being typeset.")
    (license license:lppl1.3+)))

(define-public texlive-currfile
  (package
    (name "texlive-currfile")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/currfile/" "source/latex/currfile/"
                                     "tex/latex/currfile/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0g28y2bwqnc3xfcp0ak7rxx0c40b88vl85pj7x5dccmvx0yrxy9n"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ydoc")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ydoc))
    (home-page "https://ctan.org/pkg/currfile")
    (synopsis "Provide file name and path of input files")
    (description
     "The package provides macros holding file name information (directory,
base name, extension, full name and full path) for files read by LaTeX
@code{\\input} and @code{\\include} macros; it uses the file hooks provided by
the author's @code{filehook}.  In particular, it restores the parent file name
after the trailing @code{\\clearpage} of an @code{\\included} file; as
a result, the macros may be usefully employed in the page header and footer of
the last printed page of such a file.  The depth of inclusion is made
available, together with the parent (including file) and parents (all
including files to the root of the tree).  The package supersedes FiNK.")
    (license license:lppl1.3+)))

(define-public texlive-cursolatex
  (package
    (name "texlive-cursolatex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cursolatex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "048s5fg8c19s3zbl2dkmh8ffkicb8fd9n46m0iqrc39i0wrh7p12"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cursolatex")
    (synopsis "LaTeX tutorial, in Portuguese")
    (description
     "This package provides a LaTeX tutorial, in Portuguese.  The tutorial is
presented as a set of slides.")
    (license license:gpl3+)))

(define-public texlive-calrsfs
  (package
    (name "texlive-calrsfs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/calrsfs/" "tex/latex/calrsfs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0aqa0k0zzzicx5nynd29i9pdb7a4j6fvf1xwrbm4qg64pl55i6xa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/calrsfs")
    (synopsis "Copperplate calligraphic letters in LaTeX")
    (description "This package provides a maths interface to the @code{rsfs}
fonts.")
    (license license:public-domain)))

(define-public texlive-capt-of
  (package
    (name "texlive-capt-of")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/capt-of/" "source/latex/capt-of/"
                                     "tex/latex/capt-of/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bf0cdd9ca3kkqxqqkq6jalh5ybs60l80l5gfkl2whk2v4bnzfvz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/capt-of")
    (synopsis "Captions on more than floats")
    (description
     "This package defines a command @code{\\captionof} for putting a caption
to something that's not a float.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-capt-of texlive-capt-of)

(define-public texlive-carlisle
  (package
    (name "texlive-carlisle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/carlisle/" "source/latex/carlisle/"
                                     "tex/latex/carlisle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kgbs8k6ma3kng2srwpzkla1c51ylzgb7yn8bib2zy46rmysrk86"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/carlisle")
    (synopsis "David Carlisle's small packages")
    (description
     "Many of David Carlisle's more substantial packages stand on their own,
or as part of the LaTeX latex-tools set; this set contains: making dotless
@emph{j} characters for fonts that don't have them; a method for combining the
capabilities of @code{longtable} and @code{tabularx}; an environment for
including plain TeX in LaTeX documents; a jiffy to create slashed characters
for physicists.")
    (license license:lppl)))

(define-public texlive-catchfile
  (package
    (name "texlive-catchfile")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/catchfile/" "source/latex/catchfile/"
                                     "tex/generic/catchfile/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dpxy64hs0bjp8d2dmikflc995vazf7fi6z92w51fnj2fidgl8gx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/macros/latex/contrib/catchfile")
    (synopsis "Catch an external file into a macro")
    (description
     "Catchfile catches the contents of a file and puts it in a macro.")
    (license license:lppl1.3+)))

(define-public texlive-ddphonism
  (package
    (name "texlive-ddphonism")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ddphonism/" "tex/latex/ddphonism/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p02ai76nnh6042pnmqv4n30z6yxsvyyk2nb9jk7xlyyc87zzbdd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ddphonism")
    (synopsis "Dodecaphonic diagrams for LaTeX")
    (description
     "This is a music-related package which is focused on notation from the
twelve-tone system, also called dodecaphonism.  It provides LaTeX algorithms
that produce typical dodecaphonic notation based off a musical series, or row
sequence, of variable length.")
    (license license:lppl1.3c)))

(define-public texlive-doi
  (package
    (name "texlive-doi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/doi/" "tex/latex/doi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18z9922lqb3hliqn95h883fndqs4lgyi5yqbnq2932ya0imc3j7h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/doi")
    (synopsis "Create correct hyperlinks for DOI numbers")
    (description
     "You can hyperlink DOI numbers to doi.org.  However, some publishers have
elected to use nasty characters in their DOI numbering scheme (@code{<},
@code{>}, @code{_} and @code{;} have all been spotted).  This will either
upset LaTeX, or your PDF reader.  This package contains a single user-level
command @code{\\doi{}}, which takes a DOI number, and creates a correct
hyperlink to the target of the DOI.")
    ;; Any version of the LPPL.
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-doi texlive-doi)

(define-public texlive-etoolbox
  (package
    (name "texlive-etoolbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/etoolbox/" "tex/latex/etoolbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "070iaj540rglf0c80l0hjkwg6aa7qyskhh4iwyhf7n8vrg5cjjab"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/etoolbox")
    (synopsis "e-TeX tools for LaTeX")
    (description
     "The package is a toolbox of programming facilities geared primarily
towards LaTeX class and package authors.  It provides LaTeX frontends to some
of the new primitives provided by e-TeX as well as some generic tools which
are not strictly related to e-TeX but match the profile of this package.  The
package provides functions that seem to offer alternative ways of implementing
some LaTeX kernel commands; nevertheless, the package will not modify any part
of the LaTeX kernel.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-etoolbox texlive-etoolbox)

(define-public texlive-fncychap
  (package
    (name "texlive-fncychap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fncychap/"
                                     "tex/latex/fncychap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1javlws18ncrf7rz7qfbx1db9jwk45lm6sa0s67hlr6hqnyjxf94"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fncychap")
    (synopsis "Seven predefined chapter heading styles")
    (description
     "This package provides seven predefined chapter heading styles.  Each
style can be modified using a set of simple commands.  Optionally one can
modify the formatting routines in order to create additional chapter
headings.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-fncychap texlive-fncychap)

(define-public texlive-framed
  (package
    (name "texlive-framed")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/framed/"
                                     "tex/latex/framed/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09hlzjlhz3q3l62h6gj997pfx1hc4726frhcdc6y5g66c3gh621g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/framed")
    (synopsis "Framed or shaded regions that can break across pages")
    (description
     "The package creates three environments: @code{framed}, which puts an
ordinary frame box around the region, @code{shaded}, which shades the region,
and @code{leftbar}, which places a line at the left side.  The environments
allow a break at their start (the @code{\\FrameCommand} enables creation of
a title that is “attached” to the environment); breaks are also allowed in the
course of the framed/shaded matter.  There is also a command
@code{\\MakeFramed} to make your own framed-style environments.")
    ;; The header states: "These macros may be freely transmitted, reproduced,
    ;; or modified for any purpose provided that this notice is left intact."
    (license (license:fsf-free "file://framed.sty"))))

(define-deprecated-package texlive-latex-framed texlive-framed)

(define-public texlive-g-brief
  (package
    (name "texlive-g-brief")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/g-brief/"
                                     "source/latex/g-brief/"
                                     "tex/latex/g-brief/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sicgf3wjw5jymh5xjxby2hsilakhw2lqgywx0f2zax1z854xc2m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/g-brief")
    (synopsis "Letter document class")
    (description
     "This package is designed for formatting formless letters in German; it
can also be used for English (by those who can read the documentation).  There
are LaTeX 2.09 @code{documentstyle} and LaTeX 2e class files for both an old
and a new version of @code{g-brief}.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-g-brief texlive-g-brief)

(define-public texlive-galois
  (package
    (name "texlive-galois")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/galois/"
                                     "source/latex/galois/"
                                     "tex/latex/galois/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1324nw1r1aj6khz6fvrhd1p1sinadrd83j0s2q2fhnsgwp6sw94f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/galois")
    (synopsis "Typeset Galois connections")
    (description
     "The package deals with connections in two-dimensional style, optionally
in colour.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-galois texlive-galois)

(define-public texlive-gcite
  (package
    (name "texlive-gcite")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gcite/"
                                     "source/latex/gcite/"
                                     "tex/latex/gcite/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yb7sid13bx25yar3aw6pbf4jmmfi0gdmcd7ynf5hjh9qdfb3zyh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/gcite")
    (synopsis "Citations in a reader-friendly style")
    (description
     "The package allows citations in the German style, which is considered by
many to be particularly reader-friendly.  The citation provides a small amount
of bibliographic information in a footnote on the page where each citation is
made.  It combines a desire to eliminate unnecessary page-turning with the
look-up efficiency afforded by numeric citations.  The package makes use of
BibLaTeX, and is considered experimental.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-gcite texlive-gcite)

(define-public texlive-gckanbun
  (package
    (name "texlive-gckanbun")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gckanbun/" "tex/latex/gckanbun/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hjp7nw2b34pkfxh6n2722zc83hjpn492q77gb063jzi79pgbprx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gckanbun")
    (synopsis "Kanbun typesetting for (u)pLaTeX and LuaLaTeX")
    (description
     "This package provides a Kanbun (Han Wen, ``Chinese writing'')
typesetting for @code{(u)pLaTeX} and LuaLaTeX.")
    (license license:expat)))

(define-public texlive-gentombow
  (package
    (name "texlive-gentombow")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gentombow/"
                                     "tex/latex/gentombow/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pc1cxsxlnj9d2qnvm31r3cw15mf7fwr5dadd10473mww8bp8irf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gentombow")
    (synopsis "Generate Japanese-style crop marks")
    (description
     "This bundle provides a LaTeX package for generating Japanese-style crop
marks (called tombow in Japanese) for practical use in self-publishing.

The bundle contains the following packages:
@itemize
@item @file{gentombow.sty}: Generate crop marks (called tombow in
Japanese) for practical use in self-publishing.  It provides the core
tombow feature if not available.
@item @file{pxgentombow.sty}: Superseded by @file{gentombow.sty}; kept
for compatibility only.
@item @file{bounddvi.sty}: Set papersize special to DVI file.  Can be
used on LaTeX, pLaTeX, upLaTeX (with DVI output mode) with dvips or
dvipdfmx drivers.
@end itemize")
    (license license:bsd-3)))

(define-public texlive-geometry
  (package
    (name "texlive-geometry")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/geometry/"
                                     "source/latex/geometry/"
                                     "tex/latex/geometry/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09jwdrg4s1c0gqmx7s57byw5kc09cna3li85y9ix0vxa6f6iqzi1"))))
    (build-system texlive-build-system)
    (outputs '("out" "doc"))
    (propagated-inputs (list texlive-graphics texlive-iftex))
    (home-page "https://www.ctan.org/pkg/geometry")
    (synopsis "Flexible and complete interface to document dimensions")
    (description
     "This package provides an easy and flexible user interface to customize
page layout, implementing auto-centering and auto-balancing mechanisms so that
the users have only to give the least description for the page layout.  The
package knows about all the standard paper sizes, so that the user need not
know what the nominal real dimensions of the paper are, just its standard
name (such as a4, letter, etc.).  An important feature is the package's
ability to communicate the paper size it's set up to the output.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-geometry texlive-geometry)

(define-public texlive-mdwtools
  (package
    (name "texlive-mdwtools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mdwtools/"
                                     "source/latex/mdwtools/"
                                     "tex/latex/mdwtools/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08wyw0k6r3fv7vdgwbcpq9ckifldy17fzhpar51s1qn0yib93zdg"))))
    (build-system texlive-build-system)
    (outputs '("out" "doc"))
    (home-page "https://www.ctan.org/pkg/mdwtools")
    (synopsis "Miscellaneous tools by Mark Wooding")
    (description
     "This collection of tools includes: @code{atsupport} for short commands
starting with @code{@@}, macros to sanitize the OT1 encoding of the
@code{cmtt} fonts; a @code{doafter} command; improved @code{footnote} support;
@code{mathenv} for various alignment in maths; list handling; @code{mdwmath}
which adds some minor changes to LaTeX maths; a rewrite of LaTeX's
@code{tabular} and @code{array} environments; verbatim handling; and syntax
diagrams.")
    (license license:gpl3+)))

(define-deprecated-package texlive-latex-mdwtools texlive-mdwtools)

(define-public texlive-makecmds
  (package
    (name "texlive-makecmds")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/makecmds/" "source/latex/makecmds/"
                                     "tex/latex/makecmds/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05y5n265in7mrbpgjxqg339l8r8dmp6lvl4k528pr3rkb8z94qaf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/makecmds")
    (synopsis "TeX macro to define or redefine a command")
    (description "The package provides a @code{\\makecommand} command, which
is like @code{\\newcommand} or @code{\\renewcommand} except it
always (re)defines a command.  There is also @code{\\makeenvironment} and
@code{\\provideenvironment} for environments.")
    (license license:lppl1.3c+)))

(define-public texlive-makeindex
  (package
    (name "texlive-makeindex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/makeindex.1"
                                     "doc/man/man1/makeindex.man1.pdf"
                                     "doc/man/man1/mkindex.1"
                                     "doc/man/man1/mkindex.man1.pdf"
                                     "doc/support/makeindex/"
                                     "makeindex/base/"
                                     "tex/plain/makeindex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m01m0x1kf10yvzxgrkvpic0amsr0g6q2r2wsg5f4ngybq4y9gyi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-makeindex-bin))
    (home-page "https://ctan.org/pkg/makeindexk")
    (synopsis "Makeindex development sources")
    (description
     "The package contains the development sources of MakeIndex.")
    (license
     (license:fsf-free "https://mirrors.ctan.org/indexing/makeindex/COPYING"))))

(define-public texlive-makeindex-bin
  (package
    (inherit texlive-bin)
    (name "texlive-makeindex-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "texk" '("makeindexk" "tests"))
            (delete-other-directories "utils" '())))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-makeindexk" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/makeindexk"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/makeindexk"
                  (invoke "make" "install"))))))))
    (native-inputs (list perl pkg-config))
    (inputs (list texlive-libkpathsea))
    (propagated-inputs '())
    (home-page (package-home-page texlive-makeindex))
    (synopsis "Binary for @code{texlive-makeindex}")
    (description
     "This package provides the binary for @code{texlive-makeindex}.")
    (license (package-license texlive-makeindex))))

(define-public texlive-marginfix
  (package
    (name "texlive-marginfix")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/marginfix/"
                                     "source/latex/marginfix/"
                                     "tex/latex/marginfix/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y6lmxm5ws2g0rqisvgdc8kg3whnvabrkl662sb4jvvaz02y3qdi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/marginfix")
    (synopsis "Patch @code{\\marginpar} to avoid overfull margins")
    (description
     "Authors using LaTeX to typeset books with significant margin material
often run into the problem of long notes running off the bottom of the page.
This package implements a solution to make @code{marginpars} just work by
keeping a list of floating inserts and arranging them intelligently in the
output routine.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-marginfix texlive-marginfix)

(define-public texlive-metalogo
  (package
    (name "texlive-metalogo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/metalogo/" "source/latex/metalogo/"
                                     "tex/latex/metalogo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xzy982kc7k5n7gy019rk4hbvxli2mlf4s7h7s11diasmh5fa2gf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/metalogo")
    (synopsis "Extended TeX logo macros")
    (description
     "This package exposes spacing parameters for various TeX logos to the end
user, to optimise the logos for different fonts.  It is written especially for
XeLaTeX users.")
    (license license:lppl1.3c+)))

(define-public texlive-paralist
  (package
    (name "texlive-paralist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/paralist/" "source/latex/paralist/"
                                     "tex/latex/paralist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "003gs7rjm97vqh903wdjys3ls96kx45w3s4qghjk1fdjx6qxd32l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/paralist")
    (synopsis "@code{enumerate} and @code{itemize} within paragraphs")
    (description
     "The @code{paralist} package provides @code{enumerate} and @code{itemize}
environments that can be used within paragraphs to format the items either as
running text or as separate paragraphs with a preceding number or symbol.  It
also provides compacted versions of @code{enumerate} and @code{itemize}.")
    (license license:lppl1.0+)))

(define-public texlive-polski
  (package
    (name "texlive-polski")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/polski/" "source/latex/polski/"
                                     "tex/latex/polski/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rcqyq8a96dl61fi9yr201rpm93w70sq93872ngfgvnk5m19xy13"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:build-targets #~(list "polski.ins")))
    (propagated-inputs (list texlive-hyphen-complete texlive-pl))
    (home-page "https://ctan.org/pkg/polski")
    (synopsis "Typeset Polish documents with LaTeX and Polish fonts")
    (description
     "This package provides tools to typeset monolingual Polish documents in
LaTeX2e without Babel or Polyglossia.  The package loads Polish hyphenation
patterns, ensures that a font encoding suitable for Polish is used; in
particular it enables Polish adaptation of Computer Modern fonts (the
so-called PL fonts), provides translations of @code{\\today} and names like
@samp{Bibliography} or @samp{Chapter}, redefines math symbols according to
Polish typographical tradition, provides macros for dashes according to Polish
orthography, provides a historical input method for Polish characters, works
with traditional TeX as well as with Unicode aware variants.")
    (license license:lppl1.2+)))

(define-public texlive-polyglossia
  (package
    (name "texlive-polyglossia")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/polyglossia/"
                                     "fonts/misc/xetex/fontmapping/polyglossia/"
                                     "source/latex/polyglossia/"
                                     "tex/latex/polyglossia/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r5l5c586zzvkyz8irj47pb86m4hkarc7617hvz8gsx1qqnf4463"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:tex-format "xelatex"
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'substitute-fonts
            (lambda _
              ;; Use dummy fonts for documentation.  We will install
              ;; pre-generated one anyway. Moreover, adding appropriate fonts
              ;; would bring in some large dependencies, such as webkitgtk for
              ;; Amiri.
              (substitute* "source/latex/polyglossia/polyglossia.dtx"
                (("\\{Serto Jerusalem}") "{FreeSans}")
                (("\\{Amiri-Regular}") "{FreeSans}")
                (("\\{Noto Serif CJK SC}") "{FreeSans}")
                (("\\{GFSPolyglot.otf}") "{FreeSans}"))))
          (add-after 'unpack 'extend-texmf
            (lambda _
              ;; Extend the current TEXMF environment variable to make
              ;; Polyglossia own libraries visible.
              (setenv "GUIX_TEXMF"
                      (string-append (getcwd) ":"
                                     (getenv "GUIX_TEXMF"))))))))
    (native-inputs
     (list (texlive-updmap.cfg
            (list font-dejavu
                  font-gnu-freefont
                  font-linuxlibertine
                  font-sil-ezra
                  fontconfig
                  texlive-amiri
                  texlive-babel
                  texlive-bidi
                  texlive-booktabs
                  texlive-caption
                  texlive-context
                  texlive-fancyvrb
                  texlive-graphics
                  texlive-hyperref
                  texlive-infwarerr
                  texlive-kvoptions
                  texlive-latex-fonts
                  texlive-libertine
                  texlive-metalogo
                  texlive-microtype
                  texlive-noto
                  texlive-paralist
                  texlive-pdftexcmds
                  texlive-tex
                  texlive-tools
                  texlive-xcolor
                  texlive-xetex
                  texlive-zref))))
    (propagated-inputs
     (list texlive-etoolbox
           texlive-filehook
           texlive-fontspec
           texlive-iftex
           texlive-makecmds
           texlive-xkeyval))
    (home-page "https://www.ctan.org/pkg/polyglossia")
    (synopsis "Alternative to Babel for XeLaTeX and LuaLaTeX")
    (description "This package provides a complete Babel replacement for users
of LuaLaTeX and XeLaTeX.  It includes support for over 70 different languages,
some of which in different regional or national varieties, or using a
different writing system.  It enables:
@itemize
@item
Loading the appropriate hyphenation patterns.
@item
Setting the script and language tags of the current font (if possible and
available), using the package @code{fontspec}.
@item
Switching to a font assigned by the user to a particular script or language.
@item
Adjusting some typographical conventions in function of the current language
(such as @code{afterindent}, @code{frenchindent}, spaces before or after
punctuation marks, etc.)
@item
Redefining the document strings (like @samp{chapter}, @samp{figure},
@samp{bibliography}).  Adapting the formatting of dates (for non-gregorian
calendars via external packages bundled with @code{polyglossia}: currently the
Hebrew, Islamic and Farsi calendars are supported).
@item
For languages that have their own numeration system, modifying the formatting
of numbers appropriately.
@item
Ensuring the proper directionality if the document contains languages
written from right to left.
@end itemize")
    (license license:expat)))

(define-deprecated-package texlive-latex-polyglossia texlive-polyglossia)

(define-public texlive-przechlewski-book
  (package
    (name "texlive-przechlewski-book")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/przechlewski-book/"
                                     "doc/latex/przechlewski-book/"
                                     "tex/latex/przechlewski-book/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06bsdpm26s3qqxhik185pkrxp0mx2n5jxndm14cd917drh162yr8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/przechlewski-book")
    (synopsis "Examples from Przechlewski's LaTeX book")
    (description
     "The bundle provides machine-readable copies of the examples from the
book @emph{Praca magisterska i dyplomowa z programem LaTeX}.")
    (license license:lppl)))

(define-public texlive-qpxqtx
  (package
    (name "texlive-qpxqtx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/qpxqtx/"
                                     "fonts/tfm/public/qpxqtx/"
                                     "fonts/vf/public/qpxqtx/"
                                     "tex/generic/qpxqtx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ksikdpzsv0rdnl5p536aw3625rlmzpgmhsycb8sbm9jlbrpxvi6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/qpxqtx")
    (synopsis
     "Polish macros and fonts supporting Pagella/pxfonts and Termes/txfonts")
    (description
     "This package provides Polish macros and fonts supporting Pagella/pxfonts
and Termes/txfonts")
    (license license:public-domain)))

(define-public texlive-supertabular
  (package
    (name "texlive-supertabular")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/supertabular/"
                                     "source/latex/supertabular/"
                                     "tex/latex/supertabular/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z4kyx20w2zvn6c5a7p702pxj254f2pwlk7x815gzlcc6563js6a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/supertabular")
    (synopsis "Multi-page tables package")
    (description
     "This package was a predecessor of @code{longtable}; the newer
package (designed on quite different principles) is easier to use and more
flexible, in many cases, but @code{supertabular} retains its usefulness in
a few situations where longtable has problems.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-supertabular texlive-supertabular)

(define-public texlive-tap
  (package
    (name "texlive-tap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/tap/" "tex/generic/tap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18xfn4p90i0hw5h7am982jgqnsj7qyaijw20zjy3shwihgkaq7fs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tap")
    (synopsis "TeX macros for typesetting complex tables")
    (description
     "The package offers a simple notation for pretty complex tables (to
Michael J.@: Ferguson's credit).  With PostScript, the package allows
shaded/coloured tables, diagonal rules, etc.  The package is supposed to work
with both Plain and LaTeX.  An AWK converter from ASCII semigraphic tables to
TAP notation is included.")
    (license license:public-domain)))

(define-public texlive-texinfo
  (package
    (name "texlive-texinfo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/texinfo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ds5vf98gzfqxafil4gsfqwyrxaha0cd1fx5mg76bw9y9xjzpzsl"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/texinfo")
    (synopsis "Texinfo documentation system")
    (description
     "Texinfo is the preferred format for documentation in the GNU project;
the format may be used to produce online or printed output from a single
source.  The Texinfo macros may be used to produce printable output using TeX;
other programs in the distribution offer online interactive use (with
hypertext linkages in some cases).")
    (license license:gpl3+)))

(define-deprecated-package texlive-tex-texinfo texlive-texinfo)

(define-public texlive-textcase
  (package
    (name "texlive-textcase")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/textcase/" "source/latex/textcase/"
                                     "tex/latex/textcase/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0n48zzy63vw9npwbnsg573plrlm7b5r7zjjvghcczfya1w30yf2d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/textcase")
    (synopsis "Case conversion ignoring mathematics, etc")
    (description
     "The @code{textcase} package offers commands @code{\\MakeTextUppercase}
and @code{\\MakeTextLowercase} are similar to the standard
@code{\\MakeUppercase} and @code{\\MakeLowercase}, but they do not change the
case of any sections of mathematics, or the arguments of @code{\\cite},
@code{\\label} and @code{\\ref} commands within the argument.  A further
command @code{\\NoCaseChange} does nothing but suppress case change within its
argument, so to force uppercase of a section including an environment, one
might say:

@example
\\MakeTextUppercase{...\\NoCaseChange{\\begin{foo}} ...\\NoCaseChange{\\end{foo}}...}
@end example")
    (license license:lppl)))

(define-public texlive-upquote
  (package
    (name "texlive-upquote")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/upquote/"
                                     "source/latex/upquote/"
                                     "tex/latex/upquote/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1manbljqx2859wq9by6bpcx4rnxvc596a05d21cw464484f8a8z2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/upquote")
    (synopsis "Show realistic quotes in verbatim")
    (description
     "Typewriter-style fonts are best for program listings, but Computer
Modern Typewriter prints @samp{`} and @samp{'} as bent opening and closing
single quotes.  Other fonts, and most programming languages, print @samp{`} as
a grave accent and @samp{'} upright; @samp{'} is used both to open and to
close quoted strings.  The package switches the typewriter font to Computer
Modern Typewriter in OT1 encoding, and modifies the behaviour of
@code{verbatim}, @code{verbatim*}, @code{\\verb}, and @code{\\verb*} to print
in the expected way.  It does this regardless of other fonts or encodings in
use, so long as the package is loaded after the other fonts were.  The package
does not affect @code{\\tt}, @code{\\texttt}, etc.")
    (license license:lppl1.2+)))

(define-deprecated-package texlive-latex-upquote texlive-upquote)

(define-public texlive-anysize
  (package
    (name "texlive-anysize")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/anysize/"
                                     "tex/latex/anysize/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "155s0v82zpkmv97kwqhhfw52230hka9zl3wzjw1d5ayxd4n11bxq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/anysize")
    (synopsis "Simple package to set up document margins")
    (description
     "This is a simple package to set up document margins.  This package is
considered obsolete; alternatives are the @code{typearea} package from the
@code{koma-script} bundle, or the @code{geometry} package.")
    (license license:public-domain)))

(define-deprecated-package texlive-latex-anysize texlive-anysize)

(define-public texlive-appendix
  (package
    (name "texlive-appendix")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/appendix/"
                                     "source/latex/appendix/"
                                     "tex/latex/appendix/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vqkqpzs7bc6pbjnafakrwayjyfx9mvadrqxccdf549m8172qvzk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/appendix")
    (synopsis "Extra control of appendices")
    (description
     "The @code{appendix} package provides various ways of formatting the
titles of appendices.  Also (sub)appendices environments are provided that can
be used, for example, for per chapter/section appendices.  An
@code{appendices} environment is provided which can be used instead of the
@code{\\appendix} command.")
    (license license:lppl1.3c)))

(define-deprecated-package texlive-latex-appendix texlive-appendix)

(define-public texlive-bookman
  (package
    (name "texlive-bookman")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "dvips/bookman/"
                                     "fonts/afm/adobe/bookman/"
                                     "fonts/afm/urw/bookman/"
                                     "fonts/map/dvips/bookman/"
                                     "fonts/tfm/adobe/bookman/"
                                     "fonts/tfm/urw35vf/bookman/"
                                     "fonts/type1/urw/bookman/"
                                     "fonts/vf/adobe/bookman/"
                                     "fonts/vf/urw35vf/bookman/"
                                     "tex/latex/bookman/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12wkjwpzxn1a1k3bb41gpnky1jjsh7gzj4xahsjd087fpmrsj9p9"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/urw-base35")
    (synopsis "Replacement for Adobe's Bookman font")
    (description
     "This package provides a drop-in replacement for the Bookman font from
Adobe's basic set")
    (license license:gpl3+)))

(define-public texlive-bookmark
  (package
    (name "texlive-bookmark")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bookmark/"
                                     "source/latex/bookmark/"
                                     "tex/latex/bookmark/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cfwiz7d896bfcah91x5kw8radhsyaavhzdc3x91zlzy8d5ag2bd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/bookmark")
    (synopsis "Bookmark (outline) organization for @code{hyperref}")
    (description
     "This package implements a new bookmark (outline) organization for the
@code{hyperref} package.  Bookmark properties such as style and color.  Other
action types are available (URI, GoToR, Named).")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-bookmark texlive-bookmark)

(define-public texlive-changebar
  (package
    (name "texlive-changebar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/changebar/"
                                     "source/latex/changebar/"
                                     "tex/latex/changebar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03mpvzdy3iffhayx4zbjzyr4p2xirrqczxiv3akgaa8knhrbyivr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/changebar")
    (synopsis "Generate changebars in LaTeX documents")
    (description
     "Identify areas of text to be marked with changebars with the
@code{\\cbstart} and @code{\\cbend} commands; the bars may be coloured.  The
package uses drivers to place the bars; the available drivers can work with
@code{dvitoln03}, @code{dvitops}, @code{dvips}, the emTeX and TeXtures DVI
drivers, and VTeX and pdfTeX.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-changebar texlive-changebar)

(define-public texlive-checkcites
  (package
    (name "texlive-checkcites")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/checkcites/"
                                     "scripts/checkcites/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13jlkmvnqcwryp9dn5lh77cf1yj2x7fa5kc8vx0j3sj1ryphykja"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/checkcites")
    (synopsis "Check citation commands in a document")
    (description
     "The package provides a Lua script written for the sole purpose of
detecting undefined and unused references from LaTeX auxiliary or bibliography
files.")
    (license license:lppl1.3+)))

(define-public texlive-chickenize
  (package
    (name "texlive-chickenize")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/chickenize/"
                                     "source/luatex/chickenize/"
                                     "tex/luatex/chickenize/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "055lkxc2igr0qh1lcdbnh2w0z92v3wkjgp1hpbbrj8r5kvpm7nvy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chickenize")
    (synopsis "Use Lua callbacks for some textual effects")
    (description
     "The package allows manipulations of any LuaTeX document.  Most of the
package's functions are merely for fun or educational use, but some
functions (for example, @code{colorstretch} for visualising the badness and
font expansion of each line, and @code{letterspaceadjust} doing what its name
says) could be useful in a normal LuaTeX document.")
    (license license:lppl1.3+)))

(define-public texlive-chinese-jfm
  (package
    (name "texlive-chinese-jfm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/chinese-jfm/"
                                     "tex/luatex/chinese-jfm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ixlwivijp6vvzn2j3drr13hk0ylslcd9ws8df24abda93wjm35r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chinese-jfm")
    (synopsis "Luatexja-jfm files for Chinese typesetting")
    (description
     "ChineseJFM is a series of @code{luatexja-jfm} files for better Chinese
typesetting, providing @code{quanjiao}, @code{banjiao}, and @code{kaiming}
three styles and other fancy features.  It can be used for both horizontal and
vertical writing mode in Simplified/Traditional Chinese or Japanese fonts.")
    (license license:expat)))

(define-public texlive-cloze
  (package
    (name "texlive-cloze")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/cloze/" "scripts/cloze/"
                                     "source/luatex/cloze/" "tex/luatex/cloze/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0i0bsflqgw14bik1r8qlx2287fx6lv8jmha57bx54d7icaswssf9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cloze")
    (synopsis "Lualatex package for creating cloze texts")
    (description
     "This is a LuaTeX or LuaLaTeX package for generating cloze texts.  The
main feature of the package is that the formatting doesn't change when using
the hide and show options.")
    (license license:lppl1.3+)))

(define-public texlive-cmap
  (package
    (name "texlive-cmap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cmap/"
                                     "tex/latex/cmap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hag26l3g9mpmmy1kn7lrnfzzr8k0hpm259qp087smggykvsjc4v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cmap")
    (synopsis "Make PDF files searchable and copyable")
    (description
     "This package embeds CMap tables into PDF files to make search and
copy-and-paste functions work properly.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-cmap texlive-cmap)

(define-public texlive-colorprofiles
  (package
    (name "texlive-colorprofiles")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/colorprofiles/"
                                     "tex/generic/colorprofiles/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nxbds0jhn5wvf50iy1a4mpfgk56587kqvs4wxf08ysvqx6xiaxv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/colorprofiles")
    (synopsis "Collection of free ICC profiles")
    (description
     "This package collects ICC profiles that can be used by color profile
aware applications or tools like the @code{pdfx} package, as well as TeX and
LaTeX packages to access them.")
    (license license:lppl1.2+)))        ;per "colorprofiles.sty"

(define-public texlive-colortbl
  (package
    (name "texlive-colortbl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/colortbl/" "source/latex/colortbl/"
                                     "tex/latex/colortbl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1js4ndmzhhj8py3qsqpvichbxga7w00j2qhn2ns6rmlm8hb2ln5v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/colortbl")
    (synopsis "Add colour to LaTeX tables")
    (description
     "The package allows rows and columns to be coloured, and even
individual cells.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-colortbl texlive-colortbl)

(define-public texlive-combofont
  (package
    (name "texlive-combofont")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/combofont/"
                                     "tex/lualatex/combofont/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05p044znavjjd7cpgjx46i8n6b56rpybhixqs9yaam86nb70ha7n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/combofont")
    (synopsis "Add NFSS-declarations of combo fonts to LuaLaTeX documents")
    (description
     "This highly experimental package can be used to add NFSS-declarations of
combo fonts to LuaLaTeX documents.")
    (license license:lppl1.3c)))

(define-public texlive-cstypo
  (package
    (name "texlive-cstypo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/cstypo/"
                                     "tex/lualatex/cstypo/" "tex/luatex/cstypo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07cgcda6jcmkvhp90n4a8g4x98jmzwf4199gp6nh19718v6n15j8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cstypo")
    (synopsis "Czech typography rules enforced through LuaTeX hooks")
    (description
     "This package provides macros that enforce basic Czech typography rules
through Lua hooks available in LuaTeX.")
    (license license:expat)))

(define-public texlive-fancybox
  (package
    (name "texlive-fancybox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fancybox/"
                                     "tex/latex/fancybox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pb1j0a1va8yhrzig7dwrd8jgq39mbcpygl810jhrv8pl473mfmn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fancybox")
    (synopsis "Variants of @code{\\fbox} and other games with boxes")
    (description
     "This package provides variants of @code{\\fbox}: @code{\\shadowbox},
@code{\\doublebox}, @code{\\ovalbox}, @code{\\Ovalbox}, with helpful tools for
using box macros and flexible verbatim macros.  You can box mathematics,
floats, center, flushleft, and flushright, lists, and pages.")
    (license license:lppl1.2+)))

(define-deprecated-package texlive-latex-fancybox texlive-fancybox)

(define-public texlive-fancyhdr
  (package
    (name "texlive-fancyhdr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fancyhdr/" "source/latex/fancyhdr/"
                                     "tex/latex/fancyhdr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0asx5l8kx1zsvja5arnbspr37hwmmjp01837kfrsy7dsm8wfclgr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fancyhdr")
    (synopsis "Extensive control of page headers and footers in LaTeX2e")
    (description
     "The package provides extensive facilities, both for constructing headers
and footers, and for controlling their use (for example, at times when LaTeX
would automatically change the heading style in use).")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-fancyhdr texlive-fancyhdr)

(define-public texlive-fancyhdr-it
  (package
    (name "texlive-fancyhdr-it")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fancyhdr-it/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "117826hd9zl15i8qf6d1pz2qz57l68a9nxqldxyk21acc29ifalr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fancyhdr-it")
    (synopsis "Italian translation of @code{fancyhdr} documentation")
    (description
     "This package provides an Italian translation of documentation provided
with the @code{fancyhdr} package.")
    (license license:lppl)))

(define-public texlive-fancyref
  (package
    (name "texlive-fancyref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fancyref/"
                                     "source/latex/fancyref/"
                                     "tex/latex/fancyref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0njgl53f5farwbd8xkw8im8id0scf6agbfqcdjkbqlk540vdzwbp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fancyref")
    (synopsis "LaTeX package for fancy cross-referencing")
    (description
     "This package provides fancy cross-referencing support, based on the
package's reference commands (@code{\\fref} and @code{\\Fref}) that recognise
what sort of object is being referenced.")
    (license license:gpl3+)))

(define-public texlive-float
  (package
    (name "texlive-float")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/float/"
                                     "source/latex/float/"
                                     "tex/latex/float/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rfyvk1n83zsmrrp0x643052nrjb00cj935d2cpm37x4pz649f5d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/float")
    (synopsis "Improved interface for floating objects")
    (description
     "The @code{float} package improves the interface for defining floating
objects such as figures and tables.  It introduces the boxed float, the ruled
float and the plaintop float.  You can define your own floats and improve the
behaviour of the old ones.  The package also provides the @samp{H} float
modifier option of the obsolete @code{here} package.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-float texlive-float)

(define-public texlive-footmisc
  (package
    (name "texlive-footmisc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/footmisc/" "source/latex/footmisc/"
                                     "tex/latex/footmisc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qbp5ca4asqblz41maj6i2pi9qjym7rpkv7cchbz9fxkgyamhiy4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/footmisc")
    (synopsis "Range of footnote options")
    (description
     "This is a collection of ways to change the typesetting of footnotes.
The package provides means of changing the layout of the footnotes themselves,
a way to number footnotes per page, to make footnotes disappear in a
\"moving\" argument, and to deal with multiple references to footnotes from
the same place.  The package also has a range of techniques for labelling
footnotes with symbols rather than numbers.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-footmisc texlive-footmisc)

(define-public texlive-footnotehyper
  (package
    (name "texlive-footnotehyper")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/footnotehyper/"
                                     "source/latex/footnotehyper/"
                                     "tex/latex/footnotehyper/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0f8d13zr07bl295rvpagj99s9fn4dgrcjzv1xpjmla3h6xhrv914"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/footnotehyper")
    (synopsis "@code{hyperref} aware @file{footnote.sty}")
    (description
     "The @code{footnote} package by Mark Wooding dates back to 1997 and has
not been made @code{hyperref} compatible.  The aim of the present package is
to do that.")
    (license license:lppl1.3c)))

(define-public texlive-letltxmacro
  (package
    (name "texlive-letltxmacro")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/letltxmacro/"
                                     "source/latex/letltxmacro/"
                                     "tex/latex/letltxmacro/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16bmwsng9p80jf78sdmib24apwnw3raw306cs1ms50z5s9dsfdby"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/letltxmacro")
    (synopsis "Let assignment for LaTeX macros")
    (description
     "TeX's @code{\\let} assignment does not work for LaTeX macros with
optional arguments or for macros that are defined as robust macros by
@code{\\DeclareRobustCommand}.  This package defines @code{\\LetLtxMacro} that
also takes care of the involved internal macros.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-letltxmacro texlive-letltxmacro)

(define-public texlive-frankenstein
  (package
    (name "texlive-frankenstein")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/frankenstein/"
                                     "bibtex/bst/frankenstein/"
                                     "doc/latex/frankenstein/"
                                     "source/latex/frankenstein/"
                                     "tex/latex/frankenstein/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x494vl4acl0bhfshs96ap8j47xk4m4njfincfhg2b0mi7l5mj1i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:modules '((guix build texlive-build-system)
                  (guix build utils)
                  (ice-9 match))
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'set-TEXINPUTS
            ;; The ".ins" files strip comments from ".sty", turning them into
            ;; faster ".stq" (and ".bsq") files.  Unfortunately, the ".ins"
            ;; and the ".sty" files are not located in the same
            ;; directory. This phase extends TEXINPUTS so everyone can see
            ;; each other, including the docstrip utility.
            (lambda* (#:key inputs #:allow-other-keys)
              (setenv "TEXINPUTS"
                      (let ((cwd (getcwd)))
                        (string-append
                         cwd "/tex/latex/frankenstein//:"
                         cwd "/source/latex/frankenstein//:"
                         (string-join
                          (map (match-lambda ((_ . dir) dir)) inputs)
                          "//:"))))))
          (add-before 'install 'install-faster-files
            (lambda _
              ;; Replace ".sty" and ".bst" files with their faster
              ;; counterpart.
              (copy-file "build/achicago.bsq"
                         "bibtex/bst/frankenstein/achicago.bst")
              ;; "build/tex/.../xxx.stq" -> "tex/.../xxx.sty"
              (for-each (lambda (file)
                          (copy-file file
                                     (string-append "tex/latex/frankenstein/"
                                                    (basename file ".stq")
                                                    ".sty")))
                        (find-files "build/tex" "\\.stq$")))))))
    (home-page "https://ctan.org/pkg/frankenstein")
    (synopsis "Collection of LaTeX packages")
    (description
     "Frankenstein is a bundle of LaTeX packages serving various purposes
and a BibTeX bibliography style.  The individual packages are: @code{abbrevs},
@code{achicago}, @code{achicago} bibstyle, @code{attrib}, @code{blkcntrl},
@code{compsci}, @code{dialogue}, @code{lips}, @code{moredefs},
@code{newclude}, @code{slemph} and @code{titles}.")
    ;; README mentions an unspecified version of GNU GPL and points to
    ;; COPYING, which is missing. However, the individual files mention LPPL
    ;; 1.2 or later.
    (license license:lppl1.2+)))

(define-deprecated-package texlive-latex-frankenstein texlive-frankenstein)

(define-public texlive-kantlipsum
  (package
    (name "texlive-kantlipsum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/kantlipsum/"
                                     "source/latex/kantlipsum/"
                                     "tex/latex/kantlipsum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18rnf9k0h1mysxr7g014i58h80pra5jrcsrr1r633mimsas8fzm1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/kantlipsum")
    (synopsis "Generate sentences in Kant's style")
    (description
     "The package spits out sentences in Kantian style; the text is provided
by the Kant generator for Python by Mark Pilgrim, described in the book ``Dive
into Python''.  The package is modelled on @code{lipsum}, and may be used for
similar purposes.")
    (license license:lppl1.3c)))

(define-public texlive-kurdishlipsum
  (package
    (name "texlive-kurdishlipsum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/kurdishlipsum/"
                                     "tex/xelatex/kurdishlipsum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lpdjqbif0pqsb6pmg8jc8igdf06dzwn3yfxh19mnjfzslcxkcmk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/kurdishlipsum")
    (synopsis "Lipsum package for the Kurdish language")
    (description
     "This package provides lipsum-like facilities for the Kurdish language.
The package gives you easy access to the Kurdish poetry and balladry texts of
the Diwany Vafaiy, Ahmedy Xani, Naly, Mahwy,....  The package needs to be run
under XeLaTeX.")
    (license license:lppl)))

(define-public texlive-kurier
  (package
    (name "texlive-kurier")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/kurier/"
                                     "fonts/afm/nowacki/kurier/"
                                     "fonts/enc/dvips/kurier/"
                                     "fonts/map/dvips/kurier/"
                                     "fonts/opentype/nowacki/kurier/"
                                     "fonts/tfm/nowacki/kurier/"
                                     "fonts/type1/nowacki/kurier/"
                                     "tex/latex/kurier/"
                                     "tex/plain/kurier/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0j89iv0yyy33dyyka0w0v5jykl41sdn7plxrrxa91qmxzqvi2y67"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/kurier")
    (synopsis "Two-element sans-serif typeface")
    (description
     "Kurier is a two-element sans-serif typeface.  It was designed for
a diploma in typeface design at the Warsaw Academy of Fine Arts under the
supervision of Roman Tomaszewski.  This distribution contains a significantly
extended set of characters covering the following modern alphabets:
latin (including Vietnamese), Cyrillic and Greek as well as a number of
additional symbols (including mathematical symbols).  The fonts are prepared
in Type 1 and OpenType formats.  For use with TeX the following encoding files
have been prepared: T1 (ec), T2 (abc), and OT2--Cyrillic, T5 (Vietnamese),
OT4, QX, texansi and--nonstandard (IL2 for the Czech fonts), as well as
supporting macros and files defining fonts for LaTeX.")
    (license license:gfl1.0)))

(define-public texlive-lipsum
  (package
    (name "texlive-lipsum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lipsum/" "source/latex/lipsum/"
                                     "tex/latex/lipsum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07kcma66p3s68baygzvgcmb7jvwaan7jj6s3hxmx42npcfsp57s3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lipsum")
    (synopsis "Easy access to the Lorem Ipsum dummy text")
    (description
     "This package gives you easy access to the Lorem Ipsum dummy text; an
option is available to separate the paragraphs of the dummy text into
TeX-paragraphs.  All the paragraphs are taken with permission from
@url{http://lipsum.com/}.")
    (license license:lppl1.3+)))

(define-public texlive-listings
  (package
    (name "texlive-listings")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/listings/" "source/latex/listings/"
                                     "tex/latex/listings/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0grk73jmglrwkyskmnmkx9n0rpf12bvbvdmr4xjq33m5h11m758g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    ;; Do not build intermediate "lstdrvrs.ins".
    (arguments (list #:build-targets '(list "listings.ins")))
    (home-page "https://ctan.org/pkg/listings")
    (synopsis "Typeset source code listings using LaTeX")
    (description
     "The package enables the user to typeset programs (programming code)
within LaTeX; the source code is read directly by TeX---no front-end processor
is needed.  Keywords, comments and strings can be typeset using different
styles.  Support for @code{hyperref} is provided.")
    (license license:lppl1.3+)))

(define-public texlive-listingsutf8
  (package
    (name "texlive-listingsutf8")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/listingsutf8/"
                                     "source/latex/listingsutf8/"
                                     "tex/latex/listingsutf8/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "152gzkzm7sl3bvggmmfcj1pw74vc40s2kpkbp01fd9i0d0v60wma"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/listingsutf8")
    (synopsis "Allow UTF-8 in listings input")
    (description
     "Package @code{listings} does not support files with multi-byte encodings
such as UTF-8.  In the case of @code{\\lstinputlisting}, a simple workaround
is possible if a one-byte encoding exists that the file can be converted to.
The package requires the e-TeX extensions under pdfTeX (in either PDF or DVI
output mode).")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-listings texlive-listings)

(define-public texlive-jknapltx
  (package
    (name "texlive-jknapltx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jknapltx/"
                                     "tex/latex/jknapltx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0as43yqq123cacxhvp4sbdp4ka3cyp2spmxwayqny0fh5rsk6qaq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jknapltx")
    (synopsis "Miscellaneous packages by Joerg Knappen")
    (description
     "This package provides miscellaneous macros by Joerg Knappen,
including: represent counters in greek; Maxwell's non-commutative division;
@code{latin1jk}, @code{latin2jk} and @code{latin3jk}, which are
@code{inputenc} definition files that allow verbatim input in the respective
ISO Latin codes; blackboard bold fonts in maths; use of RSFS fonts in maths;
extra alignments for @code{\\parboxes}; swap Roman and Sans fonts;
transliterate semitic languages; patches to make (La)TeX formulae embeddable
in SGML; use maths minus in text as appropriate; simple Young tableaux.")
    (license license:gpl3+)))

(define-deprecated-package texlive-latex-jknapltx texlive-jknapltx)
(define-deprecated-package texlive-jknappen texlive-jknapltx)

(define-public texlive-jmn
  (package
    (name "texlive-jmn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "fonts/afm/jmn/hans/" "fonts/enc/dvips/jmn/"
                                     "fonts/map/dvips/jmn/" "fonts/tfm/jmn/hans/"
                                     "fonts/type1/jmn/hans/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0iq5ky3llx50smw80lpylv11jmqc51m5yrhlslz3sakmgdqgg1yi"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jmn")
    (synopsis "Special fonts for ConTeXt")
    (description "This ConTeXt module provides special fonts.")
    (license license:bsd-2)))           ;as the whole ConTeXt project

(define-public texlive-kvoptions
  (package
    (name "texlive-kvoptions")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/kvoptions/"
                                     "source/latex/kvoptions/"
                                     "tex/latex/kvoptions/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14f19c53s5m067vp25h7yk1f209h1xm352zkhzv6qk5xc0ckkbxm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/kvoptions")
    (synopsis "Key/value format for package options")
    (description
     "This package provides facilities for using key-value format in
package options.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-kvoptions texlive-kvoptions)

(define-public texlive-ekdosis
  (package
    (name "texlive-ekdosis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/ekdosis/"
                                     "source/lualatex/ekdosis/"
                                     "tex/lualatex/ekdosis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bzydy6gcmikqsdiaji30a2ycifzaafbg0ccv5lq5an7rv2hajmj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ekdosis")
    (synopsis "Typesetting TEI-xml compliant Critical Editions")
    (description
     "@code{ekdosis} is a LuaLaTeX package designed for multilingual critical
editions.  It can be used to typeset texts and different layers of critical
notes in any direction accepted by LuaTeX. Texts can be arranged in running
paragraphs or on facing pages, in any number of columns which in turn can be
synchronized or not.  In addition to printed texts, @code{ekdosis} can convert
@file{.tex} source files so as to produce TEI XML-compliant critical editions.
Database-driven encoding under LaTeX then allows extraction of texts entered
segment by segment according to various criteria: main edited text, variant
readings, translations or annotated borrowings between texts.")
    (license (list license:gpl3+ license:fdl1.3+))))

(define-public texlive-emoji
  (package
    (name "texlive-emoji")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/emoji/" "tex/latex/emoji/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17i2kjb1rlgj2ipg6bkni1n8l1yhhnm1m96ynj1nv8gkmgkfklal"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/emoji")
    (synopsis "Emoji support in (Lua)LaTeX")
    (description
     "This package allows users to typeset emojis in LaTeX documents.  It
requires the LuaHBTeX engine.")
    (license license:lppl1.3c)))

(define-public texlive-emojicite
  (package
    (name "texlive-emojicite")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/emojicite/"
                                     "tex/lualatex/emojicite/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wfr4alglwhsp728fp91qxdmc9413c6k9j7hgg0qk3j4w464srbj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/emojicite")
    (synopsis "Add emojis to citations")
    (description "This package adds emojis to citations.")
    (license license:lppl1.3c)))

(define-public texlive-enigma
  (package
    (name "texlive-enigma")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/context/third/enigma/enigma/"
                                     "scripts/context/lua/third/enigma/mtx-t-enigma.lua/"
                                     "tex/context/third/enigma/t-enigma.mkv/"
                                     "tex/generic/enigma/"
                                     "tex/latex/enigma/"
                                     "tex/plain/enigma/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rnp2c903bfgq0gqshaccd1zxcb0zpbk2sh7w3lwynpp0zx8d435"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/enigma")
    (synopsis "Encrypt documents with a three rotor Enigma")
    (description
     "The package provides historical encryption (Enigma cipher) for
LuaTeX-based formats.")
    (license license:bsd-2)))

(define-public texlive-ae
  (package
    (name "texlive-ae")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/ae/" "fonts/tfm/public/ae/"
                                     "fonts/vf/public/ae/" "source/fonts/ae/"
                                     "tex/latex/ae/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xkzg381y0avdq381r2m990wp27czkdff0qkvsp2n5q62yc0bdsw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ae")
    (synopsis "Virtual fonts for T1 encoded CMR-fonts")
    (description
     "This package provides a set of virtual fonts which emulates T1 coded
fonts using the standard CM fonts.  The package name, AE fonts, supposedly
stands for \"Almost European\".  The main use of the package was to produce
PDF files using Adobe Type 1 versions of the CM fonts instead of bitmapped EC
fonts.  Note that direct substitutes for the bitmapped EC fonts are available,
via the CM-super, Latin Modern and (in a restricted way) CM-LGC font sets.")
    (license license:lppl1.3+)))

(define-public texlive-aeguill
  (package
    (name "texlive-aeguill")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/aeguill/" "tex/latex/aeguill/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dbl2dky8gbax9blj0nvk23y2pwkmyikxnbbn27zivpamwc0j8nc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/aeguill")
    (synopsis "Add several kinds of guillemets to the @code{ae} fonts")
    (description
     "The package enables the user to add guillemets from several
source (Polish cmr, Cyrillic cmr, lasy and ec) to the @code{ae} fonts.  This
was useful when the @code{ae} fonts were used to produce PDF files, since the
additional guillemets exist in fonts available in Adobe Type 1 format.")
    (license license:lppl)))

(define-public texlive-incgraph
  (package
    (name "texlive-incgraph")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/incgraph/" "tex/latex/incgraph/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18ygl211wpnx433xy4v3jyl7wn9vn0dw23m709xs01kq7pwmsz3i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/incgraph")
    (synopsis "Sophisticated graphics inclusion in a PDF document")
    (description
     "The package provides tools for including graphics at the full size of
the output medium, or for creating pages whose size is that of the graphic
they contain.  A principal use case is documents that require inclusion
of (potentially many) scans or photographs.  Bookmarking is especially
supported.  The tool box has basic macros and a convenience user interface
that wraps @code{\\includegraphics}.")
    (license license:lppl1.3+)))

(define-public texlive-inconsolata
  (package
    (name "texlive-inconsolata")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/inconsolata/"
                                     "fonts/enc/dvips/inconsolata/"
                                     "fonts/map/dvips/inconsolata/"
                                     "fonts/opentype/public/inconsolata/"
                                     "fonts/tfm/public/inconsolata/"
                                     "fonts/type1/public/inconsolata/"
                                     "tex/latex/inconsolata/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19lvma52vk7x8d7j4s9ymjwm3w2k08860fh6dkzn76scgpdm4wlb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/inconsolata")
    (synopsis "Monospaced font with support files for use with TeX")
    (description
     "Inconsolata is a monospaced font designed by Raph Levien.  This package
contains the font (in both Adobe Type 1 and OpenType formats) in regular and
bold weights, with additional glyphs and options to control slashed zero,
upright quotes and a shapelier lower-case L, plus metric files for use with
TeX, and LaTeX font definition and other relevant files.")
    (license (list license:lppl1.3+
                   license:silofl1.1
                   license:asl2.0))))

(define-public texlive-innerscript
  (package
    (name "texlive-innerscript")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/innerscript/"
                                     "source/lualatex/innerscript/"
                                     "tex/lualatex/innerscript/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13kw7xkc3bpa494mzfphl2v3yn6y08013qnrp3h9awq4blgi2y8b"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "lualatex"))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-booktabs
                  texlive-etoolbox
                  texlive-hypdoc
                  texlive-infwarerr
                  texlive-kvoptions
                  texlive-microtype
                  texlive-pdftexcmds))))
    (home-page "https://ctan.org/pkg/innerscript")
    (synopsis "Modifies automatic mathematics spacing")
    (description
     "This package modifies two aspects of TeX's automatic interatom
mathematics spacing.  It uses LuaTeX's @code{\\Umath} primitives to make
superscripts and subscripts more closely resemble @code{\\textstyle} and
@code{\\displaystyle} math and to treat @code{\\mathinner} subformulas as
@code{\\mathord}, effectively eliminating this class.")
    (license license:lppl1.3c)))

(define-public texlive-interpreter
  (package
    (name "texlive-interpreter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/interpreter/"
                                     "tex/luatex/interpreter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03h6bjhvbl3bfkiyssplivqmn2986asv8b1jvr1ahsh7p04bkk4j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/interpreter")
    (synopsis "Translate input files on the fly")
    (description
     "The package preprocesses input files to a Lua(La)TeX run, on the fly.
The user defines Lua regular expressions to search for patterns and modify
input lines (or entire paragraphs) accordingly, before TeX reads the material.
In this way, documents may be prepared in a non-TeX language (e.g., some
lightweight markup language) and turned into proper TeX for processing.")
    (license license:lppl)))

(define-public texlive-times
  (package
    (name "texlive-times")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "dvips/times/"
                                     "fonts/afm/adobe/times/"
                                     "fonts/afm/urw/times/"
                                     "fonts/map/dvips/times/"
                                     "fonts/tfm/adobe/times/"
                                     "fonts/tfm/urw35vf/times/"
                                     "fonts/type1/urw/times/"
                                     "fonts/vf/adobe/times/"
                                     "fonts/vf/urw35vf/times/"
                                     "tex/latex/times/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13g41a7vbkvsf7ki9dgl7qm100w382mnlqkcngwgl3axp6s5s8l0"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/urw-base35")
    (synopsis "Replacement for Adobe's Times font")
    (description
     "This package provides a drop-in replacement for the Times font from
Adobe's basic set.")
    ;; No license version specified.
    (license license:gpl3+)))

(define-deprecated-package texlive-fonts-adobe-times texlive-times)

(define-public texlive-palatino
  (package
    (name "texlive-palatino")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "dvips/palatino/"
                                     "fonts/afm/adobe/palatino/"
                                     "fonts/afm/urw/palatino/"
                                     "fonts/map/dvips/palatino/"
                                     "fonts/tfm/adobe/palatino/"
                                     "fonts/tfm/urw35vf/palatino/"
                                     "fonts/type1/urw/palatino/"
                                     "fonts/vf/adobe/palatino/"
                                     "fonts/vf/urw35vf/palatino/"
                                     "tex/latex/palatino/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12jc0av7v99857jigmva47qaxyllhpzsnqis10n0qya2kz44xf22"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/urw-base35")
    (synopsis "Replacement for Adobe's Palatino font")
    (description
     "This package provides a drop-in replacement for the Palatino font from
Adobe's basic set.")
    ;; No license version specified.
    (license license:gpl3+)))

(define-deprecated-package texlive-fonts-adobe-palatino texlive-palatino)

(define-public texlive-poltawski
  (package
    (name "texlive-poltawski")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/poltawski/"
                                     "fonts/afm/gust/poltawski/"
                                     "fonts/enc/dvips/poltawski/"
                                     "fonts/map/dvips/poltawski/"
                                     "fonts/opentype/gust/poltawski/"
                                     "fonts/tfm/gust/poltawski/"
                                     "fonts/type1/gust/poltawski/"
                                     "tex/latex/poltawski/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cf8vxah8j6nnaq2lhmiy1q3dnq6swprfmizzxd6y67sc60rznzm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/poltawski")
    (synopsis "Antykwa Poltawskiego Family of Fonts")
    (description
     "The package contains the Antykwa Poltawskiego family of fonts in the
PostScript Type 1 and OpenType formats Following the route set out by the
Latin Modern and TeX Gyre projects, the Antykwa Poltawskiego digitisation
project aims at providing a rich collection of diacritical characters in the
attempt to cover as many Latin-based scripts as possible.  To our knowledge,
the repertoire of characters covers all European languages as well as some
other Latin-based alphabets such as Vietnamese and Navajo; at the request of
users, recent extensions (following the enhancement of the Latin Modern
collection) provide glyphs sufficient for typesetting of romanized
transliterations of Arabic and Sanskrit scripts.  The Antykwa Poltawskiego
family consists of 4 weights (light, normal, medium, bold), each having
upright and italic forms and one of 5 design sizes: 6, 8, 10, 12 and 17pt.")
    (license license:gfl1.0)))

(define-public texlive-zapfchan
  (package
    (name "texlive-zapfchan")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "dvips/zapfchan/"
                                     "fonts/afm/adobe/zapfchan/"
                                     "fonts/afm/urw/zapfchan/"
                                     "fonts/map/dvips/zapfchan/"
                                     "fonts/tfm/adobe/zapfchan/"
                                     "fonts/tfm/urw35vf/zapfchan/"
                                     "fonts/type1/urw/zapfchan/"
                                     "fonts/vf/adobe/zapfchan/"
                                     "fonts/vf/urw35vf/zapfchan/"
                                     "tex/latex/zapfchan/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1753lvv2bq29g43s4chc884n742695agvgal0b99gsrvlkyfp8gn"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/urw-base35")
    (synopsis "Replacement for Adobe's Zapf Chancery font")
    (description
     "This package provides a drop-in replacement for the Zapf Chancery
font from Adobe's basic set.")
    (license license:gpl3+)))

(define-public texlive-zapfding
  (package
    (name "texlive-zapfding")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "dvips/zapfding/"
                                     "fonts/afm/adobe/zapfding/"
                                     "fonts/afm/urw/zapfding/"
                                     "fonts/map/dvips/zapfding/"
                                     "fonts/tfm/adobe/zapfding/"
                                     "fonts/tfm/urw35vf/zapfding/"
                                     "fonts/type1/urw/zapfding/"
                                     "tex/latex/zapfding/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17mls8wilz9api9ivsbcczpiqp1f39qy8wa6ajssi8zhnc5lq7zn"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/urw-base35")
    (synopsis "Replacement for Adobe's Zapfding font")
    (description
     "This package provides a drop-in replacement for the Zapfding font from
Adobe's basic set.")
    ;; No license version specified.
    (license license:gpl3+)))

(define-public texlive-zbmath-review-template
  (package
    (name "texlive-zbmath-review-template")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/zbmath-review-template/"
                                     "tex/xelatex/zbmath-review-template/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m5q03vjscla4wmy9fr3kl23pk8zmqw760i89zg62pj4np8vyplj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/zbmath-review-template")
    (synopsis "Template for a zbMATH Open review")
    (description
     "This package contains a template for zbMATH Open reviews.  It will show
what your review will look like on zbMATH Open and you can test whether your
LaTeX-Code will compile on our system.")
    (license (list license:gpl3 license:cc-by-sa4.0))))

(define-public texlive-zhmetrics
  (package
    (name "texlive-zhmetrics")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/zhmetrics/"
                                     "fonts/tfm/zhmetrics/cyberb/"
                                     "fonts/tfm/zhmetrics/gbk/"
                                     "fonts/tfm/zhmetrics/gbkfs/"
                                     "fonts/tfm/zhmetrics/gbkhei/"
                                     "fonts/tfm/zhmetrics/gbkkai/"
                                     "fonts/tfm/zhmetrics/gbkli/"
                                     "fonts/tfm/zhmetrics/gbksong/"
                                     "fonts/tfm/zhmetrics/gbkyou/"
                                     "fonts/tfm/zhmetrics/unifs/"
                                     "fonts/tfm/zhmetrics/unihei/"
                                     "fonts/tfm/zhmetrics/unikai/"
                                     "fonts/tfm/zhmetrics/unili/"
                                     "fonts/tfm/zhmetrics/unisong/"
                                     "fonts/tfm/zhmetrics/uniyou/"
                                     "source/fonts/zhmetrics/"
                                     "tex/generic/zhmetrics/"
                                     "tex/latex/zhmetrics/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0953rxs3k3vil9aq9v8hacwbnchz73ql8xp0dp0ynpw6v8iabxyg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/zhmetrics")
    (synopsis "TFM subfont files for using Chinese fonts in 8-bit TeX")
    (description
     "These are metrics to use existing Chinese TrueType fonts in workflows
that use LaTeX and @command{dvipdfmx}, or pdfLaTeX.  The fonts themselves are
not included in the package.  Six font families are supported: Kai, Song,
Lishu, Fangsong, Youyuan and Hei.  Two encodings (GBK and UTF-8) are
supported.")
    (license license:lppl)))

(define-public texlive-zhmetrics-uptex
  (package
    (name "texlive-zhmetrics-uptex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/zhmetrics-uptex/"
                                     "fonts/tfm/public/zhmetrics-uptex/"
                                     "fonts/vf/public/zhmetrics-uptex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1598l2k32g8nvxqzbgc6mzsib4v0pmsn9h221r4m1d95vm3n0pvd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/zhmetrics-uptex")
    (synopsis "Chinese font metrics for upTeX")
    (description
     "The package contains some Chinese font metrics (JFM, VF, etc) for upTeX
engine, together with a simple DVIPDFMx font mapping of Fandol fonts for
DVIPDFMx.")
    (license license:lppl1.3+)))

(define-public texlive-zhnumber
  (package
    (name "texlive-zhnumber")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/zhnumber/"
                                     "source/latex/zhnumber/"
                                     "tex/latex/zhnumber/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "170lwb97ji9zgmmayzxmpawjkzk50g7rwqmwr11w72zfqkc2v9g2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    ;; FIXME: I couldn't find how to build this package from source.
    (arguments
     (list #:phases #~(modify-phases %standard-phases (delete 'build))))
    (home-page "https://ctan.org/pkg/zhnumber")
    (synopsis "Typeset Chinese representations of numbers")
    (description
     "The package provides commands to typeset Chinese representations of
numbers.  The main difference between this package and CJKnumb is that the
commands provided are expandable in the proper way.")
    (license license:lppl1.3c)))

(define-public texlive-zhspacing
  (package
    (name "texlive-zhspacing")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/zhspacing/"
                                     "tex/context/third/zhspacing/"
                                     "tex/generic/zhspacing/"
                                     "tex/xelatex/zhspacing/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02hwa7yjwb6wxkkib83mjdbara5zcsixbp5xlawri8n9ah54vxjm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/zhspacing")
    (synopsis "Spacing for mixed CJK-English documents in XeTeX")
    (description
     "The package manages spacing in a CJK document; between consecutive Chinese
letters, spaces are ignored, but a consistent space is inserted between Chinese
text and English (or mathematics).  The package may be used by any document
format under XeTeX.")
    (license license:lppl1.3+)))

(define-public texlive-zref
  (package
    (name "texlive-zref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/zref/" "source/latex/zref/"
                                     "tex/latex/zref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1icii7zv0k6yxw658b0m09xnkg937i0xibcxh277zx59isc00dff"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://github.com/ho-tex/zref")
    (synopsis "Reference scheme for LaTeX")
    (description "This package offers a means to remove the limitation, of
only two properties, that is inherent in the way LaTeX's reference system
works.  The package implements an extensible referencing system, where
properties may be defined and used in the course of a document.  It provides
an interface for macro programmers to access the new reference scheme and some
modules that use it.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-fonts-adobe-zapfding texlive-zapfding)

(define-public texlive-rsfs
  (package
    (name "texlive-rsfs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/rsfs/"
                                     "fonts/afm/public/rsfs/"
                                     "fonts/map/dvips/rsfs/"
                                     "fonts/source/public/rsfs/"
                                     "fonts/tfm/public/rsfs/"
                                     "fonts/type1/public/rsfs/"
                                     "tex/plain/rsfs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sa32wnsj84wbwqji1fb4k9ik99dy5ji7zz4v0xbd7306agyhns5"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-cm")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-cm texlive-metafont))
    (home-page "https://ctan.org/pkg/rsfs")
    (synopsis "Ralph Smith's Formal Script font")
    (description
     "The fonts provide uppercase formal script letters for use as symbols in
scientific and mathematical typesetting (in contrast to the informal script
fonts such as that used for the calligraphic symbols in the TeX maths symbol
font).  The fonts are provided as Metafont source, and as derived Adobe Type
1 format.  LaTeX support, for using these fonts in mathematics, is available
via one of the packages @code{calrsfs} and @code{mathrsfs}.")
    (license (license:fsf-free "http://mirrors.ctan.org/fonts/rsfs/README"))))

(define-deprecated-package texlive-fonts-rsfs texlive-rsfs)

(define-public texlive-es-tex-faq
  (package
    (name "texlive-es-tex-faq")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/es-tex-faq/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wp5jx1qs4yp3y4qpwqhpw7rnilw3vb2z5xb4lzwph6zw27jf6sd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/faq-es")
    (synopsis "CervanTeX (Spanish TeX Group) FAQ")
    (description
     "This package provides the SGML source, converted LaTeX version, and
readable copies of the FAQ from the Spanish TeX users group.")
    (license license:lppl)))

(define-public texlive-eskd
  (package
    (name "texlive-eskd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/eskd/" "source/latex/eskd/"
                                     "tex/latex/eskd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1q83pvycckrmyaiwwg3mcl77jy5wrcy8jy7kz004x7asq2p0a2ls"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eskd")
    (synopsis "Modern Russian typesetting")
    (description
     "The class offers modern Russian text formatting, in accordance with
accepted design standards.  Fonts not (apparently) available on CTAN are
required for use of the class.")
    (license license:lppl)))

(define-public texlive-eskdx
  (package
    (name "texlive-eskdx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/eskdx/" "tex/latex/eskdx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07c9gbvgr4455s5sfsdjxbbdllx2lhmb5d1c2sdk7rpkvjh64lv8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eskdx")
    (synopsis "Modern Russian typesetting")
    (description
     "Eskdx is a collection of LaTeX classes and packages to typeset textual
and graphical documents in accordance with Russian (and probably post USSR)
standards for designers.")
    (license license:lppl1.3+)))

(define-public texlive-eso-pic
  (package
    (name "texlive-eso-pic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/eso-pic/" "source/latex/eso-pic/"
                                     "tex/latex/eso-pic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cz1al3xddbhpdq322i5pp11fmwi8jmyvi337753cnc4pz03s1qa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eso-pic")
    (synopsis "Add picture commands (or backgrounds) to every page")
    (description
     "The package adds one or more user commands to LaTeX's @code{shipout}
routine, which may be used to place the output at fixed positions.  The
@code{grid} option may be used to find the correct places.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-eso-pic texlive-eso-pic)

(define-public texlive-eepic
  (package
    (name "texlive-eepic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/eepic/"
                                     "tex/latex/eepic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16v8j3f8bgww9adddpfzpwd5q9kvak7xnp5kkvkrvhw8vshdspaa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/eepic")
    (synopsis "Extensions to @code{epic} and the LaTeX drawing tools")
    (description
     "This package provides extensions to @code{epic} and the LaTeX picture
drawing environment.  It includes the drawing of lines at any slope, the
drawing of circles in any radii, and the drawing of dotted and dashed lines
much faster with much less TeX memory, and providing several new commands for
drawing ellipses, arcs, splines, and filled circles and ellipses.")
    (license license:public-domain)))

(define-deprecated-package texlive-latex-eepic texlive-eepic)

(define-public texlive-enotez
  (package
    (name "texlive-enotez")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/enotez/" "tex/latex/enotez/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0498zr9niylpj9q5ndnj52lb06cj0b424yyq587vqhckxq4l24ik"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/enotez")
    (synopsis "Support for end-notes")
    (description
     "This package allows nested endnotes, supports @code{hyperref} and
provides means for easy customization of the list of notes.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-enotez texlive-enotez)

(define-public texlive-endnotes
  (package
    (name "texlive-endnotes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/endnotes/" "tex/latex/endnotes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1s7j5sg8fbhifng0gfqnghbvalbbh0p7j9v06r660w089364ypwz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/endnotes")
    (synopsis "Place footnotes at the end")
    (description
     "The @code{endnotes} package can be used to accumulate notes (using the
@code{\\endnote} command, which can be used as a replacement for
@code{\\footnote}), and place them at the end of the section, chapter or
document.")
    (license license:lppl1.2+)))

(define-public texlive-endnotesj
  (package
    (name "texlive-endnotesj")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/endnotesj/"
                                     "tex/latex/endnotesj/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yv8jzvps79svd4013f6cpm41mh3mx2m64jx7bv01ryqdgjzq2g9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/endnotesj")
    (synopsis "Japanese-style endnotes")
    (description
     "This package provides customized styles for endnotes to be used with
Japanese documents.  It can be used on pLaTeX, upLaTeX, and LuaLaTeX
(LuaTeX-ja).")
    (license license:bsd-3)))

(define-public texlive-enumitem
  (package
    (name "texlive-enumitem")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/enumitem/" "tex/latex/enumitem/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qwbyjb4a82qjxrfmz06v3w5vly75id4ix4sw7lz2az68kz080dv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/enumitem")
    (synopsis "Control layout of itemize, enumerate, description")
    (description
     "This package provides user control over the layout of the three basic
list environments: enumerate, itemize and description.  It supersedes both
@code{enumerate} and @code{mdwlist} (providing well-structured replacements
for all their functionality), and in addition provides functions to compute
the layout of labels, and to clone the standard environments, to create new
environments with counters of their own.")
    (license license:expat)))

(define-deprecated-package texlive-latex-enumitem texlive-enumitem)

(define-public texlive-multido
  (package
    (name "texlive-multido")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/multido/"
                                     "source/generic/multido/"
                                     "tex/generic/multido/" "tex/latex/multido/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vwf2naw5bgs93s2gcmf226f60ws9z6cmw6gi1562fs8vg4mnjsh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/multido")
    (synopsis "Loop facility for Generic TeX")
    (description
     "The package provides the @code{\\multido} command, which was originally
designed for use with PSTricks.  Fixed-point arithmetic is used when working
on the loop variable, so that the package is equally applicable in graphics
applications like PSTricks as it is with the more common integer loops.")
    (license license:lppl)))

(define-public texlive-multirow
  (package
    (name "texlive-multirow")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/multirow/"
                                     "source/latex/multirow/"
                                     "tex/latex/multirow/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18xnxqbkkzblngws1ydmkiwfrf9gvrriqrjpb6g6kmaxciwypqd6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/multirow")
    (synopsis "Create tabular cells spanning multiple rows")
    (description
     "The package has a lot of flexibility, including an option for specifying
an entry at the natural width of its text.  The package is distributed with
the @code{bigdelim} and @code{bigstrut} packages, which can be used to
advantage with @code{\\multirow} cells.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-multirow texlive-multirow)

(define-public texlive-overpic
  (package
    (name "texlive-overpic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/overpic/"
                                     "source/latex/overpic/"
                                     "tex/latex/overpic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ax69iiiz58jc8gmz0ay2b84c7j6y45nksx2zdqy1wb91rxhcsyj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/overpic")
    (synopsis "Combine LaTeX commands over included graphics")
    (description
     "The @code{overpic} environment is a cross between the LaTeX
@code{picture} environment and the @code{\\includegraphics} command of
@code{graphicx}.  The resulting picture environment has the same dimensions as
the included graphic.  LaTeX commands can be placed on the graphic at defined
positions; a grid for orientation is available.")
    (license license:lppl1.0+)))

(define-deprecated-package texlive-latex-overpic texlive-overpic)

(define-public texlive-parskip
  (package
    (name "texlive-parskip")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/parskip/"
                                     "source/latex/parskip/"
                                     "tex/latex/parskip/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18yygddxv3kblvf4jhzqa8h1js0n8g1bw723r6ss2hlz4lj64kf0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/parskip")
    (synopsis "Layout with zero @code{\\parindent}, non-zero @code{\\parskip}")
    (description
     "Simply changing @code{\\parskip} and @code{\\parindent} leaves a layout
that is untidy; this package (though it is no substitute for a properly
designed class) helps alleviate this untidiness.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-parskip texlive-parskip)

(define-public texlive-pbox
  (package
    (name "texlive-pbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pbox/"
                                     "source/latex/pbox/"
                                     "tex/latex/pbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "104x4y22msgxhnlz2x331zq7rw28v129s5ym1jqhsk685izb3hcl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pbox")
    (synopsis "@code{\\parbox} with a variable width")
    (description
     "@code{pbox} defines a @code{\\pbox} command which adjusts the box width
to that of the enclosed text, up to the maximum width given.  The package also
defines some associated length commands.")
    (license license:gpl3+)))

(define-deprecated-package texlive-latex-pbox texlive-pbox)

(define-public texlive-pdfpages
  (package
    (name "texlive-pdfpages")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdfpages/" "source/latex/pdfpages/"
                                     "tex/latex/pdfpages/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gsivj0m05i2vsl2j46zgh968j5jds1g3937dcll0zp05dw4s15x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-eso-pic texlive-graphics texlive-oberdiek texlive-tools))
    (home-page "https://ctan.org/pkg/pdfpages")
    (synopsis "Include PDF documents in LaTeX")
    (description
     "This package simplifies the inclusion of external multi-page PDF
documents in LaTeX documents.  Pages may be freely selected and it is possible
to put several logical pages onto each sheet of paper.  Furthermore a lot of
hypertext features like hyperlinks and article threads are provided.  The
package supports pdfTeX (pdfLaTeX) and VTeX.  With VTeX it is even possible to
use this package to insert PostScript files, in addition to PDF files.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-pdfpages texlive-pdfpages)

(define-public texlive-stix2-otf
  (package
    (name "texlive-stix2-otf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/stix2-otf/"
                                     "fonts/opentype/public/stix2-otf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05xqlg61rkfky34x7mc92203z440kanr7bwpmw1djq2y36ql3p1l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/stix2-otf")
    (synopsis "OpenType Unicode text and maths fonts")
    (description
     "The Scientific and Technical Information eXchange (STIX) fonts are
intended to satisfy the demanding needs of authors, publishers, printers, and
others working in the scientific, medical, and technical fields.  They combine
a comprehensive Unicode-based collection of mathematical symbols and alphabets
with a set of text faces suitable for professional publishing.")
    (license license:silofl1.1)))

(define-public texlive-sidecap
  (package
    (name "texlive-sidecap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sidecap/" "source/latex/sidecap/"
                                     "tex/latex/sidecap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1h4ysw90dpvnj0x1j9krx40078kyzzs4ynpjz7y50v9hwrrrynjk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sidecap")
    (synopsis "Typeset captions sideways")
    (description
     "The @code{sidecap} package defines environments called @code{SCfigure}
and @code{SCtable} (analogous to @code{figure} and @code{table}) to typeset
captions sideways.  Options include @code{outercaption}, @code{innercaption},
@code{leftcaption} and @code{rightcaption}.")
    (license license:lppl1.0+)))

(define-deprecated-package texlive-latex-sidecap texlive-sidecap)

(define-public texlive-stmaryrd
  (package
    (name "texlive-stmaryrd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/stmaryrd/"
                                     "fonts/afm/public/stmaryrd/"
                                     "fonts/map/dvips/stmaryrd/"
                                     "fonts/source/public/stmaryrd/"
                                     "fonts/tfm/public/stmaryrd/"
                                     "fonts/type1/public/stmaryrd/"
                                     "source/fonts/stmaryrd/"
                                     "tex/latex/stmaryrd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ljrxbf2p301p4cmadf2w0qb5idvgmx4j6y3kq7qg2v8x4maqqj4"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-cm")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'patch-ins
            (lambda _
              (substitute* "source/fonts/stmaryrd/stmaryrd.ins"
                (("^%% LaTeX2e.*") "\\input docstrip\n")
                (("fontdef\\}\\}" line)
                 (string-append line "\n\\endbatchfile"))))))))
    (native-inputs (list texlive-cm texlive-metafont))
    (home-page "https://ctan.org/pkg/stmaryrd")
    (synopsis "St Mary Road symbols for theoretical computer science")
    (description
     "The fonts were originally distributed as Metafont sources only, but
Adobe Type 1 versions are also now available.  Macro support is provided for
use under LaTeX; the package supports the @code{only} option (provided by the
@code{somedefs} package) to restrict what is loaded, for those who don't need
the whole font.")
    (license license:lppl)))

(define-deprecated-package texlive-fonts-stmaryrd texlive-stmaryrd)

(define-public texlive-subfig
  (package
    (name "texlive-subfig")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/subfig/" "source/latex/subfig/"
                                     "tex/latex/subfig/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bq1328pb1ak91j7q8n1kh2fncr742lvff7apgf8kkxzxjfg2z9r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/subfig")
    (synopsis "Figures broken into subfigures")
    (description
     "The package provides support for the manipulation and reference of small
or sub figures and tables within a single figure or table environment.  It is
convenient to use this package when your subfigures are to be separately
captioned, referenced, or are to be included in the List-of-Figures.  A new
@code{\\subfigure} command is introduced which can be used inside a figure
environment for each subfigure.  An optional first argument is used as the
caption for that subfigure.")
    (license license:lppl)))

(define-public texlive-subfigure
  (package
    (name "texlive-subfigure")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/subfigure/"
                                     "source/latex/subfigure/"
                                     "tex/latex/subfigure/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1327ygajf6gza5msvhfjjnk6r3sw7vb7rxg23v4gx4dmyxqfqrbi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/subfigure")
    (synopsis "Deprecated: Figures divided into subfigures")
    (description
     "This (deprecated) package provides support for the manipulation and
reference of small, or sub, figures and tables within a single figure or table
environment.  It is convenient to use this package when your subfigures are to
be separately captioned, referenced, or are to be included in the
List-of-Figures.  A new @code{\\subfigure} command is introduced which can be
used inside a figure environment for each subfigure.  An optional first
argument is used as the caption for that subfigure.  The package is now
considered obsolete: it was superseded by @code{subfig}, but users may find
the more recent @code{subcaption} package more satisfactory.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-subfigure texlive-subfigure)

(define-public texlive-tabulary
  (package
    (name "texlive-tabulary")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tabulary/" "source/latex/tabulary/"
                                     "tex/latex/tabulary/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00afi9r5264rhfy5kg73fk763i7wm6bvzkmrlg7n17fwl6hx0sa1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tabulary")
    (synopsis "Tabular with variable width columns balanced")
    (description
     "The package defines a @code{tabular*}-like environment, @code{tabulary},
taking a \"total width\" argument as well as the column specifications.  The
environment uses column types @code{L}, @code{C}, @code{R} and @code{J} for
variable width columns (@code{\\raggedright}, @code{\\centering},
@code{\\raggedleft}, and normally justified).  In contrast to
@code{tabularx}'s @code{X} columns, the width of each column is weighted
according to the natural width of the widest cell in the column.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-tabulary texlive-tabulary)

(define-public texlive-tamethebeast
  (package
    (name "texlive-tamethebeast")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/bibtex/tamethebeast/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13shw7hcimckn7pp8pj0cr1zsi1wq6r400x1v6akpmwwjxkw09g5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tamethebeast")
    (synopsis "Manual about bibliographies and especially BibTeX")
    (description
     "This package is an as complete as possible manual about bibliographies
in LaTeX, and thus mainly about BibTeX.")
    (license license:lppl1.3+)))

(define-public texlive-tds
  (package
    (name "texlive-tds")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/tds/" "doc/info/tds.info"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04lhavbayyisxxqfm1vpfq38xx1xwkn136hdnjaa3szky2xyn3yh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tds")
    (synopsis "TeX Directory Structure standard")
    (description
     "This package defines a structure for placement of TeX-related files on
an hierarchical file system, in a way that is well-defined, and is readily
implementable.")
    (license license:fdl1.1+)))

(define-public texlive-tex-font-errors-cheatsheet
  (package
    (name "texlive-tex-font-errors-cheatsheet")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tex-font-errors-cheatsheet/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pfd5qphmizhxb2p4gg6809xcx1rlfkwqa6vs4f74457chcwljwn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tex-font-errors-cheatsheet")
    (synopsis "Cheat sheet outlining the most common TeX font errors")
    (description
     "This is a compact three-pages document highlighting the TeX flow of
integrating fonts, and explains how some of the most common font-related error
messages occur.  Also, hints are given on how to address those.")
    (license license:lppl)))

(define-public texlive-tex-nutshell
  (package
    (name "texlive-tex-nutshell")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/tex-nutshell/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01nmw2lj7dvylfypgyr7lsw1i2b4vlmhd56jyy1grv8hx1rfl0yh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tex-nutshell")
    (synopsis "Short document about TeX principles")
    (description
     "This document is meant for users who are looking for information about
the basics of TeX.  Its main goal is its brevity.  The pure TeX features are
described, no features provided by macro extensions.  Only the last section
gives a summary of plain TeX macros.")
    (license license:public-domain)))

(define-public texlive-tex-overview
  (package
    (name "texlive-tex-overview")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tex-overview/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1agfya9rwvyjvip0alvibimz75jivpf19hp4jvlv7z0n9m26m9jd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tex-overview")
    (synopsis "Overview of the development of TeX")
    (description
     "The document gives a short overview of TeX and its children, as well as
the macro packages LaTeX and ConTeXt.")
    (license license:lppl1.3+)))

(define-public texlive-tex-refs
  (package
    (name "texlive-tex-refs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/tex-refs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1w7hcd3qsdhmb2siakjg2hm3h6kxa90ncsaif9spr4xkxs03ib6l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tex-references")
    (synopsis "References for TeX and Friends")
    (description
     "This is an ongoing project with the aim of providing a help file for
LaTeX (and its friends like ConTeXt, MetaPost, Metafont, etc.) using
DocBook/XML source format.")
    (license license:fdl1.2+)))

(define-public texlive-tex-vpat
  (package
    (name "texlive-tex-vpat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tex-vpat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1y7f87prympxg8av128npsa43cri71jjl9gxq1p04pjlpdjjm0fv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tex-vpat")
    (synopsis "TeX accessibility conformance report")
    (description
     "This package provides the TeX accessibility conformance report based on
ITI VPAT(R) guidelines.")
    (license license:cc-by3.0)))

(define-public texlive-texbytopic
  (package
    (name "texlive-texbytopic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/texbytopic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pnh1hsd6k434c8i1xdjq3ywrwylmryrsl86d6h7i1cnmzz4pwlx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/texbytopic")
    (synopsis "@emph{TeX by Topic} book")
    (description
     "@emph{TeX by Topic} is a book originally published by Addison-Wesley.
It describes itself as ``a TeXnician's reference'', and covers the way
TeX (the engine) works in as much detail as most ordinary TeX programmers will
ever need to know.")
    (license license:fdl1.3+)))

(define-public texlive-texonly
  (package
    (name "texlive-texonly")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/plain/texonly/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h40f8hj03ha0ilpj2fx5kzzvdv0yplmr4528s2rmmy62l9kgdkd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/texonly")
    (synopsis "Sample document in Plain TeX")
    (description
     "This package provides a file written with TeX, not using any packages,
to be compiled with TeX or pdfTeX only, not with LaTeX and al.")
    (license license:lppl1.3c)))

(define-public texlive-threeparttable
  (package
    (name "texlive-threeparttable")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/threeparttable/"
                                     "tex/latex/threeparttable/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05i50k1y736m52903nz4kf2xl23w6y7rrzyacs4kgd1w6kmjm6f7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/threeparttable")
    (synopsis "Tables with captions and notes all the same width")
    (description
     "This package facilitates tables with titles (captions) and notes.  The
title and notes are given a width equal to the body of the table (a
@code{tabular} environment).  By itself, a @code{threeparttable} does not
float, but you can put it in a @code{table} or a @code{table*} or some other
environment.")
    (license (license:fsf-free "file://threeparttable.sty"))))

(define-public texlive-thumbpdf
  (package
    (name "texlive-thumbpdf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/thumbpdf/"
                                     "doc/man/man1/thumbpdf.1"
                                     "doc/man/man1/thumbpdf.man1.pdf"
                                     "scripts/thumbpdf/" "tex/generic/thumbpdf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ya18440rpkav0z1zddzii9jh2swybicj87413l5iin2acrssw42"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "thumbpdf.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/thumbpdf")
    (synopsis "Thumbnails for pdfTeX and dvips/ps2pdf")
    (description
     "This package provides a Perl script that provides support for thumbnails
in pdfTeX and dvips/ps2pdf.  The script uses Ghostscript to generate the
thumbnails which get represented in a TeX readable file that is read by the
package @code{thumbpdf.sty} to automatically include the thumbnails.  This
arrangement works with both plain TeX and LaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-titlepages
  (package
    (name "texlive-titlepages")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/titlepages/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17ib7rpb2dhb2m724x66fdzddv8cqd808wxy5kkvx0vb3rl27hyh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/titlepages")
    (synopsis "Sample titlepages, and how to code them")
    (description
     "The document provides examples of over two dozen title page designs
based on a range of published books and theses, together with the LaTeX code
used to create them.")
    (license license:lppl)))

(define-public texlive-tlc2
  (package
    (name "texlive-tlc2")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tlc2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ysb233rjb8gpl9s35qql1dny5rj6fn8ssy2dqdqsn5xj9pdasyy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tlc2-examples")
    (synopsis "Examples from @emph{The LaTeX Companion}, second edition")
    (description
     "This package provides the source of the examples printed in @emph{The
LaTeX Companion} book, together with necessary supporting files.")
    (license license:lppl)))

(define-public texlive-tlc3-examples
  (package
    (name "texlive-tlc3-examples")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tlc3-examples/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01ny6r3ycji0af0cdywn2fmxd0fyz3y7afdnn983a5gy1j9rza7v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tlc3-examples")
    (synopsis "All examples from @emph{The LaTeX Companion}, third edition")
    (description
     "This package provides the PDFsand sources for all examples from
@emph{The LaTeX Companion}, third edition (Parts I+II), together with
necessary supporting files.")
    (license license:lppl1.3c)))

(define-public texlive-tlmgr-intro-zh-cn
  (package
    (name "texlive-tlmgr-intro-zh-cn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/tlmgr-intro-zh-cn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "127fad3aq66rnn4jkccyw7qc8pdcwapyjb6lj9kn49nqcy3jm6nk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tlmgr-intro-zh-cn")
    (synopsis "Short tutorial on using @command{tlmgr} in Chinese")
    (description
     "This is a Chinese translation of the @command{tlmgr} documentation.  It
introduces some of the common usage of the TeX Live Manager.  The original can
be found in the @code{tlmgrbasics} package.")
    (license license:gpl3+)))

(define-public texlive-tlmgrbasics
  (package
    (name "texlive-tlmgrbasics")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/tlmgrbasics/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mgncnr778i5s310zp7bfcdcilsxlf63cis7iy4hbf9y8qzvjx0h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tlmgrbasics")
    (synopsis "Simplified documentation for @command{tlmgr}")
    (description
     "This package provides simplified documentation for @command{tlmgr}, the
TeX Live manager.  It describes the most commonly-used actions and options in
a convenient format.")
    (license license:gpl2+)))

(define-public texlive-txfonts
  (package
    (name "texlive-txfonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/txfonts/"
                                     "fonts/afm/public/txfonts/"
                                     "fonts/enc/dvips/txfonts/"
                                     "fonts/map/dvips/txfonts/"
                                     "fonts/tfm/public/txfonts/"
                                     "fonts/type1/public/txfonts/"
                                     "fonts/vf/public/txfonts/"
                                     "tex/latex/txfonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "017zjas5y1zlyq0iy4x6mv1qbz23xcy3y5xs0crj6zdnfvnccqgp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/txfonts")
    (synopsis "Times-like fonts in support of mathematics")
    (description
     "Txfonts supplies virtual text roman fonts using Adobe Times (or URW
NimbusRomNo9L) with some modified and additional text symbols in the OT1, T1,
and TS1 encodings; maths alphabets using Times/URW Nimbus; maths fonts
providing all the symbols of the Computer Modern and AMS fonts, including all
the Greek capital letters from CMR; and additional maths fonts of various
other symbols.

The set is complemented by a sans-serif set of text fonts, based on
Helvetica/NimbusSanL, and a monospace set.

All the fonts are in Type 1 format (AFM and PFB files), and are supported by
TeX metrics (VF and TFM files) and macros for use with LaTeX.")
    ;; Any version of the GPL with font exception.
    (license license:gpl3+)))

(define-deprecated-package texlive-fonts-txfonts texlive-txfonts)

(define-public texlive-typehtml
  (package
    (name "texlive-typehtml")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/typehtml/"
                                     "source/latex/typehtml/"
                                     "tex/latex/typehtml/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nmdh2mhkzdqs5y4k95g9il6vz4rgndzhkikiilknkwg1a04rrzi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/typehtml")
    (synopsis "Typeset HTML directly from LaTeX")
    (description
     "This package typesets HTML directly from LaTeX.  It can handle almost
all of HTML2, and most of the math fragment of the draft HTML3.")
    (license license:lppl)))

(define-public texlive-iwona
  (package
    (name "texlive-iwona")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/iwona/"
                                     "fonts/afm/nowacki/iwona/"
                                     "fonts/enc/dvips/iwona/"
                                     "fonts/map/dvips/iwona/"
                                     "fonts/opentype/nowacki/iwona/"
                                     "fonts/tfm/nowacki/iwona/"
                                     "fonts/type1/nowacki/iwona/"
                                     "tex/latex/iwona/"
                                     "tex/plain/iwona/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gk80zj711rcnk06cvszic7lpm06nj47kbypg13rpijdzfsvmi8m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/iwona")
    (synopsis "Sans-serif typeface for TeX")
    (description "Iwona is a two-element sans-serif typeface.  It was created
as an alternative version of the Kurier typeface, which was designed in 1975
for a diploma in typeface design at the Warsaw Academy of Fine Arts under the
supervision of Roman Tomaszewski.  Kurier was designed for linotype
typesetting of newspapers and similar periodicals.  The Iwona fonts are an
alternative version of the Kurier fonts.  The difference lies in the absence
of ink traps which typify the Kurier font.")
    (license license:gfl1.0)))

(define-deprecated-package texlive-fonts-iwona texlive-iwona)

(define-public texlive-jadetex
  (package
    (name "texlive-jadetex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/jadetex.1"
                                     "doc/man/man1/jadetex.man1.pdf"
                                     "doc/man/man1/pdfjadetex.1"
                                     "doc/man/man1/pdfjadetex.man1.pdf"
                                     "doc/otherformats/jadetex/base/"
                                     "source/jadetex/base/"
                                     "tex/jadetex/base/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0acan496ixymwjvygcd5rx5pmz4p5vffzkmazdryw1kpilhiixcx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:create-formats #~(list "jadetex" "pdfjadetex")
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'install 'install-wrappers
            (lambda* (#:key inputs #:allow-other-keys)
              (let ((pdftex (search-input-file inputs "/bin/pdftex"))
                    (bin (string-append #$output "/bin")))
                (mkdir-p bin)
                (with-directory-excursion bin
                  (symlink pdftex "jadetex")
                  (symlink pdftex "pdfjadetex"))))))))
    (propagated-inputs
     (list texlive-amsfonts
           texlive-auxhook
           texlive-babel
           texlive-bigintcalc
           texlive-bitset
           texlive-cm
           texlive-colortbl
           texlive-cyrillic
           texlive-ec
           texlive-etoolbox
           texlive-fancyhdr
           texlive-firstaid
           texlive-gettitlestring
           texlive-graphics
           texlive-graphics-cfg
           texlive-graphics-def
           texlive-hycolor
           texlive-hyperref
           texlive-hyphen-complete
           texlive-iftex
           texlive-infwarerr
           texlive-intcalc
           texlive-kvdefinekeys
           texlive-kvoptions
           texlive-kvsetkeys
           texlive-l3backend
           texlive-l3kernel
           texlive-latex
           texlive-latex-fonts
           texlive-latexconfig
           texlive-letltxmacro
           texlive-ltxcmds
           texlive-marvosym
           texlive-passivetex
           texlive-pdfescape
           texlive-pdftex
           texlive-pdftexcmds
           texlive-psnfss
           texlive-refcount
           texlive-rerunfilecheck
           texlive-stmaryrd
           texlive-symbol
           texlive-tex
           texlive-tex-ini-files
           texlive-tipa
           texlive-tools
           texlive-ulem
           texlive-unicode-data
           texlive-uniquecounter
           texlive-url
           texlive-wasysym
           texlive-zapfding))
    (home-page "https://www.ctan.org/pkg/jadetex/")
    (synopsis "TeX macros to produce TeX output using OpenJade")
    (description "JadeTeX is a companion package to the OpenJade DSSSL
processor.  OpenJade applies a DSSSL stylesheet to an SGML or XML document.
The output of this process can be in a number of forms, including a set of
high level LaTeX macros.  It is the task of the JadeTeX package to transform
these macros into DVI/PostScript (using the @command{jadetex} command) or
Portable Document Format (PDF) form (using the @command{pdfjadetex}
command).")
    ;; The license text is found at the header of the jadetex.dtx file.
    (license license:expat)))

(define-public texlive-japanese-mathformulas
  (package
    (name "texlive-japanese-mathformulas")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/japanese-mathformulas/"
                                     "tex/lualatex/japanese-mathformulas/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a5kqgkl89m5yc9zgkhlz44dvvi52jfaja3lwcf7g7q039k2h6fg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/japanese-mathformulas")
    (synopsis "Compiling basic math formulas in Japanese using LuaLaTeX")
    (description
     "This is a style file for compiling basic maths formulas in Japanese
using LuaLaTeX.  @code{\\NewDocumentCommand} allows you to specify whether the
formula should be used within a sentence or on a new line.")
    (license license:lppl1.3c)))

(define-public texlive-japanese-otf
  (package
    (name "texlive-japanese-otf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/japanese-otf/"
                                     "fonts/tfm/public/japanese-otf/"
                                     "fonts/vf/public/japanese-otf/"
                                     "source/fonts/japanese-otf/"
                                     "tex/platex/japanese-otf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "199cipyli3l5man5gbhx3djvh4xs0vhmsaxmlvph4kvlhwcmhzm3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/japanese-otf")
    (synopsis "Advanced font selection for platex and its friends")
    (description
     "The package contains pLaTeX support files and virtual fonts for
supporting a wide variety of fonts in LaTeX using the pTeX engine.")
    (license license:bsd-3)))

(define-public texlive-jieeetran
  (package
    (name "texlive-jieeetran")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/jieeetran/"
                                     "doc/bibtex/jieeetran/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "122g618j9wli9amx9c82whjp81i5cpjz1mj4pnmyfa8x5mfdh6dp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jieeetran")
    (synopsis
     "UnofficiaL BibTeX style for citing Japanese articles in IEEE format")
    (description
     "This package provides an unofficial BibTeX style for authors trying to
cite Japanese articles in the Institute of Electrical and Electronics
Engineers (IEEE) format.")
    (license license:expat)))

(define-public texlive-jlreq
  (package
    (name "texlive-jlreq")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jlreq/"
                                     "fonts/tfm/public/jlreq/"
                                     "fonts/vf/public/jlreq/"
                                     "source/latex/jlreq/"
                                     "tex/latex/jlreq/"
                                     "tex/luatex/jlreq/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06nbsmmqxwnhikbgkyvwdmwipyw9m517h0zyigynawna6x4i19yp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jlreq")
    (synopsis
     "Japanese document class based on requirements for Japanese text layout")
    (description
     "This package provides a Japanese document class based on requirements
for Japanese text layout.  The class file and the JFM (Japanese font metric)
files for LuaTeX-ja, pLaTeX, or upLaTeX are provided.")
    (license license:bsd-2)))

(define-public texlive-jlreq-deluxe
  (package
    (name "texlive-jlreq-deluxe")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/platex/jlreq-deluxe/"
                                     "fonts/tfm/public/jlreq-deluxe/"
                                     "fonts/vf/public/jlreq-deluxe/"
                                     "tex/platex/jlreq-deluxe/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0clyspji3pdkxdshwksbkldvv7qhph4gqwlmvjp6080r4gjm5x8j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jlreq-deluxe")
    (synopsis "Multi-weight Japanese font support for the @code{jlreq} class")
    (description
     "This package provides multi-weight Japanese font support for the
@code{jlreq} class.")
    (license license:expat)))

(define-public texlive-jpneduenumerate
  (package
    (name "texlive-jpneduenumerate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jpneduenumerate/"
                                     "tex/latex/jpneduenumerate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ndg4ig5bg9ns2pxcf070c7jyh7d7r3r7c7xg5d99k3qlg4vkd9n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jpneduenumerate")
    (synopsis "Enumerative expressions in Japanese education")
    (description
     "Mathematical equation representation in Japanese education differs
somewhat from the standard LaTeX writing style.  This package introduces
enumerative expressions in Japanese education.")
    (license license:expat)))

(define-public texlive-jpnedumathsymbols
  (package
    (name "texlive-jpnedumathsymbols")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jpnedumathsymbols/"
                                     "tex/latex/jpnedumathsymbols/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ap370bp831xxrq45zllyrbhhxs0yv3qb1l5pkpvgsildfk5rk7m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jpnedumathsymbols")
    (synopsis "Mathematical equation representation in Japanese education")
    (description
     "Mathematical equation representation in Japanese education differs
somewhat from the standard LaTeX writing style.  This package introduces
mathematical equation representation in Japanese education.")
    (license license:expat)))

(define-public texlive-kanbun
  (package
    (name "texlive-kanbun")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/kanbun/" "tex/latex/kanbun/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a922jly8f791r4jbz4097h8js5z29435zphm5i52pvkl6p245wy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/kanbun")
    (synopsis "Typeset kanbun-kundoku with support for kanbun annotation")
    (description
     "This package allows users to manually input macros for elements in
a kanbun-kundoku (Han Wen Xun Du) paragraph.  More importantly, it accepts
plain text input in the kanbun annotation form when used with LuaLaTeX, which
allows typesetting kanbun-kundoku paragraphs efficiently.")
    (license license:lppl1.3+)))

(define-public texlive-libertine
  (package
    (name "texlive-libertine")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/libertine/"
                                     "fonts/enc/dvips/libertine/"
                                     "fonts/map/dvips/libertine/"
                                     "fonts/opentype/public/libertine/"
                                     "fonts/tfm/public/libertine/"
                                     "fonts/type1/public/libertine/"
                                     "fonts/vf/public/libertine/"
                                     "tex/latex/libertine/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fw0pldmyjm7p59n951ayf4kc5wb5hrif5lhc4kiw8cgp82inxcm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-fontaxes
           texlive-iftex
           texlive-mweights
           texlive-xkeyval))
    (home-page "https://ctan.org/pkg/libertine")
    (synopsis "Use of Linux Libertine and Biolinum fonts with LaTeX")
    (description
     "The package provides the Libertine and Biolinum fonts in both Type 1 and
OTF styles, together with support macros for their use.  Monospaced and
display fonts, and the keyboard set are also included, in OTF style, only.
The @code{mweights} package is used to manage the selection of font weights.")
    (license (list license:gpl2+        ; with font exception
                   license:silofl1.1
                   license:lppl))))

(define-public texlive-librarian
  (package
    (name "texlive-librarian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/librarian/"
                                     "tex/generic/librarian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a40ac9vg2niafg6dd2iv0c5nrxqxz8vhh2awdw756xsd0znb5n0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/librarian")
    (synopsis "Tools to create bibliographies in TeX")
    (description
     "The package extracts information in @file{.bib} files, makes it
available in the current document, and sorts lists of entries according to
that information and the user's specifications.  Citation and bibliography
styles can then be written directly in TeX, without any use of BibTeX.  The
package works with all formats that use plain TeX's basic syntactic sugar; the
distribution includes a third-party file for ConTeXt and a style file for
LaTeX.")
    (license license:lppl)))

(define-public texlive-dejavu
  (package
    (name "texlive-dejavu")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/dejavu/"
                                     "fonts/afm/public/dejavu/"
                                     "fonts/enc/dvips/dejavu/"
                                     "fonts/map/dvips/dejavu/"
                                     "fonts/tfm/public/dejavu/"
                                     "fonts/truetype/public/dejavu/"
                                     "fonts/type1/public/dejavu/"
                                     "fonts/vf/public/dejavu/"
                                     "tex/latex/dejavu/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y4qf5jl0xncah9nkcaalmy69wwq02n3j895zp71n2p0nfi24aka"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dejavu")
    (synopsis "LaTeX support for the DejaVu fonts")
    (description
     "The package contains LaTeX support for the DejaVu fonts, which are
derived from the Vera fonts but contain more characters and styles.  The fonts
are included in the original TrueType format, and in converted Type 1 format.
The (currently) supported encodings are: OT1, T1, IL2, TS1, T2*, X2, QX, and
LGR.  The package doesn't (currently) support mathematics.")
    (license license:lppl)))

(define-public texlive-titlesec
  (package
    (name "texlive-titlesec")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/titlesec/" "tex/latex/titlesec/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n0i2icwra1wrpv1k9d2sgrg5b5z5z08i6323kv7rm3m3m5kbfrz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/titlesec")
    (synopsis "Select alternative section titles")
    (description
     "This package provides an interface to sectioning commands for selection
from various title styles, e.g. for marginal titles and to change the font of
all headings with a single command, also providing simple one-step page
styles.  It also includes a package to change the page styles when there are
floats in a page.  You may assign headers/footers to individual floats, too.")
    (license license:expat)))

(define-deprecated-package texlive-latex-titlesec texlive-titlesec)

(define-public texlive-type1cm
  (package
    (name "texlive-type1cm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/type1cm/" "source/latex/type1cm/"
                                     "tex/latex/type1cm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1922af5xvhrh4l8rqwz3bjd1gqvzfkxrfim28rpnvbx4n7jl6sdh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/type1cm")
    (synopsis "Arbitrary size font selection in LaTeX")
    (description
     "LaTeX, by default, restricts the sizes at which you can use its default
computer modern fonts, to a fixed set of discrete sizes (effectively, a set
specified by Knuth).  The @code{type1cm} package removes this restriction;
this is particularly useful when using scalable versions of the @code{cm}
fonts (Bakoma, or the versions from BSR/Y&Y, or True Type versions from Kinch,
PCTeX, etc.).  Note that the LaTeX distribution now contains a package
@code{fix-cm}, which performs the task of @code{type1cm}, as well as doing the
same job for T1- and TS1-encoded @code{ec} fonts.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-type1cm texlive-type1cm)

(define-public texlive-lh
  (package
    (name "texlive-lh")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/lh/"
                                     "fonts/source/lh/base/"
                                     "fonts/source/lh/lh-XSlav/"
                                     "fonts/source/lh/lh-conc/"
                                     "fonts/source/lh/lh-lcy/"
                                     "fonts/source/lh/lh-ot2/"
                                     "fonts/source/lh/lh-t2a/"
                                     "fonts/source/lh/lh-t2b/"
                                     "fonts/source/lh/lh-t2c/"
                                     "fonts/source/lh/lh-t2d/"
                                     "fonts/source/lh/lh-x2/"
                                     "fonts/source/lh/nont2/"
                                     "fonts/source/lh/specific/"
                                     "source/fonts/lh/"
                                     "source/latex/lh/"
                                     "tex/latex/lh/"
                                     "tex/plain/lh/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cqwns4zy1847fn3dp8z3wbfpy4dl05cr065nk9k65fmp7wksnjk"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-cm"
                                               "texlive-metafont")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-cm texlive-metafont))
    (propagated-inputs (list texlive-ec))
    (home-page "https://ctan.org/pkg/lh")
    (synopsis "Cyrillic fonts that support LaTeX standard encodings")
    (description
     "The LH fonts address the problem of the wide variety of alphabets that
are written with Cyrillic-style characters.  The fonts are the original basis
of the set of T2* and X2 encodings that are now used when LaTeX users need to
write in Cyrillic languages.  Macro support in standard LaTeX encodings is
offered through the latex-cyrillic and t2 bundles, and the package itself
offers support for other (more traditional) encodings.  The fonts, in the
standard T2* and X2 encodings are available in Adobe Type 1 format, in the
CM-Super family of fonts.  The package also offers its own LaTeX support for
OT2 encoded fonts, CM bright shaped fonts and Concrete shaped fonts.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-lh texlive-lh)

(define-public texlive-marvosym
  (package
    (name "texlive-marvosym")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/marvosym/"
                                     "fonts/afm/public/marvosym/"
                                     "fonts/map/dvips/marvosym/"
                                     "fonts/tfm/public/marvosym/"
                                     "fonts/truetype/public/marvosym/"
                                     "fonts/type1/public/marvosym/"
                                     "source/fonts/marvosym/"
                                     "tex/latex/marvosym/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16s5ibpw6c9d3vzc82hfn90dg643xlracivikdbr9s43f2ayak41"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/marvosym")
    (synopsis "Martin Vogel's Symbols (marvosym) font")
    (description
     "Martin Vogel's Symbol font (marvosym) contains the Euro currency symbol
as defined by the European commission, along with symbols for structural
engineering; symbols for steel cross-sections; astronomy signs (sun, moon,
planets); the 12 signs of the zodiac; scissor symbols; CE sign and others.
The package contains both the original TrueType font and the derived Type
1 font, together with support files for TeX (LaTeX).")
    (license (list license:lppl          ;for TeX support files
                   license:silofl1.1)))) ;for fonts

(define-public texlive-metapost
  (package
    (name "texlive-metapost")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/dvitomp.1"
                                     "doc/man/man1/dvitomp.man1.pdf"
                                     "doc/man/man1/mpost.1"
                                     "doc/man/man1/mpost.man1.pdf"
                                     "doc/metapost/base/"
                                     "fonts/afm/metapost/"
                                     "fonts/enc/dvips/metapost/"
                                     "fonts/map/dvips/metapost/"
                                     "fonts/tfm/metapost/"
                                     "fonts/type1/metapost/"
                                     "metapost/base/"
                                     "metapost/config/"
                                     "metapost/misc/"
                                     "metapost/support/"
                                     "tex/generic/metapost/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11ily9x63q2gk41mxv5xggaszp1fwkc7qy10sklqw60arr106h4h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-kpathsea texlive-metapost-bin))
    (home-page "https://ctan.org/pkg/metapost")
    (synopsis "Create scalable illustrations")
    (description
     "MetaPost uses a language based on that of Metafont to produce precise
technical illustrations.  Its output is scalable PostScript or SVG, rather
than the bitmaps Metafont creates.")
    (license license:lppl)))

(define-public texlive-metapost-bin
  (package
    (inherit texlive-bin)
    (name "texlive-metapost-bin")
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(delete "--enable-web2c" #$flags))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'install
              (lambda _
                (let ((bin (string-append #$output "/bin")))
                  (with-directory-excursion "texk/web2c"
                    (invoke "make" "mpost")
                    (install-file "mpost" bin))
                  (with-directory-excursion bin
                    (for-each (lambda (link) (symlink "mpost" link))
                              '("dvitomp" "mfplain" "r-mpost"))))))))))
    (native-inputs (list pkg-config))
    (inputs (modify-inputs (package-inputs texlive-bin)
              (append cairo mpfi mpfr)))
    (home-page (package-home-page texlive-metapost))
    (synopsis "Binary for @code{texlive-metapost}")
    (description
     "This package provides the binary for @code{texlive-metapost}.")
    (license (package-license texlive-metapost))))

(define-public texlive-acmart
  (package
    (name "texlive-acmart")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/acmart/" "doc/latex/acmart/"
                                     "source/latex/acmart/" "tex/latex/acmart/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ffmkpqa7nvzyavx7m4n9l22xidwkywm987h3xnzb22ca5fa88vi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/acmart")
    (synopsis "Class for typesetting publications of ACM")
    (description
     "This package provides a class for typesetting publications of the
Association for Computing Machinery (ACM).")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-acmart texlive-acmart)

(define-public texlive-varwidth
  (package
    (name "texlive-varwidth")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/varwidth/" "tex/latex/varwidth/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jcrv4klcjpl17ml0zyqfvkrq6qwn2imxv8syqs5m6qk0fk7hg6l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/varwidth")
    (synopsis "Variable-width @code{minipage}")
    (description
     "The @code{varwidth} environment is superficially similar to @code{minipage},
but the specified width is just a maximum value -- the box may get a narrower
natural width.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-varwidth texlive-varwidth)

(define-public texlive-wasy
  (package
    (name "texlive-wasy")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/wasy/" "fonts/source/public/wasy/"
                                     "fonts/tfm/public/wasy/" "tex/plain/wasy/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1swzxgld3lndi5q0q6zkwbw06ndh13fvp04as7zpwyhh646s0hbx"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-cm")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-cm texlive-metafont))
    (home-page "https://ctan.org/pkg/wasy")
    (synopsis "Waldi symbol fonts")
    (description "This package provides the @code{wasy} (Waldi symbol) fonts,
in the Metafont and Adobe Type 1 formats.  Support under LaTeX is provided by
the @code{wasysym} package.")
    (license license:public-domain)))

(define-public texlive-wasy-type1
  (package
    (name "texlive-wasy-type1")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/wasy-type1/"
                                     "fonts/afm/public/wasy-type1/"
                                     "fonts/map/dvips/wasy-type1/"
                                     "fonts/type1/public/wasy-type1/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01xwryijs787ab4ayfsj44ylf72s0zkm49zm0yk4ghs4vck2qvq3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-wasy))
    (home-page "https://ctan.org/pkg/wasy-type1")
    (synopsis "Type 1 versions of @code{wasy} fonts")
    (description
     "This package provides converted (Adobe Type 1) outlines of the
@code{wasy} fonts.")
    (license license:public-domain)))

(define-public texlive-wasysym
  (package
    (name "texlive-wasysym")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/wasysym/" "source/latex/wasysym/"
                                     "tex/latex/wasysym/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n0rrrh510hy04a4fkxqh7skwfhp3xiiji78cw3mc65g06h1jyjc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/wasysym")
    (synopsis "LaTeX support for the @code{wasy} fonts")
    (description
     "The @code{wasy} (Waldi Symbol) font by Roland Waldi provides many glyphs
like male and female symbols and astronomical symbols, as well as the complete
@code{lasy} font set and other odds and ends.  The @code{wasysym} package
implements an easy to use interface for these symbols.")
    (license license:lppl1.3c)))

(define-deprecated-package texlive-latex-wasysym texlive-wasysym)

(define-public texlive-willowtreebook
  (package
    (name "texlive-willowtreebook")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/willowtreebook/"
                                     "tex/latex/willowtreebook/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rv6pmyl02fpysviz4mvz9az9bgk96p6s7mbi9ykxxp74xzh8jik"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/willowtreebook")
    (synopsis "Easy basic book class, built on @code{memoir}")
    (description
     "The @code{willowtreebook} class is a simple book class, which the author
uses for his lecture notes to be found on his web page Benjamin McKay.  It
actually just selects options for the more sophisticated @code{memoir}
class.")
    (license license:lppl1.3c)))

(define-public texlive-wrapfig
  (package
    (name "texlive-wrapfig")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/wrapfig/" "tex/latex/wrapfig/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wk1vp0dqsp597xzsqbwj8xk80v7d77qmpjir84n54f920rf9ka9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/wrapfig")
    (synopsis "Produces figures which text can flow around")
    (description
     "This package allows figures or tables to have text wrapped around them.
It does not work in combination with list environments, but can be used in a
@code{parbox} or @code{minipage}, and in two-column format.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-wrapfig texlive-wrapfig)

(define-public texlive-ucharcat
  (package
    (name "texlive-ucharcat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ucharcat/"
                                     "source/latex/ucharcat/"
                                     "tex/latex/ucharcat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0r6mphnn26053vb4bgw1zjhw7y7xjavii9hnn7607cbscnx5f9di"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ucharcat")
    (synopsis
     "Implementation of the XeTeX @code{\\Ucharcat} command for LuaTeX")
    (description
     "The package implements the @code{\\Ucharcat} command for LuaLaTeX.
@code{\\Ucharcat} is a new primitive in XeTeX, an extension of the existing
@code{\\Uchar} command, that allows the specification of the catcode as well
as character code of the character token being constructed.")
    (license license:lppl)))

(define-public texlive-ucs
  (package
    (name "texlive-ucs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ucs/" "fonts/enc/dvips/ucs/"
                                     "source/latex/ucs/" "tex/latex/ucs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ihsx71ignmyp7hrpnq90p1cl01z4lw9fldhg1897aw1l1bpnagi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ucs")
    (synopsis "Extended UTF-8 input encoding support for LaTeX")
    (description
     "The bundle provides the @code{ucs} package, and @file{utf8x.def},
together with a large number of support files.  The @file{utf8x.def}
definition file for use with @code{inputenc} covers a wider range of Unicode
characters than does @file{utf8.def} in the LaTeX distribution.  The package
provides facilities for efficient use of its large sets of Unicode characters.
Glyph production may be controlled by various options, which permits use of
non-ASCII characters when coding mathematical formulae.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-ucs texlive-ucs)

(define-public texlive-preview
  (package
    (name "texlive-preview")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/preview/" "source/latex/preview/"
                                     "tex/latex/preview/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yv4fm93ffh6gggqb90qcs7pczn5ff9y5xghxpq5va5hsmh169zx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/preview")
    (synopsis "Extract bits of a LaTeX source for output")
    (description
     "The main purpose of the preview package is the extraction of selected
elements from a LaTeX source, like formulas or graphics, into separate
pages of a DVI file.  A flexible and convenient interface allows it to
specify what commands and constructs should be extracted.  This works
with DVI files postprocessed by either Dvips and Ghostscript or
dvipng, but it also works when you are using PDFTeX for generating PDF
files.")
    (license license:gpl3+)))

(define-deprecated-package texlive-latex-preview texlive-preview)

(define-public texlive-acronym
  (package
    (name "texlive-acronym")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/acronym/" "source/latex/acronym/"
                                     "tex/latex/acronym/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0p2sws3qy7wv0v6bsy6c5j36n9s1ps7b1z7dmg1370schrjpqnfh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/acronym")
    (synopsis "Expand acronyms at least once")
    (description
     "This package ensures that all acronyms used in the text are spelled out
in full at least once.  It also provides an environment to build a list of
acronyms used.  The package is compatible with PDF bookmarks.  The package
requires the @code{suffix} package, which in turn requires that it runs under
e-TeX.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-acronym texlive-acronym)

(define-public texlive-pdftex
  (package
    (name "texlive-pdftex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/pdfetex.1"
                                     "doc/man/man1/pdfetex.man1.pdf"
                                     "doc/man/man1/pdftex.1"
                                     "doc/man/man1/pdftex.man1.pdf"
                                     "doc/pdftex/"
                                     "fonts/map/dvips/dummy-space/"
                                     "fonts/tfm/public/pdftex/"
                                     "fonts/type1/public/pdftex/"
                                     "scripts/simpdftex/"
                                     "tex/generic/config/pdftex-dvi.tex"
                                     "tex/generic/pdftex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03l4qmlx3ax9dfgbp6266l2hfxgra53n5an5hbdai4a0x1k2d1pm"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "ghostscript")))
    (build-system texlive-build-system)
    (arguments
     (list #:texlive-latex-bin? #f
           #:link-scripts #~(list "simpdftex")
           #:create-formats #~(list "etex" "pdfetex" "pdftex")
           #:phases
           #~(modify-phases %standard-phases
               (replace 'patch-shell-scripts
                 (lambda _
                   (substitute* "scripts/simpdftex/simpdftex"
                     (("/bin/(cp|date|echo|mv|rm)" _ command)
                      (which command))
                     (("basename|dirname|mkdir|sed" command)
                      (which command))
                     (("(^[ \t]*)(cat|rm)" _ indent command)
                      (string-append indent (which command)))
                     (("(distillerpath=\").*" _ prefix)
                      (string-append prefix
                                     #$(this-package-input "ghostscript")
                                     "/bin\"\n"))))))))
    (inputs (list ghostscript))
    (propagated-inputs
     (list texlive-cm
           texlive-etex
           texlive-hyphen-complete
           texlive-knuth-lib
           texlive-kpathsea
           texlive-plain
           texlive-tex-ini-files))
    (home-page "https://ctan.org/pkg/pdftex")
    (synopsis "TeX extension for direct creation of PDF")
    (description
     "This package is an extension of TeX which can directly generate PDF
documents as well as DVI output.")
    (license license:gpl3+)))

(define-deprecated-package texlive-generic-pdftex texlive-pdftex)

(define-public texlive-biber
  (package
    (name "texlive-biber")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/bibtex/biber/" "source/bibtex/biber/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11y03jim2vjbcwylp3hz9hbdw3zal3di3p0q58dffm3a27vbcr0j"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "perl-config-autoconf"
                                               "perl-extutils-libbuilder"
                                               "perl-file-which"
                                               "perl-module-build"
                                               "perl-test-differences")
                  (updater-extra-inputs "perl"
                                        "perl-autovivification"
                                        "perl-class-accessor"
                                        "perl-data-dump"
                                        "perl-data-compare"
                                        "perl-data-uniqid"
                                        "perl-datetime-format-builder"
                                        "perl-datetime-calendar-julian"
                                        "perl-file-slurper"
                                        "perl-io-string"
                                        "perl-ipc-cmd"
                                        "perl-ipc-run3"
                                        "perl-list-allutils"
                                        "perl-list-moreutils"
                                        "perl-mozilla-ca"
                                        "perl-regexp-common"
                                        "perl-log-log4perl"
                                        "perl-parse-recdescent"
                                        "perl-unicode-collate"
                                        "perl-unicode-normalize"
                                        "perl-unicode-linebreak"
                                        "perl-encode-eucjpascii"
                                        "perl-encode-jis2k"
                                        "perl-encode-hanextra"
                                        "perl-xml-libxml"
                                        "perl-xml-libxml-simple"
                                        "perl-xml-libxslt"
                                        "perl-xml-writer"
                                        "perl-sort-key"
                                        "perl-text-csv"
                                        "perl-text-csv-xs"
                                        "perl-text-roman"
                                        "perl-uri"
                                        "perl-text-bibtex"
                                        "perl-libwww"
                                        "perl-lwp-protocol-https"
                                        "perl-business-isbn"
                                        "perl-business-issn"
                                        "perl-business-ismn"
                                        "perl-lingua-translit")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:tests? #true
      #:imported-modules `(,@%texlive-build-system-modules
                           (guix build perl-build-system))
      #:modules '((guix build texlive-build-system)
                  ((guix build perl-build-system) #:prefix perl:)
                  (guix build utils))
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'unpack-biber-source
            (lambda _
              (mkdir-p "build")
              (with-directory-excursion "build"
                (invoke "tar" "xvf"
                        "../source/bibtex/biber/biblatex-biber.tar.gz"
                        "--strip-components=1"))))
          (add-after 'unpack-biber-source 'build-biber
            (lambda args
              (with-directory-excursion "build"
                ;; The following tests fail on i686.
                #$@(if (target-x86-32?)
                       '((delete-file "t/dateformats.t"))
                       '())
                (for-each (lambda (phase)
                            (apply (assoc-ref perl:%standard-phases phase) args))
                          '(configure build check install)))))
          (add-after 'install 'wrap-programs
            (lambda _
              (let ((perl5lib (getenv "PERL5LIB")))
                (wrap-program (string-append #$output "/bin/biber")
                  `("PERL5LIB" ":" prefix
                    (,(string-append perl5lib ":"
                                     #$output "/lib/perl5/site_perl"))))))))))
    (native-inputs
     (list perl-config-autoconf
           perl-extutils-libbuilder
           perl-file-which
           perl-module-build
           perl-test-differences))
    (inputs
     (list bash-minimal
           perl
           perl-autovivification
           perl-business-isbn
           perl-business-ismn
           perl-business-issn
           perl-class-accessor
           perl-data-compare
           perl-data-dump
           perl-data-uniqid
           perl-datetime-calendar-julian
           perl-datetime-format-builder
           perl-encode-eucjpascii
           perl-encode-hanextra
           perl-encode-jis2k
           perl-file-slurper
           perl-io-string
           perl-ipc-cmd
           perl-ipc-run3
           perl-libwww
           perl-lingua-translit
           perl-list-allutils
           perl-list-moreutils
           perl-log-log4perl
           perl-lwp-protocol-https
           perl-mozilla-ca
           perl-parse-recdescent
           perl-regexp-common
           perl-sort-key
           perl-text-bibtex
           perl-text-csv
           perl-text-csv-xs
           perl-text-roman
           perl-unicode-collate
           perl-unicode-linebreak
           perl-unicode-normalize
           perl-uri
           perl-xml-libxml
           perl-xml-libxml-simple
           perl-xml-libxslt
           perl-xml-writer))
    (home-page "https://ctan.org/pkg/biber")
    (synopsis "BibTeX replacement for users of BibLaTeX")
    (description
     "Biber is a BibTeX replacement for users of BibLaTeX.  It supports full
UTF-8, can (re)-encode input and output, supports highly configurable sorting,
dynamic bibliography sets and many other features.")
    (license license:artistic2.0)))

(define-deprecated-package biber texlive-biber)

(define-public rubber
  (package
    (name "rubber")
    (version "1.6.0")
    (source (origin
              (method git-fetch)
              (uri (git-reference
                    (url "https://gitlab.com/latex-rubber/rubber/")
                    (commit version)))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kndj42f87042x44p4jqwcf44bhpvhfqi2ilhh8sl09px2rm0qzl"))))
    (build-system pyproject-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          (delete 'build)
          ;; setup.py script does not support one of the Python build
          ;; system's default flags, "--single-version-externally-managed".
          (replace 'install
            (lambda _
              (invoke "python" "setup.py" "install"
                      (string-append "--prefix=" #$output)
                      "--root=/"))))))
    (native-inputs
     (list texinfo (texlive-updmap.cfg (list texlive-texinfo))))
    (inputs (list python-wrapper))
    (home-page "https://gitlab.com/latex-rubber/rubber/")
    (synopsis "Wrapper for LaTeX and friends")
    (description
     "Rubber is a program whose purpose is to handle all tasks related to the
compilation of LaTeX documents.  This includes compiling the document itself,
of course, enough times so that all references are defined, and running BibTeX
to manage bibliographic references.  Automatic execution of dvips to produce
PostScript documents is also included, as well as usage of pdfLaTeX to produce
PDF documents.")
    (license license:gpl3+)))

(define-public texmaker
  (package
    (name "texmaker")
    (version "5.0.4")
    (source (origin
              (method url-fetch)
              (uri (string-append "http://www.xm1math.net/texmaker/texmaker-"
                                  version ".tar.bz2"))
              (sha256
               (base32
                "1qnh5g8zkjpjmw2l8spcynpfgs3wpcfcla5ms2kkgvkbdlzspqqx"))))
    (build-system qt-build-system)
    (arguments
     `(#:test-target "check"
       #:phases
       (modify-phases %standard-phases
         ;; Qt has its own configuration utility.
         (replace 'configure
           (lambda* (#:key outputs #:allow-other-keys)
             (let ((out (assoc-ref outputs "out")))
               (invoke "qmake"
                       (string-append "PREFIX=" out)
                       (string-append "DESKTOPDIR=" out "/share/applications")
                       (string-append "ICONDIR=" out "/share/pixmaps")
                       (string-append "METAINFODIR=" out "/share/metainfo")
                       "texmaker.pro")))))))
    (inputs
     (list poppler-qt5 qtbase-5 qtwayland-5 qtscript zlib))
    (native-inputs
     (list pkg-config))
    (home-page "https://www.xm1math.net/texmaker/")
    (synopsis "LaTeX editor")
    (description "Texmaker is a program that integrates many tools needed to
develop documents with LaTeX, in a single application.")
    (license license:gpl2+)))

(define-public texstudio
  (package
    (name "texstudio")
    (version "4.8.2")
    (source (origin
              (method git-fetch)
              (uri (git-reference
                    (url "https://github.com/texstudio-org/texstudio")
                    (commit version)))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1grkvwh174a2dx19w6wlkhq2adj6g2myy31f5hji7kxw4ks759xb"))))
    (build-system qt-build-system)
    (arguments
     `(#:tests? #f))                    ;tests work only with debug build
    (native-inputs
     (list pkg-config
           poppler-qt5
           qtdeclarative-5
           qtsvg-5
           qttools-5))
    (home-page "https://www.texstudio.org/")
    (synopsis "Feature-packed LaTeX editor")
    (description
     "TeXstudio is an integrated writing environment for creating LaTeX
documents.  It makes writing LaTeX comfortable by providing features such as
syntax-highlighting, an integrated viewer and reference checking.")
    (license license:gpl3)))

(define-public dvisvgm
  (package
    (name "dvisvgm")
    (version "3.0.3")
    (source (origin
              (method git-fetch)
              (uri (git-reference
                    (url "https://github.com/mgieseki/dvisvgm")
                    (commit version)))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11r401yqbw61n1mwsfk5qmwx2c92djwpl0q756qkds5kh25l9ci8"))))
    (native-inputs (list pkg-config
                         autoconf
                         autoconf-archive
                         automake
                         python-wrapper
                         libtool))
    (inputs (list texlive-libkpathsea
                  freetype
                  fontforge
                  clipper
                  ghostscript
                  xxhash
                  google-brotli
                  woff2
                  zlib))
    (build-system gnu-build-system)
    (synopsis "Command-line utility for generating SVG from DVI, EPS and PDF
files")
    (description
     "Dvisvgm converts TeX DVI, EPS and PDF files into an
SVG (Scalable Vector Graphics) image.  It provides full font support including
virtual fonts, font maps and sub-fonts.  The embedded SVG fonts can optionally
be replaced with graphics paths for applications that do not support SVG
fonts.  Dvisvgm supports also colors, emTeX, tpic, papersize, PDF mapfile
and PostScript specials.  A working TeX installation is needed.")
    (home-page "https://dvisvgm.de/")
    (license license:gpl3+)))

(define-public teximpatient
  ;; The homepage seems to be distributing this version which is currently the
  ;; most recent commit
  (let ((commit "e3666abff186832fd9c467ceda3958058f30bac2")
        (revision "0"))
    (package
      (name "teximpatient")
      (version (git-version "2.4" revision commit))
      (source (origin
                (method git-fetch)
                (uri (git-reference
                      (url
                       "https://git.savannah.gnu.org/git/teximpatient.git/")
                      (commit commit)))
                (file-name (git-file-name name version))
                (sha256
                 (base32
                  "0r30383nmly7w29il6v3vmilnnyrzak0x0qmabjvnpaga9ansjmi"))))
      (build-system gnu-build-system)
      (arguments
       `(#:tests? #f ;there are none
         #:allowed-references ("out")
         #:phases (modify-phases %standard-phases
                    (add-after 'unpack 'fix-build
                      (lambda* (#:key inputs #:allow-other-keys)
                        (chdir "teximpatient")

                        ;; Remove generated files
                        (for-each delete-file
                                  '("book.pdf"
                                    "book.aux"
                                    "book.ccs"
                                    "book.log"
                                    "book.idx"
                                    "config.log"
                                    "config.status"
                                    "configure"
                                    "Makefile"))
                        (delete-file-recursively "autom4te.cache")

                        ;; make build reproducible
                        (substitute* "eplain.tex"
                          (("timestamp.*%")
                           (string-append "timestamp{"
                                          ,version "}"))))))))
      (native-inputs
       (list autoconf
             automake
             (texlive-updmap.cfg
              (list texlive-mflogo-font
                    texlive-palatino
                    texlive-zapfding))))
      (home-page "https://www.gnu.org/software/teximpatient/")
      (synopsis "Book on TeX, plain TeX and Eplain")
      (description
       "@i{TeX for the Impatient} is a ~350 page book on TeX,
plain TeX, and Eplain, originally written by Paul Abrahams, Kathryn Hargreaves,
and Karl Berry.")
      (license license:fdl1.3+))))

(define-public lyx
  (package
    (name "lyx")
    (version "2.3.7")
    (source (origin
              (method url-fetch)
              ;; XXX: Upstream version is 2.3.7, but they released a suffixed
              ;; tarball.  This can probably be removed after next release.
              (uri (let ((suffix "-1"))
                     (string-append "https://ftp.lyx.org/pub/lyx/stable/"
                                    (version-major+minor version) ".x/"
                                    "lyx-" version suffix ".tar.xz")))
              (sha256
               (base32
                "1vfq30big55038bcymh83xh9dqp9wn0gnw0f6644xcw6zdj8igir"))
              (modules '((guix build utils)))
              (snippet
               '(begin
                  (delete-file-recursively "3rdparty")))))
    (build-system qt-build-system)
    (arguments
     (list #:configure-flags
           #~(list "-DLYX_USE_QT=QT5"
                   "-DLYX_EXTERNAL_BOOST=1"
                   "-DLYX_INSTALL=1"
                   "-DLYX_RELEASE=1"
                   "-DLYX_PROGRAM_SUFFIX=OFF"
                   (string-append "-DLYX_INSTALL_PREFIX=" #$output))
           #:phases
           #~(modify-phases %standard-phases
               (add-after 'unpack 'patch-python
                 (lambda* (#:key inputs #:allow-other-keys)
                   (substitute* '("lib/configure.py"
                                  "src/support/ForkedCalls.cpp"
                                  "src/support/Systemcall.cpp"
                                  "src/support/os.cpp"
                                  "src/support/filetools.cpp")
                     (("\"python ")
                      (string-append "\""
                                     (search-input-file inputs "/bin/python3")
                                     " ")))))
               (add-after 'unpack 'add-missing-test-file
                 (lambda _
                   ;; Create missing file that would cause tests to fail.
                   (with-output-to-file "src/tests/check_layout.cmake"
                     (const #t)))))))
    (inputs
     ;; XXX: Aspell library is properly detected during build, but hunspell
     ;; isn't.  So we use the former here.
     (list aspell
           boost
           libx11
           mythes
           python
           qtbase-5
           qtsvg-5
           zlib))
    (native-inputs
     (list python pkg-config))
    (home-page "https://www.lyx.org/")
    (synopsis "Document preparation system with GUI")
    (description "LyX is a document preparation system.  It excels at letting
you create complex technical and scientific articles with mathematics,
cross-references, bibliographies, indexes, etc.  It is very good for working
with documents of any length in which the usual processing abilities are
required: automatic sectioning and pagination, spell checking and so forth.")
    (license license:gpl2+)))

(define-public texlive-media9
  (package
    (name "texlive-media9")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/media9/" "source/latex/media9/"
                                     "tex/latex/media9/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hzwan5y199a6za32h7bn653f2pzd91z9idrq8xdz6fjhns3fcdr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/media9")
    (synopsis "Multimedia inclusion package with Adobe Reader-9/X compatibility")
    (description
     "The package provides an interface to embed interactive Flash (SWF) and
3D objects (Adobe U3D & PRC), as well as video and sound files or streams in
the popular MP4, FLV and MP3 formats into PDF documents with Acrobat-9/X
compatibility.  Playback of multimedia files uses the built-in Flash Player of
Adobe Reader and does, therefore, not depend on external plug-ins.  Flash
Player supports the efficient H.264 codec for video compression.

The package is based on the RichMedia Annotation, an Adobe addition to the PDF
specification.  It replaces the now obsolete @code{movie15} package.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-media9 texlive-media9)

(define-public texlive-ocgx2
  (package
    (name "texlive-ocgx2")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ocgx2/" "tex/latex/ocgx2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jpvwy6sp7almdbhxizz22h3jxgfnsl4nirs93p7y1lqdgc4srl4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ocgx2")
    (synopsis "Drop-in replacement for 'ocgx' and 'ocg-p'")
    (description
     "This package serves as a drop-in replacement for the packages
@code{ocgx} by Paul Gaborit and @code{ocg-p} by Werner Moshammer for the
creation of PDF Layers.  It re-implements the functionality of the @code{ocg},
@code{ocgx}, and @code{ocg-p} packages and adds support for all known engines
and back-ends.  It also ensures compatibility with the @code{media9} and
@code{animate} packages.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-ocgx2 texlive-ocgx2)

(define-public texlive-optex
  (package
    (name "texlive-optex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/optex.1"
                                     "doc/man/man1/optex.man1.pdf"
                                     "doc/optex/base/"
                                     "tex/optex/base/"
                                     "tex/optex/demo/"
                                     "tex/optex/pkg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1px8hihdhnv7364qhysk78i56kwccfdwzrkmvfxhz0jm1f0zqbd1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:create-formats #~(list "optex")
           #:phases
           #~(modify-phases %standard-phases
               (add-after 'install 'symlink-binaries
                 (lambda* (#:key inputs #:allow-other-keys)
                   (let ((luatex (search-input-file inputs "bin/luatex"))
                         (bin (string-append #$output "/bin")))
                     (mkdir-p bin)
                     (with-directory-excursion bin
                       (symlink luatex "optex"))))))))
    (propagated-inputs
     (list texlive-amsfonts
           texlive-cm
           texlive-ec
           texlive-hyphen-base
           texlive-librarian
           texlive-lm
           texlive-luaotfload
           texlive-luatex
           texlive-rsfs
           texlive-unicode-data))
    (home-page "https://ctan.org/pkg/optex")
    (synopsis "LuaTeX format based on Plain TeX and OPmac")
    (description
     "OpTeX is a LuaTeX format based on Plain TeX macros with power from
OPmac (fonts selection system, colors, external graphics, references,
hyperlinks, ...) with Unicode fonts.")
    (license license:public-domain)))

(define-public texlive-ms
  (package
    (name "texlive-ms")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ms/" "source/latex/ms/"
                                     "tex/latex/ms/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cgrpx5mybiirjjdmni8kvqdg37dwfkixq3h9ami0mgxqqqfl2x3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/ms")
    (synopsis "Various LaTeX packages by Martin Schroder")
    (description
     "This package is the remains of a bundle of LaTeX packages by Martin
Schroder; the collection comprises: @code{count1to}, make use of TeX counters;
and @code{multitoc}, typeset the table of contents in multiple columns.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-ms texlive-ms)

(define-public texlive-ncctools
  (package
    (name "texlive-ncctools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ncctools/" "source/latex/ncctools/"
                                     "tex/latex/ncctools/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g3fpvrg6kx2ns97ih6iwdk0rcbxlv043x8rdppxdincl2lvbdx5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ncctools")
    (synopsis "Collection of general packages for LaTeX")
    (description
     "The NCCtools bundle contains many packages for general use under LaTeX;
many are also used by NCC LaTeX.  The bundle includes tools for:
@itemize
@item executing commands after a package is loaded;
@item watermarks;
@item counter manipulation;
@item improvements to the @code{description} environment;
@item hyphenation of compound words;
@item new levels of footnotes;
@item space-filling patterns;
@item poor man's Black Board Bold symbols;
@item alignment of the content of a box; use comma as decimal separator;
@item boxes with their own crop marks;
@item page cropmarks;
@item improvements to fancy headers;
@item float styles, mini floats, side floats;
@item manually marked footnotes;
@item extension of amsmath;
@item control of paragraph skip;
@item an envelope to the @code{graphicx} package;
@item dashed and multiple rules;
@item alternative techniques for declarations of sections, captions, and
toc-entries;
@item generalised text-stretching;
@item generation of new theorem-like environments;
@item control of the text area;
@item centered page layouts;
@item un-numbered top-level section.
@end itemize")
    (license license:lppl)))

(define-public texlive-ncntrsbk
  (package
    (name "texlive-ncntrsbk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "dvips/ncntrsbk/"
                                     "fonts/afm/adobe/ncntrsbk/"
                                     "fonts/afm/urw/ncntrsbk/"
                                     "fonts/map/dvips/ncntrsbk/"
                                     "fonts/tfm/adobe/ncntrsbk/"
                                     "fonts/tfm/urw35vf/ncntrsbk/"
                                     "fonts/type1/urw/ncntrsbk/"
                                     "fonts/vf/adobe/ncntrsbk/"
                                     "fonts/vf/urw35vf/ncntrsbk/"
                                     "tex/latex/ncntrsbk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0i6a48zbn9lg4pwbw8ya2wjjgppwac816fnbpmahm67kknx4d7ij"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/urw-base35")
    (synopsis "Replacement for Adobe's New Century Schoolbook font")
    (description
     "This package provides a drop-in replacement for the New Century
Schoolbook font from Adobe's basic set.")
    (license license:gpl3+)))

(define-public texlive-numprint
  (package
    (name "texlive-numprint")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/numprint/" "source/latex/numprint/"
                                     "tex/latex/numprint/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rqbqj4ffcfxxxxbs100pdslaiimwzgg19mf2qzcmm5snxwrf7zj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/numprint")
    (synopsis "Print numbers with separators and exponent if necessary")
    (description
     "The package numprint prints numbers with a separator every three digits
and converts numbers given as @samp{12345.6e789} to @samp{12\\,345,6\\cdot
10^@{789@}}.  Numbers are printed in the current mode (text or math) in order
to use the correct font.

Many things, including the decimal sign, the thousand separator, as well as
the product sign can be changed by the user.  If an optional argument is given
it is printed upright as unit.  Numbers can be rounded to a given number of
digits.  The package supports an automatic, language-dependent change of the
number format.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-numprint texlive-numprint)

(define-public texlive-needspace
  (package
    (name "texlive-needspace")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/needspace/"
                                     "source/latex/needspace/"
                                     "tex/latex/needspace/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12hbvv1w6b1k29qjvp72bkpnzsxpvrimzshllwinrxh9rx1mn550"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-filecontents")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs (list texlive-filecontents))
    (home-page "https://ctan.org/pkg/needspace")
    (synopsis "Insert pagebreak if not enough space")
    (description
     "This package provides commands to disable pagebreaking within a given
vertical space.  If there is not enough space between the command and the
bottom of the page, a new page will be started.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-needspace texlive-needspace)

(define-public texlive-changepage
  (package
    (name "texlive-changepage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/changepage/"
                                     "source/latex/changepage/"
                                     "tex/latex/changepage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0g9zlbqrgxh3p2vys2s84i8v590qi4fbpppp5lkaqc1di8kw60lm"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-filecontents")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs (list texlive-filecontents))
    (home-page "https://ctan.org/pkg/changepage")
    (synopsis "Margin adjustment and detection of odd/even pages")
    (description
     "The package provides commands to change the page layout in the middle of
a document, and to robustly check for typesetting on odd or even pages.  The
package is an extraction of code from the @code{memoir} class, whose user
interface it shares.  This package will eventually replace the @code{chngpage}
package, which is distributed with the package.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-changepage texlive-changepage)

(define-public texlive-eukdate
  (package
    (name "texlive-eukdate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/eukdate/" "source/latex/eukdate/"
                                     "tex/latex/eukdate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bz32l4500y4sx7ighpcvzfh0z45lzyyxm1dq1knmhdsv46gqaxi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eukdate")
    (synopsis "UK format dates, with weekday")
    (description
     "The package is used to change the format of @code{\\today}’s date,
including the weekday, e.g., @samp{Saturday, 26 June 2008}, the UK format,
which is preferred in many parts of the world, as distinct from that which is
used in @code{\\maketitle} of the article class, @samp{June 26, 2008}, the US
format.")
    (license license:lppl)))

(define-deprecated-package texlive-latex-eukdate texlive-eukdate)

(define-public texlive-euler
  (package
    (name "texlive-euler")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/euler/" "source/latex/euler/"
                                     "tex/latex/euler/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xd4lniaj243jvmlgfan7rp1zx308cfvpdd02nvvqpdnrwc69irk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/euler")
    (synopsis "Use AMS Euler fonts for math")
    (description
     "This package provides a setup for using the AMS Euler family of fonts
for mathematics in LaTeX documents. ``The underlying philosophy of Zapf's
Euler design was to capture the flavour of mathematics as it might be written
by a mathematician with excellent handwriting.'' The @code{euler} package is
based on Knuth's macros for the book Concrete Mathematics'.  The text fonts
for the Concrete book are supported by the @code{beton} package.")
    (license license:lppl)))

(define-public texlive-extsizes
  (package
    (name "texlive-extsizes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/extsizes/" "tex/latex/extsizes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1akxh0x8y1rhmpq8qzqi2bpbm1ffy8x0212jkyib7gm1i1d9ijgl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/extsizes")
    (synopsis "Extend the standard classes' size options")
    (description
     "This package provides classes @code{extarticle}, @code{extreport},
@code{extletter}, @code{extbook} and @code{extproc} which provide for
documents with a base font size from 8-20pt.  There is also a LaTeX package,
@file{extsizes.sty}, which can be used with nonstandard document classes.  But
it cannot be guaranteed to work with any given class.")
    (license license:lppl)))

(define-public texlive-ulem
  (package
    (name "texlive-ulem")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/ulem/" "tex/generic/ulem/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wcfnw5h6lsg2ilvkkf7mns8jgcn0n5sh45iznfsb49pfb4mming"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ulem")
    (synopsis "Package for underlining")
    (description
     "The package provides an @code{\\ul} (underline) command which will break
over line ends; this technique may be used to replace @code{\\em} (both in
that form and as the @code{\\emph} command), so as to make output look as if
it comes from a typewriter.  The package also offers double and wavy
underlining, and striking out, and crossing out.")
    (license license:lppl1.3c+)))

(define-public texlive-pdfarticle
  (package
    (name "texlive-pdfarticle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/pdfarticle/"
                                     "tex/lualatex/pdfarticle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16cy8n3hws1gm3bsv3h4mwnpvaajiy5sj6hpchy0r9hq28liara4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfarticle")
    (synopsis "Class for PDF publications")
    (description
     "pdfArticle is simple document class dedicated for creating PDF documents
with LuaLaTeX.")
    (license license:expat)))

(define-public texlive-pdfextra
  (package
    (name "texlive-pdfextra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/optex/pdfextra/" "tex/luatex/pdfextra/"
                                     "tex/optex/pdfextra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vv7vidcvi6c9bg9rdp00d324d3xfyazpwlc7l4vggz1w6n8l96y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfextra")
    (synopsis "Extra PDF features for (Op)TeX")
    (description
     "This package provides extra PDF features for OpTeX (or in limited form
for plain LuaTeX and LuaLaTeX).  As a minimalistic format, OpTeX does not
support advanced features of the PDF file format in its base.  This third
party package aims to provide them.  As such, it supports insertion of
multimedia (audio, video, 3D), hyperlinks and other actions, triggering
events, transitions, and attachments.")
    (license license:bsd-0)))

(define-public texlive-penlight
  (package
    (name "texlive-penlight")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/penlight/"
                                     "tex/luatex/penlight/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cs4kgm3nbs3b56iyj3q7lsds6iky78i47airkxd3cfyjv5ri47y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/penlight")
    (synopsis "Penlight Lua libraries made available to LuaLaTeX users")
    (description
     "This LuaLaTeX package provides a wrapper to use the penlight Lua
libraries with LuaLaTeX, with some extra functionality added.")
    (license license:expat)))

(define-public texlive-pgf
  (package
    (name "texlive-pgf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pgf/"
                                     "tex/context/third/pgf/basiclayer/"
                                     "tex/context/third/pgf/frontendlayer/"
                                     "tex/context/third/pgf/math/"
                                     "tex/context/third/pgf/systemlayer/"
                                     "tex/context/third/pgf/utilities/"
                                     "tex/generic/pgf/"
                                     "tex/latex/pgf/basiclayer/"
                                     "tex/latex/pgf/compatibility/"
                                     "tex/latex/pgf/doc/"
                                     "tex/latex/pgf/frontendlayer/"
                                     "tex/latex/pgf/math/"
                                     "tex/latex/pgf/systemlayer/"
                                     "tex/latex/pgf/utilities/"
                                     "tex/plain/pgf/basiclayer/"
                                     "tex/plain/pgf/frontendlayer/"
                                     "tex/plain/pgf/math/"
                                     "tex/plain/pgf/systemlayer/"
                                     "tex/plain/pgf/utilities/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16kdxcyk60i1c8y3i3d0v2076kapg2vs2pd4pbb434w3vjf8jfm5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-atveryend
           texlive-fp
           texlive-graphics
           texlive-ms
           texlive-pdftexcmds
           texlive-xcolor))
    (home-page "https://ctan.org/pkg/pgf")
    (synopsis "Create PostScript and PDF graphics in TeX")
    (description
     "PGF is a macro package for creating graphics.  It is platform- and
format-independent and works together with the most important TeX backend
drivers, including pdfTeX and dvips.  It comes with a user-friendly syntax
layer called TikZ.  Its usage is similar to @code{pstricks} and the standard
@code{picture} environment.  PGF works with plain (pdf-)TeX, (pdf-)LaTeX, and
ConTeXt.  Unlike @code{pstricks}, it can produce either PostScript or PDF
output.")
    ;; The code of the package is dual-license: GPL-2 or LPPL-1.3c+.  The
    ;; documentation is also dual-license: LPPL-1.3c+ or GFDL-1.2.
    (license (list license:gpl2 license:lppl1.3c+ license:fdl1.2+))))

(define-deprecated-package texlive-latex-pgf texlive-pgf)

(define-public texlive-piton
  (package
    (name "texlive-piton")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/piton/"
                                     "source/lualatex/piton/"
                                     "tex/lualatex/piton/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l225vs825n6v1bxwlv8d6gp0q8gp6ni2igjkvfyj3krfb9l2p1s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/piton")
    (synopsis "Typeset Python listings with LPEG")
    (description
     "This package uses the Lua library LPEG to typeset and highlight Python
listings.")
    (license license:lppl1.3+)))

(define-public texlive-placeat
  (package
    (name "texlive-placeat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/placeat/" "scripts/placeat/"
                                     "source/lualatex/placeat/"
                                     "tex/lualatex/placeat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lwr71sxrs1idy2nqqn2xsi3pmgv0hyfkhhiyir53cix203n18aq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/placeat")
    (synopsis "Absolute content positioning")
    (description
     "The package provides commands so that the user of LuaLaTeX may position
arbitrary content at any position specified by absolute coordinates on the
page.  The package draws a grid on each page of the document, to aid
positioning (the grid may be disabled, for final copy using the command
\\placeatsetup).")
    (license license:lppl1.3+)))

(define-public texlive-plantuml
  (package
    (name "texlive-plantuml")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/plantuml/"
                                     "tex/lualatex/plantuml/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1akyksvw9hcxgvikm7w6m4c1bpi5nzwpnl9w5r1332a3ggybpca4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/plantuml")
    (synopsis
     "Support for rendering UML diagrams using syntax and tool of PlantUML")
    (description
     "The package provides support for rendering UML diagrams using the syntax
and tools of PlantUML.  The PlantUML syntax is very short and thus enables
quickly specifying UML diagrams.  Using @command{dot}, PlantUML layouts the
diagrams.")
    (license license:lppl1.3c)))

(define-public texlive-pyluatex
  (package
    (name "texlive-pyluatex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/pyluatex/"
                                     "tex/lualatex/pyluatex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b88lxzig8ky539hnf4cvjrl0jqdhbdy55yvbwv84qvqqx9wz9qg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pyluatex")
    (synopsis "Execute Python code on the fly in your LaTeX documents")
    (description
     "PyLuaTeX allows you to execute Python code and to include the resulting
output in your LaTeX documents in a single compilation run.  LaTeX documents
must be compiled with LuaLaTeX for this to work.  PyLuaTeX runs a Python
InteractiveInterpreter (actually several if you use different sessions) in the
background for on-the-fly code execution.  Python code from your LaTeX file is
sent to the background interpreter through a TCP socket.  This approach allows
your Python code to be executed and the output to be integrated in your LaTeX
file in a single compilation run.")
    (license (list license:expat license:lppl1.3c))))

(define-public texlive-pythontex
  (package
    (name "texlive-pythontex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pythontex/" "scripts/pythontex/"
                                     "source/latex/pythontex/"
                                     "tex/latex/pythontex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "161kyk3sg7fnp9wxjmb1c9xbw0az0dxw2izipdyz0378ciqhqjfw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "depythontex.py" "pythontex.py")))
    (inputs (list python))
    (home-page "https://ctan.org/pkg/pythontex")
    (synopsis "Run Python from within a document, typesetting the results")
    (description
     "The package allows you to enter Python code within a LaTeX document,
execute the code, and access its output in the original document.  There is
also support for Bash, JavaScript, Julia, Octave, Perl, R, Raku (Perl 6),
Ruby, Rust, and SageMath.  Code is only executed when it has been modified, or
when it meets user-specified criteria.  Code may be divided into user-defined
sessions, which automatically run in parallel.  Errors and warnings are
synchronized with the LaTeX document, so that they refer to the document's
line numbers.  External dependencies can be tracked, so that code is
re-executed when the data it depends on is modified.  PythonTeX also provides
syntax highlighting for code in LaTeX documents via the Pygments syntax
highlighter.

The package also provides a @command{depythontex} utility.  This creates
a copy of the document in which all Python code has been replaced by its
output.  This is useful for journal submissions, sharing documents, and
conversion to other formats.")
    (license license:lppl1.3+)))

(define-public texlive-koma-script
  (package
    (name "texlive-koma-script")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/koma-script/"
                                     "source/latex/koma-script/"
                                     "tex/latex/koma-script/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r2li64g7fk7qg4gb215z2q86by2f2ah9hjlqf0wcv8985qshnif"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          ;; Building the package requires "scrdocstrip.tex", which is deeper
          ;; in the tree.  Extend TEXINPUTS accordingly.
          (add-before 'build 'fix-build
            (lambda _
              (setenv "TEXINPUTS"
                      (string-append (getcwd)
                                     "/source/latex/koma-script/doc:")))))))
    (propagated-inputs (list texlive-etoolbox texlive-xpatch))
    (home-page "https://ctan.org/pkg/koma-script")
    (synopsis "Bundle of versatile classes and packages")
    (description
     "The KOMA-Script bundle provides replacements for the article, report,
and book classes with emphasis on typography and versatility.  There is also
a letter class.  The bundle also offers: a package for calculating type areas
in the way laid down by the typographer Jan Tschichold, packages for easily
changing and defining page styles, a package @code{scrdate} for getting not
only the current date but also the name of the day, and a package
@code{scrtime} for getting the current time.  All these packages may be used
not only with KOMA-Script classes but also with the standard classes.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-koma-script texlive-koma-script)

(define-public texlive-koma-script-examples
  (package
    (name "texlive-koma-script-examples")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/koma-script-examples/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1s95a3vgjxrn34cpcinkyr1yw2rj8s2973np71yxrwzi9dqdjpn1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/koma-script-examples")
    (synopsis "Examples from the KOMA-Script book")
    (description
     "This package contains some examples from the 6th edition of the book
@emph{KOMA-Script<, Eine Sammlung von Klassen und Paketen fur LaTeX2e} by
Markus Kohm, published by Lehmanns Media.  There are no further descriptions
of these examples.")
    (license license:lppl1.3c)))

(define-public texlive-atbegshi
  (package
    (name "texlive-atbegshi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/atbegshi/" "source/latex/atbegshi/"
                                     "tex/generic/atbegshi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vd90wdjwj5w4g4xka4nms3rgixjw63iwf0hj0v1akcfflwvgn69"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-latex"
                                               "texlive-pdftex")))
    (build-system texlive-build-system)
    (arguments (list #:texlive-latex-bin? #f))
    (native-inputs (list texlive-latex texlive-pdftex))
    (home-page "https://ctan.org/pkg/atbegshi")
    (synopsis "Execute commands at @code{\\shipout} time")
    (description
     "This package is a modern reimplementation of package @code{everyshi},
providing various commands to be executed before a @code{\\shipout} command.
It makes use of e-TeX’s facilities if they are available.  The package may
be used either with LaTeX or with plain TeX.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-generic-atbegshi texlive-atbegshi)

(define-public texlive-bigintcalc
  (package
    (name "texlive-bigintcalc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bigintcalc/"
                                     "source/latex/bigintcalc/"
                                     "tex/generic/bigintcalc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cyv4mcvx83ab782l6h2f86a63ipm845r7hv1m6f1z2336vy7rc5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bigintcalc")
    (synopsis "Integer calculations on very large numbers")
    (description
     "This package provides expandable arithmetic operations with big integers
that can exceed TeX's number limits.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-generic-bigintcalc texlive-bigintcalc)

(define-public texlive-bitset
  (package
    (name "texlive-bitset")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bitset/" "source/latex/bitset/"
                                     "tex/generic/bitset/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1q7vk5gr5a4vaa3l20j178cg2q7a99rxdiyxhzpx9a6lfqfkjddz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-bigintcalc))
    (home-page "https://ctan.org/pkg/bitset")
    (synopsis "Handle bit-vector datatype")
    (description
     "This package defines and implements the data type bit set, a vector of
bits.  The size of the vector may grow dynamically.  Individual bits can be
manipulated.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-generic-bitset texlive-bitset)

(define-public texlive-etexcmds
  (package
    (name "texlive-etexcmds")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/etexcmds/" "source/latex/etexcmds/"
                                     "tex/generic/etexcmds/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13cf1fs5x9d8749b2jgxmgnkrx0r4hwpl389r15kq3ldz9jfl627"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/etexcmds")
    (synopsis "Avoid name clashes with e-TeX commands")
    (description
     "New primitive commands are introduced in e-TeX; sometimes the names
collide with existing macros.  This package solves the name clashes by adding
a prefix to e-TeX’s commands.  For example, ε-TeX’s @code{\\unexpanded} is
provided as @code{\\etex@@unexpanded}.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-generic-etexcmds texlive-etexcmds)

(define-public texlive-etextools
  (package
    (name "texlive-etextools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/etextools/"
                                     "source/latex/etextools/"
                                     "tex/latex/etextools/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bfcc8g8q5v1nyqmrg8n17hv4k8yvhsplansvriccpmvyx0w9y9d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/etextools")
    (synopsis "e-TeX tools for LaTeX users and package writers")
    (description
     "The package provides many (purely expandable) tools for LaTeX: extensive
list management; purely expandable loops; conversion; addition/deletion;
expansion and group control; tests on tokens, characters and control
sequences; tests on strings; purely expandable macros with options or
modifiers; some purely expandable numerics.")
    (license license:lppl)))

(define-public texlive-gettitlestring
  (package
    (name "texlive-gettitlestring")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gettitlestring/"
                                     "source/latex/gettitlestring/"
                                     "tex/generic/gettitlestring/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vbvmwrpsvy37gbwdmsqbbsicjiww3i0bh1yqnb75jiya9an0sjb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gettitlestring")
    (synopsis "Clean up title references")
    (description
     "This package provides commands for cleaning up the title string
(such as removing @code{\\label} commands) for packages that typeset such
strings.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-generic-gettitlestring texlive-gettitlestring)

(define-public texlive-infwarerr
  (package
    (name "texlive-infwarerr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/infwarerr/"
                                     "source/latex/infwarerr/"
                                     "tex/generic/infwarerr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lpcrpf3d6xfdp68ri22126x57mvmq5dpj9np68ph8p8lhvhqdjd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/infwarerr")
    (synopsis "Complete set of information/warning/error message macros")
    (description
     "This package provides a complete set of macros for information, warning
and error messages.  Under LaTeX, the commands are wrappers for the
corresponding LaTeX commands; under Plain TeX they are available as complete
implementations.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-generic-infwarerr texlive-infwarerr)

(define-public texlive-intcalc
  (package
    (name "texlive-intcalc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/intcalc/" "source/latex/intcalc/"
                                     "tex/generic/intcalc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15alwp9cr8wasfajs3p201p7nqml37vly9mpg1j5l6xv95javk7x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/intcalc")
    (synopsis "Expandable arithmetic operations with integers")
    (description
     "This package provides expandable arithmetic operations with integers,
using the e-TeX extension @code{\\numexpr} if it is available.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-generic-intcalc texlive-intcalc)

(define-public texlive-kvdefinekeys
  (package
    (name "texlive-kvdefinekeys")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/kvdefinekeys/"
                                     "source/latex/kvdefinekeys/"
                                     "tex/generic/kvdefinekeys/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1026h223ph3nzhs6jqbasa0bzsrdg3zgllfcwwcavfzb5i6p9jdf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/kvdefinekeys")
    (synopsis "Define keys for use in the @code{kvsetkeys} package")
    (description
     "This package provides the @code{\\kv@@define@@key} (analogous to
keyval’s @code{\\define@@key}, to define keys for use by @code{kvsetkeys}.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-generic-kvdefinekeys texlive-kvdefinekeys)

(define-public texlive-kvsetkeys
  (package
    (name "texlive-kvsetkeys")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/kvsetkeys/"
                                     "source/latex/kvsetkeys/"
                                     "tex/latex/kvsetkeys/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c4f4sgb3xpxmvphrvzbyqa2vl7sp2j52hb99spmpbqwgj9j61qx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/kvsetkeys")
    (synopsis "Key value parser with default handler support")
    (description
     "This package provides @code{\\kvsetkeys}, a variant of @code{\\setkeys}
from the @code{keyval} package.  Users can specify a handler that deals with
unknown options.  Active commas and equal signs may be used, and only one
level of curly braces are removed from the values.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-generic-kvsetkeys texlive-kvsetkeys)

(define-public texlive-listofitems
  (package
    (name "texlive-listofitems")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/listofitems/"
                                     "tex/generic/listofitems/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "019v5m9f443mad57wd9d6fwfxws558zan17bbq3qg4kw6drl0kh3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/listofitems")
    (synopsis "Grab items in lists using user-specified separation character")
    (description
     "This package is designed to read a list, for which the parsing character
has been selected by the user, and to access any of these items with a simple
interface.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-generic-listofitems texlive-listofitems)

(define-public texlive-ltxcmds
  (package
    (name "texlive-ltxcmds")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/ltxcmds/"
                                     "source/generic/ltxcmds/"
                                     "tex/generic/ltxcmds/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11nzqfra69f1rkc3ccnmgz6j94hlav23cckjc9xbgvrwp0631l5z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ltxcmds")
    (synopsis "Some LaTeX kernel commands for general use")
    (description
     "This package exports some utility macros from the LaTeX kernel into
a separate namespace and also makes them available for other formats such as
plain TeX.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-generic-ltxcmds texlive-ltxcmds)

(define-public texlive-ltxmisc
  (package
    (name "texlive-ltxmisc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/latex/ltxmisc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14llkpla8gpx7q6a53sd8a0a42wgk93fg4mbl6pc0v7v1kjblr5m"))))
    (build-system texlive-build-system)
    (arguments
     (list #:phases
           #~(modify-phases %standard-phases
               (add-after 'unpack 'delete-non-free-file
                 ;; This file has a non-commercial license.
                 (lambda _ (delete-file "tex/latex/ltxmisc/vrbexin.sty"))))))
    (home-page "https://ctan.org/pkg/ltxmisc")
    (synopsis "Miscellaneous LaTeX packages")
    (description
     "This package provides miscellaneous LaTeX packages and classes.")
    (license (list license:public-domain ;beletter.cls
                   license:gpl2+         ;bibcheck.sty
                   license:lppl          ;iagproc.cls
                   (license:fsf-free "file:/linsys.sty")
                   license:lppl1.0+)))) ;topcapt.sty

(define-public texlive-pdfescape
  (package
    (name "texlive-pdfescape")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdfescape/"
                                     "source/latex/pdfescape/"
                                     "tex/generic/pdfescape/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16a0rdmpa4wxh6gyf46qwfgyh399rwdind2wc89phqd50ky9b5m4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfescape")
    (synopsis "Implements pdfTeX's escape features using TeX or e-TeX")
    (description
     "This package implements pdfTeX's escape features (@code{\\pdfescapehex},
@code{\\pdfunescapehex}, @code{\\pdfescapename}, @code{\\pdfescapestring})
using TeX or e-TeX.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-generic-pdfescape texlive-pdfescape)

(define-public texlive-uniquecounter
  (package
    (name "texlive-uniquecounter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uniquecounter/"
                                     "source/latex/uniquecounter/"
                                     "tex/generic/uniquecounter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ll3iwk8x44l3qx1dhna399ngg66vbllivv8i3lwzriwkx22xbf3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uniquecounter")
    (synopsis "Provides unlimited unique counter")
    (description
     "This package provides a kind of counter that provides unique number values.
Several counters can be created with different names.  The numeric values are
not limited.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-generic-uniquecounter texlive-uniquecounter)

(define-public texlive-readarray
  (package
    (name "texlive-readarray")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/readarray/" "tex/latex/readarray/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0iy3m20761mp83g59qpx9l20bg3fvm28l64vq735rcha7yqbhf22"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/readarray")
    (synopsis "Read, store and recall array-formatted data")
    (description
     "This package allows the user to input formatted data into elements of
a 2-D or 3-D array and to recall that data at will by individual cell number.
The data can be but need not be numerical in nature.  It can be, for example,
formatted text.")
    (license license:lppl1.3)))

(define-deprecated-package texlive-latex-readarray texlive-readarray)

(define-public texlive-verbatimbox
  (package
    (name "texlive-verbatimbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/verbatimbox/"
                                     "tex/latex/verbatimbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13y3indc2mgx3jgj2xrqjd6g456h1g8vhf67ha4jvmrrgzcm36l6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/verbatimbox")
    (synopsis "Deposit verbatim text in a box")
    (description
     "The package provides a @code{verbbox} environment to place its contents
into a globally available box, or into a box specified by the user.  The
global box may then be used in a variety of situations (for example, providing
a replica of the @code{boxedverbatim} environment itself).  A valuable use is
in places where the standard @code{verbatim} environment (which is based on a
@code{trivlist}) may not appear.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-verbatimbox texlive-verbatimbox)

(define-public texlive-verifica
  (package
    (name "texlive-verifica")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/verifica/"
                                     "source/latex/verifica/"
                                     "tex/latex/verifica/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1q7kdx7rywc98sdgycj33v8w3a3rk30qil5nqh9h0kgmc7a91mpc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/verifica")
    (synopsis "Typeset (Italian high school) exercises")
    (description
     "This class provides various environments and commands to produce the
typical exercises contained in a test.  It is mainly intended for Italian high
school teachers, as the style is probably more in line with Italian high
school tests.")
    (license license:lppl1.3+)))

(define-public texlive-exam-zh
  (package
    (name "texlive-exam-zh")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/exam-zh/" "tex/latex/exam-zh/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jxs1gha989ncz46hqcxsqwvkxp1qni7najw244nahzh7pi6p2i9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/exam-zh")
    (synopsis "LaTeX template for Chinese exams")
    (description
     "This package provides a class @file{exam-zh.cls} suitable for Chinese
exams of all types.  It also includes several module packages like
@file{exam-zh-question.sty} and @file{exam-zh-choices.sty}, which can be used
individually.")
    (license license:lppl1.3c)))

(define-public texlive-examplep
  (package
    (name "texlive-examplep")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/examplep/" "tex/latex/examplep/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0afbl77i57hxngc3l0czdzmmkhcgh2l4h2dpbg9ax9p9dv8c006n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/examplep")
    (synopsis "Verbatim phrases and listings in LaTeX")
    (description
     "The @code{examplep} package provides sophisticated features for
typesetting verbatim source code listings, including the display of the source
code and its compiled LaTeX or Metapost output side-by-side, with automatic
width detection and enabled page breaks (in the source), without the need for
specifying the source twice.  Special care is taken that section, page and
footnote numbers do not interfere with the main document.  For typesetting
short verbatim phrases, a replacement for the @code{\\verb} command is also
provided in the package, which can be used inside tables and moving arguments
such as footnotes and section titles.")
    ;; No version of the GPL is specified.
    (license license:gpl3+)))

(define-deprecated-package texlive-latex-examplep texlive-examplep)

(define-public texlive-xunicode
  (package
    (name "texlive-xunicode")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/xunicode/"
                                     "tex/xelatex/xunicode/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1d96i8kd2lhbykc3rxy2jjvws404f2vy1cvdcp5bdr6l9m72q1fa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-tipa))
    (home-page "https://ctan.org/pkg/xunicode")
    (synopsis "Generate Unicode characters from accented glyphs")
    (description
     "The package supports XeTeX's (and other putative future similar
engines') need for Unicode characters, in a similar way to what the fontenc
does for 8-bit (and the like) fonts: convert accent-glyph sequence to a single
Unicode character for output.  The package also covers glyphs specified by
packages (such as @code{tipa}) which define many commands for single text
glyphs.")
    (license license:lppl1.3+)))

(define-public texlive-xypic
  (package
    (name "texlive-xypic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/xypic/"
                                     "dvips/xypic/"
                                     "fonts/afm/public/xypic/"
                                     "fonts/enc/dvips/xypic/"
                                     "fonts/map/dvips/xypic/"
                                     "fonts/source/public/xypic/"
                                     "fonts/tfm/public/xypic/"
                                     "fonts/type1/public/xypic/"
                                     "tex/generic/xypic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09b51bbm189xh7039h5n8nmab5nn2bybhh26qjn08763m80zdhjg"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-cm")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-cm texlive-metafont))
    (home-page "https://ctan.org/pkg/xypic")
    (synopsis "Flexible diagramming macros")
    (description
     "This package provides a package for typesetting a variety of graphs and
diagrams with TeX.  Xy-pic works with most formats (including LaTeX,
AMS-LaTeX, AMS-TeX, and plain TeX).  The distribution includes Michael Barr's
@code{diag} package, which was previously distributed stand-alone.")
    (license license:gpl3+)))

(define-deprecated-package texlive-fonts-xypic texlive-xypic)

(define-deprecated-package texlive-generic-xypic texlive-xypic)

(define-public texlive-xypic-tut-pt
  (package
    (name "texlive-xypic-tut-pt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/xypic-tut-pt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d9ivdz5jnhnh3pg8qb2jn7qfxad06hxff65scyhdd6wbsfaizi9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xypic-tut-pt")
    (synopsis "Tutorial for XY-pic, in Portuguese")
    (description "This is a tutorial for XY-pic, in Portuguese.")
    (license license:gpl3+)))

(define-public texlive-bibtex
  (package
    (name "texlive-bibtex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/base/"
                                     "bibtex/bst/base/"
                                     "doc/bibtex/base/"
                                     "doc/man/man1/bibtex.1"
                                     "doc/man/man1/bibtex.man1.pdf"
                                     "tex/generic/bibtex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zf0via3lh3797wsfg9cjvlfxkrsyshbb1kskijdqfgal8f80nms"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-bibtex-bin texlive-kpathsea))
    (home-page "https://ctan.org/pkg/bibtex")
    (synopsis "Process bibliographies for LaTeX")
    (description
     "BibTeX allows the user to store his citation data in generic form, while
printing citations in a document in the form specified by a BibTeX style, to
be specified in the document itself (one often needs a LaTeX citation-style
package, such as @command{natbib} as well).")
    (license license:knuth)))

(define-public texlive-bibtex-bin
  (package
    (inherit texlive-bin)
    (name "texlive-bibtex-bin")
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(delete "--enable-web2c" #$flags))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'install
              (lambda _
                (with-directory-excursion "texk/web2c"
                  (invoke "make" "bibtex")
                  (install-file "bibtex"
                                (string-append #$output "/bin")))))))))
    (native-inputs (list pkg-config))
    (home-page (package-home-page texlive-bibtex))
    (synopsis "Binary for @code{texlive-bibtex}")
    (description
     "This package provides the binary for @code{texlive-bibtex}.")
    (license (package-license texlive-bibtex))))

(define-public texlive-charissil
  (package
    (name "texlive-charissil")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/charissil/"
                                     "fonts/enc/dvips/charissil/"
                                     "fonts/map/dvips/charissil/"
                                     "fonts/tfm/SIL/charissil/"
                                     "fonts/truetype/SIL/charissil/"
                                     "fonts/type1/SIL/charissil/"
                                     "fonts/vf/SIL/charissil/"
                                     "tex/latex/charissil/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hdwxbck39xjkyq981fm3zxxkjw753mnr05jb7h7824k9x9wpfsl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/charissil")
    (synopsis "CharisSIL fonts with support for all LaTeX engines")
    (description
     "This package provides the CharisSIL family of fonts adapted by SIL
International from Bitstream Charter in TrueType format, with support for
LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX.")
    (license (list license:silofl1.1 license:lppl))))

(define-public texlive-charter
  (package
    (name "texlive-charter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/charter/"
                                     "fonts/afm/bitstrea/charter/"
                                     "fonts/tfm/bitstrea/charter/"
                                     "fonts/type1/bitstrea/charter/"
                                     "fonts/vf/bitstrea/charter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09l5ymgz48s3hyn776l01g3isk3dnhrj1vdavdw4qq4kfxxpqdn9"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-propagated-inputs "texlive-psnfss")))
    (build-system texlive-build-system)
     ;; This provides charter.map.
    (propagated-inputs (list texlive-psnfss))
    (home-page "https://www.ctan.org/pkg/charter")
    (synopsis "Charter fonts for TeX")
    (description "This package provides a copy of the Charter Type-1 fonts
which Bitstream contributed to the X consortium, renamed for use with TeX.
Support for use with LaTeX is available in @code{freenfss}, part of
@command{psnfss}.")
    (license (license:non-copyleft
              "http://mirrors.ctan.org/fonts/charter/readme.charter"))))

(define-deprecated-package texlive-fonts-charter texlive-charter)

(define-public texlive-chngcntr
  (package
    (name "texlive-chngcntr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chngcntr/" "tex/latex/chngcntr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ag1hb1vkl0xdzslp6f0j59dijwr9k9kq7vaada148241q0hflbj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chngcntr")
    (synopsis "Change the resetting of counters")
    (description
     "This package defines commands @code{\\counterwithin} (which sets up
a counter to be reset when another is incremented) and
@code{\\counterwithout} (which unsets such a relationship).")
    (license license:lppl)))

(define-public texlive-context
  (package
    (name "texlive-context")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "context/data/scite/context/"
                                     "context/data/texworks/"
                                     "context/data/vscode/"
                                     "doc/context/"
                                     "doc/man/man1/context.1"
                                     "doc/man/man1/context.man1.pdf"
                                     "doc/man/man1/mtx-babel.1"
                                     "doc/man/man1/mtx-babel.man1.pdf"
                                     "doc/man/man1/mtx-base.1"
                                     "doc/man/man1/mtx-base.man1.pdf"
                                     "doc/man/man1/mtx-bibtex.1"
                                     "doc/man/man1/mtx-bibtex.man1.pdf"
                                     "doc/man/man1/mtx-cache.1"
                                     "doc/man/man1/mtx-cache.man1.pdf"
                                     "doc/man/man1/mtx-chars.1"
                                     "doc/man/man1/mtx-chars.man1.pdf"
                                     "doc/man/man1/mtx-check.1"
                                     "doc/man/man1/mtx-check.man1.pdf"
                                     "doc/man/man1/mtx-colors.1"
                                     "doc/man/man1/mtx-colors.man1.pdf"
                                     "doc/man/man1/mtx-context.1"
                                     "doc/man/man1/mtx-context.man1.pdf"
                                     "doc/man/man1/mtx-convert.1"
                                     "doc/man/man1/mtx-convert.man1.pdf"
                                     "doc/man/man1/mtx-ctan.1"
                                     "doc/man/man1/mtx-ctan.man1.pdf"
                                     "doc/man/man1/mtx-dvi.1"
                                     "doc/man/man1/mtx-dvi.man1.pdf"
                                     "doc/man/man1/mtx-epub.1"
                                     "doc/man/man1/mtx-epub.man1.pdf"
                                     "doc/man/man1/mtx-evohome.1"
                                     "doc/man/man1/mtx-evohome.man1.pdf"
                                     "doc/man/man1/mtx-fcd.1"
                                     "doc/man/man1/mtx-fcd.man1.pdf"
                                     "doc/man/man1/mtx-fixpdf.1"
                                     "doc/man/man1/mtx-fixpdf.man1.pdf"
                                     "doc/man/man1/mtx-flac.1"
                                     "doc/man/man1/mtx-flac.man1.pdf"
                                     "doc/man/man1/mtx-fonts.1"
                                     "doc/man/man1/mtx-fonts.man1.pdf"
                                     "doc/man/man1/mtx-grep.1"
                                     "doc/man/man1/mtx-grep.man1.pdf"
                                     "doc/man/man1/mtx-install-modules.1"
                                     "doc/man/man1/mtx-install-modules.man1.pdf"
                                     "doc/man/man1/mtx-install.1"
                                     "doc/man/man1/mtx-install.man1.pdf"
                                     "doc/man/man1/mtx-interface.1"
                                     "doc/man/man1/mtx-interface.man1.pdf"
                                     "doc/man/man1/mtx-kpse.1"
                                     "doc/man/man1/mtx-kpse.man1.pdf"
                                     "doc/man/man1/mtx-metapost.1"
                                     "doc/man/man1/mtx-metapost.man1.pdf"
                                     "doc/man/man1/mtx-modules.1"
                                     "doc/man/man1/mtx-modules.man1.pdf"
                                     "doc/man/man1/mtx-package.1"
                                     "doc/man/man1/mtx-package.man1.pdf"
                                     "doc/man/man1/mtx-patterns.1"
                                     "doc/man/man1/mtx-patterns.man1.pdf"
                                     "doc/man/man1/mtx-pdf.1"
                                     "doc/man/man1/mtx-pdf.man1.pdf"
                                     "doc/man/man1/mtx-plain.1"
                                     "doc/man/man1/mtx-plain.man1.pdf"
                                     "doc/man/man1/mtx-profile.1"
                                     "doc/man/man1/mtx-profile.man1.pdf"
                                     "doc/man/man1/mtx-rsync.1"
                                     "doc/man/man1/mtx-rsync.man1.pdf"
                                     "doc/man/man1/mtx-scite.1"
                                     "doc/man/man1/mtx-scite.man1.pdf"
                                     "doc/man/man1/mtx-server.1"
                                     "doc/man/man1/mtx-server.man1.pdf"
                                     "doc/man/man1/mtx-spell.1"
                                     "doc/man/man1/mtx-spell.man1.pdf"
                                     "doc/man/man1/mtx-synctex.1"
                                     "doc/man/man1/mtx-synctex.man1.pdf"
                                     "doc/man/man1/mtx-texworks.1"
                                     "doc/man/man1/mtx-texworks.man1.pdf"
                                     "doc/man/man1/mtx-tools.1"
                                     "doc/man/man1/mtx-tools.man1.pdf"
                                     "doc/man/man1/mtx-unicode.1"
                                     "doc/man/man1/mtx-unicode.man1.pdf"
                                     "doc/man/man1/mtx-unzip.1"
                                     "doc/man/man1/mtx-unzip.man1.pdf"
                                     "doc/man/man1/mtx-update.1"
                                     "doc/man/man1/mtx-update.man1.pdf"
                                     "doc/man/man1/mtx-vscode.1"
                                     "doc/man/man1/mtx-vscode.man1.pdf"
                                     "doc/man/man1/mtx-watch.1"
                                     "doc/man/man1/mtx-watch.man1.pdf"
                                     "doc/man/man1/mtx-youless.1"
                                     "doc/man/man1/mtx-youless.man1.pdf"
                                     "doc/man/man1/mtxrun.1"
                                     "doc/man/man1/mtxrun.man1.pdf"
                                     "fonts/afm/hoekwater/context/"
                                     "fonts/cid/fontforge/"
                                     "fonts/enc/dvips/context/"
                                     "fonts/map/dvips/context/"
                                     "fonts/map/luatex/context/"
                                     "fonts/map/pdftex/context/"
                                     "fonts/misc/xetex/fontmapping/context/"
                                     "fonts/tfm/hoekwater/context/"
                                     "fonts/type1/hoekwater/context/"
                                     "metapost/context/base/common/"
                                     "metapost/context/base/mpiv/"
                                     "metapost/context/base/mpxl/"
                                     "metapost/context/fonts/mpiv/"
                                     "scripts/context/lua/context.lua"
                                     "scripts/context/lua/mtx-babel.lua"
                                     "scripts/context/lua/mtx-base.lua"
                                     "scripts/context/lua/mtx-bibtex.lua"
                                     "scripts/context/lua/mtx-cache.lua"
                                     "scripts/context/lua/mtx-chars.lua"
                                     "scripts/context/lua/mtx-check.lua"
                                     "scripts/context/lua/mtx-colors.lua"
                                     "scripts/context/lua/mtx-context.lua"
                                     "scripts/context/lua/mtx-context.xml"
                                     "scripts/context/lua/mtx-convert.lua"
                                     "scripts/context/lua/mtx-ctan.lua"
                                     "scripts/context/lua/mtx-dvi.lua"
                                     "scripts/context/lua/mtx-epub.lua"
                                     "scripts/context/lua/mtx-evohome.lua"
                                     "scripts/context/lua/mtx-fcd.lua"
                                     "scripts/context/lua/mtx-fixpdf.lua"
                                     "scripts/context/lua/mtx-flac.lua"
                                     "scripts/context/lua/mtx-fonts.lua"
                                     "scripts/context/lua/mtx-grep.lua"
                                     "scripts/context/lua/mtx-install-modules.lua"
                                     "scripts/context/lua/mtx-install.lua"
                                     "scripts/context/lua/mtx-interface.lua"
                                     "scripts/context/lua/mtx-kpse.lua"
                                     "scripts/context/lua/mtx-metapost.lua"
                                     "scripts/context/lua/mtx-mk-help.lua"
                                     "scripts/context/lua/mtx-modules.lua"
                                     "scripts/context/lua/mtx-package.lua"
                                     "scripts/context/lua/mtx-patterns.lua"
                                     "scripts/context/lua/mtx-pdf.lua"
                                     "scripts/context/lua/mtx-plain.lua"
                                     "scripts/context/lua/mtx-profile.lua"
                                     "scripts/context/lua/mtx-rsync.lua"
                                     "scripts/context/lua/mtx-scite.lua"
                                     "scripts/context/lua/mtx-server-ctx-fonttest.lua"
                                     "scripts/context/lua/mtx-server-ctx-help.lua"
                                     "scripts/context/lua/mtx-server-ctx-startup.lua"
                                     "scripts/context/lua/mtx-server.lua"
                                     "scripts/context/lua/mtx-spell.lua"
                                     "scripts/context/lua/mtx-synctex.lua"
                                     "scripts/context/lua/mtx-texworks.lua"
                                     "scripts/context/lua/mtx-tools.lua"
                                     "scripts/context/lua/mtx-unicode.lua"
                                     "scripts/context/lua/mtx-unzip.lua"
                                     "scripts/context/lua/mtx-update.lua"
                                     "scripts/context/lua/mtx-vscode.lua"
                                     "scripts/context/lua/mtx-watch.lua"
                                     "scripts/context/lua/mtx-youless.lua"
                                     "scripts/context/lua/mtxlibs.lua"
                                     "scripts/context/lua/mtxrun.lua"
                                     "scripts/context/lua/texlua.lua"
                                     "scripts/context/perl/makempy.pl"
                                     "scripts/context/perl/path_tre.pm"
                                     "scripts/context/perl/pdftrimwhite.pl"
                                     "scripts/context/perl/texfind.pl"
                                     "scripts/context/perl/texfont.pl"
                                     "tex/context/"
                                     "tex/generic/context/luatex/"
                                     "tex/generic/context/ppchtex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1657n2pp14m3wz4y18s90chvlxb5ff2lf3k8d3milr43fab65b7v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'install 'install-executables
            (lambda* (#:key inputs #:allow-other-keys)
              (let* ((bin (string-append #$output "/bin"))
                     (context (string-append bin "/context"))
                     (mtxrun (string-append bin "/mtxrun"))
                     (texmfcnf.lua
                      (search-input-file inputs
                                         "share/texmf-dist/web2c/texmfcnf.lua"))
                     (sh (search-input-file inputs "bin/sh")))
                (mkdir-p bin)
                ;; Create "mtxrun" runner.
                ;;
                ;; Out of the box, "mtxrun" first looks for "texmfcnf.lua" in
                ;; "~/texmf", then in TEXMFCNF.  The latter is set within
                ;; TEXLIVE-LIBKPATHSEA; it cannot contain the configuration
                ;; file provided by TEXLIVE-LUATEX.  Point to the right file
                ;; instead.
                (call-with-output-file mtxrun
                  (lambda (port)
                    (format port
                            "#!~a~%env ~a ~a luatex --luaonly mtxrun.lua \"$@\""
                            sh
                            (string-append "LUATEXDIR="
                                           #$output
                                           "/share/texmf-dist/scripts/context/lua")
                            (format #f
                                    "TEXMFCNF={$HOME/texmf/web2c,~a}"
                                    (dirname texmfcnf.lua)))))
                (chmod mtxrun #o755)
                ;; Create "context" runner.
                (call-with-output-file context
                  (lambda (port)
                    (format port "#!~a~%mtxrun --script context \"$@\"" sh)))
                (chmod context #o755)))))))
    (propagated-inputs
     (list texlive-amsfonts
           texlive-context-companion-fonts
           texlive-context-texlive
           texlive-lm
           texlive-lm-math
           texlive-luajittex
           texlive-luatex
           texlive-manfnt-font
           texlive-mflogo-font
           texlive-stmaryrd))
    (home-page "https://ctan.org/pkg/context")
    (synopsis "Full featured, parameter driven macro package for TeX")
    (description "ConTeXt is a full featured, parameter driven macro package,
which fully supports advanced interactive documents.  See the ConTeXt garden
for a wealth of support information.")
    ;; The GPL applies to all code; alternatively, the LaTeX license may be
    ;; used.  The CC-BY-SA license applies to all documentation.
    (license (list license:lppl1.3c+
                   license:gpl2+
                   license:cc-by-sa4.0))))

(define-deprecated-package texlive-context-base texlive-context)

(define-public texlive-context-calendar-examples
  (package
    (name "texlive-context-calendar-examples")
    (version "2024.2")
    (source
     (origin
       (method svn-multi-fetch)
       (uri (svn-multi-reference
             (url (texlive-packages-repository version))
             (revision 70951)
             (locations (list
                         "doc/context/third/calendar-examples/"
                         "tex/context/third/calendar-examples/"))))
       (file-name (git-file-name name version))
       (sha256
        (base32 "02ic0vn3bn2fibcnvr6k78ndfq67f9kysszzvcw5qh4nsck06syf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-context))
    (home-page "https://ctan.org/pkg/context-calendar-examples")
    (synopsis "Collection of calendars based on the PocketDiary module")
    (description
     "The module contains examples for creating calendars based on the
PocketDiary-module in various page sizes.")
    (license license:public-domain)))

(define-public texlive-context-collating-marks
  (package
    (name "texlive-context-collating-marks")
    (version "2024.2")
    (source
     (origin
       (method svn-multi-fetch)
       (uri (svn-multi-reference
             (url (texlive-packages-repository version))
             (revision 70951)
             (locations (list
                         "doc/context/third/collating-marks/"
                         "tex/context/third/collating-marks/"))))
       (file-name (git-file-name name version))
       (sha256
        (base32 "0jrlq3gar1ibm7vj8jvqh0cdq1vbl06g9vk74h4vihnmmhj1b3wz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-context))
    (home-page "https://ctan.org/pkg/context-collating-marks")
    (synopsis "Environment to place collating marks on the spine of a section")
    (description
     "This module provides a possibility to place collating marks on the
spines of sections when using imposition.  Placing collating marks is a method
to make the correct sequence of sections of a book block visible.")
    (license license:public-domain)))

(define-public texlive-context-legacy
  (package
    (name "texlive-context-legacy")
    (version "2024.2")
    (source
     (origin
       (method svn-multi-fetch)
       (uri (svn-multi-reference
             (url (texlive-packages-repository version))
             (revision 70951)
             (locations (list "bibtex/bst/context/mkii/"
                              "context/data/texfont/"
                              "doc/context/scripts/mkii/"
                              "doc/man/man1/texexec.1"
                              "doc/man/man1/texexec.man1.pdf"
                              "doc/man/man1/texmfstart.1"
                              "doc/man/man1/texmfstart.man1.pdf"
                              "metapost/context/base/mpii/"
                              "scripts/context/ruby/"
                              "tex/context/base/mkii/"
                              "tex/context/bib/common/"
                              "tex/context/bib/mkii/"
                              "tex/context/fonts/mkii/"
                              "tex/context/interface/mkii/"
                              "tex/context/modules/mkii/"
                              "tex/context/patterns/mkii/"
                              "tex/context/user/mkii/"))))
       (file-name (git-file-name name version))
       (sha256
        (base32 "15wfyb8s3n7l7692k5ny4w0im6paicaypyjfpzm4k5yhi0jxfgqw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:link-scripts #~(list "texexec.rb" "texmfstart.rb")
      #:create-formats #~(list "cont-en")))
    (inputs (list ruby))
    (propagated-inputs (list texlive-context texlive-metapost texlive-mptopdf
                             texlive-pdftex texlive-xetex))
    (home-page "https://ctan.org/pkg/context-legacy")
    (synopsis "The ConTeXt macro package, MkII")
    (description
     "In TeX Live, ConTeXt MkII is split from current ConTeXt (MkIV and
newer).")
    ;; Same as ConTeXt.
    (license (list license:lppl1.3c+ license:gpl2+ license:cc-by-sa4.0))))

(define-public texlive-context-notes-zh-cn
  (package
    (name "texlive-context-notes-zh-cn")
    (version "2024.2")
    (source
     (origin
       (method svn-multi-fetch)
       (uri (svn-multi-reference (url (texlive-packages-repository version))
                                 (revision 70951)
                                 (locations (list
                                             "doc/context/third/context-notes-zh-cn/"))))
       (file-name (git-file-name name version))
       (sha256
        (base32 "0pdizaybvxvzh19451x90mj81ql98q91f6cj8mfxwxa0mci1b9p4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-context))
    (home-page "https://ctan.org/pkg/context-notes-zh-cn")
    (synopsis "Notes on using ConTeXt MkIV")
    (description
     "This package provides an introductory tutorial on @code{ConTeXt}, in
Chinese.  The document covers @code{ConTeXt} installation, fonts, layout
design, cross-reference, project structure, metafun and presentation design.")
    (license license:gpl3)))

(define-public texlive-context-pocketdiary
  (package
    (name "texlive-context-pocketdiary")
    (version "2024.2")
    (source
     (origin
       (method svn-multi-fetch)
       (uri (svn-multi-reference
             (url (texlive-packages-repository version))
             (revision 70951)
             (locations (list
                         "doc/context/third/pocketdiary/"
                         "tex/context/third/pocketdiary/"))))
       (file-name (git-file-name name version))
       (sha256
        (base32 "0zn2rzlhm6agz5pknf0f8qqn7w0c1qjgdxh73gglyb55jvgl8b2z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-context))
    (home-page "https://ctan.org/pkg/context-pocketdiary")
    (synopsis "Personal organiser")
    (description
     "PocketDiary is a calendar module, enabling to prepare various calendars
from day- to week, month- and year-calendars based on the ideas contained in
PocketMods, having 8 pages arranged on a A4 single-sided printed sheet of
paper.  The module comes with different templates for notes etc.  The module
provides sun and moon data calculations.")
    (license license:public-domain)))

(define-public texlive-context-squares
  (package
    (name "texlive-context-squares")
    (version "2024.2")
    (source
     (origin
       (method svn-multi-fetch)
       (uri (svn-multi-reference
             (url (texlive-packages-repository version))
             (revision 70951)
             (locations (list "doc/context/third/squares/"
                              "tex/context/third/squares/"))))
       (file-name (git-file-name name version))
       (sha256
        (base32 "13kg55djn6bppvigl395irfqsq87vw2sazfmjrfan2agl1mfsqfv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-context))
    (home-page "https://ctan.org/pkg/context-squares")
    (synopsis "Typesetting Magic and Latin squares")
    (description "The package provides typesetting of Magic and Latin squares.")
    (license license:expat)))

(define-public texlive-context-sudoku
  (package
    (name "texlive-context-sudoku")
    (version "2024.2")
    (source
     (origin
       (method svn-multi-fetch)
       (uri (svn-multi-reference
             (url (texlive-packages-repository version))
             (revision 70951)
             (locations (list "doc/context/third/sudoku/"
                              "tex/context/third/sudoku/"))))
       (file-name (git-file-name name version))
       (sha256
        (base32 "0izgrfbqblik9hmlnnqsjwnfjrjks1zdafqk68gfv87lpysz6kgj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-context))
    (home-page "https://ctan.org/pkg/context-sudoku")
    (synopsis "Sudokus for ConTeXt")
    (description
     "This package provides a port of Peter Norvig's sudoku solver to
Lua/ConTeXt.  It provides four basic commands for typesetting sudokus, as well
as a command handler.")
    (license license:expat)))

(define-public texlive-context-companion-fonts
  (package
    (name "texlive-context-companion-fonts")
    (version "2024.2")
    (source
     (origin
       (method svn-multi-fetch)
       (uri (svn-multi-reference
             (url (texlive-packages-repository version))
             (revision 70951)
             (locations
              (list "fonts/opentype/public/context-companion-fonts/"))))
       (file-name (git-file-name name version))
       (sha256
        (base32 "14xxbwjcin47pfxm6nsrvn3kvd3z72ih4py7v4bg08z39653b2sw"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/context-companion-fonts")
    (synopsis "Companion fonts with fixes for ConTeXt")
    (description
     "These files fix and/or enhance some math glyphs and are loaded in the
math font goodie files used by ConTeXt LMTX.")
    (license (list license:lppl1.3c+ license:gpl2+))))

(define-public texlive-context-cyrillicnumbers
  (package
    (name "texlive-context-cyrillicnumbers")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/context/third/cyrillicnumbers/"
                                     "tex/context/interface/third/"
                                     "tex/context/third/cyrillicnumbers/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pysyspfnlynbylh4jv4rlwc3sf618ry90l7sph4zbhqg1cairys"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-context))
    (home-page "https://ctan.org/pkg/context-cyrillicnumbers")
    (synopsis "Write numbers as cyrillic glyphs")
    (description
     "The package extends ConTeXt's system of number conversion, by adding
numeration using cyrillic letters.")
    (license license:bsd-2)))

(define-public texlive-context-filter
  (package
    (name "texlive-context-filter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/context/third/filter/"
                                     "tex/context/third/filter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03nv2zd3aiv9lkq0bwq6awibn1acjprkc6b6jr5jslcyy4sw3k7w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-context))
    (home-page "https://ctan.org/pkg/context-filter")
    (synopsis
     "Run external programs on the contents of a start-stop environment")
    (description
     "The @code{filter} module provides a simple interface to run external
programs on the contents of a start-stop environment.  Options are available
to run the external program only if the content of the environment has
changed, to specify how the program output should be read back, and to choose
the name of the temporary files that are created.  The module is compatible
with both MkII and MkIV.")
    (license license:bsd-2)))

(define-public texlive-context-gnuplot
  (package
    (name "texlive-context-gnuplot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/context/third/gnuplot/"
                                     "metapost/context/third/gnuplot/"
                                     "tex/context/third/gnuplot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bmzww4sq8n37aipy6cvplcblxwlbmpl0by2sqysc3pdyxnixg41"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-context))
    (home-page "https://ctan.org/pkg/context-gnuplot")
    (synopsis "Inclusion of Gnuplot graphs in ConTeXt")
    (description
     "This ConTeXt module enables simple creation and inclusion of graphs with
Gnuplot.  It writes a script into temporary file, runs Gnuplot and includes
the resulting graphic directly into the document.")
    (license license:gpl3+)))

(define-public texlive-context-handlecsv
  (package
    (name "texlive-context-handlecsv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/context/third/handlecsv/"
                                     "tex/context/third/handlecsv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0s1ivnv62y8dcmhwk49x3hxphn5ig326f3n5klpkkxzfhk9d9f52"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-context))
    (home-page "https://ctan.org/pkg/context-handlecsv")
    (synopsis "Data merging for automatic document creation")
    (description
     "The package handles CSV data merging for automatic document creation.")
    (license license:gpl3)))

(define-public texlive-context-letter
  (package
    (name "texlive-context-letter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/context/third/letter/"
                                     "tex/context/interface/third/"
                                     "tex/context/third/letter/base/"
                                     "tex/context/third/letter/style/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12dc8bii38s8qgiyw749walkcmpni0j33pji7rxbrslfax81cb4q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-context))
    (home-page "https://ctan.org/pkg/context-letter")
    (synopsis "ConTeXt package for writing letters")
    (description
     "This package provides a means of writing vanilla letters and memos is
provided, with support covering ConTeXt Mkii and Mkiv.  The design of
letters may be amended by a wide range of style specifications.")
    (license license:gpl3+)))

(define-public texlive-context-mathsets
  (package
    (name "texlive-context-mathsets")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/context/third/mathsets/"
                                     "tex/context/interface/third/"
                                     "tex/context/third/mathsets/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "132ps8piihyp93y2af98xl6qan0ivmjbjkljvy7ly5h763ykkv3q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-context))
    (home-page "https://ctan.org/pkg/context-mathsets")
    (synopsis "Set notation in ConTeXt")
    (description
     "Typeset good-looking set notation as well as similar things such as
Dirac braket notation, conditional probabilities, etc.  The package is at
least inspired by @code{braket}.")
    (license license:bsd-2)))           ;from "t-mathsets.tex"

(define-public texlive-context-simpleslides
  (package
    (name "texlive-context-simpleslides")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/context/third/simpleslides/"
                                     "scripts/context/lua/third/simpleslides/"
                                     "tex/context/interface/third/"
                                     "tex/context/third/simpleslides/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r7pam5darq2nfnhfnrcxj5yzdjawg6kjiqq7qbip87l9jmj7sga"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-context))
    (home-page "https://ctan.org/pkg/context-simpleslides")
    (synopsis "Module for preparing presentations")
    (description
     "This ConTeXt module provides an easy-to-use interface for creating
presentations for use with a digital projector.  The presentations are
not interactive (no buttons, hyperlinks or navigational tools such as
tables of contents).  Graphics may be mixed with the text of slides.
The module provides several predefined styles, designed for academic
presentation.  Most styles are configurable, and it is easy to design
new styles.")
    (license license:gpl3+)))

(define-public texlive-context-texlive
  (package
    (name "texlive-context-texlive")
    (version "2024.2")
    (source
     (origin
       (method svn-multi-fetch)
       (uri (svn-multi-reference
             (url (texlive-packages-repository version))
             (revision 70951)
             (locations (list "doc/man/man1/contextjit.1"
                              "doc/man/man1/contextjit.man1.pdf"
                              "doc/man/man1/luatools.1"
                              "doc/man/man1/luatools.man1.pdf"
                              "doc/man/man1/mtxrunjit.1"
                              "doc/man/man1/mtxrunjit.man1.pdf"
                              "scripts/context-texlive/stubs-mkiv/unix/"
                              "scripts/context-texlive/stubs-mkiv/win64/"
                              "scripts/context-texlive/stubs/unix/"
                              "scripts/context-texlive/stubs/win64/"
                              "tex/context/texlive/"))))
       (file-name (git-file-name name version))
       (sha256
        (base32 "1d4lga9l3yfqv1b3lskpgifkrcylnwz6v2hggylzf7ixvsi49hwd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts #~(list "contextjit" "luatools" "mtxrunjit")))
    (home-page "https://ctan.org/pkg/context-texlive")
    (synopsis "TeX Live-specific helpers for ConTeXt (caches, papersize)")
    (description
     "This package distributes @file{cont-sys.mkxl} and @file{cont-sys.mkiv}
files to update the ConTeXt filename cache if the system @file{ls-R} files are
modified (typically by @command{mktexlsr}).  It also sets the default paper
size from the @file{context-papersize.tex} file which TeX Live
creates/updates.  It also includes stubs to run the @command{luatools},
@command{contextjit}, and @command{mtxrunjit} scripts.")
    ;; Same as ConTeXt.
    (license (list license:lppl1.3c+ license:gpl2+))))

(define-public texlive-context-transliterator
  (package
    (name "texlive-context-transliterator")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/context/third/transliterator/"
                                     "scripts/context/lua/third/transliterator/"
                                     "tex/context/interface/third/"
                                     "tex/context/third/transliterator/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "089mw43yrj0l06dcv1jzf1nibrwrz6qbhaj85crzjh8k91dzsw4j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-context))
    (home-page "https://ctan.org/pkg/context-transliterator")
    (synopsis "Transliterate text from other alphabets")
    (description
     "The package will read text in one alphabet, and provide a transliterated
version in another; this is useful for readers who cannot read the original
alphabet.  The package can make allowance for hyphenation.")
    (license license:bsd-2)))           ;from "t-transliterator.mkiv"

(define-public texlive-context-typescripts
  (package
    (name "texlive-context-typescripts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/context/third/typescripts/"
                                     "tex/context/third/typescripts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kz3flqyzg2p7lvr7yy1h1nmk368glzxxhwirizn5g4xv5sdf27b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-context))
    (home-page "https://ctan.org/pkg/context-typescripts")
    (synopsis "Small modules to load various fonts for use in ConTeXt")
    (description
     "The package provides files offering interfaces to 33 publicly available
fonts (or collections of fonts from the same foundry); each is available in
a @file{.mkii} and a @file{.mkiv} version.")
    (license license:gpl2)))

(define-public texlive-context-vim
  (package
    (name "texlive-context-vim")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/context/third/vim/"
                                     "tex/context/third/vim/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03cwdqkrx6bgcikmyxrwkyac3jmz7i50cavgb6r8b26zrsm522ca"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-context texlive-context-filter))
    (home-page "https://ctan.org/pkg/context-vim")
    (synopsis "Generate ConTeXt syntax highlighting code from Vim")
    (description
     "ConTeXt has excellent pretty printing capabilities for many languages.
The code for pretty printing is written in TeX, and due to catcode juggling,
such verbatim typesetting is perhaps the trickiest part of TeX.  This makes it
difficult for a normal user to define syntax highlighting rules for a new
language.  This module takes the onus of defining syntax highlighting rules
away from the user and uses Vim editor to generate the syntax highlighting.
There is a helper @file{2context.vim} script to do the syntax parsing in
Vim.")
    (license license:bsd-2)))

(define-public texlive-context-visualcounter
  (package
    (name "texlive-context-visualcounter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/context/third/visualcounter/"
                                     "source/context/third/visualcounter/"
                                     "tex/context/third/visualcounter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rq2zqrvbidwngc4jyv4ay84y5l854z1shk08cjlvnlbsgrg7lmk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-context))
    (home-page "https://ctan.org/pkg/context-visualcounter")
    (synopsis "Visual display of ConTeXt counters")
    (description
     "This package provides a typical document usually contains many counters:
page numbers, section numbers, itemizations, enumerations, theorems, and so
on.  This module provides a visual display for such counters.")
    (license license:bsd-2)))

(define-public texlive-beamer
  (package
    (name "texlive-beamer")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamer/" "tex/latex/beamer/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ck21cwnwz5nx1hb263n9qs4gq76wiisqrh346yy6rjf425rgviy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-amscls
           texlive-amsfonts
           texlive-amsmath
           texlive-atbegshi
           texlive-etoolbox
           texlive-geometry
           texlive-hyperref
           texlive-iftex
           texlive-pgf
           texlive-translator
           texlive-xcolor))
    (home-page "https://www.ctan.org/pkg/beamer")
    (synopsis "LaTeX class for producing presentations and slides")
    (description
     "The @code{beamer} LaTeX class can be used for producing slides.
The class works in both PostScript and direct PDF output modes, using the
@code{pgf} graphics system for visual effects.  Content is created in the
@code{frame} environment, and each frame can be made up of a number of slides
using a simple notation for specifying material to appear on each slide within
a frame.  Short versions of title, authors, institute can also be specified as
optional parameters.  Whole frame graphics are supported by plain frames.  The
class supports @code{figure} and @code{table} environments, transparency
effects, varying slide transitions and animations.")
    ;; Code is dual licensed under GPLv2+ or LPPL1.3c+; documentation is
    ;; dual-licensed under either FDLv1.3+ or LPPL1.3c+.
    (license (list license:lppl1.3c+ license:gpl2+ license:fdl1.3+))))

(define-deprecated-package texlive-latex-beamer texlive-beamer)

(define-public texlive-beamer-tut-pt
  (package
    (name "texlive-beamer-tut-pt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamer-tut-pt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ayh3kbh11l4nyyzp2kcwzn0phqhzawppy044iyl1wwwc2v3zx5b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamer-tut-pt")
    (synopsis "Introduction to the @code{beamer} class, in Portuguese")
    (description
     "This package provides an introduction to the @code{beamer} class, in
Portuguese.")
    (license license:gpl3+)))

(define-public texlive-xmpincl
  (package
    (name "texlive-xmpincl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xmpincl/" "source/latex/xmpincl/"
                                     "tex/latex/xmpincl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wc48qark5hd593jh3mx1yryxsdcq5hbaxyrhwcaxzgqivdli34p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xmpincl")
    (synopsis "Include eXtensible Metadata Platform data in pdfLaTeX")
    (description
     "The XMP (eXtensible Metadata platform) is a framework to add metadata to
digital material to enhance the workflow in publication.  The essence is that
the metadata is stored in an XML file, and this XML stream is then embedded in
the file to which it applies.")
    (license license:gpl3+)))

(define-deprecated-package texlive-latex-xmpincl texlive-xmpincl)

(define-public texlive-pdfx
  (package
    (name "texlive-pdfx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdfx/" "source/latex/pdfx/"
                                     "tex/latex/pdfx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z4j4d92k2fjmf8jfap4zn7ij97d9rz2jcs9aslcac07ag4x5bdp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'fix-encoding
            (lambda _
              (substitute* "source/latex/pdfx/pdfx.dtx"
                (("    .+umaczy") "umaczy")))))))
    (home-page "https://ctan.org/pkg/pdfx")
    (synopsis "PDF/X and PDF/A support for pdfTeX, LuaTeX and XeTeX")
    (description
     "The package helps LaTeX users to create PDF/X, PFD/A and other
standards-compliant PDF documents with pdfTeX, LuaTeX and XeTeX.")
    (license license:lppl1.2+)))

(define-deprecated-package texlive-latex-pdfx texlive-pdfx)

(define-public texlive-yamlvars
  (package
    (name "texlive-yamlvars")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/yamlvars/"
                                     "tex/lualatex/yamlvars/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08s64y8gb3nxa6cadklfz31ia7k2bk42z1zg3db851d2xnvwivs8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/yamlvars")
    (synopsis "YAML parser and tool for easy LaTeX definition creation")
    (description
     "This LuaLaTeX package provides a YAML parser and some functions to
declare and define LaTeX definitions using YAML files.")
    (license license:expat)))

(define-public texlive-yax
  (package
    (name "texlive-yax")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/yax/" "tex/generic/yax/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01hv550qkmxw63m41v4qykfiracvzvjwxk49y6fc6abg89hfvsj6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/yax")
    (synopsis "Yet Another Key System")
    (description
     "YaX is advertised as a key system, but it rather organizes attributes in
parameters, which parameters can be executed, so that YaX is halfway between
key management and macro definition (and actually hopes to provide a user's
interface).  Values assigned to attributes can be retrieved and tested in
various ways, with full expandability ensured as much as possible.  Finally,
YaX's syntax is a quite peculiar (as few braces as possible), but may be
customized.")
    (license license:lppl)))

(define-public texlive-ydoc
  (package
    (name "texlive-ydoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ydoc/" "source/latex/ydoc/"
                                     "tex/generic/ydoc/" "tex/latex/ydoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00v7vlv7z2xy4sy2zd4arlndjqvgjsqar3i22vdnld4flb03jqb8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-etoolbox
           texlive-float
           texlive-hyperref
           texlive-listings
           texlive-needspace
           texlive-newverbs
           texlive-showexpl
           texlive-tools
           texlive-url
           texlive-xcolor))
    (home-page "https://ctan.org/pkg/ydoc")
    (synopsis "Macros for documentation of LaTeX classes and packages")
    (description "The package provides macros and environments to document
LaTeX packages and classes.  It is an (as yet unfinished) alternative to the
@code{ltxdoc} class and the @code{doc} or @code{xdoc} packages.  The aim is to
provide a different layout and more modern styles (using the @code{xcolor},
@code{hyperref} packages, etc.)  This is an alpha release, and should probably
not (yet) be used with other packages, since the implementation might
change.")
    (license license:lppl1.3+)))

(define-public texlive-yet-another-guide-latex2e
  (package
    (name "texlive-yet-another-guide-latex2e")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/yet-another-guide-latex2e/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a4z4ni7327jd1r4n0w2lh7bb8ag7dfdgr6xwl4q5hf2jbdv8mmy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/yet-another-guide-latex2e")
    (synopsis "Short guide to using LaTeX2e to typeset high quality documents")
    (description
     "This document is a short guide to using LaTeX2e to typeset high quality
documents.  It focuses on users of Windows and guides the reader through
installation, some of LaTeX's conventions, and creating the front matter, body
and end matter.  The appendices contain a list of useful facilities not
otherwise covered in this document and a list of helpful resources.")
    (license license:fdl1.3+)))

(define-public texlive-pstricks
  (package
    (name "texlive-pstricks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pstricks/" "dvips/pstricks/"
                                     "tex/generic/pstricks/" "tex/latex/pstricks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0z4lk96pkd3cjx264kb8dgfwwa5ag0f1aam34wqssffbbccl2d9b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "http://www.ctan.org/pkg/pstricks-base")
    (synopsis "PostScript macros for TeX")
    (description
     "PSTricks offers an extensive collection of macros for generating
PostScript that is usable with most TeX macro formats, including Plain TeX,
LaTeX, AMS-TeX, and AMS-LaTeX.  Included are macros for colour, graphics, pie
charts, rotation, trees and overlays.  It has many special features, including
a wide variety of graphics (picture drawing) macros, with a flexible interface
and with colour support.  There are macros for colouring or shading the cells
of tables.")
    (license license:lppl1.3+)))

(define-public texlive-pst-2dplot
  (package
    (name "texlive-pst-2dplot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-2dplot/"
                                     "tex/latex/pst-2dplot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lq39hdlqf4af16lx7qrs6x2hj10rsashgd3yl8659346a2mq75a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-2dplot")
    (synopsis "PSTricks package for drawing 2D curves")
    (description
     "Pst-2dplot is a PSTricks package that offers an intuitive tool for
plotting 2-d curves.  It defines an environment with commands similar to
MATLAB for plotting.")
    (license license:lppl)))

(define-public texlive-pst-3d
  (package
    (name "texlive-pst-3d")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-3d/" "dvips/pst-3d/"
                                     "source/generic/pst-3d/"
                                     "tex/generic/pst-3d/" "tex/latex/pst-3d/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12gpsg14glcjavlwsb7g0dkxcax89z2adkx7p29cpzvssnimdj50"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-3d")
    (synopsis "PSTricks package for tilting and other pseudo-3D tricks")
    (description
     "The package provides basic macros that use PSTricks for shadows, tilting
and three dimensional representations of text or graphical objects.")
    (license license:lppl)))

(define-public texlive-pst-3dplot
  (package
    (name "texlive-pst-3dplot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-3dplot/"
                                     "dvips/pst-3dplot/"
                                     "tex/generic/pst-3dplot/"
                                     "tex/latex/pst-3dplot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0n9lhqaj7zmvv781yhbm7d2swdzsjn6dzljrpchm2lz58l1lig2j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-3dplot")
    (synopsis "Draw 3D objects in parallel projection, using PSTricks")
    (description
     "This package provides a package using PSTricks to draw a large variety
of graphs and plots, including 3D maths functions.  Data can be read from
external data files, making this package a generic tool for graphing within
TeX or LaTeX, without the need for external tools.")
    (license license:lppl)))

(define-public texlive-pst-abspos
  (package
    (name "texlive-pst-abspos")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-abspos/"
                                     "source/generic/pst-abspos/"
                                     "tex/generic/pst-abspos/"
                                     "tex/latex/pst-abspos/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12k786hfhp8vrq4a6a6caf6fi1p16hd79r3lf19d5vcyykppdcm8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-abspos")
    (synopsis "Put objects at an absolute position")
    (description
     "This PSTricks package provides a command @code{\\pstPutAbs(x,y)} to put
an object at an arbitrary absolute (or even a relative) position on the
page.")
    (license license:lppl)))

(define-public texlive-pst-am
  (package
    (name "texlive-pst-am")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-am/"
                                     "source/generic/pst-am/" "tex/latex/pst-am/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dyhjycy6ccamxcp65761gbszxpvxdsiirqbpljkywsbynwfcn6q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-am")
    (synopsis "Simulation of modulation and demodulation")
    (description
     "The package allows the simulation of the modulated and demodulated
amplitude of radio waves.  The user may plot curves of modulated signals, wave
carrier, signal modulation, signal recovery and signal demodulation.")
    (license license:lppl)))

(define-public texlive-pst-antiprism
  (package
    (name "texlive-pst-antiprism")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-antiprism/"
                                     "dvips/pst-antiprism/"
                                     "tex/generic/pst-antiprism/"
                                     "tex/latex/pst-antiprism/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "158691m8i8zd0w7d7vsbmkjm4y1ixfvj4j7bxszcw67cz2q2cmyi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-antiprism")
    (synopsis "PSTricks related package which draws an antiprism")
    (description
     "@code{pst-antiprism} is a PSTricks related package which draws an antiprism,
which is a semiregular polyhedron constructed with 2-gons and triangles.")
    (license license:lppl)))

(define-public texlive-pst-arrow
  (package
    (name "texlive-pst-arrow")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-arrow/"
                                     "tex/generic/pst-arrow/"
                                     "tex/latex/pst-arrow/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z216b5189f390mdzxxcc240i0iav13nicqjqwcn31f4j4wclpzj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-arrow")
    (synopsis "Special arrows for PSTricks")
    (description
     "This package has all the code from the package @code{pstricks-add},
which was related to arrows, like multiple arrows and so on.")
    (license license:lppl)))

(define-public texlive-pst-asr
  (package
    (name "texlive-pst-asr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-asr/"
                                     "tex/generic/pst-asr/" "tex/latex/pst-asr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hxp905d2r4j2z8hfbl9v45xid20lm41k8xy52fdj5grpshhg2z1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-asr")
    (synopsis "Typeset autosegmental representations for linguists")
    (description
     "The package allows the user to typeset autosegmental representations.")
    (license license:lppl)))

(define-public texlive-pst-bar
  (package
    (name "texlive-pst-bar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-bar/" "dvips/pst-bar/"
                                     "tex/generic/pst-bar/" "tex/latex/pst-bar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19x8a3r09m28g6mpa98rz94274yahajznkkqarzwh1n8v54bb7hd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-bar")
    (synopsis "Produces bar charts using PSTricks")
    (description
     "The package uses PSTricks to draw bar charts from data stored in
a comma-delimited file.  Several types of bar charts may be drawn, and the
drawing parameters are highly customizable.")
    (license license:lppl)))

(define-public texlive-pst-barcode
  (package
    (name "texlive-pst-barcode")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-barcode/"
                                     "dvips/pst-barcode/"
                                     "tex/generic/pst-barcode/"
                                     "tex/latex/pst-barcode/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10990hhhj961rizfffplx8v3rhnv7knm8nz2zd1aqp686fr3fkgv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-barcode")
    (synopsis "Print barcodes using PostScript")
    (description
     "The @code{pst-barcode} package allows printing of barcodes, in a huge
variety of formats, including quick-response (QR) codes.  As a PSTricks
package, the package requires pstricks.  The package uses @code{PostScript}
for calculating the bars.  For PDF output use a multi-pass mechansism such as
@code{pst-pdf}.")
    (license license:lppl)))

(define-public texlive-pst-bezier
  (package
    (name "texlive-pst-bezier")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-bezier/"
                                     "dvips/pst-bezier/"
                                     "tex/generic/pst-bezier/"
                                     "tex/latex/pst-bezier/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "181232snaqfjdc5mzazsdgjvmjn27pcfx45mydkk0cpp61kdr9yk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-bezier")
    (synopsis "Draw Bezier curves")
    (description
     "The package provides a macro @code{\\psbcurve} for drawing a Bezier curve.
Provision is made for full control of over all the control points of the
curve.")
    (license license:lppl)))

(define-public texlive-pst-blur
  (package
    (name "texlive-pst-blur")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-blur/" "dvips/pst-blur/"
                                     "source/generic/pst-blur/"
                                     "tex/generic/pst-blur/"
                                     "tex/latex/pst-blur/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zz5ixznkl3i59zlv9lxz7f1cfqwbar3qjy5x4323gmzjw2k9f8m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-blur")
    (synopsis "PSTricks package for blurred shadows")
    (description
     "Pst-blur is a package built for use with PSTricks.  It provides macros
that apply blurring to the normal shadow function of PSTricks.")
    (license license:lppl)))

(define-public texlive-pst-bspline
  (package
    (name "texlive-pst-bspline")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-bspline/"
                                     "dvips/pst-bspline/"
                                     "tex/generic/pst-bspline/"
                                     "tex/latex/pst-bspline/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0djf1izf9779lgmbw5zhcz7k5hf8ay96nlgdgpsm1zj4ncwkpibg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-bspline")
    (synopsis "Draw cubic Bspline curves and interpolations")
    (description
     "The package draws uniform, cubic B-spline curves, open and closed, based
on a sequence of B-spline control points.  There is also code which permits
drawing the open or closed cubic Bspline curve interpolating a sequence of
points.  Graphical output is created using PStricks.")
    (license license:lppl1.3+)))

(define-public texlive-pst-calculate
  (package
    (name "texlive-pst-calculate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-calculate/"
                                     "tex/latex/pst-calculate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19yi0n8p4gj2p16nsk8f3i02a9adlqssyv57r67dc0qh6a0ipa9k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-calculate")
    (synopsis "Support for floating point operations at LaTeX level")
    (description
     "This package provides an interface to the LaTeX3 floating point unit,
mainly used for PSTricks related packages to allow math expressions at LaTeX
level.")
    (license license:lppl1.3+)))

(define-public texlive-pst-calendar
  (package
    (name "texlive-pst-calendar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pst-calendar/"
                                     "tex/latex/pst-calendar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07vc1jxrr0n0iwjx6qjww53xji1pv42dvlc2ghi1r14nypgm8j5n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-calendar")
    (synopsis "Plot calendars in fancy ways")
    (description
     "The package draws tabular calendars, or calendars on dodecahedra with
a month to each face.  The package works for years 2000--2099, and has options
for calendars in French German and English, but the documentation is not
available in English.")
    (license license:lppl)))

(define-public texlive-pst-cie
  (package
    (name "texlive-pst-cie")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-cie/" "dvips/pst-cie/"
                                     "tex/generic/pst-cie/" "tex/latex/pst-cie/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0g5yry8m935idznwn486gn75vjyhbdzs2w99l0szh95026kd4f0a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-cie")
    (synopsis "CIE color space")
    (description
     "pst-cie is a PSTricks related package to show the different CIE color
spaces: Adobe, CIE, ColorMatch, NTSC, Pal-Secam, ProPhoto, SMPTE, and sRGB.")
    (license license:lppl)))

(define-public texlive-pst-circ
  (package
    (name "texlive-pst-circ")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-circ/" "dvips/pst-circ/"
                                     "tex/generic/pst-circ/"
                                     "tex/latex/pst-circ/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0255xcjhm0jcgw352cmdn8d8062g2mihfzhii20zh4j0zznmk7hj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-circ")
    (synopsis "PSTricks package for drawing electric circuits")
    (description
     "The package can easily draw current 2-terminal devices and some 3- and
4-terminal devices used in electronic or electric theory.  The package's
macros are designed with a view to logical representation of circuits, as far
as possible, so as to relieve the user of purely graphical considerations when
expressing a circuit.")
    (license license:lppl)))

(define-public texlive-pst-coil
  (package
    (name "texlive-pst-coil")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-coil/" "dvips/pst-coil/"
                                     "tex/generic/pst-coil/"
                                     "tex/latex/pst-coil/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d3wqrv19zc9qwp3gbr32siad408z4g23k5861p0hqy2hw8f908q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-coil")
    (synopsis "PSTricks package for coils, etc")
    (description
     "Pst-coil is a PSTricks based package for coils and zigzags and for coil
and zigzag node connections.")
    (license license:lppl)))

(define-public texlive-pst-contourplot
  (package
    (name "texlive-pst-contourplot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-contourplot/"
                                     "tex/generic/pst-contourplot/"
                                     "tex/latex/pst-contourplot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00nqg59x1x3nh30cclqjdyyyjzinyl9czjfywznh68dzari1fvqk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-contourplot")
    (synopsis
     "Draw implicit functions using the marching squares algorithm")
    (description
     "This package allows drawing implicit functions @samp{f(x,y) = 0} with
options for coloring the inside of the surfaces, for marking the points and
arrowing the curve at points chosen by the user.  The package uses the
marching squares algorithm.")
    (license license:lppl)))

(define-public texlive-pst-cox
  (package
    (name "texlive-pst-cox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-cox/" "dvips/pst-cox/"
                                     "tex/generic/pst-cox/" "tex/latex/pst-cox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bw2qmsc735q3ji4h7l166s37wcpd6s4fvi98ggagndm29mcbia3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-cox")
    (synopsis "Drawing regular complex polytopes with PSTricks")
    (description
     "Pst-cox is a PSTricks package for drawing 2-dimensional projections of
complex regular polytopes (after the work of Coxeter).  The package consists
of a macro library for drawing the projections.  The complex polytopes appear
in the study of the root systems and play a crucial role in many domains
related to mathematics and physics.  These polytopes have been completely
described by Coxeter in his book @emph{Regular Complex Polytopes}.  There
exist only a finite numbers of exceptional regular complex polytopes (for
example the icosahedron) and some infinite series (for example, one can
construct a multi-dimensional analogue of the hypercube in any finite
dimension).

The library contains two packages.  The first, @code{pst-coxcoor}, is devoted
to the exceptional complex regular polytopes whose coordinates have been
pre-computed.  The second, @code{pst-coxeterp}, is devoted to the infinite
series.")
    (license license:lgpl3+)))

(define-public texlive-pst-dart
  (package
    (name "texlive-pst-dart")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-dart/"
                                     "tex/generic/pst-dart/"
                                     "tex/latex/pst-dart/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1834hxlg4hfqmrl6k5i2c1jimzd0lcdi6x82b8lfj8dhnddlbgzr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-dart")
    (synopsis "Plotting dart boards")
    (description
     "@code{pst-dart} is a PSTricks related package and draws dart boards.
Optional arguments are the unit and the fontsize.")
    (license license:lppl)))

(define-public texlive-pst-dbicons
  (package
    (name "texlive-pst-dbicons")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-dbicons/"
                                     "source/generic/pst-dbicons/"
                                     "tex/latex/pst-dbicons/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pzfahir5vvxw28095myqppfpyik7agzncm9vm42gvldw45byr4q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-dbicons")
    (synopsis "Support for drawing ER diagrams")
    (description
     "The package provides some useful macros in the database area.  The
package focusses on typesetting ER-Diagrams in a declarative style, i.e., by
positioning some nodes and defining the position of all other nodes relative
to them by using the standard database terminology.")
    (license license:lppl)))

(define-public texlive-pst-diffraction
  (package
    (name "texlive-pst-diffraction")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-diffraction/"
                                     "source/generic/pst-diffraction/"
                                     "tex/generic/pst-diffraction/"
                                     "tex/latex/pst-diffraction/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wi67md3046nj0arqi1wmbgdhdrsnfqgmmb0ayk2iswfhvx32myr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-diffraction")
    (synopsis "Print diffraction patterns from various apertures")
    (description
     "The package enables the user to draw (using PSTricks) the diffraction
patterns for different geometric forms of apertures for monochromatic light.
The aperture stops can have rectangular, circular or triangular openings.  The
view of the diffraction may be planar, or three-dimensional.  Options
available are the dimensions of the aperture under consideration and of the
particular optical setting, e.g., the radius in case of an circular opening.
Moreover one can choose the wavelength of the light (the associated color will
be calculated by the package).")
    (license license:lppl)))

(define-public texlive-pst-electricfield
  (package
    (name "texlive-pst-electricfield")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-electricfield/"
                                     "dvips/pst-electricfield/"
                                     "source/generic/pst-electricfield/"
                                     "tex/generic/pst-electricfield/"
                                     "tex/latex/pst-electricfield/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1awc5nqp7giqmczx1xd1y78j5vgsw7y8m767mbhgs5j12j3yl4yd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-electricfield")
    (synopsis "Draw electric field and equipotential lines with PSTricks")
    (description
     "The package provides macros to plot electric field and equipotential
lines using PStricks.  There may be any number of charges which can be placed
in a cartesian coordinate system.")
    (license license:lppl)))

(define-public texlive-pst-eps
  (package
    (name "texlive-pst-eps")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-eps/"
                                     "source/generic/pst-eps/"
                                     "tex/generic/pst-eps/" "tex/latex/pst-eps/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lf106rw3w6gicn6021jpj4bgbpgjyixp64l9aqqxn6ip6vm4yh3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-eps")
    (synopsis "Create EPS files from PSTricks figures")
    (description
     "Pst-eps is a PSTricks-based package for exporting PSTricks images on the
fly to encapsulated PostScript (EPS) image files, which can then be read into
a document in the usual way.")
    (license license:lppl)))

(define-public texlive-pst-eucl
  (package
    (name "texlive-pst-eucl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-eucl/" "dvips/pst-eucl/"
                                     "tex/generic/pst-eucl/"
                                     "tex/latex/pst-eucl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "170n1llp9wblzq1fmdnxzh6bw540i455lgpwm353k8jm4skrqm50"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-eucl")
    (synopsis "Euclidian geometry with PSTricks")
    (description
     "The package allows the drawing of Euclidean geometric figures using TeX
PSTricks macros for specifying mathematical constraints.  It is thus possible
to build point using common transformations or intersections.  The use of
coordinates is limited to points which controlled the figure.")
    (license license:lppl)))

(define-public texlive-pst-eucl-translation-bg
  (package
    (name "texlive-pst-eucl-translation-bg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pst-eucl-translation-bg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06c9ajnfl01sl81z5r8a5lzmaygq9rdmgym2v40y7xp7z033gwwv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-eucl-translation-bg")
    (synopsis "Bulgarian translation of the @code{pst-eucl} documentation")
    (description
     "The package provides the @code{pst-eucl} package documentation in
Bulgarian language.")
    (license license:lppl)))

(define-public texlive-pst-exa
  (package
    (name "texlive-pst-exa")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pst-exa/" "tex/latex/pst-exa/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jbkk5nircdv0mas1vbydqhca1r5vcmrxyyi5xwzi1qhfbw3xa8g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-exa")
    (synopsis "Typeset PSTricks examples, with code")
    (description
     "The (PSTricks-related) package provides an environment @code{PSTexample}
to put code and output side by side or one above the other.")
    (license license:lppl)))

(define-public texlive-pst-feyn
  (package
    (name "texlive-pst-feyn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-feyn/" "dvips/pst-feyn/"
                                     "tex/generic/pst-feyn/"
                                     "tex/latex/pst-feyn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08m8pwl5kk2rs835pnksap8ld6ir0chlbswchgpvks229i6gkrj0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-feyn")
    (synopsis "Draw graphical elements for Feynman diagrams")
    (description
     "@code{pst-feyn} is a set of drawing graphical elements which are used
for Feynman diagrams.")
    (license license:lppl)))

(define-public texlive-pst-fill
  (package
    (name "texlive-pst-fill")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-fill/"
                                     "tex/generic/pst-fill/"
                                     "tex/latex/pst-fill/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0anzq671nsprckhy92ybp2y93g5f2z1s0qja9wx2mrjpb4xq8ng0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-fill")
    (synopsis "Fill or tile areas with PSTricks")
    (description
     "Pst-fill is a PSTricks-based package for filling and tiling areas or
characters.")
    (license license:lppl)))

(define-public texlive-pst-fit
  (package
    (name "texlive-pst-fit")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-fit/"
                                     "tex/generic/pst-fit/" "tex/latex/pst-fit/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0w2vnd6zb9vdrqbk256ynr7lg7p9ps53rrdq9l999bw8f8vip1as"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-fit")
    (synopsis "Macros for curve fitting")
    (description
     "The package uses PSTricks to fit curves to: linear functions; power
functions; exp function; logarithm functions; Recip; Kings Law data; Gaussian;
and fourth order polynomials.")
    (license license:lppl)))

(define-public texlive-pst-flags
  (package
    (name "texlive-pst-flags")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pst-flags/"
                                     "tex/latex/pst-flags/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13078q4mg1r8hg5zvywfasfz26phcr9dvsw4s05spc116b8fz9gn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-flags")
    (synopsis "Draw flags of countries using PSTricks")
    (description
     "This package provides a number of macros for rendering flags of
countries and their associated artefacts using PSTricks.  Formatting of the
resulting drawings is entirely controlled by TeX macros.  A good working
knowledge of LaTeX should be sufficient to design flags of sovereign countries
and adapt them to create new designs.  Features such as color or shape
customisation and dynamic modifications are possible by cleverly adjusting the
options supplied to the TeX macros.")
    (license license:lppl1.3c)))

(define-public texlive-pst-fr3d
  (package
    (name "texlive-pst-fr3d")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-fr3d/"
                                     "source/generic/pst-fr3d/"
                                     "tex/generic/pst-fr3d/"
                                     "tex/latex/pst-fr3d/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y8xsq6wklpygzf0lfdy683vkdrglw5jl00qyfwk6rl08wb4l17y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-fr3d")
    (synopsis "Draw 3-dimensional framed boxes using PSTricks")
    (description
     "This package provides a package using PSTricks to draw three dimensional
framed boxes using a macro @code{\\PstFrameBoxThreeD}.  The macro is
especially useful for drawing 3D-seeming buttons.")
    (license license:lppl)))

(define-public texlive-pst-fractal
  (package
    (name "texlive-pst-fractal")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-fractal/"
                                     "dvips/pst-fractal/"
                                     "tex/generic/pst-fractal/"
                                     "tex/latex/pst-fractal/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jc9zwjp23l6njr7y63jh0xv4a6qy2610bb88fdiwdsqnh70gs72"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-fractal")
    (synopsis "Draw fractal sets using PSTricks")
    (description
     "The package uses PSTricks to draw the Julia and Mandelbrot sets, the
Sierpinski triangle, Koch flake, and Apollonius Circle as well as fractal
trees (which need not be balanced) with a variety of different
parameters (including varying numbers of iterations).")
    (license license:lppl)))

(define-public texlive-pst-fun
  (package
    (name "texlive-pst-fun")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-fun/" "dvips/pst-fun/"
                                     "source/generic/pst-fun/"
                                     "tex/generic/pst-fun/" "tex/latex/pst-fun/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "070nv0yv0rcfvx36xmya953pk89whrr26irvy0ccb41k66fvw5j1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-fun")
    (synopsis "Draw funny objects with PSTricks")
    (description
     "This is a PSTricks related package for drawing funny objects, like ant, bird,
fish, kangaroo, etc.  Such objects may be useful for testing other PSTricks
macros and/or packages. (Or they can be used for fun...)")
    (license license:lppl)))

(define-public texlive-pst-func
  (package
    (name "texlive-pst-func")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-func/" "dvips/pst-func/"
                                     "tex/generic/pst-func/"
                                     "tex/latex/pst-func/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xqqnmnhrni9lwgxpr84hg0ji72sn89zkb7hm3n36ygmpr37v97k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-func")
    (synopsis "PSTricks package for plotting mathematical functions")
    (description
     "The package is built for use with PSTricks.  It provides macros for
plotting and manipulating various mathematical functions:

@itemize
@item polynomials and their derivatives,
@item Fourier sums,
@item the Bessel function defined by its order;
@item the Gauss function defined by sigma and mu,
@item Bezier curves from order 1 (two control points) to order 9 (10 control
points),
@item the superellipse function (the Lame curve),
@item Chebyshev polynomials of the first and second kind,
@item the Thomae (or popcorn) function,
@item the Weierstrass function,
@item various integration-derived functions: normal, binomial, poisson, gamma,
chi-squared, student's t, F, beta, Cauchy and Weibull distribution functions
and the Lorenz curve,
@item the zeroes of a function, or the intermediate point of two functions,
@item the Vasicek function for describing the evolution of interest rates,
@item implicit functions.
@end itemize

The plots may be generated as volumes of rotation about the X-axis, as well.")
    (license license:lppl)))

(define-public texlive-pst-gantt
  (package
    (name "texlive-pst-gantt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-gantt/"
                                     "tex/generic/pst-gantt/"
                                     "tex/latex/pst-gantt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ziahdc0r8pkxxn6p6ijrx1diihkbbrmwbbc1pzi1sddqg05l5sc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-gantt")
    (synopsis "Draw GANTT charts with PSTricks")
    (description
     "The package uses PSTricks to draw GANTT charts, which are a kind of bar
chart that displays a project schedule.")
    (license license:lppl)))

(define-public texlive-pst-geo
  (package
    (name "texlive-pst-geo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-geo/" "dvips/pst-geo/"
                                     "tex/generic/pst-geo/" "tex/latex/pst-geo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zqmjjg9zmmzjqmhx2jwcc761f1rrxcchsnrd5s686f9p6z4w7c6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-geo")
    (synopsis "Geographical projections")
    (description
     "The package offers a set of PSTricks related packages for various
cartographic projections of the terrestrial sphere.  The package
@code{pst-map2d} provides conventional projections such as Mercator, Lambert,
cylindrical, etc.  The package @code{pst-map3d} treats representation in three
dimensions of the terrestrial sphere.  Packages @code{pst-map2dII} and
@code{pst-map3dII} allow use of the CIA World DataBank II.  Various parameters
of the packages allow for choice of the level of the detail and the layouts
possible (cities, borders, rivers etc).  Substantial data files are provided,
in an (internally) compressed format.  Decompression happens on-the-fly as
a document using the data is displayed, printed or converted to PDF format.
A Perl script is provided for the user to do the decompression, if the need
should arise.")
    (license license:lppl)))

(define-public texlive-pst-geometrictools
  (package
    (name "texlive-pst-geometrictools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-geometrictools/"
                                     "tex/generic/pst-geometrictools/"
                                     "tex/latex/pst-geometrictools/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14mhyjq8w3llkyjij274n5sdwbp3ak2xi6q6ggqdakgn032a7yhn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-geometrictools")
    (synopsis "PSTricks package to draw geometric tools")
    (description
     "This PSTricks package facilitates the drawing of protractors, rulers,
compasses and pencils.")
    (license license:lppl1.3c)))

(define-public texlive-pst-gr3d
  (package
    (name "texlive-pst-gr3d")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-gr3d/"
                                     "source/latex/pst-gr3d/"
                                     "tex/generic/pst-gr3d/"
                                     "tex/latex/pst-gr3d/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pppd4l4yrdgy0vss8l2kndd0cg9nxip7d7vcyrfr0cz9kw0z45n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-gr3d")
    (synopsis "Three dimensional grids with PSTricks")
    (description
     "This PSTricks package provides a command @code{\\PstGridThreeD} that
will draw a three dimensional grid, offering a number of options for its
appearance.")
    (license license:lppl)))

(define-public texlive-pst-grad
  (package
    (name "texlive-pst-grad")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-grad/" "dvips/pst-grad/"
                                     "tex/generic/pst-grad/"
                                     "tex/latex/pst-grad/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10b8b7mb6c1kkwvwrq31zwmn184qprd69ckypp0gs5s1nz9klc4l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-grad")
    (synopsis "Filling with colour gradients, using PSTricks")
    (description
     "The package fills with colour gradients, using PSTricks.  The RGB, CMYK
and HSB models are supported.  Other colour gradient mechanisms are to be
found in package @code{pst-slpe}.")
    (license license:lppl)))

(define-public texlive-pst-graphicx
  (package
    (name "texlive-pst-graphicx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-graphicx/"
                                     "tex/generic/pst-graphicx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0x1053a92hi1msbmw7s0222k0vfg28172qrinz3hdv94igaxi38q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-graphicx")
    (synopsis "PSTricks-compatible @code{graphicx} for use with Plain TeX")
    (description
     "The package provides a version of @code{graphicx} that avoids loading
the graphics bundle's (original) @code{keyval} package, which clashes with
PSTricks use of @code{xkeyval}.")
    (license license:lppl)))

(define-public texlive-pst-hsb
  (package
    (name "texlive-pst-hsb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-hsb/"
                                     "tex/generic/pst-hsb/" "tex/latex/pst-hsb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nhhsk5hfh1v7d9vr0g0lkvcv12bwlyasx9s2sa916p7px0ddz0s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-hsb")
    (synopsis "Curves with continuous colours")
    (description
     "This is a PSTricks-related package.  It can plot lines and/or curves
with continuous colours.  Only colours defined in the HSB model are
supported.")
    (license license:lppl)))

(define-public texlive-pst-infixplot
  (package
    (name "texlive-pst-infixplot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-infixplot/"
                                     "tex/generic/pst-infixplot/"
                                     "tex/latex/pst-infixplot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07yqjzznayk3pjbsaxjz5b63hiabmkdywv2h6kshpjqmh2q1zi6w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-infixplot")
    (synopsis "Use PSTricks plotting capacities with infix expressions")
    (description
     "Plotting functions with pst-plot is very powerful but sometimes
difficult to learn since the syntax of @code{\\psplot} and
@code{\\parametricplot} requires some PostScript knowledge.  The infix-RPN and
@code{pst-infixplot} styles simplify the usage of @code{pst-plot} for the
beginner, providing macro commands that convert natural mathematical
expressions to PostScript syntax.")
    (license license:lppl)))

(define-public texlive-pst-intersect
  (package
    (name "texlive-pst-intersect")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pst-intersect/"
                                     "dvips/pst-intersect/"
                                     "source/latex/pst-intersect/"
                                     "tex/generic/pst-intersect/"
                                     "tex/latex/pst-intersect/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "157yqj923kikm8abiv3giyf9rrr6cw0jwqj37ri5ya5iyxlfvmmv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-intersect")
    (synopsis "Compute intersections of arbitrary curves")
    (description
     "The package computes the intersections between arbitrary PostScript
paths or Bezier curves, using the Bezier clipping algorithm.")
    (license license:lppl)))

(define-public texlive-pst-jtree
  (package
    (name "texlive-pst-jtree")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-jtree/"
                                     "tex/generic/pst-jtree/"
                                     "tex/latex/pst-jtree/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07vzx418syv1v04z1552k9iwjz4b4kmw7g2m1i4nqdfg2lvina8s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-jtree")
    (synopsis "Typeset complex trees for linguists")
    (description
     "jTree uses PSTricks to enable linguists to typeset complex trees.")
    (license license:lppl1.3+)))

(define-public texlive-pst-knot
  (package
    (name "texlive-pst-knot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-knot/" "dvips/pst-knot/"
                                     "tex/generic/pst-knot/"
                                     "tex/latex/pst-knot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b69m4qwd37vd3x734r4hp4wzsirsp6k5m87yqmxlhlkrf0wmrwc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-knot")
    (synopsis "PSTricks package for displaying knots")
    (description
     "The package can produce a fair range of knot shapes, with all the
standard graphics controls one expects.")
    (license license:lppl)))

(define-public texlive-pst-labo
  (package
    (name "texlive-pst-labo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-labo/"
                                     "tex/generic/pst-labo/"
                                     "tex/latex/pst-labo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nzpqgi7g6n2hzajh4ph9idf2imrfniar7sc3gr7kc8r9sc4b5ij"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-labo")
    (synopsis "Draw objects for Chemistry laboratories")
    (description
     "Pst-labo is a PSTricks related package for drawing basic and complex
chemical objects.  The documentation of the package is illuminated with plenty
of illustrations together with their source code, making it an easy read.")
    (license license:lppl)))

(define-public texlive-pst-layout
  (package
    (name "texlive-pst-layout")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pst-layout/"
                                     "tex/latex/pst-layout/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1f07j551kiajqyrfjlsj7xk40zv18ik2b3fih5iyzkf4zk4f650r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-layout")
    (synopsis "Page layout macros based on PSTricks packages")
    (description
     "The package provides a means of creating elaborate (``pseudo-tabular'')
layouts of material, typically to be overlaid on an included graphic.")
    (license license:lppl)))

(define-public texlive-pst-lens
  (package
    (name "texlive-pst-lens")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-lens/"
                                     "source/generic/pst-lens/"
                                     "tex/generic/pst-lens/"
                                     "tex/latex/pst-lens/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h2930i4izgfjk96445yiwsk6x8cg5cl4zlqrg5rsv7nr2k8njy3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-lens")
    (synopsis "Lenses with PSTricks")
    (description
     "This PSTricks package provides a really rather simple command
@code{\\PstLens} that will draw a lens.  Command parameters provide
a remarkable range of effects.")
    (license license:lppl)))

(define-public texlive-pst-light3d
  (package
    (name "texlive-pst-light3d")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-light3d/"
                                     "dvips/pst-light3d/"
                                     "source/generic/pst-light3d/"
                                     "tex/generic/pst-light3d/"
                                     "tex/latex/pst-light3d/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kwdbf64m2kmplk4r7ifxckajh3d5sgjini70fmababnrp1g8nzf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-light3d")
    (synopsis "Three dimensional lighting effects (PSTricks)")
    (description
     "This package provides a PSTricks package for three dimensional lighting
effects on characters and PSTricks graphics, like lines, curves, plots, ...")
    (license license:lppl)))

(define-public texlive-pst-lsystem
  (package
    (name "texlive-pst-lsystem")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-lsystem/"
                                     "dvips/pst-lsystem/"
                                     "tex/generic/pst-lsystem/"
                                     "tex/latex/pst-lsystem/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1k3krdcfqa5cyzaq0jp8dzil6arfvs5ah2mp87460pl2wvfza0lr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-lsystem")
    (synopsis "Create images based on a L-system")
    (description
     "@code{pst-lsystem} is a PSTricks based package for creating images based
on a L-system.  A L-system (Lindenmayer system) is a set of rules which can be
used to model the morphology of a variety of organisms or fractals like the
Kochflake or Hilbert curve.")
    (license license:lppl)))

(define-public texlive-pst-magneticfield
  (package
    (name "texlive-pst-magneticfield")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-magneticfield/"
                                     "dvips/pst-magneticfield/"
                                     "tex/generic/pst-magneticfield/"
                                     "tex/latex/pst-magneticfield/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qxlmj4v1m3mb5rb6ls9zz664ymcac05skyk2xxjnjjn23s6zjzi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-magneticfield")
    (synopsis "Plotting a magnetic field with PSTricks")
    (description
     "@code{pst-magneticfield} is a PSTricks related package to draw the
magnetic field lines of Helmholtz coils in a two or three dimensional view.
There are several parameters to create a different output.")
    (license license:lppl)))

(define-public texlive-pst-marble
  (package
    (name "texlive-pst-marble")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-marble/"
                                     "dvips/pst-marble/"
                                     "tex/generic/pst-marble/"
                                     "tex/latex/pst-marble/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1j5jags1m4wwwfkd25n57q49ggdwc7b9qjp8da4q255yf0i54w91"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-marble")
    (synopsis "PSTricks package to draw marble-like patterns")
    (description "This is a PSTricks package to draw marble-like patterns.")
    (license license:lppl1.3c)))

(define-public texlive-pst-math
  (package
    (name "texlive-pst-math")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-math/" "dvips/pst-math/"
                                     "tex/generic/pst-math/"
                                     "tex/latex/pst-math/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10y55bgazy49p2l1d8qrsbdzwds4zjl5gdlwyhssh55szyc1p67n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-math")
    (synopsis "Enhancement of PostScript math operators to use with PSTricks")
    (description
     "PostScript lacks a lot of basic operators such as tan, acos, asin, cosh,
sinh, tanh, acosh, asinh, atanh, exp (with e base).  Also (oddly) cos and sin
use arguments in degrees.  Pst-math provides all those operators in a header
file @file{pst-math.pro} with wrappers @file{pst-math.sty} and
@file{pst-math.tex}.  In addition, sinc, gauss, gammaln and bessel are
implemented (only partially for the latter).  The package is designed
essentially to work with @code{pst-plot} but can be used in whatever PS code.
The package also provides a routine SIMPSON for numerical integration and
a solver of linear equation systems.")
    (license license:lppl)))

(define-public texlive-pst-mirror
  (package
    (name "texlive-pst-mirror")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-mirror/"
                                     "dvips/pst-mirror/"
                                     "tex/generic/pst-mirror/"
                                     "tex/latex/pst-mirror/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b2q1islf9mwphzcs6g04vq69hlmyisx4rb5fb77yiw3na5xlnq0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-mirror")
    (synopsis "Images on a spherical mirror")
    (description
     "The package provides commands and supporting PostScript material for
drawing images as if reflected by a spherical mirror.")
    (license license:lppl)))

(define-public texlive-pst-moire
  (package
    (name "texlive-pst-moire")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-moire/" "dvips/pst-moire/"
                                     "tex/generic/pst-moire/"
                                     "tex/latex/pst-moire/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0i2p5b2cfhnbmszcs5ydlk4nfxhwgl84kq148kpg6cx07gg8rr6l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-moire")
    (synopsis "PSTricks package to draw moiré patterns")
    (description "This is a PSTricks package to draw moiré patterns.")
    (license license:lppl1.3c)))

(define-public texlive-pst-node
  (package
    (name "texlive-pst-node")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-node/" "dvips/pst-node/"
                                     "tex/generic/pst-node/"
                                     "tex/latex/pst-node/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0w9j1l5hlid98sp6hm7ny0z3nh6jcccvxglprq0wr08w89zb7dmz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-node")
    (synopsis "Nodes and node connections in PSTricks")
    (description
     "The package enables the user to connect information, and to place labels,
without knowing (in advance) the actual positions of the items to be
connected, or where the connecting line should go.  The macros are useful for
making graphs and trees, mathematical diagrams, linguistic syntax diagrams,
and so on.")
    (license license:lppl)))

(define-public texlive-pst-ob3d
  (package
    (name "texlive-pst-ob3d")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-ob3d/"
                                     "source/generic/pst-ob3d/"
                                     "tex/generic/pst-ob3d/"
                                     "tex/latex/pst-ob3d/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1j6y3v4x5gkshzxnmklwl2hqbz7nr904v1qa1dr9l4m814p2jhcc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-ob3d")
    (synopsis "Three dimensional objects using PSTricks")
    (description
     "The package uses PSTricks to provide basic three-dimensional objects.
As yet, only cubes (which can be deformed to rectangular parallelipipeds) and
dies (which are only a special kind of cubes) are defined.")
    (license license:lppl)))

(define-public texlive-pst-ode
  (package
    (name "texlive-pst-ode")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-ode/" "dvips/pst-ode/"
                                     "tex/generic/pst-ode/" "tex/latex/pst-ode/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jsghzx3d0hnlm5pn3rf4maksr1s6c37n4hw6k9b5qkif1hjrksj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-ode")
    (synopsis
     "Solve initial value problems for sets of Ordinary Differential
Equations")
    (description
     "The package defines @code{\\pstODEsolve} for solving initial value
problems for sets of Ordinary Differential Equations (ODE) using the
Runge-Kutta-Fehlberg (RKF45) method with automatic step size adjustment.  The
result is stored as a PostScript object and may be plotted later using macros
from other PSTricks packages, such as @code{\\listplot} (from @code{pst-plot})
and @code{\\listplotThreeD} (from @code{pst-3dplot}), or may be further
processed by user-defined PostScript procedures.  Optionally, the computed
state vectors can be written as a table to a text file.")
    (license license:lppl)))

(define-public texlive-pst-optexp
  (package
    (name "texlive-pst-optexp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pst-optexp/" "dvips/pst-optexp/"
                                     "makeindex/pst-optexp/"
                                     "source/latex/pst-optexp/"
                                     "tex/latex/pst-optexp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m835c700a6bxd8r8m84injzz862j1xdxbbh8waxh97yrfwmhp45"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-optexp")
    (synopsis "Drawing optical experimental setups")
    (description
     "The package is a collection of optical components that facilitate easy
sketching of optical experimental setups.  The package uses PSTricks for its
output.  A wide range of free-ray and fibre components is provided, the
alignment, positioning and labelling of which can be achieved in very simple
and flexible ways.  The components may be connected with fibers or beams, and
realistic raytraced beam paths are also possible.")
    (license license:lppl1.3+)))

(define-public texlive-pst-optic
  (package
    (name "texlive-pst-optic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-optic/"
                                     "tex/generic/pst-optic/"
                                     "tex/latex/pst-optic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16rryf56zjk7z4532hgmgkld1mx7abh5dn525bw3h5ijin4y7921"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-optic")
    (synopsis "Drawing optics diagrams")
    (description
     "This package provides a package for drawing both reflective and
refractive optics diagrams.")
    (license license:lppl)))

(define-public texlive-pst-osci
  (package
    (name "texlive-pst-osci")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-osci/"
                                     "tex/generic/pst-osci/"
                                     "tex/latex/pst-osci/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07zhx2lzihip8vvninhnpakj72a7h8dyi75sfmm686yy20d0hxx3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-osci")
    (synopsis "Oscgons with PSTricks")
    (description
     "This PSTricks package enables you to produce oscilloscope screen shots.
Three channels can be used to represent the most common signals (damped or
not): namely sinusoidal, rectangular, triangular, dog's tooth (left and right
oriented).  The third channel allows you to add, to subtract or to multiply
the two other signals.  Lissajous diagrams (XY-mode) can also be obtained.")
    (license license:lppl)))

(define-public texlive-pst-ovl
  (package
    (name "texlive-pst-ovl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-ovl/" "dvips/pst-ovl/"
                                     "tex/generic/pst-ovl/" "tex/latex/pst-ovl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0v9f4k475cm922y7i2x6w6p1w3nnbaw69rniznwap9bhliv0ynfg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-ovl")
    (synopsis "Create and manage graphical overlays")
    (description
     "The package is useful when building an image from assorted material, as
in the slides of a projected presentation.")
    (license license:lppl)))

(define-public texlive-pst-pad
  (package
    (name "texlive-pst-pad")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-pad/"
                                     "source/generic/pst-pad/"
                                     "tex/generic/pst-pad/" "tex/latex/pst-pad/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vvgjf2g9dynjg1y6dm1d47v40sga4a34ngyy3h5lfmy58860jri"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-pad")
    (synopsis "Draw simple attachment systems with PSTricks")
    (description
     "The package collects a set of graphical elements based on PStricks that
can be used to facilitate display of attachment systems such as two
differently shaped surfaces with or without a fluid wedged in between.  These
macros ease the display of wet adhesion models and common friction systems
such as boundary lubrication, elastohydrodynamic lubrication and hydrodynamic
lubrication.")
    (license license:lppl)))

(define-public texlive-pst-pdf
  (package
    (name "texlive-pst-pdf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pst-pdf/" "scripts/pst-pdf/"
                                     "source/latex/pst-pdf/" "tex/latex/pst-pdf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1as5q9p6z9y3ps3hm8v8par18xmxmhrcxmknpl6rhjq0wbyjlj26"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "ps4pdf")))
    (home-page "https://ctan.org/pkg/pst-pdf")
    (synopsis "Make PDF versions of graphics by processing between runs")
    (description
     "The package @code{pst-pdf} simplifies the use of graphics from PSTricks
and other PostScript code in PDF documents.  As in building a bibliography
with BibTeX, additional external programmes are invoked.  In this case they
are used to create a PDF file that will contain all the graphics material.  In
the final document these contents will be inserted instead of the original
PostScript code.")
    (license license:lppl1.2+)))

(define-public texlive-pst-pdgr
  (package
    (name "texlive-pst-pdgr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-pdgr/"
                                     "source/generic/pst-pdgr/"
                                     "tex/generic/pst-pdgr/"
                                     "tex/latex/pst-pdgr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08v28601j7ygp7d8xliwhfbrl2gh93ikf6kbl4p86wfxsbxlhg0c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-pdgr")
    (synopsis "Draw medical pedigrees using PSTricks")
    (description
     "The package provides a set of macros based on PSTricks to draw medical
pedigrees according to the recommendations for standardized human pedigree
nomenclature.  The drawing commands place the symbols on a @code{pspicture}
canvas.  An interface for making trees is also provided.  The package may be
used both with LaTeX and PlainTeX.  A separate Perl program for generating TeX
files from spreadsheets is available.")
    (license license:lppl)))

(define-public texlive-pst-perspective
  (package
    (name "texlive-pst-perspective")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-perspective/"
                                     "tex/generic/pst-perspective/"
                                     "tex/latex/pst-perspective/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dm7qqar0kjnc68xwhp7vn4m8bcsmzcs6qzh61ainbls7gni5aq8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-perspective")
    (synopsis "Draw perspective views using PSTricks")
    (description
     "The package provides the means to draw an orthogonal parallel projection
with an arbitrarily chosen angle and a variable shortening factor.")
    (license license:lppl1.3+)))

(define-public texlive-pst-platon
  (package
    (name "texlive-pst-platon")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-platon/"
                                     "source/generic/pst-platon/"
                                     "tex/latex/pst-platon/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a4w47varc1i22h5iwd49c0clwb2k8hdlva5l6nfmc889wgwp0d7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-platon")
    (synopsis "Platonic solids in PSTricks")
    (description
     "The package adds to PSTricks the ability to draw 3-dimensional views of
the five Platonic solids.")
    (license license:lppl)))

(define-public texlive-pst-plot
  (package
    (name "texlive-pst-plot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-plot/"
                                     "tex/generic/pst-plot/"
                                     "tex/latex/pst-plot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12jrn04nxfhw07y86pjkr6bbvdvwcnhfxr6aj9ni13383dxcwl7j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-plot")
    (synopsis "Plot data using PSTricks")
    (description
     "The package provides plotting of data (typically from external files),
using PSTricks.  Plots may be configured using a wide variety of parameters.")
    (license license:lppl)))

(define-public texlive-pst-poker
  (package
    (name "texlive-pst-poker")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pst-poker/"
                                     "tex/latex/pst-poker/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c1v75rxw717hvjgzb4i0ahk7acmqpgl9czaihvw36r9yaicsm5n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-poker")
    (synopsis "Drawing poker cards")
    (description
     "This PSTricks related package can create poker cards in various
manners.")
    (license license:lgpl3)))

(define-public texlive-pst-poly
  (package
    (name "texlive-pst-poly")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-poly/"
                                     "tex/generic/pst-poly/"
                                     "tex/latex/pst-poly/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fasd2y6vv28id1w858kq4rc3qd46rkds9z7vi8k102aqvv9as8n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-poly")
    (synopsis "Polygons with PSTricks")
    (description
     "This PSTricks package provides a really rather simple command
@code{\\PstPolygon} that will draw various regular and non-regular
polygons (according to command parameters); various shortcuts to commonly-used
polygons are provided, as well as a command @code{\\pspolygonbox} that frames
text with a polygon.")
    (license license:lppl)))

(define-public texlive-pst-pulley
  (package
    (name "texlive-pst-pulley")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-pulley/"
                                     "tex/generic/pst-pulley/"
                                     "tex/latex/pst-pulley/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n1kv743vxjw8b6nqrlivb3m3pg3z9kw56bzxij438p5him3sdaa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-pulley")
    (synopsis "Plot pulleys, using PSTricks")
    (description
     "The package enables the user to draw pulley systems with up to 6 pulleys.
The pulley diagrams are labelled with the physical properties of the system.")
    (license license:lppl1.3+)))

(define-public texlive-pst-qtree
  (package
    (name "texlive-pst-qtree")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-qtree/"
                                     "tex/generic/pst-qtree/"
                                     "tex/latex/pst-qtree/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hdmv4lar1hdg9bh049kmsjqd14rdv2066qrcaacwmd39nh816z5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-qtree")
    (synopsis "Simple syntax for trees")
    (description "The package provides a Qtree-like front end for PSTricks.")
    (license license:gpl3+)))

(define-public texlive-pst-rputover
  (package
    (name "texlive-pst-rputover")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-rputover/"
                                     "tex/generic/pst-rputover/"
                                     "tex/latex/pst-rputover/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1d25sdhvira5vlibgv3r51dk64jplqbpf4fdimh2l1flq5h0d9dw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-rputover")
    (synopsis "Place text over objects without obscuring background colors")
    (description
     "This is a PSTricks package which allows placing text over objects
without obscuring background colors.")
    (license license:lppl1.3c)))

(define-public texlive-pst-rubans
  (package
    (name "texlive-pst-rubans")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-rubans/"
                                     "source/generic/pst-rubans/"
                                     "tex/generic/pst-rubans/"
                                     "tex/latex/pst-rubans/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1izpw60jm4w8xgd5aiqc7qxhjd0js1g9k9anwbpni9sn1qma66zs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-rubans")
    (synopsis "Draw three-dimensional ribbons")
    (description
     "The package uses PStricks and @code{pst-solides3d} to draw three
dimensional ribbons on a cylinder, torus, sphere, cone or paraboloid.  The
width of the ribbon, the number of turns, the colour of the outer and the
inner surface of the ribbon may be set.  In the case of circular and conical
helices, one may also choose the number of ribbons.")
    (license license:lppl)))

(define-public texlive-pst-shell
  (package
    (name "texlive-pst-shell")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-shell/" "dvips/pst-shell/"
                                     "source/generic/pst-shell/"
                                     "tex/generic/pst-shell/"
                                     "tex/latex/pst-shell/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18w5csarnjv3ws554vjw2zlmpc5mcd03fc8fircv0pbxxl53l11r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-shell")
    (synopsis "Plotting sea shells")
    (description
     "@code{pst-shell} is a PSTricks related package to draw seashells in 3D
view: Argonauta, Epiteonium, Lyria, Turritella, Tonna, Achatina, Oxystele,
Conus, Ammonite, Codakia, Escalaria, Helcion, Natalina, Planorbis, and
Nautilus, all with different parameters.")
    (license license:lppl)))

(define-public texlive-pst-sigsys
  (package
    (name "texlive-pst-sigsys")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-sigsys/"
                                     "tex/generic/pst-sigsys/"
                                     "tex/latex/pst-sigsys/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18g1s1afh3lnkb3993k1ypkzbb4a88jw5paclwgyn59yqjq8x737"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-sigsys")
    (synopsis "Support of signal processing-related disciplines")
    (description
     "The package offers a collection of useful macros for disciplines related
to signal processing.  It defines macros for plotting a sequence of numbers,
drawing the pole-zero diagram of a system, shading the region of convergence,
creating an adder or a multiplier node, placing a framed node at a given
coordinate, creating an up-sampler or a down-sampler node, drawing the block
diagram of a system, drawing adaptive systems, sequentially connecting a list
of nodes, and connecting a list of nodes using any node-connecting macro.")
    (license license:lppl)))

(define-public texlive-pst-slpe
  (package
    (name "texlive-pst-slpe")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-slpe/" "dvips/pst-slpe/"
                                     "source/generic/pst-slpe/"
                                     "tex/generic/pst-slpe/"
                                     "tex/latex/pst-slpe/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12m6iss3hqsngq2dk7n3d1zz6z2rq4j2w1di9l26hpzly2mdp26n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-slpe")
    (synopsis "Sophisticated colour gradients")
    (description
     "This PStricks package covers all the colour gradient functionality of
@code{pst-grad} (part of the base PSTricks distribution), and provides the
following facilities:

@itemize
@item it permits the user to specify an arbitrary number of colours, along
with the points at which they are to be reached;
@item it converts between RGB and HSV behind the scenes;
@item it provides concentric and radial gradients;
@item it provides a command @code{\\psBall} that generates bullets with
a three-dimensional appearance.
@end itemize")
    (license license:lppl)))

(define-public texlive-pst-solarsystem
  (package
    (name "texlive-pst-solarsystem")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-solarsystem/"
                                     "dvips/pst-solarsystem/"
                                     "tex/generic/pst-solarsystem/"
                                     "tex/latex/pst-solarsystem/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rlkxm8ac2x2gcdc29997zz1v4j9cch1blxf3m9jramg4zbqq8n7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-solarsystem")
    (synopsis "Plot the solar system for a specific date")
    (description
     "The package uses PSTricks to produce diagrams of the visible planets,
projected on the plane of the ecliptic.  It is not possible to represent all
the planets in their real proportions, so only Mercury, Venus, Earth and Mars
have their orbits in correct proportions and their relative sizes are
observed.  Saturn and Jupiter are in the right direction, but not in the
correct size.")
    (license license:lppl)))

(define-public texlive-pst-solides3d
  (package
    (name "texlive-pst-solides3d")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-solides3d/"
                                     "dvips/pst-solides3d/"
                                     "tex/generic/pst-solides3d/"
                                     "tex/latex/pst-solides3d/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1iwh7p9mapr20cyns46ihdscfcj0m6vq0nr34hwi9m1bkflm7z18"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-solides3d")
    (synopsis "Draw perspective views of 3D solids")
    (description
     "The package is designed to draw solids in 3d perspective.  Its features
include:
@itemize
@item create primitive solids;
@item create solids by including a list of its vertices and faces;
@item faces of solids and surfaces can be colored by choosing from a very
large palette of colors;
@item draw parametric surfaces in algebraic and reverse polish notation;
@item create explicit and parameterized algebraic functions drawn in 2 or
3 dimensions;
@item project text onto a plane or onto the faces of a solid;
@item support for including external database files.
@end itemize")
    (license license:lppl1.3+)))

(define-public texlive-pst-soroban
  (package
    (name "texlive-pst-soroban")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-soroban/"
                                     "source/generic/pst-soroban/"
                                     "tex/latex/pst-soroban/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cpmqgaj1h2dh3acypm9xkjinmlw9wd40n1s2vdab5ascvprbr6n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-soroban")
    (synopsis "Draw a soroban using PSTricks")
    (description
     "The package uses PSTricks to draw a Japanese abacus, or soroban.  The
soroban is still used in Japan today.")
    (license license:lppl)))

(define-public texlive-pst-spectra
  (package
    (name "texlive-pst-spectra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-spectra/"
                                     "dvips/pst-spectra/"
                                     "tex/generic/pst-spectra/"
                                     "tex/latex/pst-spectra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l88wag5i1jy6pd1lx3s9cijiymzdgwvl52hkarc84d8qpn53wcw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-spectra")
    (synopsis "Draw continuum, emission and absorption spectra with PSTricks")
    (description
     "The package is a PSTricks extension, based on a NASA lines database.  It
allows you to draw continuum, emission and absorption spectra.  A Total of 16
880 visible lines from 99 elements can be displayed.")
    (license license:lppl)))

(define-public texlive-pst-spinner
  (package
    (name "texlive-pst-spinner")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-spinner/"
                                     "dvips/pst-spinner/"
                                     "tex/generic/pst-spinner/"
                                     "tex/latex/pst-spinner/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fm70v1kgjs32pvyvcnh2j47clqgdr4hll4j7fr935584d604g49"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-spinner")
    (synopsis "Drawing a fidget spinner")
    (description
     "This package aims to propose a model of the fidget spinner gadget.  It
exists under different forms with 2, 3 poles and even more.  We chose the most
popular model: the triple fidget spinner.")
    (license license:lppl)))

(define-public texlive-pst-stru
  (package
    (name "texlive-pst-stru")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-stru/"
                                     "tex/generic/pst-stru/"
                                     "tex/latex/pst-stru/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zxf0bj43picgd86bwgc38d8valpx0fn0pr3pgfv2kn42r2pampj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-stru")
    (synopsis "Civil engineering diagrams, using PSTricks")
    (description
     "This PSTricks-based package provides facilities to draw structural
schemes in civil engineering analysis, for beams, portals, arches and piles.")
    (license license:lppl)))

(define-public texlive-pst-support
  (package
    (name "texlive-pst-support")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-support/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1470n03zanpw35dnfzyjqm7d5lgddrimypz28x0zsk9nqpamnqnv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-support")
    (synopsis "Assorted support files for use with PSTricks")
    (description
     "This package provides an appropriate set of job options, together with
process scripts for use with TeXnicCenter.")
    (license license:lppl)))

(define-public texlive-pst-text
  (package
    (name "texlive-pst-text")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-text/"
                                     "dvips/pst-text/"
                                     "tex/generic/pst-text/"
                                     "tex/latex/pst-text/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "146fpzd1xlqi94q5r48z8ni8qww713yh6nwkbr9pw27mjrqdadb9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "http://www.ctan.org/pkg/pst-text")
    (synopsis "Text and character manipulation in PSTricks")
    (description "Pst-text is a PSTricks based package for plotting text along
a different path and manipulating characters.  It includes the functionality
of the old package @code{pst-char}.")
    (license license:lppl)))

(define-public texlive-pst-thick
  (package
    (name "texlive-pst-thick")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-thick/"
                                     "source/generic/pst-thick/"
                                     "tex/generic/pst-thick/"
                                     "tex/latex/pst-thick/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1clg9ahhg3zg91phlp2ni1j5m6pb68bdk74glh398r8y2gj2b5fb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-thick")
    (synopsis "Drawing very thick lines and curves")
    (description
     "The package supports drawing of very thick lines and curves in PSTricks,
with various fillings for the body of the lines.")
    (license license:lppl)))

(define-public texlive-pst-tools
  (package
    (name "texlive-pst-tools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-tools/" "dvips/pst-tools/"
                                     "tex/generic/pst-tools/"
                                     "tex/latex/pst-tools/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ws149np6121mc7msw32wkc6pn528ldsd5g95w4n4vcm6r54pmgq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-tools")
    (synopsis "PSTricks support functions")
    (description
     "The package provides helper functions for other PSTricks related
packages.")
    (license license:lppl)))

(define-public texlive-pst-tree
  (package
    (name "texlive-pst-tree")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-tree/"
                                     "tex/generic/pst-tree/"
                                     "tex/latex/pst-tree/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vznc4qyjpnni3smdxlpqi7h3qxd13kv5pigvlly0zq676n6gw8n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-tree")
    (synopsis "Trees, using PSTricks")
    (description
     "@code{pst-tree} defines a macro \\pstree that offers a structured way of
joining nodes created using @code{pst-node} in order to draw trees.")
    (license license:lppl)))

(define-public texlive-pst-turtle
  (package
    (name "texlive-pst-turtle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-turtle/"
                                     "dvips/pst-turtle/"
                                     "tex/generic/pst-turtle/"
                                     "tex/latex/pst-turtle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mgpjs9jkgfx0hbd9l5jw60rf0vpdkv933ksjlwcjlh98y9gay4c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-turtle")
    (synopsis "Commands for Turtle operations")
    (description
     "This is a PSTricks related package for creating Turtle graphics.")
    (license license:lppl)))

(define-public texlive-pst-tvz
  (package
    (name "texlive-pst-tvz")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-tvz/"
                                     "source/generic/pst-tvz/"
                                     "tex/generic/pst-tvz/" "tex/latex/pst-tvz/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xpzvfgngv5r5cdnvip87wr1i0pmrc6ibwi5gzmibfzl64w7vkqr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-tvz")
    (synopsis "Draw trees with more than one root node, using PSTricks")
    (description
     "The package uses PSTricks to draw trees with more than one root node.
It is similar to @code{pst-tree}, though it uses a different placement
algorithm.")
    (license license:lppl1.3+)))

(define-public texlive-pst-uml
  (package
    (name "texlive-pst-uml")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-uml/"
                                     "source/generic/pst-uml/"
                                     "tex/latex/pst-uml/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sgsyg9gk4wxgz7r44h6a7f5f7gl5b522f864n0kv35cgmwnzyr7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-multido))
    (home-page "https://ctan.org/pkg/pst-uml")
    (synopsis "UML diagrams with PSTricks")
    (description
     "This a PSTricks package that provides support for drawing moderately
complex UML (Universal Modelling Language) diagrams.  (The PDF documentation
is written in French.)")
    (license license:lppl)))

(define-public texlive-pst-vectorian
  (package
    (name "texlive-pst-vectorian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pst-vectorian/"
                                     "dvips/pst-vectorian/"
                                     "tex/latex/pst-vectorian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0knvzl4gqz79jzvb4w7a9ka1iiz5f3pjivnwvwmd1kmibykqwb67"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-vectorian")
    (synopsis "Printing ornaments")
    (description
     "The package uses PSTricks to draw ornaments (a substantial repertoire of
ornaments is provided).")
    (license license:lppl)))

(define-public texlive-pst-vehicle
  (package
    (name "texlive-pst-vehicle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-vehicle/"
                                     "tex/generic/pst-vehicle/"
                                     "tex/latex/pst-vehicle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b0s5fy4w4k2q486sdwlrh649n99k9s5hy5m2v01lh7qnjl1z4c3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-vehicle")
    (synopsis "Rolling vehicles on graphs of mathematical functions")
    (description
     "This package permits representing vehicles rolling without slipping on
mathematical curves.  Different types of vehicles are proposed, the shape of
the curve is to be defined by its equation in algebraic notation.")
    (license license:lppl1.3c)))

(define-public texlive-pst-venn
  (package
    (name "texlive-pst-venn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pst-venn/"
                                     "tex/latex/pst-venn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gz7sxwycqd71yy8jln7h3v064mrzhh1852fc7b785v55x8kna2n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-venn")
    (synopsis "PSTricks package for drawing Venn sets")
    (description
     "This is a PSTricks related package for drawing Venn diagrams with three
circles.")
    (license license:lppl)))

(define-public texlive-pst-vowel
  (package
    (name "texlive-pst-vowel")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pst-vowel/"
                                     "tex/latex/pst-vowel/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0p0qnfbmd1lh21nk6xq246xr6y50q0y55rdcq3i9vkg4j7kkkfy6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pst-vowel")
    (synopsis "Enable arrows showing diphthongs on vowel charts")
    (description
     "The package extends the @code{vowel} package (distributed as part of the
@code{tipa} bundle) by allowing the user to draw arrows between vowels to show
relationships such as diphthong membership.")
    (license license:lppl)))

(define-public texlive-pst2pdf
  (package
    (name "texlive-pst2pdf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/pst2pdf/" "scripts/pst2pdf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yihyrnwwpad5hf8yrjqljpwsnj6kcbb6y6cfnxwxbi1c5pf1jk9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "pst2pdf.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/pst2pdf")
    (synopsis "Script to compile PSTricks documents via pdfTeX")
    (description
     "The script extracts the preamble of the document and runs all
@code{\\begin@{postscript@}...\\end@{postscript@}},
@code{\\begin@{pspicture@}...\\end@{pspicture@}} and
@code{\\pspicture...\\endpspicture} separately through LaTeX with the same
preamble as the original document; thus it creates EPS, PNG and PDF files of
these snippets.  In a final pdfLaTeX run the script replaces the environments
with @code{\\includegraphics} to include the processed snippets.")
    (license license:gpl2)))

(define-public texlive-pstricks-add
  (package
    (name "texlive-pstricks-add")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/pstricks-add/"
                                     "dvips/pstricks-add/"
                                     "tex/generic/pstricks-add/"
                                     "tex/latex/pstricks-add/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r3agvd9mpdahzs8qpiplyldh4ygc5yzrchk2xmrdhkvnnvyyn6i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pstricks-add")
    (synopsis "Collection of add-ons and bugfixes for PSTricks")
    (description
     "This package collects together examples that have been posted to the
PSTricks mailing list, together with many additional features for the basic
@code{pstricks}, @code{pst-plot} and @code{pst-node}, including: bugfixes; new
options for the pspicture environment; arrows; braces as node
connection/linestyle; extended axes for plots (e.g., logarithm axes); polar
plots; plotting tangent lines of curves or functions; solving and printing
differential equations; box plots; matrix plots; and pie charts.")
    (license license:lppl)))

(define-public texlive-pstricks-calcnotes
  (package
    (name "texlive-pstricks-calcnotes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pstricks_calcnotes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00vgcdf73p4143dfjcvs4b5v4phvisv76ink3iiijl6s6f9zbmy3"))))
    (outputs '("out" "doc"))
    (properties '((upstream-name . "pstricks_calcnotes")))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pstricks-calcnotes")
    (synopsis "Use of PSTricks in calculus lecture notes")
    (description
     "The bundle shows the construction of PSTricks macros to draw Riemann
sums of an integral and to draw the vector field of an ordinary differential
equation.  The results are illustrated in a fragment of lecture notes.")
    (license license:lppl)))

(define-public texlive-marginnote
  (package
    (name "texlive-marginnote")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/marginnote/"
                                     "source/latex/marginnote/"
                                     "tex/latex/marginnote/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wsprc4gnxws3hs5sfpvcw6cdjs5mn5my5ff56hvk6mxd0m6rpwg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/marginnote")
    (synopsis "Notes in the margin")
    (description "This package provides the command @code{\\marginnote} that
may be used instead of @code{\\marginpar} at almost every place where
@code{\\marginpar} cannot be used, e.g., inside floats, footnotes, or in
frames made with the @code{framed} package.")
    (license license:lppl1.3c+)))

(define-public texlive-tabu
  (package
    (name "texlive-tabu")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tabu/" "source/latex/tabu/"
                                     "tex/latex/tabu/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mixyrqavipq4ni38z42x3579cdjbz54cp2qqb4q4yhfbl0a4pka"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-varwidth))
    (home-page "https://ctan.org/macros/latex/contrib/tabu")
    (synopsis "Flexible LaTeX tabulars")
    (description
     "The package provides an environment, @code{tabu}, which will make any
sort of tabular, and an environment @code{longtabu} which provides the
facilities of @code{tabu} in a modified @code{longtable} environment.")
    (license license:lppl1.3+)))

(define-public texlive-uml
  (package
    (name "texlive-uml")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uml/" "source/latex/uml/"
                                     "tex/latex/uml/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "039kg3xk03cm4xfsaj33kx1j5hjqy9330zxamqyzs1jnp8xgcfdz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uml")
    (synopsis "UML diagrams in LaTeX")
    (description
     "This package provides a PSTricks related package for writing
UML (Unified Modelling Language) diagrams in LaTeX.  Currently, it implements
a subset of class diagrams, and some extra constructs as well.  The package
cannot be used together with @code{pst-uml}.")
    (license license:lppl)))

(define-public texlive-vaucanson-g
  (package
    (name "texlive-vaucanson-g")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/vaucanson-g/"
                                     "tex/generic/vaucanson-g/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18ig6kszjr2jfr3hvq18clq8ccxbv2zw280pw20mphfjh6rjwbrj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/vaucanson-g")
    (synopsis "PSTricks macros for drawing automata")
    (description
     "VauCanSon-G is a package that enables the user to draw automata within
texts written using LaTeX.  The package macros make use of commands of
PSTricks.")
    (license license:lppl)))

(define-public texlive-vocaltract
  (package
    (name "texlive-vocaltract")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/vocaltract/"
                                     "tex/latex/vocaltract/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "072b712bhfxq429jh4r9d786nwpdyl8rlbm6ds4nf9asxg2lg9wr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/vocaltract")
    (synopsis "Visualise the vocal tract using LaTeX and PSTricks")
    (description
     "The package enables the user to visualise the vocal tract.  The vocal
tract (in the package) is manipulated by a vector of articulation parameters
according to the S. Maeda model.  Animation may be achieved by providing
a sequence of vectors over time (e.g., from Matlab).  A sequence of vectors
for certain German phonemes is embedded in the package, which allows for
animation when no other vector is available.  The package's graphics are
produced using PSTricks.")
    (license license:lppl)))

(define-public texlive-xkeyval
  (package
    (name "texlive-xkeyval")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xkeyval/" "source/latex/xkeyval/"
                                     "tex/generic/xkeyval/" "tex/latex/xkeyval/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nclsazny3hnzsi2vcixh2g1gsj5lvwxls1v569rms8ykgd9v7z8"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:build-targets #~(list "xkeyval.dtx")
      #:tex-format "latex"              ;won't build with luatex
      #:phases
      #~(modify-phases %standard-phases
          ;; This package cannot be built out of tree as it expects to find
          ;; built files in the working directory.
          (add-before 'build 'fix-build
            (lambda _
              (setenv "TEXINPUTS" (string-append (getcwd) "/build:"))
              (substitute* "source/latex/xkeyval/xkeyval.dtx"
                (("usepackage\\{xcolor\\}")
                 "usepackage[dvips]{xcolor}")))))))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-etoolbox
                  texlive-footmisc
                  texlive-fourier
                  texlive-hypdoc
                  texlive-infwarerr
                  texlive-kvoptions
                  texlive-listings
                  texlive-lm
                  texlive-pgf
                  texlive-pst-text
                  texlive-pstricks
                  texlive-xcolor))))
    (home-page "https://ctan.org/pkg/xkeyval")
    (synopsis "Extension of the @code{keyval} package")
    (description
     "This package is an extension of the keyval package and offers additional
macros for setting keys and declaring and setting class or package options.
The package allows the programmer to specify a prefix to the name of the
macros it defines for keys, and to define families of key definitions; these
all help use in documents where several packages define their own sets of
keys.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-xkeyval texlive-xkeyval)

(define-public texlive-scikgtex
  (package
    (name "texlive-scikgtex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/scikgtex/"
                                     "tex/lualatex/scikgtex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xzb07i15khplwdm14irg4jzj9ayngkj05qc4yk70z0nra95mhb4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/scikgtex")
    (synopsis
     "Mark research contributions in scientific documents and embed them in
PDF metadata")
    (description
     "Scientific Knowledge Graph TeX (SciKgTeX) is a LuaLaTeX package which
makes it possible to annotate specific research contributions in scientific
documents.  SciKGTeX will enrich the document by adding the marked
contributions to PDF metadata in a structured XMP format which can be picked
up by search engines and knowledge graphs.")
    (license license:expat)))

(define-public texlive-selnolig
  (package
    (name "texlive-selnolig")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/selnolig/"
                                     "tex/lualatex/selnolig/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xx3agmd7ply84jjx1kcg4jpix7qg1y3wrd2kr7dv74jw5cffrfq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/selnolig")
    (synopsis "Selectively disable typographic ligatures")
    (description
     "The package suppresses typographic ligatures selectively, i.e., based on
predefined search patterns.  The search patterns focus on ligatures deemed
inappropriate because they span morpheme boundaries.")
    (license license:lppl1.3+)))

(define-public texlive-showhyphenation
  (package
    (name "texlive-showhyphenation")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/showhyphenation/"
                                     "tex/lualatex/showhyphenation/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "004ks65aac3h7zzplx10amydbhxja5llkp4kp5krs35hpyv0q11f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/showhyphenation")
    (synopsis "Marking of hyphenation points")
    (description
     "The package shows the hyphenation points in the document by either
inserting small triangles below the baseline or by typesetting explicit
hyphens.  The markers are correctly placed even within ligatures and their
size adjusts to the font size.  By option the markers can be placed behind or
in front of the glyphs.  The package requires LuaLaTeX.")
    (license license:lppl1.3c)))

(define-public texlive-showkerning
  (package
    (name "texlive-showkerning")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/showkerning/"
                                     "tex/lualatex/showkerning/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l0xc7rlxfsw8pr1w65jkfpr4q7ljybjx8rl1vpyqz8556hi683w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/showkerning")
    (synopsis "Showing kerns in a document")
    (description
     "The package displays all kerning values in the form of colored bars
directly at the respective position in the document.  Positive values are
displayed in green, negative values in red.  The width of the bars corresponds
exactly to the respective kerning value.  By option the bars can be placed
behind or in front of the glyphs.  The package requires LuaLaTeX.")
    (license license:lppl1.3c)))

(define-public texlive-spacekern
  (package
    (name "texlive-spacekern")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/spacekern/"
                                     "tex/lualatex/spacekern/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wlp45z7wzdnb0bp2fzfrmzc1ba2wz5qji2n3qf7rfz7kb0z1ma8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/spacekern")
    (synopsis "Kerning between words and against space")
    (description
     "This package provides two shorthands for typesetting breaking and
non-breaking small spaces, where both hyphenation and kerning against space
are correctly applied.  Additionally, interword kerning can be applied.")
    (license license:lppl1.3c)))

(define-public texlive-spelling
  (package
    (name "texlive-spelling")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/spelling/" "scripts/spelling/"
                                     "tex/luatex/spelling/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pg4jz1rxpjc9648b53zbnwrn59id9iv8b1jfwl6nqj58q285w7q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/spelling")
    (synopsis "Support for spell-checking of LuaTeX documents")
    (description
     "The package aids spell-checking of TeX documents compiled with the
LuaTeX engine.  It can give visual feedback in PDF output similar to WYSIWYG
word processors.  The package relies on an external spell-checker application
to check spelling of a text file and to output a list of bad spellings.  The
package should work with most spell-checkers, even dumb, TeX-unaware ones.")
    (license license:lppl1.3+)))

(define-public texlive-standalone
  (package
    (name "texlive-standalone")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/standalone/"
                                     "source/latex/standalone/"
                                     "tex/latex/standalone/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "055mz0r837ipb6f0v7lp2imwpy1zh0i45wkd5f1dbpjpb9gf7qny"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ydoc")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ydoc))
    (propagated-inputs
     (list texlive-adjustbox
           texlive-currfile
           texlive-filemod
           texlive-gincltex
           texlive-xkeyval))
    (home-page "https://ctan.org/pkg/standalone")
    (synopsis "Compile TeX pictures stand-alone or as part of a document")
    (description
     "This package provides a class and package is provided which allows TeX
pictures or other TeX code to be compiled standalone or as part of a main
document.  Special support for pictures with @code{beamer} overlays is also
provided.  The package is used in the main document and skips extra preambles
in sub-files.  The class may be used to simplify the preamble in sub-files.
By default the @code{preview} package is used to display the typeset code
without margins.")
    (license license:lppl1.3+)))

(define-public texlive-stricttex
  (package
    (name "texlive-stricttex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/stricttex/"
                                     "tex/lualatex/stricttex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ddlcwj1bnj6zrkljkz3jywgri34f4g9gshbwd0lzz4nz03v82rv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/stricttex")
    (synopsis "Strictly balanced brackets and numbers in command names")
    (description
     "This is a small, LuaLaTeX-only package providing you with three,
sometimes useful features.  It allows you to make brackets @samp{[...]}
strict, meaning that each @samp{[} must be balanced by a @samp{]}.  It also
allows you to use numbers and primes in command names.")
    (license license:lppl1.3c)))

(define-public texlive-siunitx
  (package
    (name "texlive-siunitx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/siunitx/" "source/latex/siunitx/"
                                     "tex/latex/siunitx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00a4iv5460p6i8r7q6gsqvh9g0jwa25gcja42k5895rpxb31lly3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://www.ctan.org/pkg/siunitx")
    (synopsis "Comprehensive SI units package")
    (description
     "Typesetting values with units requires care to ensure that the combined
mathematical meaning of the value plus unit combination is clear.  In
particular, the SI units system lays down a consistent set of units with rules
on how they are to be used.  However, different countries and publishers have
differing conventions on the exact appearance of numbers (and units).  A
number of LaTeX packages have been developed to provide consistent application
of the various rules.  The @code{siunitx} package takes the best from the
existing packages, and adds new features and a consistent interface.  A number
of new ideas have been incorporated, to fill gaps in the existing provision.
The package also provides backward-compatibility with @code{SIunits},
@code{sistyle}, @code{unitsdef} and @code{units}.  The aim is to have one
package to handle all of the possible unit-related needs of LaTeX users.")
    (license license:lppl1.3c)))

(define-public texlive-booktabs
  (package
    (name "texlive-booktabs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/booktabs/" "source/latex/booktabs/"
                                     "tex/latex/booktabs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pv2kv4hgayqfcij2sz1jmk6kbxqccyaksz8xlw5kvqrbag9vxm3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/booktabs")
    (synopsis "Publication quality tables in LaTeX")
    (description
     "This package enhances the quality of tables in LaTeX, providing extra
commands as well as behind-the-scenes optimisation.  Guidelines are given as
to what constitutes a good table in this context.  The package offers
@code{longtable} compatibility.")
    (license license:lppl1.3+)))

(define-public texlive-csquotes
  (package
    (name "texlive-csquotes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/csquotes/" "tex/latex/csquotes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0657rvaciq5h4qp2hg9d2w2i663p5cnxygi6dj9w61463m4nkpy6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-etoolbox))
    (home-page "https://www.ctan.org/pkg/csquotes")
    (synopsis "Context sensitive quotation facilities")
    (description
     "This package provides advanced facilities for inline and display
quotations.  It is designed for a wide range of tasks ranging from the most
simple applications to the more complex demands of formal quotations.  The
facilities include commands, environments, and user-definable smart quotes
which dynamically adjust to their context.  Quotation marks are switched
automatically if quotations are nested and they can be adjusted to the current
language if the babel package is available.  There are additional facilities
designed to cope with the more specific demands of academic writing,
especially in the humanities and the social sciences.  All quote styles as
well as the optional active quotes are freely configurable.")
    (license license:lppl1.3c+)))

(define-public texlive-csquotes-de
  (package
    (name "texlive-csquotes-de")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/csquotes-de/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "087c08c44811vd8p00l1xrkg5w6fsl8as64jq83m6gf1hfan9w4c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/csquotes-de")
    (synopsis "German translation of @code{csquotes} documentation")
    (description
     "This is a German translation of the documentation of @code{csquotes}.")
    (license license:lppl)))

(define-public texlive-dhua
  (package
    (name "texlive-dhua")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dhua/" "source/latex/dhua/"
                                     "tex/latex/dhua/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0npf0bz5cdl6a98gc4l66v0hxwgg94af31bdrz8xai6r4vwjbzhl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dhua")
    (synopsis "German abbreviations using thin space")
    (description
     "The package provides commands for those abbreviations of German phrases
for which the use of thin space is recommended.")
    (license license:lppl1.3+)))

(define-public texlive-dtk-bibliography
  (package
    (name "texlive-dtk-bibliography")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/dtk-bibliography/"
                                     "doc/bibtex/dtk-bibliography/"
                                     "tex/latex/dtk-bibliography/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lacfh7pg6z7fn1mnmd4xhf4b9s9shjzqilaxb5fjj5lglixbs30"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dtk-bibliography")
    (synopsis "Bibliography of @emph{Die TeXnische Komodie}")
    (description
     "This package contains the bibliography for @emph{Die TeXnische Komodie},
the journal of the German-speaking TeX User Group.")
    (license license:lppl1.3c)))

(define-public texlive-etdipa
  (package
    (name "texlive-etdipa")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/etdipa/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jp35apalaa1lh44dbn1zayavv1n3wkm0v69hgy8vdz73yp5yvhz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/etdipa")
    (synopsis "Simple, lightweight template for scientific documents")
    (description
     "This package provides a complete working directory for the scientific
documentation of arbitrary projects.  It was originally developed to provide
a template for Austrian @emph{Diplomarbeiten} or @emph{Vorwissenschaftliche
Arbeiten}, which are scientfic projects of students at a secondary school.")
    (license license:lppl1.3+)))

(define-public texlive-etoolbox-de
  (package
    (name "texlive-etoolbox-de")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/etoolbox-de/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vchha7ymvj51jfnvl76rxv466lzfpxr6xcvwafxhi78w4bk9yry"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/etoolbox-de")
    (synopsis "German translation of documentation of @code{etoolbox}")
    (description "This package provides the German translation of
@code{etoolbox} documentation.")
    (license license:lppl)))

(define-public texlive-fifinddo-info
  (package
    (name "texlive-fifinddo-info")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fifinddo-info/"
                                     "source/latex/fifinddo-info/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m95qyd5kbaa2x8rpjwr6f9c76ajg6l49igzw9yb0hcrwwg7cni6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fifinddo-info")
    (synopsis "German HTML beamer presentation on nicetext and morehype")
    (description
     "The bundle: exhibits the process of making an HTML beamer presentation
with the @code{blogdot} package from the @code{morehype} bundle, and HTML
generation based on the @code{fifinddo} package.")
    (license license:lppl1.3+)))

(define-public texlive-german
  (package
    (name "texlive-german")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/german/"
                                     "source/generic/german/"
                                     "tex/generic/german/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0n17j7rc69kxgs3b2cyxjb8hsh6bc9aydxf90x98rdc2ardl9idg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/german")
    (synopsis "Support for German typography")
    (description
     "This package provides supports the old German orthography (alte deutsche
Rechtschreibung).")
    (license license:lppl)))

(define-public texlive-germbib
  (package
    (name "texlive-germbib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/germbib/" "doc/bibtex/germbib/"
                                     "tex/latex/germbib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mc95h4ndzbg2q30vsq2rx9v0a8f0q0vhmjiz709lllkmj6n402p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/germbib")
    (synopsis "German variants of standard BibTeX styles")
    (description
     "This package provides a development of the (old) @file{german.sty}, this
bundle provides German packages, BibTeX styles and documentary examples, for
writing documents with bibliographies.  The author has since developed the
@code{babelbib} bundle, which (he asserts) supersedes @code{germbib}.")
    ;; The license is a variation of Knuth's.
    (license (license:fsf-free "file://doc/bibtex/germbib/apalike.tex"))))

(define-public texlive-germkorr
  (package
    (name "texlive-germkorr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/germkorr/" "tex/latex/germkorr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qgh3j97dljwh7625m577jcsvqhfkas3jn4q09m05jsjfxb7n2bx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/germkorr")
    (synopsis "Change kerning for German quotation marks")
    (description
     "The package brings some letters nearer to German single and double
quotes even when that letter wears a standard accent")
    (license license:gpl3+)))

(define-public texlive-hausarbeit-jura
  (package
    (name "texlive-hausarbeit-jura")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hausarbeit-jura/"
                                     "source/latex/hausarbeit-jura/"
                                     "tex/latex/hausarbeit-jura/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14raizfrrfnwdgwaq9irxdkg2mg280csjcirsxjq4rpdwqg2nkwh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hausarbeit-jura")
    (synopsis
     "Class for writing @emph{juristische Hausarbeiten} at German Universities")
    (description
     "The class was developed for use by students writing legal
essays (@emph{juristische Hausarbeit}) at German Universities.  It is based on
@code{jurabook} and @code{jurabib} and makes it easy for LaTeX beginners to
get a correct and nicely formatted paper.")
    (license license:lppl1.3+)))

(define-public texlive-logreq
  (package
    (name "texlive-logreq")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/logreq/" "tex/latex/logreq/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13difccs3cxlkqlnhw286yb0c7mifrxfd402a2x5wwxv0m1kgfqd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-etoolbox))
    (home-page "https://ctan.org/pkg/logreq")
    (synopsis "Support for automation of the LaTeX workflow")
    (description
     "The package helps to automate a typical LaTeX workflow that involves
running LaTeX several times, running tools such as BibTeX or makeindex, and so
on.  It will log requests like ``please rerun LaTeX'' or ``please run BibTeX
on file X'' to an external XML file which lists all open tasks in
a machine-readable format.  Compiler scripts and integrated LaTeX editing
environments may parse this file to determine the next steps in the
workflow. In sum, the package will do two things: enable package authors to
use LaTeX commands to issue requests, collect all requests from all packages
and write them to an external XML file at the end of the document.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex
  (package
    (name "texlive-biblatex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/biblatex/biblatex/"
                                     "bibtex/bst/biblatex/" "doc/latex/biblatex/"
                                     "tex/latex/biblatex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08wvsdwcixj50kklv4zwjs9rpjmhwzxxd242hvyi6lzkd7r0fnq4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-etoolbox
           texlive-kvoptions
           texlive-logreq
           texlive-pdftexcmds
           texlive-url))
    (home-page "https://ctan.org/pkg/biblatex")
    (synopsis "Sophisticated Bibliographies in LaTeX")
    (description
     "BibLaTeX is a complete reimplementation of the bibliographic facilities
provided by LaTeX.  Formatting of the bibliography is entirely controlled by
LaTeX macros, and a working knowledge of LaTeX should be sufficient to design
new bibliography and citation styles.  BibLaTeX uses its own data backend
program called @code{biber} to read and process the bibliographic data.  With
@code{biber}, the range of features provided by BibLaTeX includes full Unicode
support, customisable bibliography labels, multiple bibliographies in the same
document, and subdivided bibliographies, such as bibliographies per chapter or
section.")
    (license license:lppl1.3+)))

(define-public texlive-biblatex-apa
  (package
    (name "texlive-biblatex-apa")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biblatex-apa/"
                                     "tex/latex/biblatex-apa/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1q0agi722ap1ai9w6yw1q9fvwx1wgxldrq9l626fw55q5wxwl2dx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biblatex-apa")
    (synopsis "BibLaTeX citation and reference style for APA")
    (description
     "This is a fairly complete BibLaTeX style (citations and references) for
APA (American Psychological Association) publications.  It implements and
automates most of the guidelines in the APA 7th edition style guide for
citations and references.")
    (license license:lppl1.3c)))

(define-public texlive-truthtable
  (package
    (name "texlive-truthtable")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/truthtable/"
                                     "tex/lualatex/truthtable/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z148ga6a3apalf8wvl6y7rghwz80f1a3rpds3gsf6apzjzkxjfy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/truthtable")
    (synopsis
     "Automatically generate truth tables for given variables and statements")
    (description
     "This LuaLaTeX package permits automatically generating truth tables
given a table header.  It supports a number of logical operations which can be
combined as needed.")
    (license license:lppl1.3c)))

(define-public texlive-todonotes
  (package
    (name "texlive-todonotes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/todonotes/"
                                     "source/latex/todonotes/"
                                     "tex/latex/todonotes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a7z4za1c67cjp2g4v4mh0ql3l8n6m2clqyzlkxbkmpr1pa70has"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-pgf texlive-tools texlive-xcolor texlive-xkeyval))
    (home-page "https://ctan.org/pkg/todonotes")
    (synopsis "Marking things to do in a LaTeX document")
    (description
     "The @code{todonotes} package lets the user mark things to do later, in
a simple and visually appealing way.  The package takes several options to
enable customization and finetuning of the visual appearance.")
    (license license:lppl1.3+)))

(define-public texlive-tsvtemplate
  (package
    (name "texlive-tsvtemplate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/tsvtemplate/"
                                     "tex/luatex/tsvtemplate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05q1vfsy9w0pmc489dl995iqr9srdv107mj89nlc269m3wjnwn7a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tsvtemplate")
    (synopsis "Apply a template to a TSV file")
    (description
     "This is a simple TSV (tab-separated values) reader for LuaLaTeX and
plain LuaTeX.  It also supports (non-quoted) comma-separated values, or indeed
values separated by any character.")
    (license license:eupl1.2)))

(define-public texlive-typewriter
  (package
    (name "texlive-typewriter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/typewriter/"
                                     "tex/lualatex/typewriter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00c53vbm8fchjggi3h1w49y07ma4cmmliqx2bhkvis6qsqgddw5f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/typewriter")
    (synopsis "Typeset with a randomly variable monospace font")
    (description
     "The typewriter package uses the OpenType Computer Modern Unicode
Typewriter font, together with a LuaTeX virtual font setup that introduces
random variability in grey level and angle of each character.")
    (license license:lppl)))

(define-public texlive-uninormalize
  (package
    (name "texlive-uninormalize")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/uninormalize/"
                                     "tex/lualatex/uninormalize/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c4pki1yw5599s9nyj1ir7j26mgbhf1iw7m44685d8la9vbzv8dm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uninormalize")
    (synopsis "Unicode normalization support")
    (description
     "This package provides Unicode normalization (useful for composed
characters) for LuaLaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-units
  (package
    (name "texlive-units")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/units/" "source/latex/units/"
                                     "tex/latex/units/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mrdsg55f40cvarrx84gbhrnsk8mlv915nll17lnfzfapgmvjsbl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/units")
    (synopsis "Typeset physical units and fractions")
    (description "@code{units} is a package for typesetting physical units in
a standard-looking way.  The package is based upon @code{nicefrac}, a package
for typing fractions.  @code{nicefrac} is included in the @code{units}
bundle.")
    (license license:gpl3+)))

(define-public texlive-microtype
  (package
    (name "texlive-microtype")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/microtype/"
                                     "source/latex/microtype/"
                                     "tex/latex/microtype/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "039v1dw3n4lnd8ipazlkb7p5abqcrigjayx797ggh3ak8dcqwlli"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/microtype")
    (synopsis "Subliminal refinements towards typographical perfection")
    (description
     "The package provides a LaTeX interface to the micro-typographic
extensions that were introduced by pdfTeX and have since also propagated to
XeTeX and LuaTeX: most prominently, character protrusion and font expansion,
furthermore the adjustment of interword spacing and additional kerning, as
well as hyphenatable letterspacing (tracking) and the possibility to disable
all or selected ligatures.  These features may be applied to customisable sets
of fonts, and all micro-typographic aspects of the fonts can be configured in
a straight-forward and flexible way.  An alternative package
@code{letterspace}, which also works with plain TeX, is included in the
bundle.")
    (license license:lppl1.3c)))

(define-public texlive-microtype-de
  (package
    (name "texlive-microtype-de")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/microtype-de/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "069d2f0jcg9m4fv8dli2dr9ags9gz6mkwy6fzz37ns4jzrqfsvwi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/microtype-de")
    (synopsis "Translation into German of the documentation of @code{microtype}")
    (description
     "This package provides the translation into German of the documentation
of @code{microtype}.")
    (license license:lppl1.3+)))

(define-public texlive-minitoc
  (package
    (name "texlive-minitoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/minitoc/"
                                     "tex/latex/minitoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yd1na5b9m7z1j87a5fjwjqddfpiblfbpzcv0vlvql6lwh38mii7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/minitoc")
    (synopsis "Produce a table of contents for each chapter, part or section")
    (description
     "The @code{minitoc} package allows you to add
mini-tables-of-contents (minitocs) at the beginning of every chapter, part or
section.  There is also provision for mini-lists of figures and of tables.  At
the part level, they are parttocs, partlofs and partlots.  If the type of
document does not use chapters, the basic provision is section level secttocs,
sectlofs and sectlots.  The package has provision for language-specific
configuration of its own fixed names, using @file{.mld} files.")
    (license license:lppl1.3+)))

(define-public texlive-minted
  (package
    (name "texlive-minted")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/minted/" "source/latex/minted/"
                                     "tex/latex/minted/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dybmrnhbmfba4lm02g8xg2rncqdm651fbds74l94c0l47vmw33x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-catchfile
           texlive-etoolbox
           texlive-float
           texlive-framed
           texlive-fvextra
           texlive-graphics
           texlive-ifplatform
           texlive-kvoptions
           texlive-lineno
           texlive-newfloat
           texlive-pdftexcmds
           texlive-tools
           texlive-xcolor
           texlive-xstring))
    (home-page "https://ctan.org/pkg/minted")
    (synopsis "Highlighted source code for LaTeX")
    (description
     "The package that facilitates expressive syntax highlighting in LaTeX
using the powerful Pygments library.  The package also provides options to
customize the highlighted source code output using @code{fancyvrb}.")
    (license license:lppl1.3+)))

(define-public texlive-caption
  (package
    (name "texlive-caption")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/caption/" "source/latex/caption/"
                                     "tex/latex/caption/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lqdhi8z1dk46z8yf3qpplxj2vlqlym3rlprdci9239838yfcdbq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/caption")
    (synopsis "Customising captions in floating environments")
    (description
     "The @code{caption} package provides many ways to customise the captions
in floating environments like figure and table, and cooperates with many other
packages.  Facilities include rotating captions, sideways captions, continued
captions (for tables or figures that come in several parts).  A list of
compatibility notes, for other packages, is provided in the documentation.
The package also provides the caption outside float facility, in the same way
that simpler packages like capt-of do.")
    (license license:lppl1.3+)))

(define-public texlive-symbol
  (package
    (name "texlive-symbol")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "dvips/symbol/"
                                     "fonts/afm/adobe/symbol/"
                                     "fonts/afm/urw/symbol/"
                                     "fonts/map/dvips/symbol/"
                                     "fonts/tfm/adobe/symbol/"
                                     "fonts/tfm/monotype/symbol/"
                                     "fonts/tfm/urw35vf/symbol/"
                                     "fonts/type1/urw/symbol/"
                                     "tex/latex/symbol/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pdkpr86bhia5hcmf7q3nhvklnsga4mqqrrirgl8a7al7x6q3ivs"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/urw-base35")
    (synopsis "Replacement for Adobe's Symbol font")
    (description
     "This package provides a drop-in replacement for the Symbol font from
Adobe's basic set.")
    (license license:gpl3+)))

(define-public texlive-mathpazo
  (package
    (name "texlive-mathpazo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mathpazo/"
                                     "fonts/afm/public/mathpazo/"
                                     "fonts/tfm/public/mathpazo/"
                                     "fonts/type1/public/mathpazo/"
                                     "fonts/vf/public/mathpazo/"
                                     "source/latex/mathpazo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0g10rjgg1kb78lgyxmwjrkgpy24yq3v0m47h6zhbc68rrmmawvwp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-fpl texlive-palatino))
    (home-page "https://ctan.org/pkg/mathpazo")
    (synopsis "Fonts to typeset mathematics to match Palatino")
    (description "The Pazo Math fonts are a family of PostScript fonts
suitable for typesetting mathematics in combination with the Palatino family
of text fonts.  The Pazo Math family is made up of five fonts provided in
Adobe Type 1 format.  These contain glyphs that are usually not available in
Palatino and for which Computer Modern looks odd when combined with Palatino.
These glyphs include the uppercase Greek alphabet in upright and slanted
shapes, the lowercase Greek alphabet in slanted shape, several mathematical
glyphs and the uppercase letters commonly used to represent various number
sets.  LaTeX macro support is provided in package @code{psnfss}.")
    (license license:gpl3+)))

(define-public texlive-mathspec
  (package
    (name "texlive-mathspec")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/mathspec/"
                                     "tex/xelatex/mathspec/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bfdzlim2kkvfzs8p7brwlc46qy41hvxb72xr53ijg2kplsqmkh8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mathspec")
    (synopsis "Specify arbitrary fonts for mathematics in XeTeX")
    (description
     "The mathspec package provides an interface to typeset mathematics in
XeLaTeX with arbitrary text fonts using @code{fontspec} as a backend.")
    (license license:lppl)))

(define-public texlive-mathtools
  (package
    (name "texlive-mathtools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mathtools/"
                                     "source/latex/mathtools/"
                                     "tex/latex/mathtools/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "196mz0y26000mls7ca127aw99kaqqamvkki7mlfr6rshgyyfibhn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mathtools")
    (synopsis "Mathematical tools to use with @code{amsmath}")
    (description
     "Mathtools provides a series of packages designed to enhance the
appearance of documents containing a lot of mathematics.  It is based on
@code{amsmath} and fixes various deficiencies of it and standard LaTeX.  It
provides:
@itemize
@item Extensible symbols, such as brackets, arrows, harpoons, etc.;
@item Various symbols such as \\coloneqq (:=);
@item Easy creation of new tag forms;
@item Showing equation numbers only for referenced equations;
@item Extensible arrows, harpoons and hookarrows;
@item Starred versions of the @code{matrix} environments for specifying the
column alignment;
@item More building blocks: multlined, cases-like environments, new gathered
environments;
@item Maths versions of @code{\\makebox}, @code{\\llap}, @code{\\rlap} etc.;
@item Cramped math styles; and more...
@end itemize")
    (license license:lppl1.3c)))

(define-public texlive-memoir
  (package
    (name "texlive-memoir")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/memoir/" "makeindex/memoir/"
                                     "source/latex/memoir/" "tex/latex/memoir/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ry8glac6mah9dz7x2qq02mc5kmnfpbnnzwf01bz12jrdgi6cnn0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/memoir")
    (synopsis "Typeset fiction, non-fiction and mathematical books")
    (description
     "The @code{memoir} class is for typesetting poetry, fiction,
non-fiction, and mathematical works.  Permissible document base font sizes
range from 9 to 60pt.  There is a range of page-styles and well over a dozen
chapter-styles to choose from, as well as methods for specifying your own
layouts and designs.  The class also provides the functionality of over thirty
of the more popular packages, thus simplifying document sources.")
    (license license:lppl1.3+)))

(define-public texlive-milog
  (package
    (name "texlive-milog")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/milog/" "tex/latex/milog/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1114i8hgs84nnvmkiy8azbh6rgk0gjzp387idvvkx651vcyc82kf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/milog")
    (synopsis
     "LaTeX class for documentation duties according to the German minimum wage law
MiLoG")
    (description
     "The @file{milog.cls} class provides means to fulfill the documentation
duties by the German minimum wage law MiLoG.  The recording of working hours
is carried out in a simple CSV file from which the class will automatically
create a time sheet.  Alternatively, data can also be collected by a CSV
export of a suitable app.")
    (license license:lppl)))

(define-public texlive-fp
  (package
    (name "texlive-fp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fp/" "tex/latex/fp/"
                                     "tex/plain/fp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1q555fx71cf88sn3npzb0j2i10ak920k0qc9ccdygz99vqg10dad"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fp")
    (synopsis "Fixed point arithmetic")
    (description
     "This package provides an extensive collection of arithmetic operations
for fixed point real numbers of high precision.")
    (license license:lppl)))

(define-public texlive-fpl
  (package
    (name "texlive-fpl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/fpl/" "fonts/afm/public/fpl/"
                                     "fonts/type1/public/fpl/" "source/fonts/fpl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02gkl516z9kn8xqs269pdkqn37sxm8ib0pcs43s4rs2rhyyl5z68"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fpl")
    (synopsis "SC and OsF fonts for URW Palladio L")
    (description "The FPL Fonts provide a set of SC/OsF fonts for URW
Palladio L which are compatible with the Palatino SC/OsF fonts from
Adobe.  LaTeX use is enabled by the mathpazo package, which is part of
the @code{psnfss} distribution.")
    ;; Either LPPL version 1.0 or later, or GPL version 2
    (license (list license:lppl1.0+ license:gpl2))))

(define-public texlive-arabxetex
  (package
    (name "texlive-arabxetex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/arabxetex/"
                                     "fonts/misc/xetex/fontmapping/arabxetex/"
                                     "source/xelatex/arabxetex/"
                                     "tex/xelatex/arabxetex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "097lh7ksw9rg93f1c7a4fqglgfpydf1qp3sbgy9xfgszcdpknmrk"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:tex-format "xelatex"
      #:phases
      #~(modify-phases %standard-phases
          ;; Use dummy fonts to avoid pulling in needless dependencies.
          ;; We're only interested in building the package, not the
          ;; documentation.
          (add-after 'unpack 'change-fonts
            (lambda _
              (substitute* "source/xelatex/arabxetex/arabxetex.dtx"
                (("(newfontfamily.*?\\{)[^}]+}" _ prefix)
                 (string-append prefix "FreeSans}"))
                (("(set(main|mono|sans)font(\\[.*?])?\\{)[^}]+}" _ prefix)
                 (string-append prefix "FreeSans}"))))))))
    (native-inputs
     (list (texlive-updmap.cfg
            (list fontconfig
                  font-gnu-freefont
                  texlive-amsmath
                  texlive-amsfonts
                  texlive-bidi
                  texlive-etoolbox
                  texlive-fancyvrb
                  texlive-fontspec
                  texlive-hologo
                  texlive-hypdoc
                  texlive-hyperref
                  texlive-infwarerr
                  texlive-kvdefinekeys
                  texlive-kvoptions
                  texlive-kvsetkeys
                  texlive-ltxcmds
                  texlive-paralist
                  texlive-pdftexcmds
                  texlive-supertabular
                  texlive-tools
                  texlive-xetex
                  texlive-xkeyval
                  texlive-zref))))
    (home-page "https://ctan.org/pkg/arabxetex")
    (synopsis "ArabTeX-like interface for XeLaTeX")
    (description
     "ArabXeTeX provides a convenient ArabTeX-like user-interface for
typesetting languages using the Arabic script in XeLaTeX, with flexible access
to font features.  Input in ArabTeX notation can be set in three different
vocalization modes or in roman transliteration.  Direct UTF-8 input is also
supported.")
    (license license:lppl1.3c)))

(define-public texlive-arev
  (package
    (name "texlive-arev")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/arev/"
                                     "fonts/afm/public/arev/"
                                     "fonts/enc/dvips/arev/"
                                     "fonts/map/dvips/arev/"
                                     "fonts/tfm/public/arev/"
                                     "fonts/type1/public/arev/"
                                     "fonts/vf/public/arev/"
                                     "source/fonts/arev/"
                                     "tex/latex/arev/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a0zw9vc6z0shxvb4kdhfqdhwpzph5hm9v7klpchlisabvk421y1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/arev")
    (synopsis "Fonts and LaTeX support files for Arev Sans")
    (description
     "The @code{arev} package provides type 1 fonts, virtual fonts and LaTeX
packages for using Arev Sans in both text and mathematics.  Arev Sans is
a derivative of Bitstream Vera Sans, adding support for Greek and Cyrillic
characters and a few variant letters appropriate for mathematics.  The font is
primarily used in LaTeX for presentations, particularly when using a computer
projector.  Arev Sans has large x-height, open letters, wide spacing and thick
stems.  The style is very similar to the SliTeX font @code{lcmss} but heavier.
Arev is one of a very small number of sans-font mathematics support
packages.")
    (license (list license:silofl1.1    ;for Arev Sans
                   license:lppl1.3a     ;for TeX support files
                   license:gpl2))))     ;for ams-mdbch.sty

(define-public texlive-awesomebox
  (package
    (name "texlive-awesomebox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/awesomebox/"
                                     "tex/latex/awesomebox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jmxhas12fs30x2csv1rbsjr71a60fv2r3i5q7xd5n9zmmrnh32f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/awesomebox")
    (synopsis "Draw admonition blocks in your documents")
    (description
     "Awesome Box is all about drawing admonition blocks around text to inform
or alert readers about something particular.  The specific aim of this package
is to use FontAwesome icons to ease the illustration of these blocks.")
    (license license:wtfpl2)))

(define-public texlive-mathdesign
  (package
    (name "texlive-mathdesign")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/mathdesign/"
                                     "dvips/mathdesign/"
                                     "fonts/enc/dvips/mathdesign/"
                                     "fonts/map/dvips/mathdesign/"
                                     "fonts/tfm/public/mathdesign/mdbch/"
                                     "fonts/tfm/public/mathdesign/mdgreek/"
                                     "fonts/tfm/public/mathdesign/mdici/"
                                     "fonts/tfm/public/mathdesign/mdpgd/"
                                     "fonts/tfm/public/mathdesign/mdpus/"
                                     "fonts/tfm/public/mathdesign/mdput/"
                                     "fonts/tfm/public/mathdesign/mdugm/"
                                     "fonts/type1/public/mathdesign/mdbch/"
                                     "fonts/type1/public/mathdesign/mdici/"
                                     "fonts/type1/public/mathdesign/mdpgd/"
                                     "fonts/type1/public/mathdesign/mdpus/"
                                     "fonts/type1/public/mathdesign/mdput/"
                                     "fonts/type1/public/mathdesign/mdugm/"
                                     "fonts/vf/public/mathdesign/mdbch/"
                                     "fonts/vf/public/mathdesign/mdgreek/"
                                     "fonts/vf/public/mathdesign/mdici/"
                                     "fonts/vf/public/mathdesign/mdpgd/"
                                     "fonts/vf/public/mathdesign/mdpus/"
                                     "fonts/vf/public/mathdesign/mdput/"
                                     "fonts/vf/public/mathdesign/mdugm/"
                                     "tex/latex/mathdesign/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jcby2sd0l3ank2drxc0qcf5d1cwa8idzh4g91h4nxk8zrzxj8nr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mathdesign")
    (synopsis "Mathematical fonts to fit with particular text fonts")
    (description
     "The Math Design project offers mathematical fonts that match with
existing text fonts.  To date, three free font families are available: Adobe
Utopia, URW Garamond and Bitstream Charter.  Mathdesign covers the whole LaTeX
glyph set including AMS symbols.  Both roman and bold versions of these
symbols can be used.  Moreover, there is a choice between three greek
fonts (two of them created by the Greek Font Society).")
    (license license:gpl3+)))

(define-public texlive-bera
  (package
    (name "texlive-bera")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/bera/"
                                     "fonts/afm/public/bera/"
                                     "fonts/map/dvips/bera/"
                                     "fonts/tfm/public/bera/"
                                     "fonts/type1/public/bera/"
                                     "fonts/vf/public/bera/"
                                     "tex/latex/bera/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pkmhhr6ah44xhipjr7nianv03hr4w4bn45xcvp264yw6ymqzqwr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bera")
    (synopsis "Bera fonts")
    (description "The @code{bera} package contains the Bera Type 1 fonts and
files to use the fonts with LaTeX.  Bera is a set of three font families: Bera
Serif (a slab-serif Roman), Bera Sans (a Frutiger descendant) and Bera
Mono (monospaced/typewriter).  The Bera family is a repackaging, for use with
TeX, of the Bitstream Vera family.")
    (license license:silofl1.1)))

(define-public texlive-fourier
  (package
    (name "texlive-fourier")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/fourier/"
                                     "fonts/afm/public/fourier/"
                                     "fonts/map/dvips/fourier/"
                                     "fonts/opentype/public/fourier/"
                                     "fonts/tfm/public/fourier/"
                                     "fonts/type1/public/fourier/"
                                     "fonts/vf/public/fourier/"
                                     "tex/latex/fourier/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10nw0s3820mf4nv4b655cfvm8asjb1q71yd21cnm8zjxj0xpcrpx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fourier")
    (synopsis "Using Utopia fonts for LaTeX documents")
    (description
     "Fourier-GUTenberg is a LaTeX typesetting system which uses Adobe Utopia
as its standard base font.  Fourier-GUTenberg provides all complementary
typefaces needed to allow Utopia based TeX typesetting, including an extensive
mathematics set and several other symbols.  The system is absolutely
stand-alone: apart from Utopia and Fourier, no other typefaces are required.
Utopia is a registered trademark of Adobe Systems Incorporated")
    (license license:lppl)))

(define-public texlive-utopia
  (package
    (name "texlive-utopia")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/utopia/" "fonts/afm/adobe/utopia/"
                                     "fonts/tfm/adobe/utopia/"
                                     "fonts/type1/adobe/utopia/"
                                     "fonts/vf/adobe/utopia/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "113wgkfz4z0ls2grxxfj17l42a1yv9r5ipcd0156xnfsrqvqzxfc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/utopia")
    (synopsis "Adobe Utopia fonts")
    (description
     "The Adobe Standard Encoding set of the Utopia font family, as
contributed by the X Consortium.  The set comprises upright and italic shapes
in medium and bold weights.  Macro support and matching maths fonts are
provided by the @code{fourier} and the @code{mathdesign} font packages.")
    (license (license:fsf-free
              "http://mirrors.ctan.org/fonts/utopia/README"))))

(define-public texlive-fontaxes
  (package
    (name "texlive-fontaxes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fontaxes/" "source/latex/fontaxes/"
                                     "tex/latex/fontaxes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1d9ji2qvjf1ky8l6rfqbag2hw61r0hyjxkzsp18s4pckyq4dqwdm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fontaxes")
    (synopsis "Additional font axes for LaTeX")
    (description "The @code{fontaxes} package adds several new font axes on
top of LaTeX's New Font Selection Scheme (NFSS).  In particular, it splits the
shape axis into a primary and a secondary shape axis and it adds three new
axes to deal with the different figure versions offered by many professional
fonts.")
    (license license:lppl1.3+)))

(define-public texlive-preprint
  (package
    (name "texlive-preprint")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/preprint/" "source/latex/preprint/"
                                     "tex/latex/preprint/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "198xwg6mll3yndc1kf79l6zgnq3nsk7fsh3rlj28nipd26ysw6lq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/preprint")
    (synopsis "Bundle of modules for preprints")
    (description "The bundle comprises: @code{authblk}, which permits
footnote style author/affiliation input in the @command{\\author} command,
@code{balance}, to balance the end of @command{\\twocolumn} pages,
@code{figcaps}, to send figure captions, etc., to end document,
@code{fullpage}, to set narrow page margins and set a fixed page style, and
@code{sublabel}, which permits counters to be subnumbered.")
    (license license:lppl1.3+)))

(define-public texlive-mweights
  (package
    (name "texlive-mweights")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mweights/" "tex/latex/mweights/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12493g3yz06mhiybnphqbp49fjzy36clzw63b74mkfhsg1pq7h1b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mweights")
    (synopsis "Support for multiple-weight font packages")
    (description
     "Many font families available for use with LaTeX are available at
multiple weights.  Many Type 1-oriented support packages for such fonts
re-define the standard @code{\\mddefault} or @code{\\bfdefault} macros.  This
can create difficulties if the weight desired for one font family isn't
available for another font family, or if it differs from the weight desired
for another font family.  The package provides a solution to these
difficulties.")
    (license license:lppl)))

(define-public texlive-cabin
  (package
    (name "texlive-cabin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cabin/"
                                     "fonts/enc/dvips/cabin/"
                                     "fonts/map/dvips/cabin/"
                                     "fonts/opentype/impallari/cabin/"
                                     "fonts/tfm/impallari/cabin/"
                                     "fonts/type1/impallari/cabin/"
                                     "fonts/vf/impallari/cabin/"
                                     "tex/latex/cabin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dy1a6xfnwlmlv8rb0gdfa70dz14rrg78b43bclx0lc7ghs3fm4c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cabin")
    (synopsis "Humanist Sans Serif font with LaTeX support")
    (description
     "Cabin is a humanist sans with four weights and true italics and small
capitals.  According to the designer, Pablo Impallari, Cabin was inspired by
Edward Johnston's and Eric Gill's typefaces, with a touch of modernism.  Cabin
incorporates modern proportions, optical adjustments, and some elements of the
geometric sans.  @file{cabin.sty} supports use of the font under LaTeX,
pdfLaTeX, XeLaTeX and LuaLaTeX; it uses the @code{mweights}, to manage the
user's view of all those font weights.  An option is provided to enable Cabin
as the default text font.")
    (license (list license:silofl1.1    ;for Cabin
                   license:lppl))))     ;for support files

(define-public texlive-newtx
  (package
    (name "texlive-newtx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/newtx/"
                                     "fonts/afm/public/newtx/"
                                     "fonts/enc/dvips/newtx/"
                                     "fonts/map/dvips/newtx/"
                                     "fonts/opentype/public/newtx/"
                                     "fonts/tfm/public/newtx/"
                                     "fonts/type1/public/newtx/"
                                     "fonts/vf/public/newtx/"
                                     "tex/latex/newtx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12ygizxrkscqn2hyrdmgpyz6d65nnm1qhhq0hy4nqs4mkff8md7f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-kastrup))
    (home-page "https://www.ctan.org/pkg/newtx")
    (synopsis "Repackaging of the TX fonts with improved metrics")
    (description
     "The @code{newtx} bundle splits @file{txfonts.sty} (from the TX fonts
distribution) into two independent packages, @code{newtxtext.sty} and
@code{newtxmath.sty}, each with fixes and enhancements.  @code{newtxmath}'s
metrics have been re-evaluated to provide a less tight appearance and to
provide a @code{libertine} option that substitutes Libertine italic and Greek
letters for the existing math italic and Greek glyphs, making a mathematics
package that matches Libertine text quite well.")
    (license license:lppl1.3)))

(define-public texlive-xcharter
  (package
    (name "texlive-xcharter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/xcharter/"
                                     "fonts/afm/public/xcharter/"
                                     "fonts/enc/dvips/xcharter/"
                                     "fonts/map/dvips/xcharter/"
                                     "fonts/opentype/public/xcharter/"
                                     "fonts/tfm/public/xcharter/"
                                     "fonts/type1/public/xcharter/"
                                     "fonts/vf/public/xcharter/"
                                     "tex/latex/xcharter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ci1ibmscrd4c9f5gp57f43dcd9gshrpv4afyzn7kpi3m7k5b1vb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xcharter")
    (synopsis "Extension of Bitstream Charter fonts")
    (description "@code{xcharter} repackages Bitstream Charter with an
extended set of features.  The extension provides small caps, oldstyle
figures and superior figures in all four styles, accompanied by LaTeX
font support files.  The fonts themselves are provided in both Adobe
Type 1 and OTF formats, with supporting files as necessary.")
    (license (list (license:fsf-free
                    "http://mirrors.ctan.org/fonts/xcharter/README")
                   license:lppl1.3))))

(define-public texlive-ly1
  (package
    (name "texlive-ly1")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ly1/"
                                     "fonts/enc/dvips/ly1/"
                                     "fonts/map/dvips/ly1/"
                                     "fonts/tfm/adobe/ly1/"
                                     "fonts/vf/adobe/ly1/"
                                     "tex/latex/ly1/"
                                     "tex/plain/ly1/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mwk8bfpvpzbwjw3jd6plw0w7kykpb499fv50a9bqxh0jqcyh0j5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ly1")
    (synopsis "Support for LY1 LaTeX encoding")
    (description
     "The legacy @code{texnansi} (TeX and ANSI) encoding is known in the LaTeX
scheme of things as @emph{LY1} encoding.  The @code{ly1} bundle includes
metrics and LaTeX macros to use the three basic Adobe Type 1 fonts (Times,
Helvetica and Courier) in LaTeX using LY1 encoding.")
    (license license:lppl1.0+)))

(define-public texlive-section
  (package
    (name "texlive-section")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/section/" "tex/latex/section/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gjajhlwwgyqnmw9bzr0l7dsq12mdhgv8sdkm86m4zn107qab0p9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/section")
    (synopsis "Modifying section commands in LaTeX")
    (description
     "The package implements a pretty extensive scheme to make more manageable
the business of configuring LaTeX output.")
    (license license:lppl)))

(define-public texlive-sectsty
  (package
    (name "texlive-sectsty")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sectsty/" "source/latex/sectsty/"
                                     "tex/latex/sectsty/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1h7zi622s84vqjl6bi4g6iv639jz9m2imz4g7y1qpc0zdw1mlqv4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://www.ctan.org/pkg/sectsty")
    (synopsis "Control sectional headers")
    (description
     "This is a LaTeX2ε package to help change the style of any or all of
LaTeX's sectional headers in the article, book, or report classes.  Examples
include the addition of rules above or below a section title.")
    (license license:lppl1.2+)))

(define-public texlive-morefloats
  (package
    (name "texlive-morefloats")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/morefloats/"
                                     "source/latex/morefloats/"
                                     "tex/latex/morefloats/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y8rd3ys71ys9cab172wwhrmbs9b52wqrj6d3p0iy3075z93h51c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/morefloats")
    (synopsis "Increase the number of simultaneous LaTeX floats")
    (description "LaTeX can, by default, only cope with 18 outstanding floats;
any more, and you get the error “too many unprocessed floats”.  This package
releases the limit; TeX itself imposes limits (which are independent of the
help offered by e-TeX).

However, if your floats can’t be placed anywhere, extending the number of
floats merely delays the arrival of the inevitable error message.")
    (license license:lppl1.3c+)))

(define-public texlive-ifmtarg
  (package
    (name "texlive-ifmtarg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ifmtarg/" "source/latex/ifmtarg/"
                                     "tex/latex/ifmtarg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19bfi12j5ra19k6vjd1q5fjsm68vipa7ida7pg9pf15l5pxwbgqz"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-filecontents")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs (list texlive-filecontents))
    (home-page "https://ctan.org/pkg/ifmtarg")
    (synopsis "If-then-else command for processing potentially empty arguments")
    (description
     "This package provides a command for the LaTeX programmer for testing
whether an argument is empty.")
    (license license:lppl1.3c+)))

(define-public texlive-pagenote
  (package
    (name "texlive-pagenote")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pagenote/" "source/latex/pagenote/"
                                     "tex/latex/pagenote/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dffh7ac13w3gs94lvfxgw1i4k6cfkrpcyikj1sfrqaivrxpmqpi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pagenote")
    (synopsis "Notes at end of document")
    (description
     "The @code{pagenote} package provides tagged notes on a separate
page (also known as end notes).")
    (license license:lppl1.3c+)))

(define-public texlive-pagesel
  (package
    (name "texlive-pagesel")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pagesel/" "source/latex/pagesel/"
                                     "tex/latex/pagesel/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x4nb53d5gm0vrhiinaqf6ai63bgjpbw0b5kk3c2f6j6gfvp0n53"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pagesel")
    (synopsis "Select pages of a document for output")
    (description
     "This package selects single pages, ranges of pages, odd pages or even
pages for output.  The package is part of the @code{oberdiek} bundle.")
    (license license:lppl1.3c)))

(define-public texlive-titling
  (package
    (name "texlive-titling")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/titling/" "source/latex/titling/"
                                     "tex/latex/titling/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wp5r6wwrz1nx3wrmc0hxjfapqppcb126l4wmmzh14sfb1py7mz4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/titling")
    (synopsis "Control typesetting of the @code{\\maketitle} command")
    (description
     "The @code{titling} package provides control over the typesetting of the
@code{\\maketitle} command and @code{\\thanks} commands, and makes the
@code{\\title}, @code{\\author} and @code{\\date} information permanently
available.  Multiple titles are allowed in a single document.  New titling
elements can be added and a @code{titlepage} title can be centered on
a physical page.")
    (license license:lppl)))

(define-public texlive-ifoddpage
  (package
    (name "texlive-ifoddpage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ifoddpage/"
                                     "source/latex/ifoddpage/"
                                     "tex/latex/ifoddpage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mxi28lf97l4zg5kcv524b29n5r167yczrhgy132hql866vkdvyr"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ydoc")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ydoc))
    (home-page "https://ctan.org/pkg/ifoddpage")
    (synopsis "Determine if the current page is odd or even")
    (description
     "This package provides an @code{\\ifoddpage} conditional to determine if
the current page is odd or even.  The macro @code{\\checkoddpage} must be used
directly before to check the page number using a label.  Two compiler runs are
therefore required to achieve correct results.  In addition, the conditional
@code{\\ifoddpageoronside} is provided which is also true in @code{oneside}
mode where all pages use the odd page layout.")
    (license license:lppl1.3)))

(define-public texlive-storebox
  (package
    (name "texlive-storebox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/storebox/" "source/latex/storebox/"
                                     "tex/latex/storebox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vbjq9aq2kbncq1dn4rk7jspfb6kcxk66h49z0xz1qix5yg94gmx"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ydoc")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ydoc))
    (home-page "https://ctan.org/pkg/storebox")
    (synopsis "Storing information for reuse")
    (description
     "The package provides store boxes whose user interface matches that of
normal LaTeX save boxes, except that the content of a store box appears at
most once in the output PDF file, however often it is used.  The present
version of the package supports pdfLaTeX and LuaLaTeX; when DVI is output,
store boxes behave the same as save boxes.")
    (license license:lppl1.3+)))

(define-public texlive-collectbox
  (package
    (name "texlive-collectbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/collectbox/"
                                     "source/latex/collectbox/"
                                     "tex/latex/collectbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mn0hdzjhbmziqqh2k7knfz816lxbjil0zld0n30qi3ila5v3gk6"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ydoc")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ydoc))
    (home-page "https://ctan.org/pkg/collectbox")
    (synopsis "Collect and process macro arguments as boxes")
    (description
     "The package provides macros to collect and process a macro
argument (i.e., something which looks like a macro argument) as a horizontal
box rather than as a real macro argument.  The \"arguments\" are stored as if
they had been saved by @code{\\savebox} or by the @code{lrbox} environment.
Grouping tokens @code{\\bgroup} and @code{\\egroup} may be used, which allows
the user to have the beginning and end of a group in different macro
invocations, or to place them in the begin and end code of an environment.
Arguments may contain verbatim material or other special use of characters.
The macros were designed for use within other macros.")
    (license license:lppl1.3)))

(define-public texlive-collection-basic
  (package
    (name "texlive-collection-basic")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
   (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-amsfonts
           texlive-bibtex
           texlive-bin                  ;for the TeX engine
           texlive-cm
           texlive-colorprofiles
           texlive-dvipdfmx
           texlive-dvips
           texlive-ec
           texlive-enctex
           texlive-etex
           texlive-etex-pkg
           texlive-glyphlist
           texlive-graphics-def
           texlive-hyphen-complete
           texlive-hyphenex
           texlive-ifplatform
           texlive-iftex
           texlive-knuth-lib
           texlive-knuth-local
           texlive-kpathsea
           texlive-lua-alt-getopt
           texlive-luahbtex
           texlive-luatex
           texlive-makeindex
           texlive-metafont
           texlive-mflogo
           texlive-mfware
           texlive-modes
           texlive-pdftex
           texlive-plain
           texlive-tex
           texlive-tex-ini-files
           texlive-unicode-data
           texlive-xdvi))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Essential programs and files")
    (description
     "These files are regarded as basic for any TeX system, covering plain TeX
macros, Computer Modern fonts, and configuration for common drivers; no
LaTeX.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-bibtexextra
  (package
    (name "texlive-collection-bibtexextra")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-aaai-named
           texlive-aichej
           texlive-ajl
           texlive-amsrefs
           texlive-annotate
           texlive-apacite
           texlive-apalike-ejor
           texlive-apalike2
           texlive-archaeologie
           texlive-authordate
           texlive-beebe
           texlive-besjournals
           texlive-bestpapers
           texlive-bib2gls
           texlive-bibarts
           texlive-bibcop
           texlive-biber
           texlive-biber-ms
           texlive-bibexport
           texlive-bibhtml
           texlive-biblatex
           texlive-biblatex-abnt
           texlive-biblatex-ajc2020unofficial
           texlive-biblatex-anonymous
           texlive-biblatex-apa
           texlive-biblatex-apa6
           texlive-biblatex-archaeology
           texlive-biblatex-arthistory-bonn
           texlive-biblatex-bath
           texlive-biblatex-bookinarticle
           texlive-biblatex-bookinother
           texlive-biblatex-bwl
           texlive-biblatex-caspervector
           texlive-biblatex-chem
           texlive-biblatex-chicago
           texlive-biblatex-claves
           texlive-biblatex-cv
           texlive-biblatex-dw
           texlive-biblatex-enc
           texlive-biblatex-ext
           texlive-biblatex-fiwi
           texlive-biblatex-gb7714-2015
           texlive-biblatex-german-legal
           texlive-biblatex-gost
           texlive-biblatex-historian
           texlive-biblatex-ieee
           texlive-biblatex-ijsra
           texlive-biblatex-iso690
           texlive-biblatex-jura2
           texlive-biblatex-juradiss
           texlive-biblatex-license
           texlive-biblatex-lncs
           texlive-biblatex-lni
           texlive-biblatex-luh-ipw
           texlive-biblatex-manuscripts-philology
           texlive-biblatex-mla
           texlive-biblatex-morenames
           texlive-biblatex-ms
           texlive-biblatex-multiple-dm
           texlive-biblatex-musuos
           texlive-biblatex-nature
           texlive-biblatex-nejm
           texlive-biblatex-nottsclassic
           texlive-biblatex-opcit-booktitle
           texlive-biblatex-oxref
           texlive-biblatex-philosophy
           texlive-biblatex-phys
           texlive-biblatex-publist
           texlive-biblatex-readbbl
           texlive-biblatex-realauthor
           texlive-biblatex-sbl
           texlive-biblatex-science
           texlive-biblatex-shortfields
           texlive-biblatex-socialscienceshuberlin
           texlive-biblatex-software
           texlive-biblatex-source-division
           texlive-biblatex-spbasic
           texlive-biblatex-subseries
           texlive-biblatex-swiss-legal
           texlive-biblatex-trad
           texlive-biblatex-true-citepages-omit
           texlive-biblatex-unified
           texlive-biblatex-vancouver
           texlive-biblatex2bibitem
           texlive-biblist
           texlive-bibtexperllibs
           texlive-bibtopic
           texlive-bibtopicprefix
           texlive-bibunits
           texlive-biolett-bst
           texlive-bookdb
           texlive-breakcites
           texlive-cell
           texlive-chbibref
           texlive-chembst
           texlive-chicago
           texlive-chicago-annote
           texlive-chicagoa
           texlive-chscite
           texlive-citation-style-language
           texlive-citeall
           texlive-citeref
           texlive-collection-latex
           texlive-collref
           texlive-compactbib
           texlive-crossrefware
           texlive-custom-bib
           texlive-din1505
           texlive-dk-bib
           texlive-doipubmed
           texlive-ecobiblatex
           texlive-econ-bst
           texlive-economic
           texlive-fbs
           texlive-figbib
           texlive-footbib
           texlive-francais-bst
           texlive-gbt7714
           texlive-geschichtsfrkl
           texlive-harvard
           texlive-harvmac
           texlive-hep-bibliography
           texlive-historische-zeitschrift
           texlive-icite
           texlive-ietfbibs
           texlive-ijqc
           texlive-inlinebib
           texlive-iopart-num
           texlive-is-bst
           texlive-jbact
           texlive-jmb
           texlive-jneurosci
           texlive-jurabib
           texlive-ksfh-nat
           texlive-listbib
           texlive-logreq
           texlive-ltb2bib
           texlive-luabibentry
           texlive-margbib
           texlive-multibib
           texlive-multibibliography
           texlive-munich
           texlive-nar
           texlive-newcastle-bst
           texlive-nmbib
           texlive-notes2bib
           texlive-notex-bst
           texlive-oscola
           texlive-perception
           texlive-plainyr
           texlive-pnas2009
           texlive-rsc
           texlive-showtags
           texlive-sort-by-letters
           texlive-splitbib
           texlive-turabian-formatting
           texlive-uni-wtal-ger
           texlive-uni-wtal-lin
           texlive-urlbst
           texlive-usebib
           texlive-vak
           texlive-windycity
           texlive-xcite
           texlive-zootaxa-bst))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "BibTeX additional styles")
    (description
     "This collection provides additional BibTeX styles and bibliography
data(bases), notably including BibLaTeX.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-binextra
  (package
    (name "texlive-collection-binextra")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list asymptote
           texlive-a2ping
           texlive-adhocfilelist
           texlive-arara
           texlive-bibtex8
           texlive-bibtexu
           texlive-bundledoc
           texlive-checklistings
           texlive-chklref
           texlive-chktex
           texlive-clojure-pamphlet
           texlive-cluttex
           texlive-collection-basic
           texlive-ctan-o-mat
           texlive-ctan-chk
           texlive-ctanbib
           texlive-ctanify
           texlive-ctanupload
           texlive-ctie
           texlive-cweb
           texlive-de-macro
           texlive-detex
           texlive-digestif
           texlive-dtl
           texlive-dtxgen
           texlive-dvi2tty
           texlive-dviasm
           texlive-dvicopy
           texlive-dvidvi
           texlive-dviinfox
           texlive-dviljk
           texlive-dviout-util
           texlive-dvipng
           texlive-dvipos
           texlive-dvisvgm
           texlive-findhyph
           texlive-fragmaster
           texlive-git-latexdiff
           texlive-gsftopk
           texlive-hook-pre-commit-pkg
           texlive-installfont
           texlive-ketcindy
           texlive-lacheck
           texlive-latex-git-log
           texlive-latex-papersize
           texlive-latex2man
           texlive-latex2nemeth
           texlive-latexdiff
           texlive-latexfileversion
           texlive-latexindent
           texlive-latexmk
           texlive-latexpand
           texlive-light-latex-make
           texlive-listings-ext
           texlive-ltxfileinfo
           texlive-ltximg
           texlive-luajittex
           texlive-make4ht
           texlive-match-parens
           texlive-mflua
           texlive-mkjobtexmf
           texlive-optexcount
           texlive-patgen
           texlive-pdfbook2
           texlive-pdfcrop
           texlive-pdfjam
           texlive-pdflatexpicscale
           texlive-pdftex-quiet
           texlive-pdftosrc
           texlive-pdfxup
           texlive-pfarrei
           texlive-pkfix
           texlive-pkfix-helper
           texlive-purifyeps
           texlive-pythontex
           texlive-seetexk
           texlive-spix
           texlive-srcredact
           texlive-sty2dtx
           texlive-synctex
           texlive-tex4ebook
           texlive-texaccents
           texlive-texcount
           texlive-texdef
           texlive-texdiff
           texlive-texdirflatten
           texlive-texdoc
           texlive-texdoctk
           texlive-texfot
           texlive-texliveonfly
           texlive-texloganalyser
           texlive-texlogfilter
           texlive-texlogsieve
           texlive-texosquery
           texlive-texplate
           texlive-texware
           texlive-tie
           texlive-tlcockpit
           texlive-tpic2pdftex
           texlive-typeoutfileinfo
           texlive-upmendex
           texlive-web
           texlive-xindex
           texlive-xindy
           texlive-xpdfopen))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "TeX auxiliary programs")
    (description
     "This package provides a myriad of additional TeX-related support
programs.  It includes programs and macros for DVI file manipulation, literate
programming, patgen, and plenty more.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-context
  (package
    (name "texlive-collection-context")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs (list texlive-collection-basic
                             texlive-context
                             texlive-context-calendar-examples
                             texlive-context-collating-marks
                             texlive-context-cyrillicnumbers
                             texlive-context-filter
                             texlive-context-gnuplot
                             texlive-context-handlecsv
                             texlive-context-legacy
                             texlive-context-letter
                             texlive-context-mathsets
                             texlive-context-notes-zh-cn
                             texlive-context-pocketdiary
                             texlive-context-simpleslides
                             texlive-context-squares
                             texlive-context-sudoku
                             texlive-context-texlive
                             texlive-context-transliterator
                             texlive-context-typescripts
                             texlive-context-vim
                             texlive-context-visualcounter
                             texlive-jmn
                             texlive-luajittex))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "ConTeXt and packages")
    (description
     "This package provides Hans Hagen's powerful ConTeXt system, along with
third-party ConTeXt packages.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-fontsextra
  (package
    (name "texlive-collection-fontsextra")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-aboensis
           texlive-academicons
           texlive-accanthis
           texlive-adforn
           texlive-adfsymbols
           texlive-aesupp
           texlive-alegreya
           texlive-alfaslabone
           texlive-algolrevived
           texlive-allrunes
           texlive-almendra
           texlive-almfixed
           texlive-andika
           texlive-anonymouspro
           texlive-antiqua
           texlive-antt
           texlive-archaic
           texlive-archivo
           texlive-arev
           texlive-arimo
           texlive-arvo
           texlive-asana-math
           texlive-asapsym
           texlive-ascii-font
           texlive-aspectratio
           texlive-astro
           texlive-atkinson
           texlive-augie
           texlive-auncial-new
           texlive-aurical
           texlive-b1encoding
           texlive-barcodes
           texlive-baskervald
           texlive-baskervaldx
           texlive-baskervillef
           texlive-bbding
           texlive-bbm
           texlive-bbm-macros
           texlive-bbold
           texlive-bbold-type1
           texlive-bboldx
           texlive-belleek
           texlive-bera
           texlive-berenisadf
           texlive-beuron
           texlive-bguq
           texlive-bitter
           texlive-blacklettert1
           texlive-boisik
           texlive-bookhands
           texlive-boondox
           texlive-braille
           texlive-brushscr
           texlive-cabin
           texlive-caladea
           texlive-calligra
           texlive-calligra-type1
           texlive-cantarell
           texlive-carlito
           texlive-carolmin-ps
           texlive-cascadia-code
           texlive-ccicons
           texlive-cfr-initials
           texlive-cfr-lm
           texlive-charissil
           texlive-cherokee
           texlive-chivo
           texlive-cinzel
           texlive-clara
           texlive-clearsans
           texlive-cm-lgc
           texlive-cm-mf-extra-bold
           texlive-cm-unicode
           texlive-cmathbb
           texlive-cmbright
           texlive-cmexb
           texlive-cmll
           texlive-cmpica
           texlive-cmsrb
           texlive-cmtiup
           texlive-cmupint
           texlive-cochineal
           texlive-coelacanth
           texlive-collection-basic
           texlive-comfortaa
           texlive-comicneue
           texlive-concmath-fonts
           texlive-concmath-otf
           texlive-cookingsymbols
           texlive-cooperhewitt
           texlive-cormorantgaramond
           texlive-countriesofeurope
           texlive-courier-scaled
           texlive-courierten
           texlive-crimson
           texlive-crimsonpro
           texlive-cryst
           texlive-cuprum
           texlive-cyklop
           texlive-dancers
           texlive-dantelogo
           texlive-dejavu
           texlive-dejavu-otf
           texlive-dice
           texlive-dictsym
           texlive-dingbat
           texlive-domitian
           texlive-doublestroke
           texlive-doulossil
           texlive-dozenal
           texlive-drm
           texlive-droid
           texlive-dsserif
           texlive-duerer
           texlive-duerer-latex
           texlive-dutchcal
           texlive-ean
           texlive-ebgaramond
           texlive-ebgaramond-maths
           texlive-ecc
           texlive-eco
           texlive-eczar
           texlive-eiad
           texlive-eiad-ltx
           texlive-ektype-tanka
           texlive-electrum
           texlive-elvish
           texlive-epigrafica
           texlive-epsdice
           texlive-erewhon
           texlive-erewhon-math
           texlive-esrelation
           texlive-esstix
           texlive-esvect
           texlive-etbb
           texlive-euler-math
           texlive-eulervm
           texlive-euxm
           texlive-fbb
           texlive-fdsymbol
           texlive-fetamont
           texlive-feyn
           texlive-fge
           texlive-fira
           texlive-firamath
           texlive-firamath-otf
           texlive-foekfont
           texlive-fonetika
           texlive-fontawesome
           texlive-fontawesome5
           texlive-fontmfizz
           texlive-fonts-churchslavonic
           texlive-forum
           texlive-fourier
           texlive-fouriernc
           texlive-frcursive
           texlive-frederika2016
           texlive-frimurer
           texlive-garamond-libre
           texlive-garamond-math
           texlive-genealogy
           texlive-gentium-tug
           texlive-gfsartemisia
           texlive-gfsbodoni
           texlive-gfscomplutum
           texlive-gfsdidot
           texlive-gfsdidotclassic
           texlive-gfsneohellenic
           texlive-gfsneohellenicmath
           texlive-gfssolomos
           texlive-gillcm
           texlive-gillius
           texlive-gnu-freefont
           texlive-gofonts
           texlive-gothic
           texlive-greenpoint
           texlive-grotesq
           texlive-gudea
           texlive-hacm
           texlive-hamnosys
           texlive-hands
           texlive-hep-font
           texlive-hep-math-font
           texlive-heros-otf
           texlive-heuristica
           texlive-hfbright
           texlive-hfoldsty
           texlive-hindmadurai
           texlive-ibarra
           texlive-ifsym
           texlive-imfellenglish
           texlive-inconsolata
           texlive-initials
           texlive-inriafonts
           texlive-inter
           texlive-ipaex-type1
           texlive-iwona
           texlive-jablantile
           texlive-jamtimes
           texlive-josefin
           texlive-junicode
           texlive-kixfont
           texlive-kpfonts
           texlive-kpfonts-otf
           texlive-kurier
           texlive-lato
           texlive-lexend
           texlive-lfb
           texlive-libertine
           texlive-libertinegc
           texlive-libertinus
           texlive-libertinus-fonts
           texlive-libertinus-otf
           texlive-libertinus-type1
           texlive-libertinust1math
           texlive-librebaskerville
           texlive-librebodoni
           texlive-librecaslon
           texlive-librefranklin
           texlive-libris
           texlive-lineara
           texlive-linguisticspro
           texlive-lobster2
           texlive-logix
           texlive-lxfonts
           texlive-ly1
           texlive-magra
           texlive-marcellus
           texlive-mathabx
           texlive-mathabx-type1
           texlive-mathdesign
           texlive-mdputu
           texlive-mdsymbol
           texlive-merriweather
           texlive-miama
           texlive-mintspirit
           texlive-missaali
           texlive-mlmodern
           texlive-mnsymbol
           texlive-montserrat
           texlive-mpfonts
           texlive-mweights
           texlive-newcomputermodern
           texlive-newpx
           texlive-newtx
           texlive-newtxsf
           texlive-newtxtt
           texlive-niceframe-type1
           texlive-nimbus15
           texlive-nkarta
           texlive-noto
           texlive-noto-emoji
           texlive-notomath
           texlive-nunito
           texlive-obnov
           texlive-ocherokee
           texlive-ocr-b
           texlive-ocr-b-outline
           texlive-ogham
           texlive-oinuit
           texlive-old-arrows
           texlive-oldlatin
           texlive-oldstandard
           texlive-opensans
           texlive-orkhun
           texlive-oswald
           texlive-overlock
           texlive-pacioli
           texlive-pagella-otf
           texlive-paratype
           texlive-phaistos
           texlive-phonetic
           texlive-pigpen
           texlive-playfair
           texlive-plex
           texlive-plex-otf
           texlive-plimsoll
           texlive-poiretone
           texlive-poltawski
           texlive-prodint
           texlive-punk
           texlive-punk-latex
           texlive-punknova
           texlive-pxtxalfa
           texlive-qualitype
           texlive-quattrocento
           texlive-raleway
           texlive-recycle
           texlive-roboto
           texlive-romande
           texlive-rosario
           texlive-rsfso
           texlive-sansmathaccent
           texlive-sansmathfonts
           texlive-sauter
           texlive-sauterfonts
           texlive-schola-otf
           texlive-scholax
           texlive-schulschriften
           texlive-semaphor
           texlive-shobhika
           texlive-simpleicons
           texlive-skull
           texlive-sourcecodepro
           texlive-sourcesanspro
           texlive-sourceserifpro
           texlive-spectral
           texlive-srbtiks
           texlive-starfont
           texlive-staves
           texlive-step
           texlive-stepgreek
           texlive-stickstoo
           texlive-stix
           texlive-stix2-otf
           texlive-stix2-type1
           texlive-superiors
           texlive-svrsymbols
           texlive-symbats3
           texlive-tapir
           texlive-tempora
           texlive-tengwarscript
           texlive-termes-otf
           texlive-tfrupee
           texlive-theanodidot
           texlive-theanomodern
           texlive-theanooldstyle
           texlive-tinos
           texlive-tpslifonts
           texlive-trajan
           texlive-twemoji-colr
           texlive-txfontsb
           texlive-txuprcal
           texlive-typicons
           texlive-umtypewriter
           texlive-universa
           texlive-universalis
           texlive-uppunctlm
           texlive-urwchancal
           texlive-venturisadf
           texlive-wsuipa
           texlive-xcharter
           texlive-xcharter-math
           texlive-xits
           texlive-yfonts
           texlive-yfonts-otf
           texlive-yfonts-t1
           texlive-yinit-otf
           texlive-zlmtt))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Additional fonts")
    (description "This collection provides additional fonts.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-fontsrecommended
  (package
    (name "texlive-collection-fontsrecommended")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-avantgar
           texlive-bookman
           texlive-charter
           texlive-cm-super
           texlive-cmextra
           texlive-collection-basic
           texlive-courier
           texlive-euro
           texlive-euro-ce
           texlive-eurosym
           texlive-fpl
           texlive-helvetic
           texlive-lm
           texlive-lm-math
           texlive-manfnt-font
           texlive-marvosym
           texlive-mathpazo
           texlive-mflogo-font
           texlive-ncntrsbk
           texlive-palatino
           texlive-pxfonts
           texlive-rsfs
           texlive-symbol
           texlive-tex-gyre
           texlive-tex-gyre-math
           texlive-times
           texlive-tipa
           texlive-txfonts
           texlive-utopia
           texlive-wasy
           texlive-wasy-type1
           texlive-wasysym
           texlive-zapfchan
           texlive-zapfding))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Recommended fonts")
    (description
     "This collection provides recommended fonts, including the base 35
PostScript fonts, Latin Modern, TeX Gyre, and T1 and other encoding support
for Computer Modern, in outline form.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-fontutils
  (package
    (name "texlive-collection-fontutils")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-accfonts
           texlive-afm2pl
           texlive-albatross
           texlive-collection-basic
           texlive-dosepsbin
           texlive-dvipsconfig
           texlive-epstopdf
           texlive-fontinst
           texlive-fontools
           texlive-fontware
           texlive-lcdftypetools
           texlive-luafindfont
           texlive-metatype1
           texlive-mf2pt1
           texlive-ps2eps
           texlive-ps2pk
           texlive-psutils
           texlive-t1utils
           texlive-ttfutils))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Graphics and font utilities")
    (description
     "This collection of packages provides programs for conversion between
font formats, testing fonts, virtual fonts, @file{.gf} and @file{.pk}
manipulation, mft, fontinst, etc.  Manipulating OpenType, TrueType, Type 1,and
for manipulation of PostScript and other image formats.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-formatsextra
  (package
    (name "texlive-collection-formatsextra")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-aleph
           texlive-antomega
           texlive-collection-basic
           texlive-collection-latex
           texlive-edmac
           texlive-eplain
           texlive-hitex
           texlive-jadetex
           texlive-lambda
           texlive-lollipop
           texlive-mltex
           texlive-mxedruli
           texlive-omega
           texlive-omegaware
           texlive-otibet
           texlive-passivetex
           texlive-psizzl
           texlive-startex
           texlive-texsis
           texlive-xmltex
           texlive-xmltexconfig))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Additional TeX formats")
    (description
     "This is a collection of TeX formats, i.e., large-scale macro packages
designed to be dumped into @file{.fmt} files --- excluding the most common
ones, such as LaTeX and ConTeXt, which have their own package(s).  It also
includes the Aleph engine and related Omega formats and packages, and the
HiTeX engine and related.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-games
  (package
    (name "texlive-collection-games")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-bartel-chess-fonts
           texlive-chess
           texlive-chess-problem-diagrams
           texlive-chessboard
           texlive-chessfss
           texlive-chinesechess
           texlive-collection-latex
           texlive-crossword
           texlive-crosswrd
           texlive-customdice
           texlive-egameps
           texlive-gamebook
           texlive-gamebooklib
           texlive-go
           texlive-hanoi
           texlive-havannah
           texlive-hexboard
           texlive-hexgame
           texlive-hmtrump
           texlive-horoscop
           texlive-jeuxcartes
           texlive-jigsaw
           texlive-labyrinth
           texlive-logicpuzzle
           texlive-mahjong
           texlive-maze
           texlive-musikui
           texlive-nimsticks
           texlive-onedown
           texlive-othello
           texlive-othelloboard
           texlive-pas-crosswords
           texlive-psgo
           texlive-realtranspose
           texlive-reverxii
           texlive-rubik
           texlive-schwalbe-chess
           texlive-scrabble
           texlive-sgame
           texlive-skak
           texlive-skaknew
           texlive-soup
           texlive-sudoku
           texlive-sudokubundle
           texlive-tangramtikz
           texlive-wargame
           texlive-xq
           texlive-xskak))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Games typesetting")
    (description
     "This collection includes setups for typesetting various games,
including chess.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-humanities
  (package
    (name "texlive-collection-humanities")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-adtrees
           texlive-bibleref
           texlive-bibleref-lds
           texlive-bibleref-mouth
           texlive-bibleref-parse
           texlive-collection-latex
           texlive-covington
           texlive-diadia
           texlive-dramatist
           texlive-dvgloss
           texlive-ecltree
           texlive-edfnotes
           texlive-eledform
           texlive-eledmac
           texlive-expex
           texlive-gb4e
           texlive-gmverse
           texlive-jura
           texlive-juraabbrev
           texlive-juramisc
           texlive-jurarsp
           texlive-langnames
           texlive-ledmac
           texlive-lexikon
           texlive-lexref
           texlive-ling-macros
           texlive-linguex
           texlive-liturg
           texlive-metrix
           texlive-nnext
           texlive-parallel
           texlive-parrun
           texlive-phonrule
           texlive-plari
           texlive-play
           texlive-poemscol
           texlive-poetry
           texlive-poetrytex
           texlive-qobitree
           texlive-qtree
           texlive-reledmac
           texlive-rrgtrees
           texlive-rtklage
           texlive-screenplay
           texlive-screenplay-pkg
           texlive-sides
           texlive-stage
           texlive-textglos
           texlive-thalie
           texlive-theatre
           texlive-tree-dvips
           texlive-verse
           texlive-xyling))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Humanities packages")
    (description
     "This collection contains packages for law, linguistics, social sciences,
humanities, etc.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-langarabic
  (package
    (name "texlive-collection-langarabic")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-alkalami
           texlive-alpha-persian
           texlive-amiri
           texlive-arabi
           texlive-arabi-add
           texlive-arabic-book
           texlive-arabluatex
           texlive-arabtex
           texlive-bidi
           texlive-bidihl
           texlive-collection-basic
           texlive-dad
           texlive-ghab
           texlive-hvarabic
           texlive-hyphen-complete
           texlive-imsproc
           texlive-kurdishlipsum
           texlive-lshort-persian
           texlive-luabidi
           texlive-na-box
           texlive-persian-bib
           texlive-quran
           texlive-sexam
           texlive-simurgh
           texlive-texnegar
           texlive-tram
           texlive-xepersian
           texlive-xepersian-hm
           texlive-xindy-persian))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Support for Arabic and Persian")
    (description "This collection provides support for Arabic and Persian.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-langchinese
  (package
    (name "texlive-collection-langchinese")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-arphic
           texlive-arphic-ttf
           texlive-asymptote-by-example-zh-cn
           texlive-asymptote-faq-zh-cn
           texlive-asymptote-manual-zh-cn
           texlive-cns
           texlive-collection-langcjk
           texlive-ctex
           texlive-ctex-faq
           texlive-exam-zh
           texlive-fandol
           texlive-fduthesis
           texlive-hanzibox
           texlive-hyphen-complete
           texlive-impatient-cn
           texlive-install-latex-guide-zh-cn
           texlive-latex-notes-zh-cn
           texlive-lshort-chinese
           texlive-nanicolle
           texlive-njurepo
           texlive-pgfornament-han
           texlive-qyxf-book
           texlive-texproposal
           texlive-tlmgr-intro-zh-cn
           texlive-upzhkinsoku
           texlive-xpinyin
           texlive-xtuthesis
           texlive-zhlineskip
           texlive-zhlipsum
           texlive-zhmetrics
           texlive-zhmetrics-uptex
           texlive-zhnumber
           texlive-zhspacing))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Support for Chinese")
    (description
     "This collection provides support for Chinese, with additional packages
from @code{collection-langcjk}.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-langcjk
  (package
    (name "texlive-collection-langcjk")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-adobemapping
           texlive-c90
           texlive-cjk
           texlive-cjk-gs-integrate
           texlive-cjkpunct
           texlive-cjkutils
           texlive-collection-basic
           texlive-dnp
           texlive-evangelion-jfm
           texlive-fixjfm
           texlive-garuda-c90
           texlive-jfmutil
           texlive-norasi-c90
           texlive-pxtatescale
           texlive-xcjk2uni
           texlive-xecjk
           texlive-zitie
           texlive-zxjafont))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Chinese/Japanese/Korean support (base)")
    (description
     "This is a collection of packages supporting a combination of Chinese,
Japanese, Korean, including macros, fonts, documentation.  Also Thai in the
c90 encoding, since there is some overlap in those fonts; standard Thai
support is in @code{collection-langother}.  Additional packages for CJK are in
their individual language collections.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-langcyrillic
  (package
    (name "texlive-collection-langcyrillic")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-babel-belarusian
           texlive-babel-bulgarian
           texlive-babel-russian
           texlive-babel-serbian
           texlive-babel-serbianc
           texlive-babel-ukrainian
           texlive-churchslavonic
           texlive-cmcyr
           texlive-collection-basic
           texlive-collection-latex
           texlive-cyrillic
           texlive-cyrillic-bin
           texlive-cyrplain
           texlive-disser
           texlive-eskd
           texlive-eskdx
           texlive-gost
           texlive-hyphen-complete
           texlive-lcyw
           texlive-lh
           texlive-lhcyr
           texlive-lshort-bulgarian
           texlive-lshort-mongol
           texlive-lshort-russian
           texlive-lshort-ukr
           texlive-mongolian-babel
           texlive-montex
           texlive-mpman-ru
           texlive-numnameru
           texlive-pst-eucl-translation-bg
           texlive-russ
           texlive-serbian-apostrophe
           texlive-serbian-date-lat
           texlive-serbian-def-cyr
           texlive-serbian-lig
           texlive-t2
           texlive-xecyrmongolian))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Support for Cyrillic scripts")
    (description
     "This collection provides packages supporting Cyrillic scripts (Bulgarian,
Russian, Serbian, Ukrainian), even if Latin alphabets may also be used.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-langczechslovak
  (package
    (name "texlive-collection-langczechslovak")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-babel-czech
           texlive-babel-slovak
           texlive-cnbwp
           texlive-collection-basic
           texlive-collection-latex
           texlive-cs
           texlive-csbulletin
           texlive-cslatex
           texlive-csplain
           texlive-cstex
           texlive-hyphen-complete
           texlive-lshort-czech
           texlive-lshort-slovak
           texlive-vlna))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Support for Czech and Slovak")
    (description
     "This collection of packages provides support for Czech and Slovak.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-langenglish
  (package
    (name "texlive-collection-langenglish")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-amiweb2c-guide
           texlive-amscls-doc
           texlive-amslatex-primer
           texlive-around-the-bend
           texlive-ascii-chart
           texlive-biblatex-cheatsheet
           texlive-collection-basic
           texlive-components
           texlive-comprehensive
           texlive-dickimaw
           texlive-docsurvey
           texlive-dtxtut
           texlive-first-latex-doc
           texlive-fontinstallationguide
           texlive-forest-quickstart
           texlive-gentle
           texlive-guide-to-latex
           texlive-happy4th
           texlive-hyphen-complete
           texlive-impatient
           texlive-intro-scientific
           texlive-knuth-errata
           texlive-knuth-hint
           texlive-knuth-pdf
           texlive-l2tabu-english
           texlive-latex-brochure
           texlive-latex-course
           texlive-latex-doc-ptr
           texlive-latex-for-undergraduates
           texlive-latex-graphics-companion
           texlive-latex-refsheet
           texlive-latex-veryshortguide
           texlive-latex-web-companion
           texlive-latex2e-help-texinfo
           texlive-latex4wp
           texlive-latexcheat
           texlive-latexcourse-rug
           texlive-latexfileinfo-pkgs
           texlive-lshort-english
           texlive-macros2e
           texlive-math-into-latex-4
           texlive-maths-symbols
           texlive-memdesign
           texlive-memoirchapterstyles
           texlive-metafont-beginners
           texlive-metapost-examples
           texlive-patgen2-tutorial
           texlive-pictexsum
           texlive-plain-doc
           texlive-short-math-guide
           texlive-simplified-latex
           texlive-svg-inkscape
           texlive-tamethebeast
           texlive-tds
           texlive-tex-font-errors-cheatsheet
           texlive-tex-nutshell
           texlive-tex-overview
           texlive-tex-refs
           texlive-tex-vpat
           texlive-texbytopic
           texlive-texonly
           texlive-titlepages
           texlive-tlc2
           texlive-tlc3-examples
           texlive-tlmgrbasics
           texlive-undergradmath
           texlive-visualfaq
           ;; texlive-webguide XXX: No license?
           texlive-xetexref
           texlive-yet-another-guide-latex2e))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Support for, and documentation in, English")
    (description
     "These packages provide support for, and documentation in, English.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-langeuropean
  (package
    (name "texlive-collection-langeuropean")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-armtex
           texlive-babel-albanian
           texlive-babel-bosnian
           texlive-babel-breton
           texlive-babel-croatian
           texlive-babel-danish
           texlive-babel-dutch
           texlive-babel-estonian
           texlive-babel-finnish
           texlive-babel-friulan
           texlive-babel-hungarian
           texlive-babel-icelandic
           texlive-babel-irish
           texlive-babel-kurmanji
           texlive-babel-latin
           texlive-babel-latvian
           texlive-babel-lithuanian
           texlive-babel-macedonian
           texlive-babel-norsk
           texlive-babel-occitan
           texlive-babel-piedmontese
           texlive-babel-romanian
           texlive-babel-romansh
           texlive-babel-samin
           texlive-babel-scottish
           texlive-babel-slovenian
           texlive-babel-swedish
           texlive-babel-turkish
           texlive-babel-welsh
           texlive-collection-basic
           texlive-finbib
           texlive-gloss-occitan
           texlive-hrlatex
           texlive-huaz
           texlive-hulipsum
           texlive-hyphen-complete
           texlive-kaytannollista-latexia
           texlive-lithuanian
           texlive-lshort-dutch
           texlive-lshort-estonian
           texlive-lshort-finnish
           texlive-lshort-slovenian
           texlive-lshort-turkish
           texlive-nevelok
           texlive-rojud
           texlive-swebib
           texlive-turkmen))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Support for a some European languages")
    (description
     "This collection provides support for a number of European languages;
others (Greek, German, French, ...)  have their own collections, depending
simply on the size of the support.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-langfrench
  (package
    (name "texlive-collection-langfrench")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-aeguill
           texlive-annee-scolaire
           texlive-apprendre-a-programmer-en-tex
           texlive-apprends-latex
           texlive-babel-basque
           texlive-babel-french
           texlive-basque-book
           texlive-basque-date
           texlive-bib-fr
           texlive-bibleref-french
           texlive-booktabs-fr
           texlive-collection-basic
           texlive-droit-fr
           texlive-e-french
           texlive-epslatex-fr
           texlive-expose-expl3-dunkerque-2019
           texlive-facture
           texlive-formation-latex-ul
           texlive-frenchmath
           texlive-frletter
           texlive-frpseudocode
           texlive-hyphen-complete
           texlive-impatient-fr
           texlive-impnattypo
           texlive-l2tabu-french
           texlive-latex2e-help-texinfo-fr
           texlive-letgut
           texlive-lshort-french
           texlive-mafr
           texlive-matapli
           texlive-profcollege
           texlive-proflabo
           texlive-proflycee
           texlive-tabvar
           texlive-tdsfrmath
           texlive-translation-array-fr
           texlive-translation-dcolumn-fr
           texlive-translation-natbib-fr
           texlive-translation-tabbing-fr
           texlive-variations
           texlive-visualfaq-fr
           texlive-visualtikz))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Support for French and Basque")
    (description
     "This collection provides support packages for French and Basque.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-langgerman
  (package
    (name "texlive-collection-langgerman")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-apalike-german
           texlive-babel-german
           texlive-bibleref-german
           texlive-booktabs-de
           texlive-collection-basic
           texlive-csquotes-de
           texlive-dhua
           texlive-dtk-bibliography
           texlive-etdipa
           texlive-etoolbox-de
           texlive-fifinddo-info
           texlive-german
           texlive-germbib
           texlive-germkorr
           texlive-hausarbeit-jura
           texlive-hyphen-complete
           texlive-koma-script-examples
           texlive-l2picfaq
           texlive-l2tabu
           texlive-latexcheat-de
           texlive-lshort-german
           texlive-lualatex-doc-de
           texlive-microtype-de
           texlive-milog
           texlive-quran-de
           texlive-r-und-s
           texlive-schulmathematik
           texlive-templates-fenn
           texlive-templates-sommer
           texlive-termcal-de
           texlive-tipa-de
           texlive-translation-arsclassica-de
           texlive-translation-biblatex-de
           texlive-translation-chemsym-de
           texlive-translation-ecv-de
           texlive-translation-enumitem-de
           texlive-translation-europecv-de
           texlive-translation-filecontents-de
           texlive-translation-moreverb-de
           texlive-udesoftec
           texlive-uhrzeit
           texlive-umlaute
           texlive-voss-mathcol))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Support for German")
    (description "This collection provides support packages for German.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-langgreek
  (package
    (name "texlive-collection-langgreek")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-babel-greek
           texlive-begingreek
           texlive-betababel
           texlive-cbfonts
           texlive-cbfonts-fd
           texlive-collection-basic
           texlive-gfsbaskerville
           texlive-gfsporson
           texlive-greek-fontenc
           texlive-greek-inputenc
           texlive-greekdates
           texlive-greektex
           texlive-greektonoi
           texlive-hyphen-complete
           texlive-ibycus-babel
           texlive-ibygrk
           texlive-kerkis
           texlive-levy
           texlive-lgreek
           texlive-lgrmath
           texlive-mkgrkindex
           texlive-talos
           texlive-teubner
           texlive-xgreek
           texlive-yannisgr))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Support for Greek")
    (description "This collection provides support for Greek.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-langitalian
  (package
    (name "texlive-collection-langitalian")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-amsldoc-it
           texlive-amsmath-it
           texlive-amsthdoc-it
           texlive-antanilipsum
           texlive-babel-italian
           texlive-codicefiscaleitaliano
           texlive-collection-basic
           texlive-fancyhdr-it
           texlive-fixltxhyph
           texlive-frontespizio
           texlive-hyphen-complete
           texlive-itnumpar
           texlive-l2tabu-italian
           texlive-latex4wp-it
           texlive-layaureo
           texlive-lshort-italian
           texlive-psfrag-italian
           texlive-verifica))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Support for Italian")
    (description "This collection provides support packages for Italian.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-langjapanese
  (package
    (name "texlive-collection-langjapanese")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-ascmac
           texlive-asternote
           texlive-babel-japanese
           texlive-bxbase
           texlive-bxcjkjatype
           texlive-bxghost
           texlive-bxjaholiday
           texlive-bxjalipsum
           texlive-bxjaprnind
           texlive-bxjatoucs
           texlive-bxjscls
           texlive-bxorigcapt
           texlive-bxwareki
           texlive-collection-langcjk
           texlive-convbkmk
           texlive-endnotesj
           texlive-gckanbun
           texlive-gentombow
           texlive-haranoaji
           texlive-haranoaji-extra
           texlive-ieejtran
           texlive-ifptex
           texlive-ifxptex
           texlive-ipaex
           texlive-japanese-mathformulas
           texlive-japanese-otf
           texlive-jieeetran
           texlive-jlreq
           texlive-jlreq-deluxe
           texlive-jpneduenumerate
           texlive-jpnedumathsymbols
           texlive-jsclasses
           texlive-kanbun
           texlive-lshort-japanese
           texlive-luatexja
           texlive-mendex-doc
           texlive-morisawa
           texlive-pbibtex-base
           texlive-pbibtex-manual
           texlive-platex
           texlive-platex-tools
           texlive-platexcheat
           texlive-plautopatch
           texlive-ptex
           texlive-ptex-base
           texlive-ptex-fontmaps
           texlive-ptex-fonts
           texlive-ptex-manual
           texlive-ptex2pdf
           texlive-pxbase
           texlive-pxchfon
           texlive-pxcjkcat
           texlive-pxjahyper
           texlive-pxjodel
           texlive-pxrubrica
           texlive-pxufont
           texlive-uplatex
           texlive-uptex
           texlive-uptex-base
           texlive-uptex-fonts
           texlive-wadalab
           texlive-zxjafbfont
           texlive-zxjatype))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Support for Japanese")
    (description
     "This collection provides support for Japanese, with additional packages
from @code{collection-langcjk}.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-langkorean
  (package
    (name "texlive-collection-langkorean")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-baekmuk
           texlive-cjk-ko
           texlive-collection-langcjk
           texlive-kotex-oblivoir
           texlive-kotex-plain
           texlive-kotex-utf
           texlive-kotex-utils
           texlive-lshort-korean
           texlive-nanumtype1
           texlive-pmhanguljamo
           texlive-uhc
           texlive-unfonts-core
           texlive-unfonts-extra))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Support for Korean")
    (description
     "This collection provides support for Korean, with additional packages
from @code{collection-langcjk}.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-langother
  (package
    (name "texlive-collection-langother")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-aalok
           texlive-akshar
           texlive-amsldoc-vn
           texlive-aramaic-serto
           texlive-babel-azerbaijani
           texlive-babel-esperanto
           texlive-babel-georgian
           texlive-babel-hebrew
           texlive-babel-indonesian
           texlive-babel-interlingua
           texlive-babel-malay
           texlive-babel-sorbian
           texlive-babel-thai
           texlive-babel-vietnamese
           texlive-bangla
           texlive-bangtex
           texlive-bengali
           texlive-burmese
           texlive-chhaya
           texlive-cjhebrew
           texlive-collection-basic
           texlive-ctib
           texlive-ebong
           texlive-ethiop
           texlive-ethiop-t1
           texlive-fc
           texlive-fonts-tlwg
           texlive-hindawi-latex-template
           texlive-hyphen-complete
           texlive-latex-mr
           texlive-latexbangla
           texlive-latino-sine-flexione
           texlive-lshort-thai
           texlive-lshort-vietnamese
           texlive-marathi
           texlive-ntheorem-vn
           texlive-padauk
           texlive-quran-bn
           texlive-quran-ur
           texlive-sanskrit
           texlive-sanskrit-t1
           texlive-thaienum
           texlive-thaispec
           texlive-unicode-alphabets
           texlive-velthuis
           texlive-vntex
           texlive-wnri
           texlive-wnri-latex
           texlive-xetex-devanagari))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Support other languages")
    (description
     "This collection provides support for languages not otherwise listed,
including Indic, Thai, Vietnamese, Hebrew, Indonesian, African languages, and
plenty more.  The split is made simply on the basis of the size of the
support, to keep both collection sizes and the number of collections
reasonable.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-langpolish
  (package
    (name "texlive-collection-langpolish")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-babel-polish
           texlive-bredzenie
           texlive-cc-pl
           texlive-collection-basic
           texlive-collection-latex
           texlive-gustlib
           texlive-gustprog
           texlive-hyphen-complete
           texlive-lshort-polish
           texlive-mex
           texlive-mwcls
           texlive-pl
           texlive-polski
           texlive-przechlewski-book
           texlive-qpxqtx
           texlive-tap
           texlive-tex-virtual-academy-pl
           texlive-utf8mex))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Support for Polish")
    (description "This collection provides support packages for Polish.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-langportuguese
  (package
    (name "texlive-collection-langportuguese")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-babel-portuges
           texlive-beamer-tut-pt
           texlive-collection-basic
           texlive-cursolatex
           texlive-feupphdteses
           texlive-hyphen-complete
           texlive-latex-via-exemplos
           texlive-latexcheat-ptbr
           texlive-lshort-portuguese
           texlive-numberpt
           texlive-ordinalpt
           texlive-xypic-tut-pt))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Support for Portuguese")
    (description "This collection provides support packages for Portuguese.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-langspanish
  (package
    (name "texlive-collection-langspanish")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-babel-catalan
           texlive-babel-galician
           texlive-babel-spanish
           texlive-collection-basic
           texlive-es-tex-faq
           texlive-hyphen-complete
           texlive-l2tabu-spanish
           texlive-latex2e-help-texinfo-spanish
           texlive-latexcheat-esmx
           texlive-lshort-spanish))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Support for Spanish")
    (description "This collection provides support packages for Spanish.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-latex
  (package
    (name "texlive-collection-latex")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-ae
           texlive-amscls
           texlive-amsmath
           texlive-atbegshi
           texlive-atveryend
           texlive-auxhook
           texlive-babel
           texlive-babel-english
           texlive-babelbib
           texlive-bigintcalc
           texlive-bitset
           texlive-bookmark
           texlive-carlisle
           texlive-collection-basic
           texlive-colortbl
           texlive-epstopdf-pkg
           texlive-etexcmds
           texlive-fancyhdr
           texlive-firstaid
           texlive-fix2col
           texlive-geometry
           texlive-gettitlestring
           texlive-graphics
           texlive-graphics-cfg
           texlive-grfext
           texlive-hopatch
           texlive-hycolor
           texlive-hyperref
           texlive-intcalc
           texlive-kvdefinekeys
           texlive-kvoptions
           texlive-kvsetkeys
           texlive-l3backend
           texlive-l3kernel
           texlive-l3packages
           texlive-latex
           texlive-latex-bin
           texlive-latex-fonts
           texlive-latexconfig
           texlive-letltxmacro
           texlive-ltxcmds
           texlive-ltxmisc
           texlive-mfnfss
           texlive-mptopdf
           texlive-natbib
           texlive-oberdiek
           texlive-pagesel
           texlive-pdfescape
           texlive-pslatex
           texlive-psnfss
           texlive-pspicture
           texlive-refcount
           texlive-rerunfilecheck
           texlive-stringenc
           texlive-tools
           texlive-uniquecounter
           texlive-url))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "LaTeX fundamental packages")
    (description
     "These packages are either mandated by the core LaTeX team, or very widely
used and strongly recommended in practice.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-latexextra
  (package
    (name "texlive-collection-latexextra")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-2up
           texlive-a0poster
           texlive-a4wide
           texlive-a5comb
           texlive-abraces
           texlive-abspos
           texlive-abstract
           texlive-accessibility
           texlive-accsupp
           texlive-achemso
           texlive-acro
           texlive-acronym
           texlive-acroterm
           texlive-actuarialangle
           texlive-actuarialsymbol
           texlive-addfont
           texlive-addlines
           texlive-adjmulticol
           texlive-adjustbox
           texlive-adrconv
           texlive-advdate
           texlive-akktex
           texlive-akletter
           texlive-alchemist
           texlive-alertmessage
           texlive-alnumsec
           texlive-alphalph
           texlive-alterqcm
           texlive-altfont
           texlive-altsubsup
           texlive-amsaddr
           texlive-animate
           texlive-anonchap
           texlive-answers
           texlive-anyfontsize
           texlive-appendix
           texlive-appendixnumberbeamer
           texlive-apptools
           texlive-arabicfront
           texlive-arcs
           texlive-arraycols
           texlive-arrayjobx
           texlive-arraysort
           texlive-arydshln
           texlive-asciilist
           texlive-askinclude
           texlive-assignment
           texlive-assoccnt
           texlive-association-matrix
           texlive-atenddvi
           texlive-atendofenv
           texlive-attachfile
           texlive-aurl
           texlive-authoraftertitle
           texlive-authorarchive
           texlive-authorindex
           texlive-autofancyhdr
           texlive-autonum
           texlive-autopdf
           texlive-autopuncitems
           texlive-avremu
           texlive-axessibility
           texlive-background
           texlive-bankstatement
           texlive-bashful
           texlive-basicarith
           texlive-bchart
           texlive-beamer-rl
           texlive-beamer2thesis
           texlive-beamerappendixnote
           texlive-beameraudience
           texlive-beamerauxtheme
           texlive-beamercolorthemeowl
           texlive-beamerdarkthemes
           texlive-beamerposter
           texlive-beamersubframe
           texlive-beamertheme-arguelles
           texlive-beamertheme-cuerna
           texlive-beamertheme-detlevcm
           texlive-beamertheme-epyt
           texlive-beamertheme-focus
           texlive-beamertheme-light
           texlive-beamertheme-metropolis
           texlive-beamertheme-npbt
           texlive-beamertheme-phnompenh
           texlive-beamertheme-pure-minimalistic
           texlive-beamertheme-saintpetersburg
           texlive-beamertheme-simpledarkblue
           texlive-beamertheme-simpleplus
           texlive-beamertheme-tcolorbox
           texlive-beamertheme-trigon
           texlive-beamertheme-upenn-bc
           texlive-beamerthemeamurmaple
           texlive-beamerthemejltree
           texlive-beamerthemelalic
           texlive-beamerthemenirma
           texlive-beamerthemenord
           texlive-bearwear
           texlive-beaulivre
           texlive-beton
           texlive-bewerbung
           texlive-bez123
           texlive-bhcexam
           texlive-bibletext
           texlive-bigfoot
           texlive-bigints
           texlive-bilingualpages
           texlive-biochemistry-colors
           texlive-bithesis
           texlive-bizcard
           texlive-blindtext
           texlive-blkarray
           texlive-block
           texlive-blowup
           texlive-bnumexpr
           texlive-boites
           texlive-bold-extra
           texlive-book-of-common-prayer
           texlive-bookcover
           texlive-bookest
           texlive-booklet
           texlive-bookshelf
           texlive-boolexpr
           texlive-bophook
           texlive-boxedminipage
           texlive-boxhandler
           texlive-bracketkey
           texlive-braket
           texlive-breakurl
           texlive-bubblesort
           texlive-bullcntr
           texlive-bxcalc
           texlive-bxdpx-beamer
           texlive-bxdvidriver
           texlive-bxenclose
           texlive-bxnewfont
           texlive-bxpapersize
           texlive-bxpdfver
           texlive-bxtexlogo
           texlive-calcage
           texlive-calctab
           texlive-calculator
           texlive-calrsfs
           texlive-cals
           texlive-calxxxx-yyyy
           texlive-cancel
           texlive-canoniclayout
           texlive-capt-of
           texlive-captcont
           texlive-captdef
           texlive-carbohydrates
           texlive-cases
           texlive-casyl
           texlive-catchfile
           texlive-catchfilebetweentags
           texlive-catechis
           texlive-catoptions
           texlive-cbcoptic
           texlive-ccaption
           texlive-cclicenses
           texlive-cd
           texlive-cd-cover
           texlive-cdcmd
           texlive-cdpbundl
           texlive-cellprops
           texlive-cellspace
           texlive-censor
           texlive-centeredline
           texlive-centerlastline
           texlive-changebar
           texlive-changelayout
           texlive-changelog
           texlive-changepage
           texlive-changes
           texlive-chappg
           texlive-chapterfolder
           texlive-cheatsheet
           texlive-checkend
           texlive-chet
           texlive-chextras
           texlive-childdoc
           texlive-chkfloat
           texlive-chletter
           texlive-chngcntr
           texlive-chronology
           texlive-circ
           texlive-circledsteps
           texlive-circledtext
           texlive-classics
           texlive-classpack
           texlive-clefval
           texlive-cleveref
           texlive-clicks
           texlive-clipboard
           texlive-clistmap
           texlive-clock
           texlive-clrdblpg
           texlive-clrstrip
           texlive-cmdstring
           texlive-cmdtrack
           texlive-cmsd
           texlive-cnltx
           texlive-cntformats
           texlive-cntperchap
           texlive-codebox
           texlive-codedoc
           texlive-codehigh
           texlive-codepage
           texlive-codesection
           texlive-collcell
           texlive-collectbox
           texlive-collection-latexrecommended
           texlive-collection-pictures
           texlive-colophon
           texlive-color-edits
           texlive-colordoc
           texlive-colorframed
           texlive-colorinfo
           texlive-coloring
           texlive-colorist
           texlive-colorspace
           texlive-colortab
           texlive-colorwav
           texlive-colorweb
           texlive-colourchange
           texlive-combelow
           texlive-combine
           texlive-comma
           texlive-commado
           texlive-commedit
           texlive-comment
           texlive-commonunicode
           texlive-competences
           texlive-concepts
           texlive-concprog
           texlive-conditext
           texlive-constants
           texlive-continue
           texlive-contour
           texlive-contracard
           texlive-conv-xkv
           texlive-cooking
           texlive-cooking-units
           texlive-cool
           texlive-coolfn
           texlive-coollist
           texlive-coolstr
           texlive-coolthms
           texlive-cooltooltips
           texlive-coop-writing
           texlive-coordsys
           texlive-copyedit
           texlive-copyrightbox
           texlive-coseoul
           texlive-counttexruns
           texlive-courseoutline
           texlive-coursepaper
           texlive-coverpage
           texlive-cprotect
           texlive-cprotectinside
           texlive-crbox
           texlive-create-theorem
           texlive-crefthe
           texlive-crossreference
           texlive-crossreftools
           texlive-crumbs
           texlive-csquotes
           texlive-css-colors
           texlive-csvmerge
           texlive-csvsimple
           texlive-cuisine
           texlive-currency
           texlive-currfile
           texlive-currvita
           texlive-cutwin
           texlive-cv
           texlive-cv4tw
           texlive-cweb-latex
           texlive-cyber
           texlive-cybercic
           texlive-darkmode
           texlive-dashbox
           texlive-dashrule
           texlive-dashundergaps
           texlive-dataref
           texlive-datatool
           texlive-datax
           texlive-dateiliste
           texlive-datenumber
           texlive-datestamp
           texlive-datetime
           texlive-datetime2
           texlive-datetime2-bahasai
           texlive-datetime2-basque
           texlive-datetime2-breton
           texlive-datetime2-bulgarian
           texlive-datetime2-catalan
           texlive-datetime2-croatian
           texlive-datetime2-czech
           texlive-datetime2-danish
           texlive-datetime2-dutch
           texlive-datetime2-en-fulltext
           texlive-datetime2-english
           texlive-datetime2-esperanto
           texlive-datetime2-estonian
           texlive-datetime2-finnish
           texlive-datetime2-french
           texlive-datetime2-galician
           texlive-datetime2-german
           texlive-datetime2-greek
           texlive-datetime2-hebrew
           texlive-datetime2-icelandic
           texlive-datetime2-irish
           texlive-datetime2-it-fulltext
           texlive-datetime2-italian
           texlive-datetime2-latin
           texlive-datetime2-lsorbian
           texlive-datetime2-magyar
           texlive-datetime2-norsk
           texlive-datetime2-polish
           texlive-datetime2-portuges
           texlive-datetime2-romanian
           texlive-datetime2-russian
           texlive-datetime2-samin
           texlive-datetime2-scottish
           texlive-datetime2-serbian
           texlive-datetime2-slovak
           texlive-datetime2-slovene
           texlive-datetime2-spanish
           texlive-datetime2-swedish
           texlive-datetime2-turkish
           texlive-datetime2-ukrainian
           texlive-datetime2-usorbian
           texlive-datetime2-welsh
           texlive-dblfloatfix
           texlive-dbshow
           texlive-debate
           texlive-decimal
           texlive-decorule
           texlive-delimtxt
           texlive-democodetools
           texlive-denisbdoc
           texlive-diabetes-logbook
           texlive-diagbox
           texlive-diagnose
           texlive-dialogl
           texlive-dichokey
           texlive-dimnum
           texlive-dinbrief
           texlive-directory
           texlive-dirtytalk
           texlive-dlfltxb
           texlive-dnaseq
           texlive-doclicense
           texlive-docmfp
           texlive-docmute
           texlive-docshots
           texlive-doctools
           texlive-documentation
           texlive-docutils
           texlive-doi
           texlive-dotarrow
           texlive-dotlessi
           texlive-dotseqn
           texlive-download
           texlive-dox
           texlive-dpfloat
           texlive-dprogress
           texlive-drac
           texlive-draftcopy
           texlive-draftfigure
           texlive-draftwatermark
           texlive-dtk
           texlive-dtxdescribe
           texlive-dtxgallery
           texlive-ducksay
           texlive-duckuments
           texlive-dvdcoll
           texlive-dynamicnumber
           texlive-dynblocks
           texlive-ean13isbn
           texlive-easy
           texlive-easy-todo
           texlive-easybook
           texlive-easyfig
           texlive-easyfloats
           texlive-easyformat
           texlive-easylist
           texlive-easyreview
           texlive-ebezier
           texlive-ecclesiastic
           texlive-econlipsum
           texlive-ecv
           texlive-ed
           texlive-edichokey
           texlive-edmargin
           texlive-eemeir
           texlive-efbox
           texlive-egplot
           texlive-ehhline
           texlive-einfart
           texlive-elements
           texlive-ellipsis
           texlive-elmath
           texlive-elocalloc
           texlive-elpres
           texlive-elzcards
           texlive-emarks
           texlive-embedall
           texlive-embedfile
           texlive-embrac
           texlive-emptypage
           texlive-emulateapj
           texlive-endfloat
           texlive-endheads
           texlive-endnotes
           texlive-endnotes-hy
           texlive-engpron
           texlive-engrec
           texlive-enotez
           texlive-enumitem
           texlive-enumitem-zref
           texlive-envbig
           texlive-environ
           texlive-envlab
           texlive-epigraph
           texlive-epigraph-keys
           texlive-epiolmec
           texlive-eq-pin2corr
           texlive-eqell
           texlive-eqlist
           texlive-eqnalign
           texlive-eqname
           texlive-eqparbox
           texlive-errata
           texlive-erw-l3
           texlive-esami
           texlive-esdiff
           texlive-esieecv
           texlive-esindex
           texlive-esint
           texlive-esint-type1
           texlive-etaremune
           texlive-etextools
           texlive-etl
           texlive-etoc
           texlive-eukdate
           texlive-eulerpx
           texlive-europasscv
           texlive-europecv
           texlive-everyhook
           texlive-everypage
           texlive-exam
           texlive-exam-lite
           texlive-exam-n
           texlive-exam-randomizechoices
           texlive-examdesign
           texlive-example
           texlive-examplep
           texlive-exceltex
           texlive-excludeonly
           texlive-exercise
           texlive-exercisebank
           texlive-exercisepoints
           texlive-exercises
           texlive-exesheet
           texlive-exframe
           texlive-exp-testopt
           texlive-expdlist
           texlive-export
           texlive-exsheets
           texlive-exsol
           texlive-extract
           texlive-facsimile
           texlive-factura
           texlive-familytree
           texlive-fancyhandout
           texlive-fancylabel
           texlive-fancynum
           texlive-fancypar
           texlive-fancyqr
           texlive-fancyslides
           texlive-fancytabs
           texlive-fancytooltips
           texlive-fbox
           texlive-fcolumn
           texlive-fetchcls
           texlive-fewerfloatpages
           texlive-ffcode
           texlive-ffslides
           texlive-fgruler
           texlive-fifo-stack
           texlive-figsize
           texlive-filecontents
           texlive-filecontentsdef
           texlive-filedate
           texlive-fileinfo
           texlive-filemod
           texlive-fink
           texlive-finstrut
           texlive-fistrum
           texlive-fithesis
           texlive-fixcmex
           texlive-fixfoot
           texlive-fixme
           texlive-fixmetodonotes
           texlive-fjodor
           texlive-flabels
           texlive-flacards
           texlive-flagderiv
           texlive-flashcards
           texlive-flashmovie
           texlive-flexipage
           texlive-flipbook
           texlive-flippdf
           texlive-floatflt
           texlive-floatrow
           texlive-flowfram
           texlive-fmp
           texlive-fmtcount
           texlive-fn2end
           texlive-fnbreak
           texlive-fncychap
           texlive-fncylab
           texlive-fnpara
           texlive-fnpct
           texlive-fnumprint
           texlive-foilhtml
           texlive-foliono
           texlive-fontaxes
           texlive-fontsetup
           texlive-fontsize
           texlive-fonttable
           texlive-footmisc
           texlive-footmisx
           texlive-footnotebackref
           texlive-footnoterange
           texlive-footnpag
           texlive-forarray
           texlive-foreign
           texlive-forloop
           texlive-formlett
           texlive-forms16be
           texlive-formular
           texlive-fragments
           texlive-frame
           texlive-framed
           texlive-frankenstein
           texlive-frege
           texlive-froufrou
           texlive-ftcap
           texlive-ftnxtra
           texlive-fullblck
           texlive-fullminipage
           texlive-fullwidth
           texlive-functional
           texlive-fundus-calligra
           texlive-fundus-cyr
           texlive-fundus-sueterlin
           texlive-fvextra
           texlive-fwlw
           texlive-g-brief
           texlive-gatherenum
           texlive-gauss
           texlive-gcard
           texlive-gcite
           texlive-gender
           texlive-genmpage
           texlive-gensymb
           texlive-getfiledate
           texlive-getitems
           texlive-gindex
           texlive-ginpenc
           texlive-gitfile-info
           texlive-gitinfo
           texlive-gitinfo2
           texlive-gitlog
           texlive-gitstatus
           texlive-gitver
           texlive-globalvals
           texlive-gloss
           texlive-glossaries
           texlive-glossaries-danish
           texlive-glossaries-dutch
           texlive-glossaries-english
           texlive-glossaries-estonian
           texlive-glossaries-extra
           texlive-glossaries-finnish
           texlive-glossaries-french
           texlive-glossaries-german
           texlive-glossaries-irish
           texlive-glossaries-italian
           texlive-glossaries-magyar
           texlive-glossaries-nynorsk
           texlive-glossaries-polish
           texlive-glossaries-portuges
           texlive-glossaries-serbian
           texlive-glossaries-slovene
           texlive-glossaries-spanish
           texlive-gmdoc
           texlive-gmdoc-enhance
           texlive-gmiflink
           texlive-gmutils
           texlive-gmverb
           texlive-grabbox
           texlive-gradient-text
           texlive-grading-scheme
           texlive-graphbox
           texlive-graphicscache
           texlive-graphicx-psmin
           texlive-graphicxbox
           texlive-graphpaper
           texlive-grayhints
           texlive-grfpaste
           texlive-grid
           texlive-grid-system
           texlive-gridpapers
           texlive-gridset
           texlive-gridslides
           texlive-gs1
           texlive-guitlogo
           texlive-ha-prosper
           texlive-hackthefootline
           texlive-halloweenmath
           texlive-handin
           texlive-handout
           texlive-handoutwithnotes
           texlive-hang
           texlive-hanging
           texlive-hardwrap
           texlive-harnon-cv
           texlive-harpoon
           texlive-hc
           texlive-he-she
           texlive-hep-acronym
           texlive-hep-float
           texlive-hep-math
           texlive-hep-text
           texlive-hep-title
           texlive-hereapplies
           texlive-hhtensor
           texlive-hideanswer
           texlive-highlightlatex
           texlive-histogr
           texlive-hitec
           texlive-hitreport
           texlive-hletter
           texlive-hobsub
           texlive-hpsdiss
           texlive-href-ul
           texlive-hrefhide
           texlive-huawei
           texlive-hvextern
           texlive-hvindex
           texlive-hvlogos
           texlive-hvpygmentex
           texlive-hvqrurl
           texlive-hwemoji
           texlive-hypdestopt
           texlive-hypdoc
           texlive-hypdvips
           texlive-hyper
           texlive-hyperbar
           texlive-hypernat
           texlive-hyperxmp
           texlive-hyphenat
           texlive-identkey
           texlive-idxcmds
           texlive-idxlayout
           texlive-iexec
           texlive-ifallfalse
           texlive-iffont
           texlive-ifmslide
           texlive-ifmtarg
           texlive-ifnextok
           texlive-ifoddpage
           texlive-ifthenx
           texlive-iitem
           texlive-image-gallery
           texlive-imakeidx
           texlive-import
           texlive-incgraph
           texlive-indextools
           texlive-inline-images
           texlive-inlinedef
           texlive-inlinelabel
           texlive-inputenx
           texlive-inputtrc
           texlive-interactiveworkbook
           texlive-interfaces
           texlive-intopdf
           texlive-inversepath
           texlive-invoice
           texlive-invoice-class
           texlive-invoice2
           texlive-iso
           texlive-iso10303
           texlive-isodate
           texlive-isodoc
           texlive-isonums
           texlive-isopt
           texlive-isorot
           texlive-isotope
           texlive-issuulinks
           texlive-jlabels
           texlive-jmsdelim
           texlive-jobname-suffix
           texlive-jslectureplanner
           texlive-jumplines
           texlive-jvlisting
           texlive-kalendarium
           texlive-kantlipsum
           texlive-kerntest
           texlive-keycommand
           texlive-keyfloat
           texlive-keyindex
           texlive-keyparse
           texlive-keyreader
           texlive-keystroke
           texlive-keyval2e
           texlive-keyvaltable
           texlive-kix
           texlive-knowledge
           texlive-koma-moderncvclassic
           texlive-koma-script-sfs
           texlive-komacv
           texlive-komacv-rg
           texlive-ktv-texdata
           texlive-l3build
           texlive-labbook
           texlive-labels
           texlive-labels4easylist
           texlive-labelschanged
           texlive-lambdax
           texlive-lastpackage
           texlive-lastpage
           texlive-latex-uni8
           texlive-latexcolors
           texlive-latexdemo
           texlive-latexgit
           texlive-layouts
           texlive-lazylist
           texlive-lccaps
           texlive-lcd
           texlive-lcg
           texlive-leading
           texlive-leaflet
           texlive-lebhart
           texlive-lectures
           texlive-lectureslides
           texlive-leftidx
           texlive-leftindex
           texlive-leipzig
           texlive-lengthconvert
           texlive-lettre
           texlive-lettrine
           texlive-lewis
           texlive-lhelp
           texlive-libgreek
           texlive-limap
           texlive-linegoal
           texlive-linop
           texlive-lipsum
           texlive-lisp-on-tex
           texlive-listing
           texlive-listingsutf8
           texlive-listlbls
           texlive-listliketab
           texlive-listofsymbols
           texlive-lkproof
           texlive-lmake
           texlive-locality
           texlive-logbox
           texlive-logical-markup-utils
           texlive-logpap
           texlive-longfbox
           texlive-longfigure
           texlive-longnamefilelist
           texlive-loops
           texlive-lsc
           texlive-lstaddons
           texlive-lstfiracode
           texlive-lt3graph
           texlive-lt3rawobjects
           texlive-ltablex
           texlive-ltabptch
           texlive-ltxdockit
           texlive-ltxguidex
           texlive-ltxkeys
           texlive-ltxnew
           texlive-ltxtools
           texlive-lua-check-hyphen
           texlive-lua-physical
           texlive-luatodonotes
           texlive-macrolist
           texlive-macroswap
           texlive-magaz
           texlive-magicnum
           texlive-magicwatermark
           texlive-mailing
           texlive-mailmerge
           texlive-makebarcode
           texlive-makebase
           texlive-makebox
           texlive-makecell
           texlive-makecirc
           texlive-makecmds
           texlive-makecookbook
           texlive-makedtx
           texlive-makeglos
           texlive-makelabels
           texlive-makerobust
           texlive-mandi
           texlive-manfnt
           texlive-manuscript
           texlive-manyind
           texlive-marginfit
           texlive-marginfix
           texlive-marginnote
           texlive-markdown
           texlive-mathalpha
           texlive-mathastext
           texlive-mathexam
           texlive-mathfam256
           texlive-mathfont
           texlive-maybemath
           texlive-mcaption
           texlive-mceinleger
           texlive-mcexam
           texlive-mcite
           texlive-mciteplus
           texlive-mdframed
           texlive-media4svg
           texlive-media9
           texlive-medstarbeamer
           texlive-meetingmins
           texlive-memexsupp
           texlive-memory
           texlive-mensa-tex
           texlive-menu
           texlive-menucard
           texlive-menukeys
           texlive-metalogox
           texlive-metanorma
           texlive-metastr
           texlive-method
           texlive-metre
           texlive-mfirstuc
           texlive-mftinc
           texlive-mi-solns
           texlive-midpage
           texlive-mindflow
           texlive-minibox
           texlive-minidocument
           texlive-minifp
           texlive-minimalist
           texlive-minipage-marginpar
           texlive-minitoc
           texlive-minorrevision
           texlive-minted
           texlive-minutes
           texlive-mla-paper
           texlive-mleftright
           texlive-mlist
           texlive-mmap
           texlive-mnotes
           texlive-moderncv
           texlive-modernposter
           texlive-moderntimeline
           texlive-modref
           texlive-modroman
           texlive-modular
           texlive-monofill
           texlive-moodle
           texlive-moreenum
           texlive-morefloats
           texlive-morehype
           texlive-moresize
           texlive-moreverb
           texlive-morewrites
           texlive-movie15
           texlive-mparhack
           texlive-mpostinl
           texlive-msc
           texlive-msg
           texlive-mslapa
           texlive-mtgreek
           texlive-multenum
           texlive-multiaudience
           texlive-multibbl
           texlive-multicap
           texlive-multicolrule
           texlive-multidef
           texlive-multienv
           texlive-multiexpand
           texlive-multifootnote
           texlive-multilang
           texlive-multiple-choice
           texlive-multirow
           texlive-mversion
           texlive-mwe
           texlive-mycv
           texlive-mylatex
           texlive-mylatexformat
           texlive-nag
           texlive-nameauth
           texlive-namespc
           texlive-ncclatex
           texlive-ncctools
           texlive-needspace
           texlive-nestquot
           texlive-newcommand
           texlive-newenviron
           texlive-newfile
           texlive-newlfm
           texlive-newspaper
           texlive-newunicodechar
           texlive-newvbtm
           texlive-newverbs
           texlive-nextpage
           texlive-nfssext-cfr
           texlive-nicefilelist
           texlive-niceframe
           texlive-nicetext
           texlive-nidanfloat
           texlive-ninecolors
           texlive-nlctdoc
           texlive-noconflict
           texlive-noindentafter
           texlive-noitcrul
           texlive-nolbreaks
           texlive-nomencl
           texlive-nomentbl
           texlive-nonfloat
           texlive-nonumonpart
           texlive-nopageno
           texlive-normalcolor
           texlive-notes
           texlive-notespages
           texlive-notestex
           texlive-notoccite
           texlive-nowidow
           texlive-nox
           texlive-ntheorem
           texlive-numberedblock
           texlive-numname
           texlive-numprint
           texlive-numspell
           texlive-ocg-p
           texlive-ocgx
           texlive-ocgx2
           texlive-ocr-latex
           texlive-octavo
           texlive-oldstyle
           texlive-onlyamsmath
           texlive-opcit
           texlive-opencolor
           texlive-optidef
           texlive-optional
           texlive-options
           texlive-orcidlink
           texlive-orientation
           texlive-outline
           texlive-outliner
           texlive-outlines
           texlive-outlining
           texlive-overlays
           texlive-overpic
           texlive-padcount
           texlive-pagecolor
           texlive-pagecont
           texlive-pagegrid
           texlive-pagelayout
           texlive-pagenote
           texlive-pagerange
           texlive-pageslts
           texlive-palette
           texlive-pangram
           texlive-paper
           texlive-papercdcase
           texlive-papermas
           texlive-papertex
           texlive-paracol
           texlive-parades
           texlive-paralist
           texlive-paresse
           texlive-parnotes
           texlive-parsa
           texlive-parselines
           texlive-pas-cours
           texlive-pas-cv
           texlive-pas-tableur
           texlive-patch
           texlive-patchcmd
           texlive-pauldoc
           texlive-pawpict
           texlive-pax
           texlive-pbalance
           texlive-pbox
           texlive-pbsheet
           texlive-pdf14
           texlive-pdfcol
           texlive-pdfcolmk
           texlive-pdfcomment
           texlive-pdfcprot
           texlive-pdfmarginpar
           texlive-pdfoverlay
           texlive-pdfpagediff
           texlive-pdfpc
           texlive-pdfpc-movie
           texlive-pdfprivacy
           texlive-pdfreview
           texlive-pdfscreen
           texlive-pdfslide
           texlive-pdfsync
           texlive-pdfwin
           texlive-pdfx
           texlive-pecha
           texlive-perltex
           texlive-permute
           texlive-petiteannonce
           texlive-pgfmath-xfp
           texlive-phfcc
           texlive-phfextendedabstract
           texlive-phffullpagefigure
           texlive-phfnote
           texlive-phfparen
           texlive-phfqit
           texlive-phfquotetext
           texlive-phfsvnwatermark
           texlive-phfthm
           texlive-philex
           texlive-phonenumbers
           texlive-photo
           texlive-photobook
           texlive-picture
           texlive-piff
           texlive-pkgloader
           texlive-placeins
           texlive-plantslabels
           texlive-plates
           texlive-plweb
           texlive-pmboxdraw
           texlive-polynom
           texlive-polynomial
           texlive-polytable
           texlive-postcards
           texlive-poster-mac
           texlive-postnotes
           texlive-powerdot
           texlive-ppr-prv
           texlive-ppt-slides
           texlive-practicalreports
           texlive-precattl
           texlive-prelim2e
           texlive-preprint
           texlive-pressrelease
           texlive-prettyref
           texlive-prettytok
           texlive-preview
           texlive-printlen
           texlive-probsoln
           texlive-program
           texlive-progress
           texlive-progressbar
           texlive-projlib
           texlive-proofread
           texlive-properties
           texlive-prosper
           texlive-protex
           texlive-protocol
           texlive-psfragx
           texlive-pstool
           texlive-pstring
           texlive-pxgreeks
           texlive-pygmentex
           texlive-python
           texlive-pythonimmediate
           texlive-qcm
           texlive-qstest
           texlive-qsymbols
           texlive-quicktype
           texlive-quiz2socrative
           texlive-quotchap
           texlive-quoting
           texlive-quotmark
           texlive-ran-toks
           texlive-randtext
           texlive-rccol
           texlive-rcs-multi
           texlive-rcsinfo
           texlive-readablecv
           texlive-readarray
           texlive-realboxes
           texlive-recipe
           texlive-recipebook
           texlive-recipecard
           texlive-rectopma
           texlive-refcheck
           texlive-refenums
           texlive-reflectgraphics
           texlive-refman
           texlive-refstyle
           texlive-regcount
           texlive-regexpatch
           texlive-register
           texlive-regstats
           texlive-relenc
           texlive-relsize
           texlive-repeatindex
           texlive-repltext
           texlive-rescansync
           texlive-resmes
           texlive-returntogrid
           texlive-rgltxdoc
           texlive-rjlparshap
           texlive-rlepsf
           texlive-rmpage
           texlive-robustcommand
           texlive-robustindex
           texlive-romanbar
           texlive-romanbarpagenumber
           texlive-romanneg
           texlive-romannum
           texlive-rotfloat
           texlive-rotpages
           texlive-roundbox
           texlive-rterface
           texlive-rtkinenc
           texlive-rulerbox
           texlive-rulercompass
           texlive-runcode
           texlive-rvwrite
           texlive-sanitize-umlaut
           texlive-sauerj
           texlive-saveenv
           texlive-savefnmark
           texlive-savesym
           texlive-savetrees
           texlive-scale
           texlive-scalebar
           texlive-scalerel
           texlive-scanpages
           texlive-schedule
           texlive-schooldocs
           texlive-scontents
           texlive-scrambledenvs
           texlive-scrlayer-fancyhdr
           texlive-scrlttr2copy
           texlive-sdaps
           texlive-sdrt
           texlive-secdot
           texlive-secnum
           texlive-sectionbox
           texlive-sectionbreak
           texlive-sectsty
           texlive-seealso
           texlive-selectp
           texlive-selinput
           texlive-semantex
           texlive-semantic
           texlive-semantic-markup
           texlive-semesterplanner
           texlive-semioneside
           texlive-semproc
           texlive-semtex
           texlive-sepfootnotes
           texlive-seqsplit
           texlive-sesstime
           texlive-sf298
           texlive-sffms
           texlive-sfmath
           texlive-shadethm
           texlive-shadow
           texlive-shadowtext
           texlive-shapepar
           texlive-shdoc
           texlive-shipunov
           texlive-shorttoc
           texlive-show2e
           texlive-showcharinbox
           texlive-showdim
           texlive-showexpl
           texlive-showlabels
           texlive-sidecap
           texlive-sidenotes
           texlive-sidenotesplus
           texlive-silence
           texlive-sillypage
           texlive-simplecd
           texlive-simplecv
           texlive-simpleinvoice
           texlive-simplivre
           texlive-sitem
           texlive-skb
           texlive-skdoc
           texlive-skeldoc
           texlive-skeycommand
           texlive-skeyval
           texlive-skills
           texlive-skrapport
           texlive-slantsc
           texlive-smalltableof
           texlive-smart-eqn
           texlive-smartref
           texlive-smartunits
           texlive-snapshot
           texlive-snaptodo
           texlive-snotez
           texlive-soulpos
           texlive-spacingtricks
           texlive-spark-otf
           texlive-sparklines
           texlive-sphack
           texlive-splitindex
           texlive-spot
           texlive-spotcolor
           texlive-spreadtab
           texlive-spverbatim
           texlive-srbook-mem
           texlive-srcltx
           texlive-sseq
           texlive-sslides
           texlive-stack
           texlive-stackengine
           texlive-standalone
           texlive-stdclsdv
           texlive-stdpage
           texlive-stealcaps
           texlive-stex
           texlive-storebox
           texlive-storecmd
           texlive-stringstrings
           texlive-sttools
           texlive-stubs
           texlive-studenthandouts
           texlive-styledcmd
           texlive-subdepth
           texlive-subdocs
           texlive-subeqn
           texlive-subeqnarray
           texlive-subfigmat
           texlive-subfigure
           texlive-subfiles
           texlive-subfloat
           texlive-substr
           texlive-supertabular
           texlive-suppose
           texlive-svg
           texlive-svgcolor
           texlive-svn
           texlive-svn-multi
           texlive-svn-prov
           texlive-svninfo
           texlive-swfigure
           texlive-swungdash
           texlive-syntax
           texlive-syntrace
           texlive-synttree
           texlive-tabbing
           texlive-tabfigures
           texlive-tableaux
           texlive-tablefootnote
           texlive-tableof
           texlive-tablists
           texlive-tabls
           texlive-tablvar
           texlive-tabstackengine
           texlive-tabto-ltx
           texlive-tabu
           texlive-tabularborder
           texlive-tabularcalc
           texlive-tabularew
           texlive-tabularray
           texlive-tabulary
           texlive-tagging
           texlive-tagpair
           texlive-tagpdf
           texlive-talk
           texlive-tamefloats
           texlive-tasks
           texlive-tcldoc
           texlive-tcolorbox
           texlive-tdclock
           texlive-technics
           texlive-ted
           texlive-templatetools
           texlive-termcal
           texlive-termlist
           texlive-termsim
           texlive-testhyphens
           texlive-testidx
           texlive-tex-label
           texlive-tex-locale
           texlive-texlogos
           texlive-texmate
           texlive-texments
           texlive-texpower
           texlive-texshade
           texlive-texsurgery
           texlive-textcsc
           texlive-textfit
           texlive-textmerg
           texlive-textpos
           texlive-textualicomma
           texlive-texvc
           texlive-theoremref
           texlive-thinsp
           texlive-thmtools
           texlive-threadcol
           texlive-threeparttable
           texlive-threeparttablex
           texlive-thumb
           texlive-thumbs
           texlive-thumby
           texlive-ticket
           texlive-tipauni
           texlive-titlecaps
           texlive-titlefoot
           texlive-titlepic
           texlive-titleref
           texlive-titlesec
           texlive-titling
           texlive-to-be-determined
           texlive-tocbibind
           texlive-tocdata
           texlive-tocloft
           texlive-tocvsec2
           texlive-todo
           texlive-todonotes
           texlive-tokcycle
           texlive-tokenizer
           texlive-toolbox
           texlive-topfloat
           texlive-topiclongtable
           texlive-totalcount
           texlive-totcount
           texlive-totpages
           texlive-tramlines
           texlive-translations
           texlive-transparent
           texlive-trfsigns
           texlive-trimspaces
           texlive-trivfloat
           texlive-trsym
           texlive-truncate
           texlive-tucv
           texlive-turnthepage
           texlive-twoinone
           texlive-twoup
           texlive-txgreeks
           texlive-type1cm
           texlive-typed-checklist
           texlive-typeface
           texlive-typoaid
           texlive-typogrid
           texlive-uassign
           texlive-ucs
           texlive-uebungsblatt
           texlive-umoline
           texlive-underlin
           texlive-underoverlap
           texlive-undolabl
           texlive-uni-titlepage
           texlive-unicodefonttable
           texlive-unisc
           texlive-unitconv
           texlive-units
           texlive-unravel
           texlive-upmethodology
           texlive-upquote
           texlive-uri
           texlive-ushort
           texlive-uspace
           texlive-utf8add
           texlive-uwmslide
           texlive-variablelm
           texlive-varindex
           texlive-varsfromjobname
           texlive-varwidth
           texlive-vcell
           texlive-vdmlisting
           texlive-verbasef
           texlive-verbatimbox
           texlive-verbatimcopy
           texlive-verbdef
           texlive-verbments
           texlive-verifiche
           texlive-version
           texlive-versions
           texlive-versonotes
           texlive-vertbars
           texlive-vgrid
           texlive-vhistory
           texlive-vmargin
           texlive-volumes
           texlive-vpe
           texlive-vruler
           texlive-vtable
           texlive-vwcol
           texlive-wallcalendar
           texlive-wallpaper
           texlive-warning
           texlive-warpcol
           texlive-was
           texlive-webquiz
           texlive-widetable
           texlive-widows-and-orphans
           texlive-williams
           texlive-willowtreebook
           texlive-withargs
           texlive-wordcount
           texlive-wordlike
           texlive-worksheet
           texlive-wrapfig
           texlive-wrapfig2
           texlive-wrapstuff
           texlive-writeongrid
           texlive-wtref
           texlive-xargs
           texlive-xassoccnt
           texlive-xbmks
           texlive-xcntperchap
           texlive-xcolor-material
           texlive-xcolor-solarized
           texlive-xcomment
           texlive-xcookybooky
           texlive-xcpdftips
           texlive-xdoc
           texlive-xellipsis
           texlive-xfakebold
           texlive-xfor
           texlive-xhfill
           texlive-xifthen
           texlive-xint
           texlive-xkcdcolors
           texlive-xltabular
           texlive-xmpincl
           texlive-xnewcommand
           texlive-xoptarg
           texlive-xpatch
           texlive-xpeek
           texlive-xprintlen
           texlive-xpunctuate
           texlive-xsavebox
           texlive-xsim
           texlive-xstring
           texlive-xtab
           texlive-xurl
           texlive-xwatermark
           texlive-xytree
           texlive-yafoot
           texlive-yagusylo
           texlive-yaletter
           texlive-ycbook
           texlive-ydoc
           texlive-yplan
           texlive-zebra-goodies
           texlive-zed-csp
           texlive-zennote
           texlive-ziffer
           texlive-zref
           texlive-zref-check
           texlive-zref-clever
           texlive-zref-vario
           texlive-zwgetfdate
           texlive-zwpagelayout))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "LaTeX additional packages")
    (description
     "This package provides a very large collection of add-on packages for
LaTeX.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-latexrecommended
  (package
    (name "texlive-collection-latexrecommended")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-anysize
           texlive-attachfile2
           texlive-beamer
           texlive-booktabs
           texlive-breqn
           texlive-caption
           texlive-cite
           texlive-cmap
           texlive-collection-latex
           texlive-crop
           texlive-ctable
           texlive-eso-pic
           texlive-etoolbox
           texlive-euenc
           texlive-euler
           texlive-everysel
           texlive-everyshi
           texlive-extsizes
           texlive-fancybox
           texlive-fancyref
           texlive-fancyvrb
           texlive-filehook
           texlive-float
           texlive-fontspec
           texlive-footnotehyper
           texlive-fp
           texlive-grffile
           texlive-hologo
           texlive-index
           texlive-infwarerr
           texlive-jknapltx
           texlive-koma-script
           texlive-l3experimental
           texlive-latexbug
           texlive-lineno
           texlive-listings
           texlive-lwarp
           texlive-mathspec
           texlive-mathtools
           texlive-mdwtools
           texlive-memoir
           texlive-metalogo
           texlive-microtype
           texlive-ms
           texlive-newfloat
           texlive-ntgclass
           texlive-parskip
           texlive-pdfcolfoot
           texlive-pdflscape
           texlive-pdfmanagement-testphase
           texlive-pdfpages
           texlive-pdftexcmds
           texlive-polyglossia
           texlive-psfrag
           texlive-ragged2e
           texlive-rcs
           texlive-sansmath
           texlive-section
           texlive-seminar
           texlive-sepnum
           texlive-setspace
           texlive-subfig
           texlive-textcase
           texlive-thumbpdf
           texlive-translator
           texlive-typehtml
           texlive-ucharcat
           texlive-underscore
           texlive-unicode-math
           texlive-xcolor
           texlive-xkeyval
           texlive-xltxtra
           texlive-xunicode))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "LaTeX recommended packages")
    (description
     "This package provides a collection of recommended add-on packages for
LaTeX which have widespread use.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-luatex
  (package
    (name "texlive-collection-luatex")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-addliga
           texlive-auto-pst-pdf-lua
           texlive-barracuda
           texlive-bezierplot
           texlive-blopentype
           texlive-checkcites
           texlive-chickenize
           texlive-chinese-jfm
           texlive-cloze
           texlive-collection-basic
           texlive-combofont
           texlive-cstypo
           texlive-ctablestack
           texlive-ekdosis
           texlive-emoji
           texlive-emojicite
           texlive-enigma
           texlive-innerscript
           texlive-interpreter
           texlive-kanaparser
           texlive-ligtype
           texlive-linebreaker
           texlive-lparse
           texlive-lt3luabridge
           texlive-lua-typo
           texlive-lua-uca
           texlive-lua-ul
           texlive-lua-uni-algos
           texlive-lua-visual-debug
           texlive-lua-widow-control
           texlive-luaaddplot
           texlive-luacas
           texlive-luacensor
           texlive-luacode
           texlive-luacolor
           texlive-luacomplex
           texlive-luagcd
           texlive-luahyphenrules
           texlive-luaimageembed
           texlive-luaindex
           texlive-luainputenc
           texlive-luakeys
           texlive-lualatex-math
           texlive-lualatex-truncate
           texlive-lualibs
           texlive-lualinalg
           texlive-luamathalign
           texlive-luamaths
           texlive-luamodulartables
           texlive-luamplib
           texlive-luaoptions
           texlive-luaotfload
           texlive-luapackageloader
           texlive-luaprogtable
           texlive-luaquotes
           texlive-luarandom
           texlive-luaset
           texlive-luatex85
           texlive-luatexbase
           texlive-luatexko
           texlive-luatextra
           texlive-luatruthtable
           texlive-luavlna
           texlive-luaxml
           texlive-lutabulartools
           texlive-minim
           texlive-minim-math
           texlive-minim-mp
           texlive-minim-pdf
           texlive-minim-xmp
           texlive-newpax
           texlive-nodetree
           texlive-odsfile
           texlive-optex
           texlive-pdfarticle
           texlive-pdfextra
           texlive-penlight
           texlive-piton
           texlive-placeat
           texlive-plantuml
           texlive-pyluatex
           texlive-scikgtex
           texlive-selnolig
           texlive-showhyphenation
           texlive-showkerning
           texlive-spacekern
           texlive-spelling
           texlive-stricttex
           texlive-truthtable
           texlive-tsvtemplate
           texlive-typewriter
           texlive-uninormalize
           texlive-yamlvars))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "LuaTeX packages")
    (description
     "This is a collection of packages for LuaTeX, a TeX engine using Lua as
an embedded scripting and extension language, with native support for Unicode,
OpenType/TrueType fonts, and both PDF and DVI output.  The LuaTeX engine
itself, and plain formats, are in @code{collection-basic}.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-mathscience
  (package
    (name "texlive-collection-mathscience")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-12many
           texlive-accents
           texlive-alg
           texlive-algobox
           texlive-algorithm2e
           texlive-algorithmicx
           texlive-algorithms
           texlive-algpseudocodex
           texlive-algxpar
           texlive-aligned-overset
           texlive-amscdx
           texlive-amstex
           texlive-annotate-equations
           texlive-apxproof
           texlive-autobreak
           texlive-axodraw2
           texlive-backnaur
           texlive-begriff
           texlive-binomexp
           texlive-biocon
           texlive-bitpattern
           texlive-bodeplot
           texlive-bohr
           texlive-boldtensors
           texlive-bosisio
           texlive-bpchem
           texlive-bropd
           texlive-bussproofs
           texlive-bussproofs-extra
           texlive-bytefield
           texlive-calculation
           texlive-cartonaugh
           texlive-cascade
           texlive-causets
           texlive-ccfonts
           texlive-ccool
           texlive-chemarrow
           texlive-chemcompounds
           texlive-chemcono
           texlive-chemexec
           texlive-chemformula
           texlive-chemgreek
           texlive-chemmacros
           texlive-chemnum
           texlive-chemobabel
           texlive-chemplants
           texlive-chemschemex
           texlive-chemsec
           texlive-chemstyle
           texlive-clrscode
           texlive-clrscode3e
           texlive-codeanatomy
           texlive-collection-fontsrecommended
           texlive-collection-latex
           texlive-commath
           texlive-commutative-diagrams
           texlive-complexity
           texlive-computational-complexity
           texlive-concmath
           texlive-concrete
           texlive-conteq
           texlive-correctmathalign
           texlive-cryptocode
           texlive-csassignments
           texlive-cvss
           texlive-decision-table
           texlive-delim
           texlive-delimseasy
           texlive-delimset
           texlive-derivative
           texlive-diffcoeff
           texlive-digiconfigs
           texlive-dijkstra
           texlive-drawmatrix
           texlive-drawstack
           texlive-dyntree
           texlive-easing
           texlive-ebproof
           texlive-econometrics
           texlive-eltex
           texlive-emf
           texlive-endiagram
           texlive-engtlc
           texlive-eolang
           texlive-eqexpl
           texlive-eqnarray
           texlive-eqnnumwarn
           texlive-euclideangeometry
           texlive-extarrows
           texlive-extpfeil
           texlive-faktor
           texlive-fascicules
           texlive-fixdif
           texlive-fixmath
           texlive-fnspe
           texlive-formal-grammar
           texlive-fouridx
           texlive-functan
           texlive-galois
           texlive-gastex
           texlive-gene-logic
           texlive-ghsystem
           texlive-glosmathtools
           texlive-gotoh
           texlive-grundgesetze
           texlive-gu
           texlive-helmholtz-ellis-ji-notation
           texlive-hep
           texlive-hep-reference
           texlive-hepnames
           texlive-hepparticles
           texlive-hepthesis
           texlive-hepunits
           texlive-ibrackets
           texlive-includernw
           texlive-interval
           texlive-ionumbers
           texlive-isomath
           texlive-jkmath
           texlive-jupynotex
           texlive-karnaugh
           texlive-karnaugh-map
           texlive-karnaughmap
           texlive-kvmap
           texlive-letterswitharrows
           texlive-lie-hasse
           texlive-logicproof
           texlive-longdivision
           texlive-lpform
           texlive-lplfitch
           texlive-lstbayes
           texlive-mathcommand
           texlive-mathcomp
           texlive-mathfixs
           texlive-mathlig
           texlive-mathpartir
           texlive-mathpunctspace
           texlive-mathsemantics
           texlive-matlab-prettifier
           texlive-matrix-skeleton
           texlive-mattens
           texlive-mecaso
           texlive-membranecomputing
           texlive-memorygraphs
           texlive-messagepassing
           texlive-mgltex
           texlive-mhchem
           texlive-mhequ
           texlive-miller
           texlive-mismath
           texlive-multiobjective
           texlive-naive-ebnf
           texlive-namedtensor
           texlive-natded
           texlive-nath
           texlive-nchairx
           texlive-nicematrix
           texlive-nuc
           texlive-nucleardata
           texlive-numerica
           texlive-numerica-plus
           texlive-numerica-tables
           texlive-objectz
           texlive-oplotsymbl
           texlive-ot-tableau
           texlive-oubraces
           texlive-overarrows
           texlive-pascaltriangle
           texlive-perfectcut
           texlive-pfdicons
           texlive-physconst
           texlive-physics
           texlive-physics2
           texlive-physunits
           texlive-pinoutikz
           texlive-pm-isomath
           texlive-polexpr
           texlive-prftree
           texlive-principia
           texlive-proba
           texlive-proof-at-the-end
           texlive-prooftrees
           texlive-pseudo
           texlive-pseudocode
           texlive-pythonhighlight
           texlive-qsharp
           texlive-rank-2-roots
           texlive-rbt-mathnotes
           texlive-rec-thy
           texlive-resolsysteme
           texlive-rest-api
           texlive-revquantum
           texlive-ribbonproofs
           texlive-rmathbr
           texlive-sankey
           texlive-sasnrdisplay
           texlive-sciposter
           texlive-sclang-prettifier
           texlive-scratchx
           texlive-sesamanuel
           texlive-sfg
           texlive-shuffle
           texlive-simplebnf
           texlive-simpler-wick
           texlive-simples-matrices
           texlive-simplewick
           texlive-sistyle
           texlive-siunits
           texlive-siunitx
           texlive-skmath
           texlive-spalign
           texlive-spbmark
           texlive-stanli
           texlive-statex
           texlive-statex2
           texlive-statistics
           texlive-statistik
           texlive-statmath
           texlive-steinmetz
           texlive-stmaryrd
           texlive-structmech
           texlive-struktex
           texlive-substances
           texlive-subsupscripts
           texlive-subtext
           texlive-susy
           texlive-syllogism
           texlive-sympytexpackage
           texlive-synproof
           texlive-t-angles
           texlive-tablor
           texlive-tensind
           texlive-tensor
           texlive-tex-ewd
           texlive-textgreek
           texlive-textopo
           texlive-thermodynamics
           texlive-thmbox
           texlive-tiscreen
           texlive-turnstile
           texlive-ulqda
           texlive-unitsdef
           texlive-venn
           texlive-witharrows
           texlive-xymtex
           texlive-yhmath
           texlive-youngtab
           texlive-yquant
           texlive-ytableau
           texlive-zx-calculus))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Mathematics, natural sciences, computer science packages")
    (description
     "This collection provides mathematics, natural sciences, and computer
science packages.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-metapost
  (package
    (name "texlive-collection-metapost")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-automata
           texlive-bbcard
           texlive-blockdraw-mp
           texlive-bpolynomial
           texlive-cmarrows
           texlive-collection-basic
           texlive-drv
           texlive-dviincl
           texlive-emp
           texlive-epsincl
           texlive-expressg
           texlive-exteps
           texlive-featpost
           texlive-feynmf
           texlive-feynmp-auto
           texlive-fiziko
           texlive-garrigues
           texlive-gmp
           texlive-hatching
           texlive-hershey-mp
           texlive-latexmp
           texlive-mcf2graph
           texlive-metago
           texlive-metaobj
           texlive-metaplot
           texlive-metapost
           texlive-metapost-colorbrewer
           texlive-metauml
           texlive-mfpic
           texlive-mfpic4ode
           texlive-minim-hatching
           texlive-mp3d
           texlive-mparrows
           texlive-mpattern
           texlive-mpcolornames
           texlive-mpgraphics
           texlive-mptrees
           texlive-piechartmp
           texlive-repere
           texlive-roex
           texlive-roundrect
           texlive-shapes
           texlive-slideshow
           texlive-splines
           texlive-suanpan
           texlive-textpath
           texlive-threeddice))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "MetaPost and Metafont packages")
    (description
     "This collection includes all MetaPost and Metafont packages, along
with packages in @code{collection-basic}.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-music
  (package
    (name "texlive-collection-music")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-abc
           texlive-autosp
           texlive-bagpipe
           texlive-chordbars
           texlive-chordbox
           texlive-collection-latex
           texlive-ddphonism
           texlive-figbas
           texlive-gchords
           texlive-gregoriotex
           texlive-gtrcrd
           texlive-guitar
           texlive-guitarchordschemes
           texlive-guitartabs
           texlive-harmony
           texlive-latex4musicians
           texlive-leadsheets
           texlive-lilyglyphs
           texlive-lyluatex
           texlive-m-tx
           texlive-musical
           texlive-musicography
           texlive-musixguit
           texlive-musixtex
           texlive-musixtex-fonts
           texlive-musixtnt
           texlive-octave
           texlive-piano
           texlive-pmx
           texlive-pmxchords
           texlive-recorder-fingering
           texlive-songbook
           texlive-songproj
           texlive-songs
           texlive-xml2pmx
           texlive-xpiano))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Music packages")
    (description "This collection includes music-related fonts and packages.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-pictures
  (package
    (name "texlive-collection-pictures")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-adigraph
           texlive-aobs-tikz
           texlive-askmaps
           texlive-asyfig
           texlive-asypictureb
           texlive-autoarea
           texlive-bardiag
           texlive-beamerswitch
           texlive-binarytree
           texlive-blochsphere
           texlive-bloques
           texlive-blox
           texlive-bodegraph
           texlive-bondgraph
           texlive-bondgraphs
           texlive-braids
           texlive-bxeepic
           texlive-byo-twemojis
           texlive-byrne
           texlive-cachepic
           texlive-callouts
           texlive-celtic
           texlive-chemfig
           texlive-circuit-macros
           texlive-circuitikz
           texlive-coffeestains
           texlive-collection-basic
           texlive-combinedgraphics
           texlive-curve
           texlive-curve2e
           texlive-curves
           texlive-dcpic
           texlive-diagmac2
           texlive-ditaa
           texlive-doc-pictex
           texlive-dot2texi
           texlive-dottex
           texlive-dpcircling
           texlive-dratex
           texlive-drs
           texlive-duotenzor
           texlive-dynkin-diagrams
           texlive-ecgdraw
           texlive-eepic
           texlive-ellipse
           texlive-endofproofwd
           texlive-epspdf
           texlive-epspdfconversion
           texlive-esk
           texlive-euflag
           texlive-fast-diagram
           texlive-fig4latex
           texlive-figchild
           texlive-figput
           texlive-fitbox
           texlive-flowchart
           texlive-forest
           texlive-genealogytree
           texlive-getmap
           texlive-gincltex
           texlive-gnuplottex
           texlive-gradientframe
           texlive-grafcet
           texlive-graph35
           texlive-graphicxpsd
           texlive-graphviz
           texlive-gtrlib-largetrees
           texlive-harveyballs
           texlive-here
           texlive-hf-tikz
           texlive-hobby
           texlive-hvfloat
           texlive-istgame
           texlive-kblocks
           texlive-kinematikz
           texlive-knitting
           texlive-knittingpattern
           texlive-ladder
           texlive-lapdf
           texlive-latex-make
           texlive-liftarm
           texlive-lpic
           texlive-lroundrect
           texlive-luamesh
           texlive-luasseq
           texlive-maker
           texlive-makeshape
           texlive-mathspic
           texlive-mercatormap
           texlive-milsymb
           texlive-miniplot
           texlive-mkpic
           texlive-modiagram
           texlive-neuralnetwork
           texlive-nl-interval
           texlive-nndraw
           texlive-numericplots
           texlive-outilsgeomtikz
           texlive-pb-diagram
           texlive-petri-nets
           texlive-pgf
           texlive-pgf-blur
           texlive-pgf-interference
           texlive-pgf-periodictable
           texlive-pgf-pie
           texlive-pgf-soroban
           texlive-pgf-spectra
           texlive-pgf-umlcd
           texlive-pgf-umlsd
           texlive-pgfgantt
           texlive-pgfkeyx
           texlive-pgfmolbio
           texlive-pgfmorepages
           texlive-pgfopts
           texlive-pgfornament
           texlive-pgfplots
           texlive-picinpar
           texlive-pict2e
           texlive-pictex
           texlive-pictex2
           texlive-pinlabel
           texlive-pixelart
           texlive-pixelarttikz
           texlive-pmgraph
           texlive-postage
           texlive-prerex
           texlive-productbox
           texlive-ptolemaicastronomy
           texlive-puyotikz
           texlive-pxpgfmark
           texlive-pxpic
           texlive-qcircuit
           texlive-qrcode
           texlive-quantikz
           texlive-randbild
           texlive-randomwalk
           texlive-realhats
           texlive-reotex
           texlive-robotarm
           texlive-rviewport
           texlive-sa-tikz
           texlive-sacsymb
           texlive-schemabloc
           texlive-scratch
           texlive-scratch3
           texlive-scsnowman
           texlive-setdeck
           texlive-signchart
           texlive-simplenodes
           texlive-simpleoptics
           texlive-smartdiagram
           texlive-spath3
           texlive-spectralsequences
           texlive-strands
           texlive-swimgraf
           texlive-syntaxdi
           texlive-table-fct
           texlive-texdraw
           texlive-ticollege
           texlive-tikz-3dplot
           texlive-tikz-among-us
           texlive-tikz-bagua
           texlive-tikz-bayesnet
           texlive-tikz-bbox
           texlive-tikz-cd
           texlive-tikz-dependency
           texlive-tikz-dimline
           texlive-tikz-ext
           texlive-tikz-feynhand
           texlive-tikz-feynman
           texlive-tikz-imagelabels
           texlive-tikz-inet
           texlive-tikz-kalender
           texlive-tikz-karnaugh
           texlive-tikz-ladder
           texlive-tikz-lake-fig
           texlive-tikz-layers
           texlive-tikz-mirror-lens
           texlive-tikz-nef
           texlive-tikz-network
           texlive-tikz-opm
           texlive-tikz-optics
           texlive-tikz-page
           texlive-tikz-palattice
           texlive-tikz-planets
           texlive-tikz-qtree
           texlive-tikz-relay
           texlive-tikz-sfc
           texlive-tikz-swigs
           texlive-tikz-timing
           texlive-tikz-trackschematic
           texlive-tikz-truchet
           texlive-tikzbricks
           texlive-tikzcodeblocks
           texlive-tikzducks
           texlive-tikzfill
           texlive-tikzinclude
           texlive-tikzlings
           texlive-tikzmark
           texlive-tikzmarmots
           texlive-tikzorbital
           texlive-tikzpackets
           texlive-tikzpagenodes
           texlive-tikzpeople
           texlive-tikzpfeile
           texlive-tikzpingus
           texlive-tikzposter
           texlive-tikzscale
           texlive-tikzsymbols
           texlive-tikztosvg
           texlive-tikzviolinplots
           texlive-tile-graphic
           texlive-timing-diagrams
           texlive-tipfr
           texlive-tkz-base
           texlive-tkz-berge
           texlive-tkz-doc
           texlive-tkz-euclide
           texlive-tkz-fct
           texlive-tkz-graph
           texlive-tkz-orm
           texlive-tkz-tab
           texlive-tkzexample
           texlive-tonevalue
           texlive-tqft
           texlive-tsemlines
           texlive-tufte-latex
           texlive-twemojis
           texlive-tzplot
           texlive-utfsym
           texlive-venndiagram
           texlive-visualpstricks
           texlive-wheelchart
           texlive-worldflags
           texlive-xistercian
           texlive-xpicture
           texlive-xypic))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Graphics, pictures, diagrams")
    (description
     "This collection provides packages related to graphics, pictures, and
diagrams.  It includes TikZ, @code{pict}, etc.  However, MetaPost and
PStricks are separate.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-plaingeneric
  (package
    (name "texlive-collection-plaingeneric")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-abbr
           texlive-abstyles
           texlive-apnum
           texlive-autoaligne
           texlive-barr
           texlive-bitelist
           texlive-borceux
           texlive-c-pascal
           texlive-catcodes
           texlive-chronosys
           texlive-collection-basic
           texlive-colorsep
           texlive-compare
           texlive-crossrefenum
           texlive-cweb-old
           texlive-dinat
           texlive-dirtree
           texlive-docbytex
           texlive-dowith
           texlive-eijkhout
           texlive-encxvlna
           texlive-epigram
           texlive-epsf
           texlive-epsf-dvipdfmx
           texlive-expex-acro
           texlive-expkv-bundle
           texlive-fenixpar
           texlive-figflow
           texlive-fixpdfmag
           texlive-fltpoint
           texlive-fntproof
           texlive-font-change
           texlive-fontch
           texlive-fontname
           texlive-gates
           texlive-getoptk
           texlive-gfnotation
           texlive-gobble
           texlive-graphics-pln
           texlive-gtl
           texlive-hlist
           texlive-hyplain
           texlive-inputnormalization
           texlive-insbox
           texlive-js-misc
           texlive-kastrup
           texlive-lambda-lists
           texlive-langcode
           texlive-lecturer
           texlive-letterspacing
           texlive-librarian
           texlive-listofitems
           texlive-localloc
           texlive-mathdots
           texlive-metatex
           texlive-midnight
           texlive-mkpattern
           texlive-modulus
           texlive-multido
           texlive-namedef
           texlive-navigator
           texlive-newsletr
           texlive-nth
           texlive-ofs
           texlive-olsak-misc
           texlive-outerhbox
           texlive-path
           texlive-pdf-trans
           texlive-pdfmsym
           texlive-pitex
           texlive-placeins-plain
           texlive-plainpkg
           texlive-plipsum
           texlive-plnfss
           texlive-plstmary
           texlive-poormanlog
           texlive-present
           texlive-pwebmac
           texlive-random
           texlive-randomlist
           texlive-resumemac
           texlive-ruler
           texlive-schemata
           texlive-shade
           texlive-simplekv
           texlive-soul
           texlive-swrule
           texlive-systeme
           texlive-tabto-generic
           texlive-termmenu
           texlive-tex-ps
           texlive-tex4ht
           texlive-texapi
           texlive-texdate
           texlive-texdimens
           texlive-texinfo
           texlive-timetable
           texlive-tracklang
           texlive-transparent-io
           texlive-treetex
           texlive-trigonometry
           texlive-ulem
           texlive-upca
           texlive-varisize
           texlive-xii
           texlive-xii-lat
           texlive-xintsession
           texlive-xlop
           texlive-yax
           texlive-zztex))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Plain (La)TeX packages")
    (description
     "This consist of add-on packages and macros that work with plain TeX,
often LaTeX, and occasionally other formats.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-pstricks
  (package
    (name "texlive-collection-pstricks")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-auto-pst-pdf
           texlive-bclogo
           texlive-collection-basic
           texlive-collection-plaingeneric
           texlive-dsptricks
           texlive-luapstricks
           texlive-makeplot
           texlive-pdftricks
           texlive-pdftricks2
           texlive-pedigree-perl
           texlive-psbao
           texlive-pst-2dplot
           texlive-pst-3d
           texlive-pst-3dplot
           texlive-pst-abspos
           texlive-pst-am
           texlive-pst-antiprism
           texlive-pst-arrow
           texlive-pst-asr
           texlive-pst-bar
           texlive-pst-barcode
           texlive-pst-bezier
           texlive-pst-blur
           texlive-pst-bspline
           texlive-pst-calculate
           texlive-pst-calendar
           texlive-pst-cie
           texlive-pst-circ
           texlive-pst-coil
           texlive-pst-contourplot
           texlive-pst-cox
           texlive-pst-dart
           texlive-pst-dbicons
           texlive-pst-diffraction
           texlive-pst-electricfield
           texlive-pst-eps
           texlive-pst-eucl
           texlive-pst-exa
           texlive-pst-feyn
           texlive-pst-fill
           texlive-pst-fit
           texlive-pst-flags
           texlive-pst-fr3d
           texlive-pst-fractal
           texlive-pst-fun
           texlive-pst-func
           texlive-pst-gantt
           texlive-pst-geo
           texlive-pst-geometrictools
           texlive-pst-gr3d
           texlive-pst-grad
           texlive-pst-graphicx
           texlive-pst-hsb
           texlive-pst-infixplot
           texlive-pst-intersect
           texlive-pst-jtree
           texlive-pst-knot
           texlive-pst-labo
           texlive-pst-layout
           texlive-pst-lens
           texlive-pst-light3d
           texlive-pst-lsystem
           texlive-pst-magneticfield
           texlive-pst-marble
           texlive-pst-math
           texlive-pst-mirror
           texlive-pst-moire
           texlive-pst-node
           texlive-pst-ob3d
           texlive-pst-ode
           texlive-pst-optexp
           texlive-pst-optic
           texlive-pst-osci
           texlive-pst-ovl
           texlive-pst-pad
           texlive-pst-pdf
           texlive-pst-pdgr
           texlive-pst-perspective
           texlive-pst-platon
           texlive-pst-plot
           texlive-pst-poker
           texlive-pst-poly
           texlive-pst-pulley
           texlive-pst-qtree
           texlive-pst-rputover
           texlive-pst-rubans
           texlive-pst-shell
           texlive-pst-sigsys
           texlive-pst-slpe
           texlive-pst-solarsystem
           texlive-pst-solides3d
           texlive-pst-soroban
           texlive-pst-spectra
           texlive-pst-spinner
           texlive-pst-stru
           texlive-pst-support
           texlive-pst-text
           texlive-pst-thick
           texlive-pst-tools
           texlive-pst-tree
           texlive-pst-turtle
           texlive-pst-tvz
           texlive-pst-uml
           texlive-pst-vectorian
           texlive-pst-vehicle
           texlive-pst-venn
           texlive-pst-vowel
           texlive-pst2pdf
           texlive-pstricks
           texlive-pstricks-add
           texlive-pstricks-calcnotes
           texlive-uml
           texlive-vaucanson-g
           texlive-vocaltract))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "PSTricks core and add-ons")
    (description
     "This collection provides PSTricks core and all add-on packages.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-publishers
  (package
    (name "texlive-collection-publishers")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-aastex
           texlive-abnt
           texlive-abntex2
           texlive-abntexto
           texlive-acmart
           texlive-acmconf
           texlive-active-conf
           texlive-adfathesis
           texlive-afparticle
           texlive-afthesis
           texlive-aguplus
           texlive-aiaa
           texlive-anonymous-acm
           texlive-anufinalexam
           texlive-aomart
           texlive-apa
           texlive-apa6
           texlive-apa6e
           texlive-apa7
           texlive-arsclassica
           texlive-articleingud
           texlive-asaetr
           texlive-ascelike
           texlive-asmeconf
           texlive-asmejour
           texlive-aucklandthesis
           texlive-bangorcsthesis
           texlive-bangorexam
           texlive-bath-bst
           texlive-beamer-fuberlin
           texlive-beamer-verona
           texlive-beilstein
           texlive-bfh-ci
           texlive-bgteubner
           texlive-bjfuthesis
           texlive-bmstu
           texlive-bmstu-iu8
           texlive-br-lex
           texlive-brandeis-dissertation
           texlive-brandeis-problemset
           texlive-brandeis-thesis
           texlive-buctthesis
           texlive-cascadilla
           texlive-cesenaexam
           texlive-chem-journal
           texlive-chifoot
           texlive-chs-physics-report
           texlive-cje
           texlive-classicthesis
           texlive-cleanthesis
           texlive-cmpj
           texlive-collection-latex
           texlive-confproc
           texlive-cquthesis
           texlive-dccpaper
           texlive-dithesis
           texlive-ebook
           texlive-ebsthesis
           texlive-ecothesis
           texlive-ejpecp
           texlive-ekaia
           texlive-elbioimp
           texlive-els-cas-templates
           texlive-elsarticle
           texlive-elteikthesis
           texlive-emisa
           texlive-erdc
           texlive-estcpmm
           texlive-etsvthor
           texlive-facture-belge-simple-sans-tva
           texlive-fbithesis
           texlive-fcavtex
           texlive-fcltxdoc
           texlive-fei
           texlive-ftc-notebook
           texlive-gaceta
           texlive-gammas
           texlive-geradwp
           texlive-gfdl
           texlive-gradstudentresume
           texlive-grant
           texlive-gsemthesis
           texlive-gzt
           texlive-h2020proposal
           texlive-hagenberg-thesis
           texlive-har2nat
           texlive-hecthese
           texlive-hep-paper
           texlive-hfutexam
           texlive-hfutthesis
           texlive-hithesis
           texlive-hitszbeamer
           texlive-hitszthesis
           texlive-hobete
           texlive-hu-berlin-bundle
           texlive-hustthesis
           texlive-icsv
           texlive-ieeeconf
           texlive-ieeepes
           texlive-ieeetran
           texlive-ijmart
           texlive-ijsra
           texlive-imac
           texlive-imtekda
           texlive-inkpaper
           texlive-iodhbwm
           texlive-iscram
           texlive-jacow
           texlive-jmlr
           texlive-jnuexam
           texlive-jourcl
           texlive-jpsj
           texlive-jwjournal
           texlive-kdgdocs
           texlive-kdpcover
           texlive-kfupm-math-exam
           texlive-kluwer
           texlive-ksp-thesis
           texlive-ku-template
           texlive-langsci
           texlive-langsci-avm
           texlive-limecv
           texlive-lion-msc
           texlive-llncs
           texlive-llncsconf
           texlive-lni
           texlive-lps
           texlive-matc3
           texlive-matc3mem
           texlive-mcmthesis
           texlive-mentis
           texlive-mlacls
           texlive-mluexercise
           texlive-mnras
           texlive-modeles-factures-belges-assocs
           texlive-msu-thesis
           texlive-mucproc
           texlive-mugsthesis
           texlive-muling
           texlive-musuos
           texlive-muthesis
           texlive-mynsfc
           texlive-nature
           texlive-navydocs
           texlive-nddiss
           texlive-ndsu-thesis
           texlive-ndsu-thesis-2022
           texlive-nih
           texlive-nihbiosketch
           texlive-njustthesis
           texlive-njuthesis
           texlive-njuvisual
           texlive-nostarch
           texlive-novel
           texlive-nrc
           texlive-nwafuthesis
           texlive-nwejm
           texlive-onrannual
           texlive-opteng
           texlive-oup-authoring-template
           texlive-philosophersimprint
           texlive-pittetd
           texlive-pkuthss
           texlive-powerdot-fuberlin
           texlive-powerdot-tuliplab
           texlive-pracjourn
           texlive-prociagssymp
           texlive-proposal
           texlive-prtec
           texlive-ptptex
           texlive-qrbill
           texlive-quantumarticle
           texlive-resphilosophica
           texlive-resumecls
           texlive-revtex
           texlive-revtex4
           texlive-revtex4-1
           texlive-rutitlepage
           texlive-ryersonsgsthesis
           texlive-ryethesis
           texlive-sageep
           texlive-sapthesis
           texlive-schule
           texlive-scientific-thesis-cover
           texlive-scripture
           texlive-scrjrnl
           texlive-sduthesis
           texlive-se2thesis
           texlive-seu-ml-assign
           texlive-seuthesis
           texlive-seuthesix
           texlive-shortmathj
           texlive-shtthesis
           texlive-smflatex
           texlive-soton
           texlive-sphdthesis
           texlive-spie
           texlive-sr-vorl
           texlive-srdp-mathematik
           texlive-stellenbosch
           texlive-suftesi
           texlive-sugconf
           texlive-tabriz-thesis
           texlive-technion-thesis-template
           texlive-texilikechaps
           texlive-texilikecover
           texlive-thesis-ekf
           texlive-thesis-gwu
           texlive-thesis-qom
           texlive-thesis-titlepage-fhac
           texlive-thuaslogos
           texlive-thubeamer
           texlive-thucoursework
           texlive-thuthesis
           texlive-tidyres
           texlive-timbreicmc
           texlive-tlc-article
           texlive-topletter
           texlive-toptesi
           texlive-tuda-ci
           texlive-tudscr
           texlive-tugboat
           texlive-tugboat-plain
           texlive-tui
           texlive-turabian
           texlive-uaclasses
           texlive-uafthesis
           texlive-uantwerpendocs
           texlive-ucalgmthesis
           texlive-ucbthesis
           texlive-ucdavisthesis
           texlive-ucsmonograph
           texlive-ucthesis
           texlive-udes-genie-these
           texlive-uestcthesis
           texlive-ufrgscca
           texlive-uhhassignment
           texlive-uiucredborder
           texlive-uiucthesis
           texlive-ukbill
           texlive-ulthese
           texlive-umbclegislation
           texlive-umich-thesis
           texlive-umthesis
           texlive-unam-thesis
           texlive-unamth-template
           texlive-unamthesis
           texlive-unbtex
           texlive-unifith
           texlive-unigrazpub
           texlive-unitn-bimrep
           texlive-univie-ling
           texlive-unizgklasa
           texlive-unswcover
           texlive-uol-physics-report
           texlive-uothesis
           texlive-uowthesis
           texlive-uowthesistitlepage
           texlive-urcls
           texlive-uspatent
           texlive-ut-thesis
           texlive-utexasthesis
           texlive-uvaletter
           texlive-uwa-colours
           texlive-uwa-letterhead
           texlive-uwa-pcf
           texlive-uwa-pif
           texlive-uwthesis
           texlive-vancouver
           texlive-wsemclassic
           texlive-xduthesis
           texlive-xduts
           texlive-xmuthesis
           texlive-yathesis
           texlive-yazd-thesis
           texlive-yb-book
           texlive-york-thesis))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "Publisher styles, theses, etc.")
    (description "This collection includes publisher styles, theses, etc.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-collection-xetex
  (package
    (name "texlive-collection-xetex")
    (version (package-version texlive-source))
    (source #f)
    (build-system trivial-build-system)
    (arguments (list #:builder #~(mkdir #$output)))
    (propagated-inputs
     (list texlive-arabxetex
           texlive-awesomebox
           texlive-bidi-atbegshi
           texlive-bidicontour
           texlive-bidipagegrid
           texlive-bidipresentation
           texlive-bidishadowtext
           texlive-businesscard-qrcode
           texlive-collection-basic
           texlive-cqubeamer
           texlive-fixlatvian
           texlive-font-change-xetex
           texlive-fontbook
           texlive-fontwrap
           texlive-interchar
           texlive-na-position
           texlive-philokalia
           texlive-ptext
           texlive-realscripts
           texlive-simple-resume-cv
           texlive-simple-thesis-dissertation
           texlive-tetragonos
           texlive-ucharclasses
           texlive-unicode-bidi
           texlive-unimath-plain-xetex
           texlive-unisugar
           texlive-xebaposter
           texlive-xechangebar
           texlive-xecolor
           texlive-xecyr
           texlive-xeindex
           texlive-xesearch
           texlive-xespotcolor
           texlive-xetex
           texlive-xetex-itrans
           texlive-xetex-pstricks
           texlive-xetex-tibetan
           texlive-xetexconfig
           texlive-xetexfontinfo
           texlive-xetexko
           texlive-xevlna
           texlive-zbmath-review-template))
    (home-page "https://www.tug.org/texlive/")
    (synopsis "XeTeX and packages")
    (description
     "This collection includes packages for XeTeX, the Unicode and
OpenType-enabled TeX by Jonathan Kew.")
    (license (license:fsf-free "https://www.tug.org/texlive/copying.html"))))

(define-public texlive-grfext
  (package
    (name "texlive-grfext")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/grfext/" "source/latex/grfext/"
                                     "tex/latex/grfext/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x35r10mkjg8dzx7aj99y4dwyf69jgs41qwapdx523lbglywmgxp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/grfext")
    (synopsis "Manipulate the @code{graphics} package's list of extensions")
    (description
     "This package provides macros for adding to, and reordering the list of
graphics file extensions recognised by package @code{graphics}.")
    (license license:lppl1.3c+)))

(define-public texlive-addliga
  (package
    (name "texlive-addliga")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/addliga/"
                                     "tex/lualatex/addliga/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gbdbwskba1rf3bmvwms3i3crj3dcqqg69wdzfdyy1a6ml05qpc7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/addliga")
    (synopsis "Access basic ligatures in legacy TrueType fonts")
    (description
     "This small and simple package allows LuaLaTeX users to access basic
ligatures (ff, fi, ffi, fl, ffl) in legacy TrueType fonts (those
lacking a liga table) accessed via @code{fontspec}.")
    (license license:public-domain)))

(define-public texlive-adigraph
  (package
    (name "texlive-adigraph")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/adigraph/" "tex/latex/adigraph/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jdvplrkq5qd1ad55vlsbgmxc438gp5nw54hmhs799j2k6lz6yyl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/adigraph")
    (synopsis "Augmenting directed graphs")
    (description
     "This LaTeX package provides the means to easily draw augmenting oriented
graphs, as well as cuts on them, to demonstrate steps of algorithms for
solving max-flow min-cut problems.")
    (license license:expat)))

(define-public texlive-adjustbox
  (package
    (name "texlive-adjustbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/adjustbox/"
                                     "source/latex/adjustbox/"
                                     "tex/latex/adjustbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02iqc3i3n3d16xx8hgfy5s28h26fhnqf1f4kcxap6rssr165jj3h"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ydoc")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ydoc))
    (propagated-inputs
     (list texlive-collectbox texlive-graphics texlive-xkeyval))
    (home-page "https://ctan.org/pkg/adjustbox")
    (synopsis "Graphics package-alike macros for general boxes")
    (description "The package provides several macros to adjust boxed
content.  One purpose is to supplement the standard @code{graphics} package,
which defines the macros @code{\\resizebox}, @code{\\scalebox} and
@code{\\rotatebox} , with the macros @code{\\trimbox} and @code{\\clipbox}.
The main feature is the general @code{\\adjustbox} macro which extends the
@code{key=value} interface of @code{\\includegraphics} from the
@code{graphics} package and applies it to general text content.  Additional
provided box macros are @code{\\lapbox}, @code{\\marginbox},
@code{\\minsizebox}, @code{\\maxsizebox} and @code{\\phantombox}.")
    (license license:lppl1.3+)))

(define-public texlive-aobs-tikz
  (package
    (name "texlive-aobs-tikz")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/aobs-tikz/"
                                     "source/latex/aobs-tikz/"
                                     "tex/latex/aobs-tikz/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04p3ghywqb3nr91vh6l39f8z9gbb3r6ca6yvq3nrcsqarxypfqny"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/aobs-tikz")
    (synopsis "TikZ styles for creating overlaid pictures in beamer")
    (description
     "The package defines auxiliary TikZ styles useful for overlaying pictures
elements in Beamer.")
    (license license:lppl1.3+)))

(define-public texlive-askmaps
  (package
    (name "texlive-askmaps")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/askmaps/" "tex/latex/askmaps/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l61gq2i1di9zn6s2nf5sn0pdp3z78rij17sgjywy0xka43znhlk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/askmaps")
    (synopsis "Typeset American style Karnaugh maps")
    (description
     "The package provides 1, 2, 3, 4 and 5 variable Karnaugh maps, in the
style used in numerous American textbooks on digital design.  The package
draws K-maps where the most significant input variables are placed on top of
the columns and the least significant variables are placed left of the rows.")
    (license license:lppl)))

(define-public texlive-asyfig
  (package
    (name "texlive-asyfig")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/asyfig/" "source/latex/asyfig/"
                                     "tex/latex/asyfig/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0116a920z8hq3v50gmgh3f8diq7307wx0zsh2pmznw7gkvn6rn4k"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-filecontents")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs (list texlive-filecontents))
    (home-page "https://ctan.org/pkg/asyfig")
    (synopsis "Commands for using Asymptote figures")
    (description
     "The package provides a means of reading Asymptote figures from separate
files, rather than within the document, as is standard in the @code{asymptote}
package, which is provided as part of the Asymptote bundle.  The Asymptote way
can prove cumbersome in a large document; the present package allows the user
to process one picture at a time, in simple test documents, and then to
migrate (with no fuss) to their use in the target document.")
    (license license:lppl)))

(define-public texlive-asypictureb
  (package
    (name "texlive-asypictureb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/asypictureb/"
                                     "source/latex/asypictureb/"
                                     "tex/latex/asypictureb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1djlphr3iz0l0x2pf8abd251q78rml6435f6ng7fa553anwgwya9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/asypictureb")
    (synopsis "User-friendly integration of Asymptote into LaTeX")
    (description
     "The package is an unofficial alternative to the package provided with
the Asymptote distribution, for including pictures within a LaTeX source file.
While it does not duplicate all the features of the official package, this
package is more user-friendly in several ways.  Most notably, Asymptote errors
are repackaged as LaTeX errors, making debugging less of a pain.  It also has
a more robust mechanism for identifying unchanged pictures that need not be
recompiled.")
    (license license:lppl1.3+)))

(define-public texlive-auto-pst-pdf-lua
  (package
    (name "texlive-auto-pst-pdf-lua")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/auto-pst-pdf-lua/"
                                     "tex/latex/auto-pst-pdf-lua/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "104pyx524icnx5aczdlilgj5rkfa4jb27g5maja0fbgardz73l0g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-iftex))
    (home-page "https://ctan.org/pkg/auto-pst-pdf-lua")
    (synopsis "Using LuaLaTeX together with PostScript code")
    (description
     "This package is a slightly modified version of @code{auto-pst-pdf} by
Will Robertson, which itself is a wrapper for @code{pst-pdf} by Rolf
Niepraschk.  The package allows the use of LuaLaTeX together with PostScript
related code, e.g., PSTricks.")
    (license license:lppl1.3c)))

(define-public texlive-autoarea
  (package
    (name "texlive-autoarea")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/autoarea/" "tex/latex/autoarea/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09a9wiihb397ljasnkxrqygsi34bd9a5spq8h3njf6awra2x2m6c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pictex-autoarea")
    (synopsis "Automatic computation of bounding boxes with PiCTeX")
    (description
     "This package makes PiCTeX recognize lines and arcs in determining the
bounding box of a picture.  The bounding box is essential for proper placement
of a picture between running text and margins and for keeping the running text
away.")
    (license license:lppl)))

(define-public texlive-bardiag
  (package
    (name "texlive-bardiag")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bardiag/" "tex/latex/bardiag/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1iy0cr24ki93jlnmzr1fgqa7jqg0zhxds422cz322zwr19936zz9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bardiag")
    (synopsis "LaTeX package for drawing bar diagrams")
    (description
     "The main purpose of the package is to make the drawing of bar diagrams
possible and easy in LaTeX.  The BarDiag package is inspired by and based on
PSTricks.")
    (license license:lppl)))

(define-public texlive-barracuda
  (package
    (name "texlive-barracuda")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/barracuda/" "scripts/barracuda/"
                                     "tex/luatex/barracuda/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1v318nbbbp2klp0rykzb3skqqw4hhj1hbliigmp3qh34iiq3wqh0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/barracuda")
    (synopsis "Draw barcodes with Lua")
    (description
     "The Barracuda library is a modular Lua package for drawing barcode
symbols.  It provides modules for writing barcodes from a LuaTeX document.  It
is also possible to use Barracuda with a standalone Lua interpreter to draw
barcodes in different graphic formats like SVG.")
    (license license:gpl2)))

(define-public texlive-beamerswitch
  (package
    (name "texlive-beamerswitch")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamerswitch/"
                                     "source/latex/beamerswitch/"
                                     "tex/latex/beamerswitch/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kz257kv9fdy9fvphd8sx1k0swsynrl6kxqidnh8lp70k8f24ggj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamerswitch")
    (synopsis "Convenient mode selection in Beamer documents")
    (description
     "This class is a wrapper around the beamer class to make it easier to use
the same document to generate the different forms of the presentation: the
slides themselves, an abbreviated slide set for transparencies or online
reference, an n-up handout version (various layouts are provided), and
a transcript or set of notes using the article class.  The class provides
a variety of handout layouts, and allows the mode to be chosen from the
command line (without changing the document itself).")
    (license license:lppl1.3c)))

(define-public texlive-bezierplot
  (package
    (name "texlive-bezierplot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/bezierplot/"
                                     "tex/lualatex/bezierplot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "125gdb9d160g729v3fbsrsrw5abk34jwa4x43yil0mzjls2aq550"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bezierplot")
    (synopsis "Approximate smooth function graphs with cubic Bezier splines")
    (description
     "This package consists of a Lua program as well as a (Lua)LaTeX
@file{.sty} file.  Given a smooth function, @code{bezierplot} returns a smooth
Bezier path written in TikZ notation, which also matches MetaPost, that
approximates the graph of the function.  For polynomial functions of degree
lesser or equal to 3 and their inverses the approximation is exact (up to
numeric precision).  @code{bezierplot} also finds special points such as
extreme points and inflection points and reduces the number of used points.")
    (license license:lppl1.3c)))

(define-public texlive-binarytree
  (package
    (name "texlive-binarytree")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/binarytree/"
                                     "source/latex/binarytree/"
                                     "tex/latex/binarytree/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lip6npfggc6p14hhpwn1g52xmyyb5rp34znb437frks4n1bk66s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/binarytree")
    (synopsis "Drawing binary trees using TikZ")
    (description
     "This package provides an easy but flexible way to draw binary trees
using TikZ.  A path specification and the setting of various options determine
the style for each edge of the tree.  There is support for the external
library of TikZ which does not affect externalization of the rest of the TikZ
figures in the document.  There is an option to use automatic file naming:
useful if the trees are often moved around.")
    (license license:lppl1.3+)))

(define-public texlive-blochsphere
  (package
    (name "texlive-blochsphere")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/blochsphere/"
                                     "source/latex/blochsphere/"
                                     "tex/latex/blochsphere/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03gl19r0cc1ajychh6f31bdjqpmmlk0cxg1akxg3h47yrf2np245"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/blochsphere")
    (synopsis "Draw pseudo-3D diagrams of Bloch spheres")
    (description
     "This package is used to draw pseudo-3D Blochsphere diagrams.  It
supports various annotations, such as great and small circles, axes, rotation
markings and state vectors.  It can be used in a standalone fashion, or nested
within a @code{tikzpicture} environment by setting the environment option
@code{nested} to @code{true}.")
    (license license:lppl1.3+)))

(define-public texlive-bloques
  (package
    (name "texlive-bloques")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bloques/" "tex/latex/bloques/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10mxqjfljcphg4nifg8xy3s6k49vxvxhs5s805640npc8jgmbf64"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bloques")
    (synopsis "Generate control diagrams")
    (description
     "The package uses TikZ to provide commands for generating control
diagrams (specially in power electronics).")
    (license license:lppl1.3+)))

(define-public texlive-blox
  (package
    (name "texlive-blox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/blox/" "source/latex/blox/"
                                     "tex/latex/blox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xkv6rvkbchkwgfam5kiymng0xnc4vja5xb3b5d89rngdr041xwk"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-etoolbox
                  texlive-fancyvrb
                  texlive-hypdoc
                  texlive-hyperref
                  texlive-infwarerr
                  texlive-kvoptions
                  texlive-pgf
                  texlive-tools))))
    (home-page "https://ctan.org/pkg/blox")
    (synopsis "Draw block diagrams, using TikZ")
    (description
     "This package, along with TikZ, will typeset block diagrams for use with
programming and control theory.  It is an English translation of the
@code{schemabloc} package.")
    (license license:lppl1.3+)))

(define-public texlive-bodegraph
  (package
    (name "texlive-bodegraph")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bodegraph/"
                                     "tex/latex/bodegraph/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p1gap8nc2l8fg14fn5xx5vnnwdnmc0whi2c37kcavgxnkji43f4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bodegraph")
    (synopsis "Draw Bode, Nyquist and Black plots with gnuplot and TikZ")
    (description
     "The package provides facilities to draw Bode, Nyquist and Black plots
using Gnuplot and Tikz.  Elementary Transfer Functions and basic correctors
are preprogrammed for use.")
    (license license:lppl)))

(define-public texlive-bondgraph
  (package
    (name "texlive-bondgraph")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bondgraph/"
                                     "tex/latex/bondgraph/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "165fgkcybazd2jqgcfqc8hh8askl1hdv86d8bz5b1s4aff95hv24"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bondgraph")
    (synopsis "Create bond graph figures in LaTeX documents")
    (description "The package draws bond graphs using PGF and TikZ.")
    (license license:lppl1.3+)))

(define-public texlive-bondgraphs
  (package
    (name "texlive-bondgraphs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bondgraphs/"
                                     "source/latex/bondgraphs/"
                                     "tex/latex/bondgraphs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gisr9f2n3mwf2qaqdj9sjmxscrpa9zrb9jm7v5l96ba8kqqw6hx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bondgraphs")
    (synopsis "Draws bond graphs in LaTeX, using PGF/TikZ")
    (description
     "The package is used to draw bond graphs in LaTeX.  Compared to the
@code{bondgraph} package this package relies more on TikZ styles and less on
macros, to generate the drawings.  As such it can be more flexible than his,
but requires more TikZ knowledge of the user.")
    (license license:lppl1.3+)))

(define-public texlive-braids
  (package
    (name "texlive-braids")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/braids/" "source/latex/braids/"
                                     "tex/latex/braids/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dn9cgnr9b7k4l3pqfkmjfpv9hq65zpnj2swbpjkjngz0f8f89yi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/braids")
    (synopsis "Draw Braid diagrams with PGF/TikZ")
    (description
     "The package enables drawing of Braid diagrams with PGF/TikZ using
a simple syntax.  The Braid itself is specified by giving a word in the Braid
group, and there are many options for styling the strands and for drawing
floors.")
    (license license:lppl1.3c)))

(define-public texlive-bxeepic
  (package
    (name "texlive-bxeepic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bxeepic/" "tex/latex/bxeepic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zxmysbnv4s47qx0yajr9h62x8azjh660811yd4qcv0ih9mcdyy7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bxeepic")
    (synopsis "Eepic facilities using @code{pict2e}")
    (description
     "The package provides an Eepic driver to use @code{pict2e} facilities.")
    (license license:expat)))

(define-public texlive-byo-twemojis
  (package
    (name "texlive-byo-twemojis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/byo-twemojis/"
                                     "source/latex/byo-twemojis/"
                                     "tex/latex/byo-twemojis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wnl6jcwrkxvzfsq04kabxanraa8zi08fjg4a1b7cqpawiphf8jp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/byo-twemojis")
    (synopsis "Build Your Own Twemojis with TikZ")
    (description
     "This package provides the means to create your own emojis (the simple,
round, and mostly yellow ones) from elements of existing emojis.  The provided
command creates a TikZ picture from the stated elements with multiple
possibilities to modify the result in color and position.")
    (license (list license:cc-by4.0 license:lppl1.3+))))

(define-public texlive-byrne
  (package
    (name "texlive-byrne")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/byrne/" "metapost/byrne/"
                                     "tex/latex/byrne/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1h4543pimjsv30phinbhs8070ymqaf43vd2wx1yhjmwsqj4fcjmc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/byrne")
    (synopsis
     "Typeset geometric proofs in the style of Euclid's @emph{Elements}")
    (description
     "This package is a LaTeX adaptation of a set of tools developed for
ConTeXt reproduction of Oliver Byrne's 1847 edition of the first six books of
Euclid's @emph{Elements}; see
@url{https://github.com/jemmybutton/byrne-euclid}.  It consists of a MetaPost
library, responsible for all the drawing and a set of LaTeX macros to
conveniently use them.")
    (license license:gpl3+)))

(define-public texlive-cachepic
  (package
    (name "texlive-cachepic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cachepic/" "scripts/cachepic/"
                                     "tex/latex/cachepic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kc713pig67igi0h294k692lmm12mx611z3v73awsf5xv14ms3yx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "cachepic.tlu")))
    (home-page "https://ctan.org/pkg/cachepic")
    (synopsis "Convert document fragments into graphics")
    (description
     "The bundle simplifies and automates conversion of document fragments
into external EPS or PDF files.  The bundle consists of two parts: a LaTeX
package that implements a document level interface, and a command line tool
that generates the external graphics.")
    (license license:lppl1.3+)))

(define-public texlive-callouts
  (package
    (name "texlive-callouts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/callouts/" "tex/latex/callouts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yb2vc1wiffap0dbq0jw40ax9kmk6np269ayij67vcmg0iqnmb11"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/callouts")
    (synopsis "Put simple annotations and notes inside a picture")
    (description
     "The package defines the @code{annotation} environment in which callouts,
notes, arrows, and the like can be placed to describe certain parts of
a picture.")
    (license license:lppl)))

(define-public texlive-celtic
  (package
    (name "texlive-celtic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/celtic/" "source/latex/celtic/"
                                     "tex/latex/celtic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zqz87y0wx5v50qnzvz6gqsz1z81ikcj4ma8mwgclrfyazpll9d0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/celtic")
    (synopsis "TikZ library for drawing celtic knots")
    (description
     "The package provides a TikZ library for drawing celtic knots.")
    (license license:lppl1.3+)))

(define-public texlive-chemfig
  (package
    (name "texlive-chemfig")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/chemfig/"
                                     "tex/generic/chemfig/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1q1kqkfw4ik89q9v2a25a644pg4h86fam9sijjb8wnxclmwlia96"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chemfig")
    (synopsis "Draw molecules with easy syntax")
    (description
     "The package provides the command @code{\\chemfig}, which draws molecules
using the TikZ package.  While the diagrams produced are essentially
2-dimensional, the package supports many of the conventional notations for
illustrating the 3-dimensional layout of a molecule.")
    (license license:lppl1.3c)))

(define-public texlive-circuit-macros
  (package
    (name "texlive-circuit-macros")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/circuit-macros/"
                                     "tex/latex/circuit-macros/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10m2zqgd7ba3gf3ix361ylxq28r904nj4zmnhp6fbz5mamqg27jz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/circuit-macros")
    (synopsis "M4 macros for electric circuit diagrams")
    (description
     "This package provides a set of m4 macros for drawing high-quality
electric circuits containing fundamental elements, amplifiers, transistors,
and basic logic gates to include in TeX, LaTeX, or similar documents.  Some
tools and examples for other types of diagrams are also included.  The macros
can be evaluated to drawing commands in the @code{pic} language, which
contains elements of a simple programming language, and is well-suited to line
drawings requiring parametric or conditional components, fine tuning,
significant geometric calculations or repetition, or that are naturally block
structured or tree structured.  Alternative output macros can create TeX
output to be read by PSTricks, TikZ commands for use by the PGF bundle, or
SVG.")
    (license license:lppl1.3c)))

(define-public texlive-circuitikz
  (package
    (name "texlive-circuitikz")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/context/third/circuitikz/"
                                     "doc/generic/circuitikz/"
                                     "doc/latex/circuitikz/"
                                     "tex/context/third/circuitikz/"
                                     "tex/generic/circuitikz/"
                                     "tex/latex/circuitikz/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ixccij17412z7bfhrf6p916a7pvlj051hxxah2zdq4b3j8asmz0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/circuitikz")
    (synopsis "Draw electrical networks with TikZ")
    (description
     "The package provides a set of macros for naturally typesetting
electrical and electronic networks.  It is designed as a tool that is native
to LaTeX, and directly supporting PDF output format.  It has therefore been
based on the PGF/TikZ package.")
    (license (list license:lppl license:gpl3+))))

(define-public texlive-coffeestains
  (package
    (name "texlive-coffeestains")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/coffeestains/"
                                     "tex/latex/coffeestains/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nc2nmxg378gg16q6gxj68w94fl3nd5lcgk2fq9hp17mg6q27gsc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/coffeestains")
    (synopsis "Add coffee stains to documents")
    (description
     "This package provides an essential feature that LaTeX has been missing
for too long: It adds coffee stains to your documents.  A lot of time can be
saved by printing stains directly on the page rather than adding them
manually.")
    (license license:public-domain)))

(define-public texlive-combinedgraphics
  (package
    (name "texlive-combinedgraphics")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/combinedgraphics/"
                                     "source/latex/combinedgraphics/"
                                     "tex/latex/combinedgraphics/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jb0bc5s8kn5aplgmry94laj92c2h16xv77km6fz0pcd4wvpng6i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/combinedgraphics")
    (synopsis "Include graphic (EPS or PDF)/LaTeX combinations")
    (description
     "This package provides the @code{\\includecombinedgraphics} macro for the
inclusion of combined EPS/LaTeX and PDF/LaTeX graphics.  Instead of including
the graphics with a simple @code{\\input}, the
@code{\\includecombinedgraphics} macro has some comforts: changing the font
and color of the text of the LaTeX part; rescaling the graphics without
affecting the font of the LaTeX part; automatic inclusion of the vector
graphics part, as far as LaTeX part does not do it; and rescaling and rotating
of complete graphics.")
    (license license:gpl3+)))

(define-public texlive-curve
  (package
    (name "texlive-curve")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/curve/" "source/latex/curve/"
                                     "tex/latex/curve/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0780i6zr24v30ixn6zcalqr2pdp5jkxk8ksfw090aaq03wpxmggg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/curve")
    (synopsis "Class for making curriculum vitae")
    (description
     "CurVe is a class for writing a CV, with configuration for the language
in which you write.  The class provides a set of commands to create rubrics,
entries in these rubrics etc.  CurVe then format the CV (possibly splitting it
onto multiple pages, repeating the titles etc), which is usually the most
painful part of CV writing.  Another nice feature of CurVe is its ability to
manage different CV flavours simultaneously.  It is often the case that you
want to maintain slightly divergent versions of your CV at the same time, in
order to emphasize on different aspects of your background.  CurVe also comes
with support for use with AUC-TeX.")
    (license license:lppl)))

(define-public texlive-curve2e
  (package
    (name "texlive-curve2e")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/curve2e/" "source/latex/curve2e/"
                                     "tex/latex/curve2e/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b7m3592qfrx6za3iz0iagbf5dw4x9d7d14nk89myjjx9wfkd6qk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/curve2e")
    (synopsis "Extensions for package @code{pict2e}")
    (description
     "The package extends the drawing capacities of the @code{pict2e} package
that serves as a LaTeX2e replacement for @code{picture} mode.  In particular,
@code{curve2e} introduces new macros for lines and vectors, new specifications
for line terminations and joins, arcs with any angular aperture, arcs with
arrows at one or both ends, generic curves specified with their nodes and the
tangent direction at these nodes.")
    (license license:lppl1.3c)))

(define-public texlive-curves
  (package
    (name "texlive-curves")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/curves/" "source/latex/curves/"
                                     "tex/latex/curves/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1diwxq6maizcnmwr6shnl044cvhnd7c2f55avgsyap6ds5wv86wn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/curves")
    (synopsis "Curves for LaTeX picture environment")
    (description
     "This package draws curves in the standard LaTeX picture environment
using parabolas between data points with continuous slope at joins; for
circles and arcs, it uses up to 16 parabolas.  The package can also draw
symbols or dash patterns along curves.  It provides facilities equivalent to
technical pens with compasses and French curves.")
    (license license:lppl1.3+)))

(define-public texlive-dcpic
  (package
    (name "texlive-dcpic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/dcpic/" "tex/generic/dcpic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1s4292g12r2vrnsdj4qsa9jgj9ndgdg7h27n2ig3mf305h5h5hfr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dcpic")
    (synopsis "Commutative diagrams in a LaTeX and TeX documents")
    (description
     "DCpic is a package for typesetting commutative diagrams within a LaTeX
and TeX documents.  Its distinguishing features are: a powerful graphical
engine, the PiCTeX package; an easy specification syntax in which
a commutative diagram is described in terms of its objects and its
arrows (morphism), positioned in a Cartesian coordinate system.")
    (license license:lppl1.3+)))

(define-public texlive-diagmac2
  (package
    (name "texlive-diagmac2")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/diagmac2/" "tex/latex/diagmac2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "002p9qmrbbkqc72iippnjhxmb7yybx06xr6bs76hg04pzvh5a49f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/diagmac2")
    (synopsis "Diagram macros, using @code{pict2e}")
    (description
     "This is a development of the long-established @code{diagmac} package,
using @code{pict2e} so that the restrictions on line direction are removed.")
    (license license:lppl)))

(define-public texlive-ditaa
  (package
    (name "texlive-ditaa")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ditaa/" "tex/latex/ditaa/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dk915p169hnpy9888kpslawhkmlipbkdrsnk1pajypcl7jyrniw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ditaa")
    (synopsis "Use ditaa diagrams within LaTeX documents")
    (description
     "With this package, @acronym{DITAA, DIagrams Through Ascii Art} diagrams
can be embedded directly into LaTeX files.")
    (license license:lppl)))

(define-public texlive-doc-pictex
  (package
    (name "texlive-doc-pictex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/doc-pictex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fdvqhkgi5j33rx0r4fifj69f4smn5w0n99vx90a3fw15qzxsg5y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/doc-pictex")
    (synopsis "Summary list of PicTeX documentation")
    (description
     "This package provides a summary of available resources providing
documentation of PicTeX.")
    (license
     (list
      (license:fsf-free "share/texmf-dist/doc/generic/doc-pictex/Doc-PiCTeX.txt")))))

(define-public texlive-dot2texi
  (package
    (name "texlive-dot2texi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dot2texi/" "tex/latex/dot2texi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m8774ds3hsky4nk0krj4a582fyznrxdfbfma5z8hp083nrlm469"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dot2texi")
    (synopsis "Create graphs within LaTeX using the @code{dot2tex} tool")
    (description
     "The @code{dot2texi} package allows you to embed graphs in the DOT graph
description language in your LaTeX documents.  The @code{dot2tex} tool is used
to invoke Graphviz for graph layout, and to transform the output from Graphviz
to LaTeX code.  The generated code relies on the TikZ and PGF package or the
PSTricks package.")
    (license license:gpl3+)))

(define-public texlive-dottex
  (package
    (name "texlive-dottex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dottex/" "source/latex/dottex/"
                                     "tex/latex/dottex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lk3ylbbgq2glni6qp6spmn8mr2qv4q1b06raadsb7hh75p1r218"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dottex")
    (synopsis "Use DOT code in LaTeX")
    (description
     "The @code{dottex} package allows you to encapsulate DOT and Neato files
in your document (DOT and Neato are both part of @code{graphviz}; DOT creates
directed graphs, Neato undirected graphs).")
    (license license:gpl3+)))

(define-public texlive-doulossil
  (package
    (name "texlive-doulossil")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/doulossil/"
                                     "fonts/truetype/public/doulossil/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0frhwpm7xzhhz83wpmlrwgz3c3bpvhm8pa0b6vkdgm8qj799irrb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/doulossil")
    (synopsis "Font for typesetting the International Phonetic Alphabet (IPA)")
    (description
     "This package provides the IPA font Doulos SIL in TrueType format.")
    (license license:silofl1.1)))

(define-public texlive-dpcircling
  (package
    (name "texlive-dpcircling")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dpcircling/"
                                     "tex/latex/dpcircling/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wpskh9rixgjvn4h5kand9ggiqa2mqca5fc0l565pxq8a9sq2bm0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dpcircling")
    (synopsis "Decorated text boxes using TikZ")
    (description
     "This simple package provides four types of text decorations using TikZ.
You can frame your text with circles, rectangles, jagged rectangles, and
fan-shapes.  The baseline will be adjusted properly according to the
surroundings.  You can use these decorations both in text mode and in math
mode.  You can specify line color, line width, width, and height using option
keys.")
    (license license:expat)))

(define-public texlive-dratex
  (package
    (name "texlive-dratex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/dratex/" "tex/generic/dratex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02qpchj2ws1d9d80284k7akzafbgdm358qxd41ms21rszyzdj11c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dratex")
    (synopsis "General drawing macros")
    (description
     "This package provides a low level (@file{DraTex.sty}) and
a high-level (@file{AlDraTex.sty}) drawing package written entirely in TeX.")
    (license license:lppl)))

(define-public texlive-drs
  (package
    (name "texlive-drs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/drs/" "tex/latex/drs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vvwbn1qxxh42v1jjvk3nra79zv0lz0fyrj5c6q8yjppn2rj10h0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/drs")
    (synopsis "Typeset Discourse Representation Structures (DRS)")
    (description
     "The package draws Discourse Representation Structures (DRSs).  It can
draw embedded DRSs, if-then conditions and quantificational duplex
conditions (with a properly scaled connecting diamond).  Formatting parameters
allow the user to control the appearance and placement of DRSs, and of DRS
variables and conditions.  The package is based on DRS macros in the
@code{covington} package.")
    (license license:lppl1.3+)))

(define-public texlive-duotenzor
  (package
    (name "texlive-duotenzor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/duotenzor/"
                                     "tex/latex/duotenzor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1l99ah5p2cp1qikk3jrbn1xrs6fz23c9h7wqc228jnrkmni7kn98"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/duotenzor")
    (synopsis "Drawing package for circuit and duotensor diagrams")
    (description
     "This is a drawing package for circuit and duotensor diagrams within
LaTeX documents.  It consists of about eighty commands, calling on TikZ for
support.")
    (license license:lppl1.3+)))

(define-public texlive-dynkin-diagrams
  (package
    (name "texlive-dynkin-diagrams")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dynkin-diagrams/"
                                     "tex/latex/dynkin-diagrams/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pymcm77bznsmkxfaq6c1rhcmxn7b1jwkyc0gwhdgfk6xhqzsbi3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dynkin-diagrams")
    (synopsis "Draw Dynkin, Coxeter, and Satake diagrams using TikZ")
    (description
     "This is a drawing package for Dynkin, Coxeter, and Satake diagrams in
LaTeX documents, using the TikZ package.")
    (license license:lppl1.3c)))

(define-public texlive-ecgdraw
  (package
    (name "texlive-ecgdraw")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ecgdraw/" "source/latex/ecgdraw/"
                                     "tex/latex/ecgdraw/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16kbmf9fckms0vhi41h2p6k8znv6plzwn4f2j374zmpqphq1m3il"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-etoolbox
                  texlive-hypdoc
                  texlive-layaureo
                  texlive-listings
                  texlive-pgf
                  texlive-tools))))
    (home-page "https://ctan.org/pkg/ecgdraw")
    (synopsis "Draws electrocardiograms (ECG)")
    (description
     "This package provides the @code{\\ECG} command, which draws
electrocardiograms (ECG).  It can generate different types of wave.")
    (license license:lppl1.3+)))

(define-public texlive-ellipse
  (package
    (name "texlive-ellipse")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ellipse/" "source/latex/ellipse/"
                                     "tex/latex/ellipse/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0biya15r55hr41vnqsviqqsqlb7p47i2n814dahfs0r65vlfnz23"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ellipse")
    (synopsis
     "Draw ellipses and elliptical arcs using @code{picture} environment")
    (description
     "This package provides commands to draw ellipses and elliptical arcs
using the standard LaTeX2e @code{picture} environment.")
    (license license:lppl1.3+)))

(define-public texlive-elocalloc
  (package
    (name "texlive-elocalloc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/elocalloc/"
                                     "source/latex/elocalloc/"
                                     "tex/latex/elocalloc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "121hpnka88y6laayjbhgiphbqn8qv42024bjda21qcc076s4b632"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/elocalloc")
    (synopsis "Local allocation macros for LaTeX 2015")
    (description
     "This package provides local allocation macros, with names taken from
@file{etex.sty} but with implementation based on the LaTeX 2015 allocation
macros.")
    (license license:lppl)))

(define-public texlive-endofproofwd
  (package
    (name "texlive-endofproofwd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/endofproofwd/"
                                     "tex/latex/endofproofwd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a88q6h266c1cbxp5gdjz0d56gwdmshavvr4b2bn3xikzlvf7yij"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/endofproofwd")
    (synopsis "End of proof sign")
    (description
     "This package provides an additional end of proof sign.  The command's
name is @code{\\wasserdicht}.")
    (license license:lppl1.3+)))

(define-public texlive-epspdfconversion
  (package
    (name "texlive-epspdfconversion")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/epspdfconversion/"
                                     "tex/latex/epspdfconversion/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1czh9ppkgk9lxw4imagnwm4b88vylr4vwhzb1k63ik749h047kg2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/epspdfconversion")
    (synopsis "On-the-fly conversion of EPS to PDF")
    (description
     "The package calls the @code{epstopdf} package to convert EPS graphics to
PDF, on the fly.  It serves as a vehicle for passing conversion options (such
as grayscale, prepress or pdfversion) to the @code{epspdf} converter.")
    (license license:lppl)))

(define-public texlive-esk
  (package
    (name "texlive-esk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/esk/" "source/latex/esk/"
                                     "tex/latex/esk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hx58ajinbfc6axd4xbj395vyhr7mj247fvlzfjx71hcg9jnwkp4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/esk")
    (synopsis "Package to encapsulate Sketch files in LaTeX sources")
    (description
     "The ESK package allows encapsulating Sketch files in LaTeX sources.
This is very useful for keeping illustrations synchronized with the text.  It
also frees the user from inventing descriptive names for new files that fit
into the confines of file system conventions.  Sketch is a 3D scene
description language by Eugene K. Ressler and can generate TikZ and PSTricks
code.  ESK behaves in a similar fashion to EMP (which encapsulates MetaPost
files), and was in fact developed from it.")
    (license license:gpl3+)))

(define-public texlive-euflag
  (package
    (name "texlive-euflag")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/euflag/" "source/latex/euflag/"
                                     "tex/latex/euflag/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dhbz79grhdls4cl7idk0hvr6vddniwgn1h21f5bvxqcv1xj0d8v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/euflag")
    (synopsis "Command to reproduce the flag of the European Union")
    (description
     "This LaTeX package implements a command to reproduce the official flag
of the European Union (EU).  The flag is reproduced at 1em high based on the
current font size, so it can be scaled arbitrarily by changing the font
size.")
    (license license:lppl1.3c)))

(define-public texlive-fast-diagram
  (package
    (name "texlive-fast-diagram")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fast-diagram/"
                                     "tex/latex/fast-diagram/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03ygmgh6gnlkn7dwnwyifv946ja6yswm3gdgv7ad39h5s0ay99hy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fast-diagram")
    (synopsis "Easy generation of FAST diagrams")
    (description
     "The package provides simple means of producing FAST diagrams, using
TikZ/PGF tools.  FAST diagrams are useful for functional analysis techniques
in design methods.")
    (license license:lppl1.3+)))

(define-public texlive-fig4latex
  (package
    (name "texlive-fig4latex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/fig4latex/"
                                     "scripts/fig4latex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0z4dnd369q1ynpb3xd4pwyhmysn78zx8izq7va1s5kpwdr2hdj99"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts #~(list "fig4latex")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/fig4latex")
    (synopsis "Management of figures for large LaTeX documents")
    (description
     "Fig4LaTeX simplifies management of the figures in a large LaTeX document.
Fig4LaTeX is appropriate for projects that include figures with graphics
created by XFig --- in particular, graphics which use the combined
PS/LaTeX (or PDF/LaTeX) export method.")
    (license license:gpl3)))

(define-public texlive-figchild
  (package
    (name "texlive-figchild")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/figchild/" "tex/latex/figchild/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1q02q8cpkjwjqlykjq64vm65shqm6bn281j2jsv7qnay19lqmd3n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/figchild")
    (synopsis "Pictures for creating children's activities")
    (description
     "This package was created with the aim of facilitating the work of
Elementary School teachers who need to create colorful and attractive
activities for their students.  It is a product of the Computational
Mathematics discipline offered at the Federal University of Vicosa --- Campus
UFV --- Florestal by professor Fernando de Souza Bastos.  It makes use of the
TikZ and @code{xcolor} packages.")
    (license license:lppl1.3c)))

(define-public texlive-figput
  (package
    (name "texlive-figput")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/figput/" "tex/latex/figput/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ckwbrsl5075902pmmjp1r3n31pdpbqvydh69vq6mkfwk3ipp4gj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/figput")
    (synopsis "Create interactive figures in LaTeX")
    (description
     "FigPut allows figures to be specified using JavaScript.  The resulting
document can be viewed as a static PDF, as usual, or the document can be
viewed in a web-browser, in which case the figures are interactive.  A variety
of interactive widgets are included.")
    (license license:cc-by-sa4.0)))

(define-public texlive-fitbox
  (package
    (name "texlive-fitbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fitbox/" "source/latex/fitbox/"
                                     "tex/latex/fitbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0li1nvwv8ifw1dkfsqgnhapkagndibs75lp03byxnwrmc99r7a2y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fitbox")
    (synopsis "Fit graphics on a page")
    (description
     "The package allows a box (usually an @code{\\includegraphics} box) to
fit on the page.  It scales the box to the maximal allowed size within the
user-set limits.  If there is not enough space on the page, the box is moved
to the next one.")
    (license license:lppl1.3+)))

(define-public texlive-flowchart
  (package
    (name "texlive-flowchart")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/flowchart/"
                                     "source/latex/flowchart/"
                                     "tex/latex/flowchart/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r0n7wr7ljhlvyhmm7f85h1c5imj9iqy7afv4mjy1ychcaws233w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/flowchart")
    (synopsis "Shapes for drawing flowcharts, using TikZ")
    (description
     "The package provides a set of traditional flowchart element shapes; the
documentation shows how to build a flowchart from these elements, using
PGF/TikZ.")
    (license license:lppl1.3+)))

(define-public texlive-forest
  (package
    (name "texlive-forest")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/forest/" "makeindex/forest/"
                                     "source/latex/forest/" "tex/latex/forest/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00zyxfi59kglnby7l24l1bz08afv7r9qc1wifcxrb6s5xygj42zs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-elocalloc
           texlive-environ
           texlive-etoolbox
           texlive-inlinedef
           texlive-l3packages
           texlive-pgf
           texlive-pgfopts))
    (home-page "https://ctan.org/pkg/forest")
    (synopsis "Drawing (linguistic) trees")
    (description
     "The package provides a PGF/TikZ-based mechanism for drawing
linguistic (and other kinds of) trees.  Its main features are: a packing
algorithm which can produce very compact trees; a user-friendly interface
consisting of the familiar bracket encoding of trees plus the key-value
interface to option-setting; many tree-formatting options, with control over
option values of individual nodes and mechanisms for their manipulation; the
possibility to decorate the tree using the full power of PGF/TikZ; and an
externalization mechanism sensitive to code-changes.")
    (license license:lppl1.3+)))

(define-public texlive-gates
  (package
    (name "texlive-gates")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/gates/" "tex/generic/gates/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0brcms8qbnsyiqnnqxyzqp12z1xpvfzb5hgh6kqm28904lr84i4g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gates")
    (synopsis "Support for writing modular and customisable code")
    (description
     "The package provides the means of writing code in a modular fashion: big
macros or functions are divided into small chunks (called gates) with names,
which can be externally controlled (e.g., they can be disabled, subjected to
conditionals, loops...) and/or augmented with new chunks.  Thus complex code
may easily be customised without having to rewrite it, or even understand its
implementation: the behavior of existing gates can be modified, and new ones
can be added, without endangering the whole design.  This allows code to be
hacked in ways the original authors might have never envisioned.  The
@code{gates} package is implemented independently for both TeX and Lua.  The
TeX implementation, running in any current environment, requires the
@code{texapi} package, whereas the Lua version can be run with any Lua
interpreter, not just LuaTeX.")
    (license license:lppl)))

(define-public texlive-genealogytree
  (package
    (name "texlive-genealogytree")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/genealogytree/"
                                     "tex/latex/genealogytree/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10h12qgjrh37ax1grpkyas5blf3s4g6bfp6g5d9x7y1ddfpxjmix"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/genealogytree")
    (synopsis "Pedigree and genealogical tree diagrams")
    (description
     "Pedigree and genealogical tree diagrams are proven tools to visualize
genetic and relational connections between individuals.  The package provides
a set of tools to typeset genealogical trees, i.e., to typeset a set of
special graphs for the description of family-like structures.  The package
uses an autolayout algorithm which can be customized, e.g., to prioritize
certain paths.")
    (license license:lppl1.3+)))


(define-public texlive-getmap
  (package
    (name "texlive-getmap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/getmap/" "scripts/getmap/"
                                     "tex/latex/getmap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12pip7a1pibjlbllkrbz0fss0i5zdd8x1pbvzzbwn6rb3ragqwl9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts #~(list "getmapdl.lua")))
    (home-page "https://ctan.org/pkg/getmap")
    (synopsis "Download OpenStreetMap maps for use in documents")
    (description
     "The package provides a simple interface to OpenStreetMap, and to Google
Maps, map images.  In the simplest case, it is sufficient to specify the
address you need.  The package loads the map image using an external Lua
script (LaTeX must be running with @samp{\\write 18} enabled).  The Lua script
may be used from the command line; a Bash version is provided.")
    (license license:lppl)))

(define-public texlive-gnuplottex
  (package
    (name "texlive-gnuplottex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gnuplottex/"
                                     "source/latex/gnuplottex/"
                                     "tex/latex/gnuplottex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c99xc24bqp0j1xy31ayna4xmdsyshs9fjarb8cmn4m3ffwvlrmw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gnuplottex")
    (synopsis "Embed Gnuplot commands in LaTeX documents")
    (description
     "This package allows you to include Gnuplot graphs in your LaTeX
documents.  The Gnuplot code is extracted from the document and written to
@file{.gnuplot} files.  Then, if shell escape is used, the graph files are
automatically processed to graphics or LaTeX code files which will then be
included in the document.  If shell escape isn't used, the user will have to
manually convert the files by running Gnuplot on the extracted @file{.gnuplot}
files.")
    (license license:gpl2)))

(define-public texlive-gradientframe
  (package
    (name "texlive-gradientframe")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gradientframe/"
                                     "source/latex/gradientframe/"
                                     "tex/latex/gradientframe/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qy3ri6fdgzdslaaa7gakswvpc299xyarm8ng4cs8w64q14675r1"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-charter
                  texlive-emp
                  texlive-etoolbox
                  texlive-hypdoc
                  texlive-listings
                  texlive-tools))))
    (home-page "https://ctan.org/pkg/gradientframe")
    (synopsis "Simple gradient frames around objects")
    (description
     "The package provides a means of drawing graded frames around objects.
The gradients of the frames are drawn using the @code{color} package.")
    (license license:lppl1.3+)))

(define-public texlive-grafcet
  (package
    (name "texlive-grafcet")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/grafcet/" "tex/latex/grafcet/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1swrap90i4l3a6azvy40b991zkqvyfw2z3mk6cq727yplmr1hkwk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/grafcet")
    (synopsis "Draw Grafcet/SFC with TikZ")
    (description
     "The package provides a library (GRAFCET) that can draw Grafcet
Sequential Function Chart (SFC) diagrams, in accordance with EN 60848, using
PGF/TikZ.")
    (license license:lppl1.0+)))

(define-public texlive-graph35
  (package
    (name "texlive-graph35")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/graph35/" "source/latex/graph35/"
                                     "tex/latex/graph35/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "048ywdw2d1mif2m4vjyjma5b8zz4w4kq71q4x2adwckqnqkcxn5a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/graph35")
    (synopsis "Draw keys and screen items of several Casio calculators")
    (description
     "This package defines commands to draw the Casio Graph 35 / Fx-9750GII
calculator (and other models).  It can draw the whole calculator, or parts of
it.")
    (license license:lppl1.3+)))

(define-public texlive-graphicxpsd
  (package
    (name "texlive-graphicxpsd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/graphicxpsd/"
                                     "tex/latex/graphicxpsd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04fll1h90rl75bqbkhjp2yp8bragfkv5rj2kwrbbi6p7zq9nfrpn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/graphicxpsd")
    (synopsis
     "Adobe Photoshop Data format (PSD) support for @code{graphicx} package")
    (description
     "This package provides Adobe Photoshop Data format (PSD) support for the
@code{graphicx} package with the @command{convert} command from ImageMagick.")
    (license license:expat)))

(define-public texlive-graphviz
  (package
    (name "texlive-graphviz")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/graphviz/"
                                     "source/latex/graphviz/"
                                     "tex/latex/graphviz/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0abg1cmzr449gd5pbg3ppgf35xixjyszy3jxnrg37kqly7c26l6s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/graphviz")
    (synopsis "Write Graphviz inline in LaTeX documents")
    (description
     "The package allows inline use of Graphviz code, in a LaTeX document.")
    (license license:lppl1.3+)))

(define-public texlive-gtrlib-largetrees
  (package
    (name "texlive-gtrlib-largetrees")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gtrlib-largetrees/"
                                     "source/latex/gtrlib-largetrees/"
                                     "tex/latex/gtrlib-largetrees/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yfc18v919brdj6psah8q9hsjpqs8zalnz3ridrhgir98x0l8wq9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gtrlib-largetrees")
    (synopsis "Library for genealogytree aiming at large trees")
    (description
     "The main goal of this package is to offer additional database fields and
formats for the @code{genealogytree} package, particularly for typesetting
large trees.")
    (license license:lppl1.2+)))

(define-public texlive-harveyballs
  (package
    (name "texlive-harveyballs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/harveyballs/"
                                     "tex/latex/harveyballs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15zng922zyc0jiq8yrdgl3gwj1gvdqk71zc1bcc8gl08j4y0cxgi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/harveyballs")
    (synopsis "Create Harvey Balls using TikZ")
    (description
     "The package provides five commands to create Harvey Balls in
a document.")
    (license license:gpl3+)))

(define-public texlive-here
  (package
    (name "texlive-here")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/here/" "tex/latex/here/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pmjh9xvwmv6cf775lzfagf9wziwrgx6fri4jjhl4mzkxmxhsnpp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/here")
    (synopsis "Emulation of obsolete package for @code{here} floats")
    (description
     "This package provides the @samp{H} option for floats in LaTeX to signify
that the environment is not really a float, and should therefore be placed
@emph{here} and not float at all.  The package emulates an older package of
the same name, which has long been suppressed by its author.  The job is done
by nothing more than loading the @code{float} package, which has long provided
the option in an acceptable framework.")
    (license license:public-domain)))

(define-public texlive-hf-tikz
  (package
    (name "texlive-hf-tikz")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hf-tikz/" "source/latex/hf-tikz/"
                                     "tex/latex/hf-tikz/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02zkax3k50rb080yn5bwy12680y0mdzddv9an3wgsycl9ycxrmi8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hf-tikz")
    (synopsis "Highlight formulas and formula parts")
    (description
     "The package provides a way to highlight formulas and formula parts in
both documents and presentations, us TikZ.")
    (license license:lppl1.3+)))

(define-public texlive-hobby
  (package
    (name "texlive-hobby")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hobby/" "source/latex/hobby/"
                                     "tex/latex/hobby/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1czyi3wiypzr6j564zn36g8svwvx74fq4jrri6qxhh92k4dvdxjl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hobby")
    (synopsis "Implementation of Hobby's algorithm for PGF/TikZ")
    (description
     "This package defines a path generation function for PGF/TikZ which
implements Hobby's algorithm for a path built out of Bezier curves which
passes through a given set of points.")
    (license license:lppl1.3+)))

(define-public texlive-hvfloat
  (package
    (name "texlive-hvfloat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hvfloat/" "tex/latex/hvfloat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vh9hj03hg9rddbv3p2yp9pcmz72zf40m3nm97zhnki9rs4rwy3i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hvfloat")
    (synopsis "Controlling captions, fullpage and doublepage floats")
    (description
     "This package defines a macro to place objects (tables and figures) and
their captions in different positions with different rotating angles within
a float.  All objects and captions can be framed.")
    (license license:lppl)))

(define-public texlive-inlinedef
  (package
    (name "texlive-inlinedef")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/inlinedef/"
                                     "source/latex/inlinedef/"
                                     "tex/latex/inlinedef/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ys2pb8dmgg41nwh9r9qhmxlfw5wxrfwryvdx1ppab4ndi138baw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/inlinedef")
    (synopsis "Inline expansions within definitions")
    (description
     "The package provides a macro @code{\\Inline} that precedes
a @code{\\def} or @code{\\gdef}.  Within the definition text of an inlined
definition, keywords such as @code{\\Expand} may be used to selectively inline
certain expansions at definition-time.  This eases the process of redefining
macros in terms of the original definition, as well as definitions in which
the token that must be expanded is deep within, where @code{\\expandafter}
would be difficult and @code{\\edef} is not suitable.  Another application is
as an easier version of @code{\\aftergroup}, by defining a macro in terms of
expanded local variables, then ending the group with
@code{\\expandafter\\endgroup\\macro}.")
    (license license:lppl)))

(define-public texlive-istgame
  (package
    (name "texlive-istgame")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/istgame/" "tex/latex/istgame/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00hpr45s31bhvhhzmgm49knjb8jb3v53gd0w87rlx9ghll38lg0m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/istgame")
    (synopsis "Draw game trees with TikZ")
    (description
     "This LaTeX package provides macros based on TikZ to draw a game tree.
The main idea underlying its core macros is the completion of a whole tree by
using a sequence of simple parent-child tree structures, with no longer nested
relations involved (like the use of grandchildren or great-grandchildren).
Using this package you can draw a game tree as easily as drawing a game tree
with pen and paper.")
    (license license:lppl1.3c)))

(define-public texlive-kblocks
  (package
    (name "texlive-kblocks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/kblocks/" "tex/latex/kblocks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0x85k295bxn4b3i083qmfvjvz2nqrh1r4r6njn491lgsfymyc0pq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/kblocks")
    (synopsis "Easily typeset control block diagrams and signal flow graphs")
    (description
     "Kblocks defines a number of commands to make drawing control block
diagrams using TikZ/PGF more structured and easier.  It reduces the learning
curve for TikZ/PGF and serves as a frontend, by focusing on the block or flow
diagrams only.")
    (license license:expat)))

(define-public texlive-kinematikz
  (package
    (name "texlive-kinematikz")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/kinematikz/"
                                     "tex/latex/kinematikz/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cg1s59xq8dkfzhnf9mh2lgyrwnlwgpqf1wjwqqnscvds85s52l2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/kinematikz")
    (synopsis "Design kinematic chains and mechanisms")
    (description
     "This package provides functionalities to draw kinematic diagrams for
mechanisms using dedicate symbols (some from the ISO standard and others).
The intention is not to represent CAD mechanical drawings of mechanisms and
robots, but only to represent 2D and 3D kinematic chains.  The package
provides links, joints and other symbols, mostly in the form of TikZ pic
objects.  These pictures can be placed in the canvas either by a central point
for joints, and start and end points for some links.")
    (license (list license:lppl1.3+ license:gpl3+))))

(define-public texlive-knitting
  (package
    (name "texlive-knitting")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/knitting/"
                                     "fonts/afm/public/knitting/"
                                     "fonts/map/dvips/knitting/"
                                     "fonts/source/public/knitting/"
                                     "fonts/tfm/public/knitting/"
                                     "fonts/type1/public/knitting/"
                                     "tex/latex/knitting/"
                                     "tex/plain/knitting/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "106p9wx4zdkz609kxsyk4zjdb0zvhnwihlnrqd1wh2p5ij7mv7vx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/knitting")
    (synopsis "Produce knitting charts, in Plain TeX or LaTeX")
    (description
     "The package provides symbol fonts and commands to write charted
instructions for cable and lace knitting patterns, using either plain TeX or
LaTeX.  The fonts are available both as Metafont source and in Adobe Type
1 format.")
    (license license:lppl1.3+)))

(define-public texlive-knittingpattern
  (package
    (name "texlive-knittingpattern")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/knittingpattern/"
                                     "tex/latex/knittingpattern/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q52213yj08bhhgwr622ss3gwhx3l1yvgv0a2g3arhp3a8iq2g9a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/knittingpattern")
    (synopsis "Create knitting patterns")
    (description
     "The class provides a simple, effective method for knitters to produce
high-quality, attractive patterns using LaTeX.  It does this by providing
commands to handle as much of the layout of the document as possible, leaving
the author free to concentrate on the pattern.")
    (license license:lppl1.3+)))

(define-public texlive-ladder
  (package
    (name "texlive-ladder")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ladder/" "tex/latex/ladder/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wm0c75g6k8pb9kqdbw7rmbhs9sjdq8pn01nsaxfv2zqxnbc1znz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ladder")
    (synopsis "Draw simple ladder diagrams using TikZ")
    (description
     "This package permits the creation of simple ladder diagrams within LaTeX
documents.")
    (license license:expat)))

(define-public texlive-qrcode
  (package
    (name "texlive-qrcode")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/qrcode/" "source/latex/qrcode/"
                                     "tex/latex/qrcode/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "197v18lsvb90i07gxvc6mrmn1z63q8v0wvcnbk8dnn3hhabpn16y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/qrcode")
    (synopsis "QR codes without external tools")
    (description
     "The package generates QR (Quick Response) codes in LaTeX, without the
need for PSTricks or any other graphical package.")
    (license license:lppl1.3c+)))

(define-public texlive-tcolorbox
  (package
    (name "texlive-tcolorbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tcolorbox/" "tex/latex/tcolorbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nzhi7nw1lmck5l6iwgr6iaqk36ivqpw1dwgjlv1zg7ywhza9a0c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tcolorbox")
    (synopsis "Coloured boxes, for LaTeX examples and theorems, etc")
    (description
     "This package provides an environment for coloured and framed text boxes
with a heading line.  Optionally, such a box may be split in an upper and
a lower part; thus the package may be used for the setting of LaTeX examples
where one part of the box displays the source code and the other part shows
the output.  Another common use case is the setting of theorems.  The package
supports saving and reuse of source code and text parts.")
    (license license:lppl1.3c+)))

(define-public texlive-ebproof
  (package
    (name "texlive-ebproof")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ebproof/" "source/latex/ebproof/"
                                     "tex/latex/ebproof/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a3203jgxsgihfgb6wwm0gfpaxbf1lg5axcakan9rj316xrrj4lc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ebproof")
    (synopsis "Formal proofs in the style of sequent calculus")
    (description
     "This package provides commands to typeset proof trees in the style of
sequent calculus and related systems.  The commands allow for writing
inferences with any number of premises and alignment of successive formulas on
an arbitrary point.  Various options allow complete control over spacing,
styles of inference rules, placement of labels, etc.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-ebproof texlive-ebproof)

(define-public texlive-bussproofs
  (package
    (name "texlive-bussproofs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bussproofs/"
                                     "tex/latex/bussproofs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gb8y9g89fqw1kix4d2vb7mj440vlb8hnpsa3jqpk9yicndwcyk6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bussproofs")
    (synopsis "Proof trees in the style of the sequent calculus")
    (description
     "This package provides commands to typeset proof trees in the style of
sequent calculus and related systems.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-bussproofs texlive-bussproofs)

(define-public texlive-euenc
  (package
    (name "texlive-euenc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/euenc/" "source/latex/euenc/"
                                     "tex/latex/euenc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vhqxhj1v68rhi08xivps8icxmlcq9mv8slqmsmf2qhvzj6x6qx3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     ;; Sole ".dtx" file bundled only generates documentation.
     (list #:build-targets #~(list)))
    (home-page "https://ctan.org/pkg/euenc")
    (synopsis "Unicode font encoding definitions for XeTeX")
    (description
     "The package provides font encoding definitions for unicode fonts loaded
by LaTeX in XeTeX or LuaTeX.  The package provides two encodings: EU1,
designed for use with XeTeX, which the fontspec uses for unicode fonts which
require no macro-level processing for accents, and EU2, which provides the
same facilities for use with LuaTeX.  Neither encoding places any restriction
on the glyphs provided by a font; use of EU2 causes the package
@code{euxunicode} to be loaded (the package is part of this distribution).
The package includes font definition files for use with the Latin Modern
OpenType fonts.")
    (license license:lppl1.3+)))

(define-public texlive-euro
  (package
    (name "texlive-euro")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/euro/" "source/latex/euro/"
                                     "tex/latex/euro/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bmswsw4clzrrgxmk473ghsdbnw6zwa2rgbjs32i1i5c37026yfi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/euro")
    (synopsis "Provide Euro values for national currency amounts")
    (description
     "This package converts arbitrary national currency amounts using the Euro
as base unit, and typesets monetary amounts in almost any desired way.
Conversion rates for the initial Euro-zone countries are already built-in.
Further rates can be added easily.")
    (license license:lppl)))

(define-public texlive-euro-ce
  (package
    (name "texlive-euro-ce")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/euro-ce/"
                                     "fonts/source/public/euro-ce/"
                                     "fonts/tfm/public/euro-ce/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vyh6ln2wdn42g5r1rg0gqf6q39ny7ldv2b6ikw8b029bdg5079p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/euro-ce")
    (synopsis "Euro and CE sign font")
    (description
     "This package provides Metafont source for the Euro and CE symbols in
several variants, designed to fit with the Computer Modern-set text.")
    (license license:bsd-3)))           ;from "euro-ce.doc"

(define-public texlive-eurosym
  (package
    (name "texlive-eurosym")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/eurosym/"
                                     "fonts/map/dvips/eurosym/"
                                     "fonts/source/public/eurosym/"
                                     "fonts/tfm/public/eurosym/"
                                     "fonts/type1/public/eurosym/"
                                     "tex/latex/eurosym/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ml24rxbl1yir4s3fjjxm0z7axklc3p33syg41b76zc7hck9mk8s"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-cm")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-cm texlive-metafont))
    (home-page "https://ctan.org/pkg/eurosym")
    (synopsis "Metafont and macros for Euro sign")
    (description
     "The European currency symbol for the Euro implemented in Metafont, using
the official European Commission dimensions, and providing several
shapes (normal, slanted, bold, outline).  The package also includes a LaTeX
package which defines the macro, pre-compiled @file{tfm} files, and
documentation.")
    (license (license:non-copyleft "file:///doc/fonts/eurosym/COPYING"))))

(define-public texlive-kanaparser
  (package
    (name "texlive-kanaparser")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/kanaparser/"
                                     "tex/luatex/kanaparser/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bcvxkdb2y60w7c0swi3f8yncli0yswalrdzxjv7h0xp21c202hp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/kanaparser")
    (synopsis "Kana parser for LuaTeX")
    (description
     "The package provides a kana parser for LuaTeX.  It is a set of four
macros that handle transliteration of text: from hiragana and katakana to
Latin from Latin and katakana to hiragana from Latin and hiragana to katakana
It can be used to write kana directly using only the ASCII character set or
for education purposes.  The package has support for obsolete and rarely used
syllables, some only accessible via the provided toggle macro.")
    ;; License is BSD.  Assuming original BSD-4.
    (license license:bsd-4)))

(define-public texlive-kastrup
  (package
    (name "texlive-kastrup")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/kastrup/"
                                     "source/generic/kastrup/"
                                     "tex/generic/kastrup/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sbf4xw1jsh9pbjhqw3f0bg067f0rhf936wfnqpzj9kp2167n41j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/binhex")
    (synopsis "Convert numbers into binary, octal and hexadecimal")
    (description
     "The @code{kastrup} package provides the @emph{binhex.tex} file.  This
file provides expandable macros for both fixed-width and minimum-width numbers
to bases 2, 4, 8 and 16.  All constructs TeX accepts as arguments to its
@code{\\number} primitive are valid as arguments for the macros.  The package
may be used under LaTeX and plain TeX.")
    (license (license:fsf-free "file:/binhex.dtx"))))

(define-public texlive-translation-arsclassica-de
  (package
    (name "texlive-translation-arsclassica-de")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/translation-arsclassica-de/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ix5lafy3ay2bc9zkkbqw2rrw6ng3izb8d9p6rki6h2j7n0qj47s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/translation-arsclassica-de")
    (synopsis "German version of @code{arsclassica}")
    (description
     "This is a German translation of the @code{arsclassica} documentation.")
    (license license:lppl)))

(define-public texlive-translation-biblatex-de
  (package
    (name "texlive-translation-biblatex-de")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/translation-biblatex-de/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ygbz7prjg6pdiqm7lknnk8a9ar05xvpdam38piivif3d3yk5bg1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/translation-biblatex-de")
    (synopsis "German translation of the User Guide for BibLaTeX")
    (description
     "This package provides a German translation of the User Guide for
BibLaTeX.")
    (license license:lppl)))

(define-public texlive-translation-chemsym-de
  (package
    (name "texlive-translation-chemsym-de")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/translation-chemsym-de/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01liazqafs3lh9ppipw6i6sljcjzr31nq70r83qgknqmb9j0yfl0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/translation-chemsym-de")
    (synopsis "German version of @code{chemsym}")
    (description
     "This is a German translation of the @code{chemsym} documentation.")
    (license license:lppl)))

(define-public texlive-translation-ecv-de
  (package
    (name "texlive-translation-ecv-de")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/translation-ecv-de/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06b4vhsgdphi6kdh5x4a2kl74b64z3y5qzxcpkn0hj40038z1av7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/translation-ecv-de")
    (synopsis "@code{ecv} documentation, in German")
    (description "This is a German translation of the @code{ecv} documentation.")
    (license license:lppl)))

(define-public texlive-translation-enumitem-de
  (package
    (name "texlive-translation-enumitem-de")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/translation-enumitem-de/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "121raikamd33gabvbgwygrc8hyi3qhvx4hhv4h8wq2chrglj37dq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/translation-enumitem-de")
    (synopsis "@code{enumitem} documentation, in German")
    (description
     "This is a German translation of the manual for @code{enumitem}.")
    (license license:lppl)))

(define-public texlive-translation-europecv-de
  (package
    (name "texlive-translation-europecv-de")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/translation-europecv-de/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0n3x8g6k3qq3f4drkhzygz4khxyw6isgxmz963xqp91s0y667gws"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/translation-europecv-de")
    (synopsis "German version of @code{europecv}")
    (description
     "This is a German translation of the @code{europecv} documentation.")
    (license license:lppl)))

(define-public texlive-translation-filecontents-de
  (package
    (name "texlive-translation-filecontents-de")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/translation-filecontents-de/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d2ds8kc98yd1can0gzcngm7gsn2gwhriaxnnds5kz3z3al71gkc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/translation-filecontents-de")
    (synopsis "German version of @code{filecontents}")
    (description
     "This is a German translation of the @code{filecontents} documentation.")
    (license license:lppl)))

(define-public texlive-translation-moreverb-de
  (package
    (name "texlive-translation-moreverb-de")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/translation-moreverb-de/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jbpmvcm9q73kh09mhrbsb2wlycwwm4n8il342hz4jd15gwhmy8f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/translation-moreverb-de")
    (synopsis "German version of @code{moreverb}")
    (description
     "This is a German translation of the @code{moreverb} documentation.")
    (license license:lppl)))

(define-public texlive-translations
  (package
    (name "texlive-translations")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/translations/"
                                     "tex/latex/translations/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16jcpb6afjqcqb8hn47dip2w7l9hg7q1vspg791sp1r1dsn81yf4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/translations")
    (synopsis "Internationalisation of LaTeX2e packages")
    (description
     ;; Polish not mentioned on CTAN, but there is a
     ;; translations-basic-dictionary-polish.trsl file.
     "This package (once part of the @code{exsheets} package), provides a
framework for providing multilingual features to a LaTeX package.  The package
has its own basic dictionaries for English, Brazilian, Catalan, Dutch, French,
German, Polish and Spanish.  It aims to use translation material for English,
Dutch, French, German, Italian, Spanish, Catalan, Turkish, Croatian, Hungarian,
Danish and Portuguese from babel or polyglossia if either is in use in the
document.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-translations texlive-translations)

(define-public texlive-translator
  (package
    (name "texlive-translator")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/translator/"
                                     "tex/latex/translator/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vmg4w5spl98y9r4h6p89xa43xxfqmv5qlc3sf7kjkyp58px8axs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/translator")
    (synopsis "Easy translation of strings in LaTeX")
    (description
     "This LaTeX package provides a flexible mechanism for translating
individual words into different languages.  Such a translation mechanism is
useful when the author of some package would like to localize the package such
that texts are correctly translated into the language preferred by the user.
This package is not intended to be used to automatically translate more than
a few words.")
    (license (list license:lppl license:gpl1+))))

(define-public texlive-texapi
  (package
    (name "texlive-texapi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/texapi/" "tex/generic/texapi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ivg2a2pgl6bmb2242cjjcz7n9cs514dp1r8c89mva2zlm9l323j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/texapi")
    (synopsis "Macros to write format-independent packages")
    (description
     "Texapi provides utility macros to write format-independent (and -aware)
packages.  It is similar in spirit to the etoolbox, except that it isn't tied
to LaTeX.  The tools include engine and format detection, expansion control,
command definition and manipulation, various testing macros, string
operations, and highly customizable while and for loops.")
    (license license:lppl)))

(define-public texlive-textpos
  (package
    (name "texlive-textpos")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/textpos/" "source/latex/textpos/"
                                     "tex/latex/textpos/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0spxbk9w69kcmgib33nq2x7ls8566fg214rcmkb126yyn7jqg567"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/textpos")
    (synopsis "Place boxes at arbitrary positions on the LaTeX page")
    (description
     "This package provides a package to facilitate placement of boxes at
absolute positions on the LaTeX page.  There are several reasons why this
might be useful, an important one being to help the creation of large-format
conference posters.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-textpos texlive-textpos)

(define-public texlive-udesoftec
  (package
    (name "texlive-udesoftec")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/udesoftec/"
                                     "doc/latex/udesoftec/"
                                     "source/latex/udesoftec/"
                                     "tex/latex/udesoftec/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02ja6n570hc1521anr12lkgc5xrcfg97lxca2pylwgi5bfkbsr0b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/udesoftec")
    (synopsis "Thesis class for the University of Duisburg-Essen")
    (description
     "The class is designed for typesetting theses in the Research Group for
Business Informatics and Software Engineering.  (The class may also serve as
a template for such theses.)  The class is designed for use with pdfLaTeX;
input in UTF-8 encoding is assumed.")
    (license license:lppl1.3+)))

(define-public texlive-uhc
  (package
    (name "texlive-uhc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/uhc/umj/"
                                     "dvips/uhc/"
                                     "fonts/afm/uhc/umj/"
                                     "fonts/map/dvips/uhc/"
                                     "fonts/tfm/uhc/umj/"
                                     "fonts/tfm/uhc/uwmj/"
                                     "fonts/tfm/uhc/wmj/"
                                     "fonts/type1/uhc/umj/"
                                     "fonts/vf/uhc/uwmj/"
                                     "fonts/vf/uhc/wmj/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hpqdzmz4xrcgk443lysif8yk52rbra8rh6cjjfr4kibyfpy77p3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uhc")
    (synopsis "Fonts for the Korean language")
    (description
     "This package provides support for Korean documents written in Korean
standard KSC codes for LaTeX2e.")
    (license license:lppl)))

(define-public texlive-uhrzeit
  (package
    (name "texlive-uhrzeit")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uhrzeit/" "tex/latex/uhrzeit/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18qms6ych9q8bras2ajkl4z3dmnrp07gpzizywz206c3i1any3rc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uhrzeit")
    (synopsis "Time printing, in German")
    (description
     "The primary goal of this package is to facilitate formats and ranges of
times as formerly used in Germany.  A variety of printing formats are
available.")
    (license license:lppl1.3+)))

(define-public texlive-umlaute
  (package
    (name "texlive-umlaute")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/umlaute/" "source/latex/umlaute/"
                                     "tex/latex/umlaute/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fz2v0p8a46car0iga8m0si7ampff8hqpsmc9v2miqqzmdlqcqcj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/umlaute")
    (synopsis "German input encodings in LaTeX")
    (description
     "This is an early package for using alternate input encodings.  The
author considers the package mostly obsolete, since most of its functions are
taken by the @code{inputenc} package; however, @code{inputenc} doesn't support
the @code{roman8} and @code{atari} encodings, so umlaute remains the sole
source of that support.")
    (license license:lppl)))

(define-public texlive-unicode-math
  (package
    (name "texlive-unicode-math")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/unicode-math/"
                                     "source/latex/unicode-math/"
                                     "tex/latex/unicode-math/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0697k7kn6rs7c1p34589cp882ksbx4ww07dbd79ymccaf4q05jp2"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-xetex")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "xelatex"))
    (native-inputs (list texlive-xetex))
    (propagated-inputs (list texlive-fontspec texlive-lm-math))
    (home-page "https://ctan.org/pkg/unicode-math")
    (synopsis "Unicode mathematics support for XeTeX and LuaTeX")
    (description
     "This package will provide a complete implementation of unicode maths for
XeLaTeX and LuaLaTeX.  Unicode maths is currently supported by the following
fonts:
@itemize
@item Latin Modern Math,
@item TeX Gyre Bonum Math,
@item TeX Gyre Pagella Math,
@item TeX Gyre Schola Math,
@item TeX Gyre Termes Math,
@item DejaVu Math TeX Gyre,
@item Asana-Math fonts,
@item STIX,
@item XITS Math,
@item Libertinus Math,
@item Fira Math.
@end itemize")
    (license license:lppl1.3c+)))

(define-public texlive-voss-mathcol
  (package
    (name "texlive-voss-mathcol")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/voss-mathcol/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c7kzk2m2i8f6vqywnzfvcmv11ckanhcjxf72p4rgivw8f0lbwjm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/voss-mathcol")
    (synopsis "Typesetting mathematics in colour, in (La)TeX")
    (description
     "This is a short paper from the TeXnische Komodie, in German.  Since the
body of the paper is dominated by clear LaTeX coding examples, most LaTeX
programmers will understand how to achieve the results shown in the diagrams,
even if they don't understand German.")
    (license license:lppl)))

(define-public texlive-xifthen
  (package
    (name "texlive-xifthen")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xifthen/" "tex/latex/xifthen/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b33mlmnxsj5mi06v2w2zgamk51mgv1lxdr1cax8nkpn9g7n9axw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xifthen")
    (synopsis "Extended conditional commands")
    (description
     "This package extends the @code{ifthen} package by implementing new
commands to go within the first argument of @code{\\\\ifthenelse}: to test
whether a string is void or not, if a command is defined or equivalent to
another.  The package also enables use of complex expressions as introduced by
the package @code{calc}, together with the ability of defining new commands to
handle complex tests.")
    (license license:lppl)))

(define-public texlive-xindy
  (package
    (name "texlive-xindy")
    (version "2024.2")
    (source
     (origin
       (method svn-multi-fetch)
       (uri (svn-multi-reference
             (url (texlive-packages-repository version))
             (revision 70951)
             (locations (list "doc/man/man1/tex2xindy.1"
                              "doc/man/man1/tex2xindy.man1.pdf"
                              "doc/man/man1/texindy.1"
                              "doc/man/man1/texindy.man1.pdf"
                              "doc/man/man1/xindy.1"
                              "doc/man/man1/xindy.man1.pdf"
                              "doc/xindy/"
                              "scripts/xindy/"
                              "xindy/"))))
       (file-name (git-file-name name version))
       (sha256
        (base32
         "12j2bi0wwp1hyxr1427hhigqmhsd1fyg90bvghxkm1qck85r24vf"))))
    (outputs '("out" "doc"))
    (properties '((updater-ignored-inputs "perl"))) ;in "-bin" already
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-xindy-bin))
    (home-page "https://ctan.org/pkg/xindy")
    (synopsis "General-purpose index processor")
    (description
     "Xindy was developed after an impasse had been encountered in the attempt
to complete internationalisation of @command{makeindex}.  Xindy can be used to
process indexes for documents marked up using (La)TeX, Nroff family and
SGML-based languages.  Xindy is highly configurable, both in markup terms and
in terms of the collating order of the text being processed.")
    (license license:gpl2+)))

(define-public texlive-xindy-bin
  (package
    (inherit texlive-bin)
    (name "texlive-xindy-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs/" '())
            (delete-other-directories "utils/" '("xindy"))
            (delete-other-directories "texk/" '())))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-xindy" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (add-before 'build 'set-texmfvar
              ;; Building documentation require to generate font metrics, but
              ;; HOME and therefore TEXMFVAR are unavailable.  Use a local
              ;; TEXMFVAR instead.
              (lambda _
                (setenv "TEXMFVAR" (string-append (getcwd) "/texmf-var"))))
            (add-before 'install 'create-missing-directory
              ;; XXX: Install process does not create this directory.
              (lambda _
                (mkdir-p (string-append #$output "/bin"))))
            (add-after 'install 'patch-clisp-location
              (lambda* (#:key inputs #:allow-other-keys)
                ;; The scripts are encoded in ISO-8859-1 (or iso-latin-1).
                (with-fluids ((%default-port-encoding "ISO-8859-1"))
                  (substitute* (find-files #$output "xindy\\.pl$")
                    (("our \\$clisp = .*")
                     (format #f "our $clisp = ~s;~%"
                             (search-input-file inputs "/bin/clisp")))))))))))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-cbfonts-fd
                  texlive-cyrillic
                  texlive-etoolbox
                  texlive-greek-fontenc
                  texlive-lh))))
    (inputs (list clisp perl))
    (propagated-inputs '())
    (native-search-paths '())
    (home-page (package-home-page texlive-xindy))
    (synopsis "Binary for @code{texlive-xindy}")
    (description
     "This package provides the binary for @code{texlive-xindy}.")
    (license (package-license texlive-xindy))))

(define-public texlive-xindy-persian
  (package
    (name "texlive-xindy-persian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/xindy-persian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04w3h65215slnakk5w19m94xmj9cjx01izbk9xijifv5l6dqh447"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xindy-persian")
    (synopsis "Support for the Persian language in Xindy")
    (description
     "The package offers Persian language support for indexing using Xindy.")
    (license license:lppl1.3+)))

(define-public texlive-xits
  (package
    (name "texlive-xits")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/xits/"
                                     "fonts/opentype/public/xits/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1359zgi8r4mwjv273zmc5jghyy4i54amkrmkq80z67x4kx092724"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xits")
    (synopsis "Scientific Times-like font")
    (description
     "XITS is a Times-like font for scientific typesetting with proper
mathematical support for modern, Unicode and OpenType capable TeX engines,
namely LuaTeX and XeTeX.  For use with LuaLaTeX or XeLaTeX, support is
available from the @code{fontspec} and @code{unicode-math} packages.")
    (license license:silofl1.1)))

(define-public texlive-ntgclass
  (package
    (name "texlive-ntgclass")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ntgclass/"
                                     "source/latex/ntgclass/"
                                     "tex/latex/ntgclass/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04rvr1gldp87nqplmnqkwi3l9jclsjaawj5rym72gy6sw9snpmck"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ntgclass")
    (synopsis "European versions of standard classes")
    (description
     "The bundle offers versions of the standard LaTeX @code{article} and
@code{report} classes, rewritten to reflect a more European design, and the
@code{a4} package, which is better tuned to the shape of a4 paper than is the
@code{a4paper} class option of the standard classes.  The classes include
several for @code{article} and @code{report} requirements, and a @code{letter}
class.  The elements of the bundle were designed by members of the Dutch TeX
Users Group NTG.")
    (license license:lppl1.3+)))

(define-public texlive-nth
  (package
    (name "texlive-nth")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/generic/nth/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0716sd99xjdkplm7jdmg4lx8lpfnnx6mxjp1l1sp2bfqcg73p4hm"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nth")
    (synopsis "Generate English ordinal numbers")
    (description
     "The command @code{\\nth{<number>}} generates English ordinal numbers of
the form 1st, 2nd, 3rd, 4th, etc.  LaTeX package options may specify that the
ordinal mark be superscripted, and that negative numbers may be treated; Plain
TeX users have no access to package options, so need to redefine macros for
these changes.")
    (license license:public-domain)))

(define-public texlive-ntheorem
  (package
    (name "texlive-ntheorem")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ntheorem/" "source/latex/ntheorem/"
                                     "tex/latex/ntheorem/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16xain8s0azcnhwj5xwh3m365sb9bhdvxanh19kvmnc52dggjc1y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ntheorem")
    (synopsis "Enhanced theorem environment")
    (description
     "The package offers enhancements for theorem-like environments: easier
control of layout; proper placement of endmarks even when the environment ends
with @code{\\end@{enumerate@}} or @code{\\end@{displaymath@}} (including
support for @code{amsmath} displayed-equation environments); and support for
making a list of theorems, analogous to @code{\\listoffigures}.")
    (license license:lppl)))

(define-public texlive-ntheorem-vn
  (package
    (name "texlive-ntheorem-vn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ntheorem-vn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13lkgb4qjiblbfm4jcxgkxsf08zk90lqz02bxrmim1n8gvyihwcc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ntheorem-vn")
    (synopsis "Vietnamese translation of documentation of @code{ntheorem}")
    (description
     "This is a translation of the documentation provided with
@code{ntheorem}.")
    (license license:lppl)))

(define-public texlive-fmtcount
  (package
    (name "texlive-fmtcount")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fmtcount/" "scripts/fmtcount/"
                                     "source/latex/fmtcount/" "tex/latex/fmtcount/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1biw0g6s2arq6kq52c1yfkl0vzafja2az65c3d0syq0vgjzj9763"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fmtcount")
    (synopsis "Display the value of a LaTeX counter in a variety of formats")
    (description
     "The package provides commands that display the value of a LaTeX counter
in a variety of formats (ordinal, text, hexadecimal, decimal, octal, binary
etc).  The package offers some multilingual support; configurations for use in
English (both British and American usage), French (including Belgian and Swiss
variants), German, Italian, Portuguese and Spanish documents are provided.")
    (license license:lppl1.3+)))

(define-public texlive-inriafonts
  (package
    (name "texlive-inriafonts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/inriafonts/"
                                     "fonts/enc/dvips/inriafonts/"
                                     "fonts/map/dvips/inriafonts/"
                                     "fonts/opentype/public/inriafonts/"
                                     "fonts/tfm/public/inriafonts/"
                                     "fonts/truetype/public/inriafonts/"
                                     "fonts/type1/public/inriafonts/"
                                     "fonts/vf/public/inriafonts/"
                                     "tex/latex/inriafonts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ngbpr4pl7r82jmdhiksp32qvbvggf2nawwqq0pkb7cffp95ya49"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/inriafonts")
    (synopsis "Inria fonts with LaTeX support")
    (description
     "Inria is a free font designed by Black[Foundry] for Inria, a French
research institute.  It comes as Serif and Sans Serif, each with three weights
and matching italics.  Using these fonts with XeLaTeX and LuaLaTeX is easy
using the @code{fontspec} package.  The present package provides a way of
using them with LaTeX and pdfLaTeX: it provides two style files,
@file{InriaSerif.sty} and @file{InriaSans.sty}, together with the PostScript
version of the fonts and their associated files.")
    (license (list license:lppl license:silofl1.1))))

(define-public texlive-floatflt
  (package
    (name "texlive-floatflt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/floatflt/" "source/latex/floatflt/"
                                     "tex/latex/floatflt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1piy8ajbbcadsjwp0mhlgxm2ggggnb5sn75arfs5fxiaqrwd572j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/floatflt")
    (synopsis "Wrap text around floats")
    (description
     "The package can float text around figures and tables which do not span
the full width of a page; it improves upon floatfig, and allows tables/figures
to be set left/right or alternating on even/odd pages.")
    (license license:lppl1.3+)))

(define-public texlive-fvextra
  (package
    (name "texlive-fvextra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fvextra/" "source/latex/fvextra/"
                                     "tex/latex/fvextra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07bjbl2q4jly3hxfcimbxa938n5dhl72h3pm7ab3g5q41fzgjfr3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fvextra")
    (synopsis "Extensions and patches for @code{fancyvrb}")
    (description
     "This package provides several extensions to fancyvrb, including
automatic line breaking and improved math mode.")
    (license license:lppl1.3+)))

(define-public bibtool
  (package
    (name "bibtool")
    (version "2.68")
    (source
     (origin
       (method git-fetch)
       (uri
        (git-reference
         (url "https://github.com/ge-ne/bibtool")
         (commit (string-append
                  "BibTool_"
                  (string-map (lambda (c) (if (char=? c #\.) #\_ c))
                              version)))))
       (file-name (git-file-name name version))
       (sha256
        (base32 "0grnmqj8w5018nd7r6drnq2yvfhf22gj9i3rj8ilhzm7zmz3zn0g"))))
    (build-system gnu-build-system)
    (arguments
     `(#:test-target "test"))
    (native-inputs
     (list perl))
    (home-page "http://www.gerd-neugebauer.de/software/TeX/BibTool/en")
    (synopsis "Tool for manipulating BibTeX databases")
    (description
     "BibTool manipulates BibTeX files.  The possibilities of BibTool include
sorting and merging of BibTeX databases, generation of uniform reference keys,
and selecting references used in a publication.")
    (license license:gpl2+)))

(define-public texlive-apa6
  (package
    (name "texlive-apa6")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/apa6/" "source/latex/apa6/"
                                     "tex/latex/apa6/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l8x28ijyyj0bz6ypwp2azp296knqk2iy5qv5afnpnrd2kh37x6r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'fix-build
            ;; Build process wants to generate files in the wrong directory.
            (lambda _
              (substitute* "source/latex/apa6/apa6.ins"
                (("file\\{\\./.*?/") "file{")))))))
    (home-page "https://ctan.org/pkg/apa6")
    (synopsis "Format documents in APA style (6th edition)")
    (description
     "The class formats documents in APA style (6th Edition).  It provides
a full set of facilities in three different output modes (journal-like
appearance, double-spaced manuscript, LaTeX-like document).  The class can
mask author identity for copies for use in masked peer review.")
    (license license:lppl1.3c+)))

(define-public texlive-apacite
  (package
    (name "texlive-apacite")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/apacite/" "doc/bibtex/apacite/"
                                     "source/bibtex/apacite/" "tex/latex/apacite/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nc86zngk71xpbinrfm8p0413xphc0v86ddhcw94gi2sl00hsmzq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/apacite")
    (synopsis "Citation style following the rules of the APA")
    (description
     "Apacite provides a BibTeX style and a LaTeX package which are designed
to match the requirements of the American Psychological Association's style
for citations.  The package follows the 6th edition of the APA manual, and is
designed to work with the @code{apa6} class.")
    (license license:lppl)))

(define-public texlive-apalike-german
  (package
    (name "texlive-apalike-german")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/apalike-german/"
                                     "doc/bibtex/apalike-german/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15mr1s9622bj5vmmlw7cp0afcbrz2h4kq9cp303ijklcslfsx748"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/apalike-german")
    (synopsis "Copy of @file{apalike.bst} with German localization")
    (description
     "This package provides a copy of @file{apalike.bst}, which is part of the
base BibTeX distribution, with German localization.")
    (license license:lppl1.3c)))

(define-public texlive-endfloat
  (package
    (name "texlive-endfloat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/endfloat/" "source/latex/endfloat/"
                                     "tex/latex/endfloat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zslmc5g28z6adfyd8bdlbw03jawxmgafq0mgwy811hrbcppb2kg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/endfloat")
    (synopsis "Move floats to the end, leaving markers where they belong")
    (description
     "The @code{endfloat} package places all floats on pages by themselves at
the end of the document, optionally leaving markers in the text near to where
the figure (or table) would normally have occurred.")
    (license license:gpl3+)))

(define-public texlive-wadalab
  (package
    (name "texlive-wadalab")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/wadalab/"
                                     "fonts/afm/wadalab/dgj/"
                                     "fonts/afm/wadalab/dmj/"
                                     "fonts/afm/wadalab/mc2j/"
                                     "fonts/afm/wadalab/mcj/"
                                     "fonts/afm/wadalab/mr2j/"
                                     "fonts/afm/wadalab/mrj/"
                                     "fonts/map/dvips/wadalab/"
                                     "fonts/tfm/wadalab/dgj/"
                                     "fonts/tfm/wadalab/dmj/"
                                     "fonts/tfm/wadalab/mc2j/"
                                     "fonts/tfm/wadalab/mcj/"
                                     "fonts/tfm/wadalab/mr2j/"
                                     "fonts/tfm/wadalab/mrj/"
                                     "fonts/tfm/wadalab/udgj/"
                                     "fonts/tfm/wadalab/udmj/"
                                     "fonts/tfm/wadalab/umcj/"
                                     "fonts/tfm/wadalab/umrj/"
                                     "fonts/type1/wadalab/dgj/"
                                     "fonts/type1/wadalab/dmj/"
                                     "fonts/type1/wadalab/mc2j/"
                                     "fonts/type1/wadalab/mcj/"
                                     "fonts/type1/wadalab/mr2j/"
                                     "fonts/type1/wadalab/mrj/"
                                     "fonts/vf/wadalab/udgj/"
                                     "fonts/vf/wadalab/udmj/"
                                     "fonts/vf/wadalab/umcj/"
                                     "fonts/vf/wadalab/umrj/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i72xbn28wh2rl4j1yzl1rvb5nd8bxmci9q9qjzynwq845zgjvnk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/wadalab")
    (synopsis "Wadalab (Japanese) font packages")
    (description
     "These are font bundles for the Japanese Wadalab fonts which work with
the CJK package.  All subfonts now have glyph names compliant to the Adobe
Glyph List, making ToUnicode CMaps in PDF documents (created automatically by
@code{dvipdfmx}) work correctly.  All font bundles now contain virtual Unicode
subfonts.")
    (license (license:fsf-free "https://fedoraproject.org/wiki/Licensing:Wadalab"))))

(define-public texlive-was
  (package
    (name "texlive-was")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/was/" "source/latex/was/"
                                     "tex/latex/was/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c2kmfrm898c69bizw0650w82bjabp3jf57hmqfcb9y625pq0s05"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/was")
    (synopsis "Collection of small packages by Walter Schmidt")
    (description
     "This package provides a bundle of packages that arise in the author's
area of interest: compliance of maths typesetting with ISO standards; symbols
that work in both maths and text modes commas for both decimal separator and
maths; and upright Greek letters in maths.")
    (license license:lppl1.2+)))

(define-public texlive-xpatch
  (package
    (name "texlive-xpatch")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xpatch/" "source/latex/xpatch/"
                                     "tex/latex/xpatch/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0r08hadnwx9vyppzmbn1bj69b12i5fw1mhk49piw2rqbk01722zk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-etoolbox))
    (home-page "https://ctan.org/pkg/xpatch")
    (synopsis "Extending @code{etoolbox} patching commands")
    (description
     "The package generalises the macro patching commands provided by Philipp
Lehmann's @code{etoolbox}.")
    (license license:lppl1.3c+)))

(define-public texlive-threeparttablex
  (package
    (name "texlive-threeparttablex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/threeparttablex/"
                                     "tex/latex/threeparttablex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19pvw2ifswxcf8dxw0mzjmqhl592477w5hcfh97f4wpya0dv2m9p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/threeparttablex")
    (synopsis "Notes in @code{longtables}")
    (description
     "The package provides the functionality of the @code{threeparttable}
package to tables created using the @code{longtable} package.")
    (license license:lppl1.3+)))

(define-public texlive-ligtype
  (package
    (name "texlive-ligtype")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/ligtype/"
                                     "tex/lualatex/ligtype/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10vi607lwracjdgiv1iqbg228f0ccd0zafcyn02q0xcv5r3i7h7a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ligtype")
    (synopsis "Comprehensive ligature suppression functionalities")
    (description
     "This package suppresses inappropriate ligatures following specified
rules.  Both font and user kerning are applied correctly, and f-glyphs are
automatically replaced with their short-arm variant (if available).  Also
there is an emphasis on speed.  By default the package applies German language
ligature suppression rules.  With the help of options and macros it can be
used for other languages as well.  The package requires LuaLaTeX.")
    (license license:lppl1.3c)))

(define-public texlive-linebreaker
  (package
    (name "texlive-linebreaker")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/linebreaker/"
                                     "tex/lualatex/linebreaker/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19nx0hjzf8fi7ryp0mw2pjyrxy5cfpj8gr82hbk0jn3y3m3lp66b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/linebreaker")
    (synopsis "Prevent overflow boxes with LuaLaTeX")
    (description
     "This package tries to prevent overflow lines in paragraphs or boxes.  It
changes LuaTeX's @code{\\linebreak} callback and re-typesets the paragraph
with increased values of @code{\\tolerance} and @code{\\emergencystretch}
until the overflow no longer happens.  If that doesn't help, it chooses the
solution with the lowest badness.")
    (license license:lppl1.3+)))

(define-public texlive-lineno
  (package
    (name "texlive-lineno")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lineno/" "tex/latex/lineno/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03gkd5iby50jmm8i2q7r30pli7fz8lsryaim24jn11f6kvn4jfil"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lineno")
    (synopsis "Line numbers on paragraphs")
    (description
     "The @code{lineno} package adds line numbers to selected paragraphs with
reference possible through the LaTeX @code{\\ref} and @code{\\pageref} cross
reference mechanism.  Line numbering may be extended to footnote lines, using
the @code{fnlineno} package.")
    (license license:lppl1.3a+)))

(define-public texlive-lparse
  (package
    (name "texlive-lparse")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/lparse/" "tex/luatex/lparse/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m75w69qm67j82ja0lp38yckdsbn465aipzdbi2kg4y2xz34hli1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lparse")
    (synopsis "Lua module for parsing key-value options")
    (description
     "@code{lparse} is derived from @code{xparse}, but only works with LuaTeX.
Just as with xparse, it is possible to use a special syntax consisting of
single letters to express the arguments of a macro.  However, @code{lparse} is
able to read arguments regardless of the macro systemd used -- whether LaTeX,
or ConTeXt, or even plain TeX.  Of course, LuaTeX must always be used as the
engine.")
    (license license:lppl1.3c)))

(define-public texlive-lt3luabridge
  (package
    (name "texlive-lt3luabridge")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/lt3luabridge/"
                                     "source/generic/lt3luabridge/"
                                     "tex/generic/lt3luabridge/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nlca8b5rwcjcw9amc3lx8mr4wmlwyx7lbd517maj72n1b2x2bsn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lt3luabridge")
    (synopsis "Execute Lua code in any TeX engine that exposes the shell")
    (description
     "This is an expl3(-generic) package for plain TeX, LaTeX, and ConTeXt
that allows you to execute Lua code in LuaTeX or any other TeX engine that
exposes the shell.")
    (license license:lppl1.3c)))

(define-public texlive-lua-typo
  (package
    (name "texlive-lua-typo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/lua-typo/"
                                     "source/lualatex/lua-typo/"
                                     "tex/lualatex/lua-typo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lgv4z3psgb1vlmq2lgwnqcqn07wj5af1i5xrgjxr98gigglnrvw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lua-typo")
    (synopsis "Highlighting typographical flaws with LuaLaTeX")
    (description
     "This package tracks common typographic flaws in LuaLaTeX documents,
especially widows, orphans, hyphenated words split over two pages, consecutive
lines ending with hyphens, paragraphs ending on too short lines, etc.
Customisable colours are used to highlight these flaws, and the list of pages
on which typographical flaws were found is printed.")
    (license license:lppl1.3c)))

(define-public texlive-lua-uca
  (package
    (name "texlive-lua-uca")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/lua-uca/" "scripts/lua-uca/"
                                     "source/support/lua-uca/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03wpdaz0z3zqfjs43ar65lx521qyf0c2q62b5p53kdx17xfr09jz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lua-uca")
    (synopsis "Unicode Collation Algorithm library for Lua")
    (description
     "The Lua-UCA library provides basic support for Unicode Collation
Algorithm in Lua.  It can be used to sort arrays of strings according to rules
of particular languages.  It can be used in other Lua projects that need to
sort text in a language dependent way, like indexing processors, bibliographic
generators, etc.")
    (license license:expat)))

(define-public texlive-lua-ul
  (package
    (name "texlive-lua-ul")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/lua-ul/"
                                     "source/lualatex/lua-ul/"
                                     "tex/lualatex/lua-ul/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16mli85fcrhfgpjlr6bmgjiwk9s2gq6dda5dvazks32ypbqkkfrd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lua-ul")
    (synopsis "Underlining for LuaLaTeX")
    (description
     "This package provides underlining, strikethough, and highlighting using
features in LuaLaTeX which avoid the restrictions imposed by other methods.
In particular, kerning is not affected, the underlined text can use arbitrary
commands, hyphenation works etc.")
    (license license:lppl1.3c)))

(define-public texlive-lua-visual-debug
  (package
    (name "texlive-lua-visual-debug")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/lua-visual-debug/"
                                     "tex/luatex/lua-visual-debug/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g4n4xfqbgcja2x3b7yi59nn76jq695yndv90610pakask2k560l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lua-visual-debug")
    (synopsis "Visual debugging with LuaLaTeX")
    (description
     "The package uses Lua code to provide visible indications of boxes,
glues, kerns and penalties in the PDF output.  The package is known to work in
LaTeX and Plain TeX documents.")
    (license license:expat)))

(define-public texlive-lua-widow-control
  (package
    (name "texlive-lua-widow-control")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/lua-widow-control/"
                                     "source/luatex/lua-widow-control/"
                                     "tex/context/third/lua-widow-control/"
                                     "tex/lualatex/lua-widow-control/"
                                     "tex/luatex/lua-widow-control/"
                                     "tex/optex/lua-widow-control/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0j7gdd8zp8b8xyb9namjpgc7rphjzh3im6gzk2ynp9dhg0ww24ns"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lua-widow-control")
    (synopsis "Automatically remove widows and orphans from any document")
    (description
     "Unmodified TeX has very few ways of preventing widows and orphans.  In
documents with figures, section headings, and equations, TeX can stretch the
vertical glue between items in order to prevent widows and orphans, but many
documents have no figures or headings.  TeX can also shorten the page by
1 line, but this will give each page a different length which can make
a document look uneven.  The typical solution is to strategically insert
@samp{\\looseness=1}, but this requires manual editing every time that the
document is edited.  Lua-widow-control is essentially an automation of the
@code{\\looseness} method: it uses Lua callbacks to find stretchy paragraphs,
then it lengthens them to remove widows and orphans.  Lua-widow-control is
compatible with all LuaTeX and LuaMetaTeX-based formats.")
    ;; Use either license.
    (license (list license:mpl2.0 license:cc-by-sa4.0))))

(define-public texlive-luaaddplot
  (package
    (name "texlive-luaaddplot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/luaaddplot/"
                                     "source/luatex/luaaddplot/"
                                     "tex/luatex/luaaddplot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0r7n2s8isw3rm0g2l0zljh86ysh1zyfbmypci3kgciad5smjzx15"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luaaddplot")
    (synopsis "Extension to @code{pgfplots}' @code{\\addplot} macro")
    (description
     "This package is an extension to @code{pgfplots}.  It extends the
@code{\\addplot} macro by a facility which allows modification of data files
while they are read.  With @code{luaaddplot} it is no longer necessary to
pre-process data files generated by measuring devices with external scripts.")
    (license license:lppl1.3+)))

(define-public texlive-luacas
  (package
    (name "texlive-luacas")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luacas/" "tex/lualatex/luacas/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "118qpll5l0xg2bmy5baaqzzpsnl30pysh141ry55yl5nc7hf23pi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luacas")
    (synopsis "Computer algebra system for users of LuaLaTeX")
    (description
     "This package provides a portable computer algebra system capable of
symbolic computation, written entirely in Lua, designed for use in LuaLaTeX.
Its features are: arbitrary-precision integer and rational arithmetic,
factoring of univariate polynomials over the rationals and finite fields,
number theoretic algorithms, symbolic differentiation and integration, and
more.  The target audience for this package are mathematics students,
instructors, and professionals who would like some ability to perform basic
symbolic computations within LaTeX without the need for laborious and
technical setup.")
    (license license:lppl1.3c)))

(define-public texlive-luacensor
  (package
    (name "texlive-luacensor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luacensor/"
                                     "tex/lualatex/luacensor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nw83zzpb9y4vnm4rjz786nz9fxv1vzlz3dv8fjwxqpxngqws4g8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luacensor")
    (synopsis "Securely redact sensitive information using Lua")
    (description
     "This package provides simple tools for creating redacted contents.  Its
tools are useful for lawyers, workers in sensitive industries, and others who
need to easily produce both unrestricted versions of documents (for limited,
secure release) and restricted versions of documents (for general release).
Redaction is done both by hiding all characters and by slightly varying the
length of strings to prevent jigsaw identification.  It also is friendly to
screen readers by adding alt-text indicating redacted content.")
    (license license:lppl1.3+)))

(define-public texlive-luacolor
  (package
    (name "texlive-luacolor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/luacolor/"
                                     "source/latex/luacolor/"
                                     "tex/latex/luacolor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19n4h0a505wr7a0q4p8l6nv6zql5xirp85qsfbv8mgnp79plrpn0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luacolor")
    (synopsis "Color support based on LuaTeX's node attributes")
    (description
     "This package implements color support based on LuaTeX's node
attributes.")
    (license license:lppl1.3+)))

(define-public texlive-luacomplex
  (package
    (name "texlive-luacomplex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luacomplex/"
                                     "tex/lualatex/luacomplex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "093hzcgw1jx71m7ah27r3xmk3pd0hj7hzs7k7n77388vgh7mpp8m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luacomplex")
    (synopsis "Operations on complex numbers inside LaTeX documents using Lua")
    (description
     "The @code{luacomplex} package is developed to define complex numbers and
perform basic arithmetic on complex numbers in LaTeX.  It also loads the
@code{luamathspackage}.  It provides an easy way to define complex numbers and
perform operations on complex numbers.  There is no particular environment for
performing operations on complex numbers.  The package commands can be used in
any environment (including the mathematics environment).")
    (license license:lppl1.3c)))

(define-public texlive-luagcd
  (package
    (name "texlive-luagcd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luagcd/"
                                     "tex/lualatex/luagcd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09igp58ql95hnc7r0zbwamqij5plscs289g33plypw9i6rppcq6x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luagcd")
    (synopsis "Computation of gcd of integers inside LaTeX using Lua")
    (description
     "Using Lua, the @code{luagcd} package is developed to find the greatest
common divisor (gcd) of integers in LaTeX.  The package provides commands to
obtain step-by-step computation of gcd of two integers by using the Euclidean
algorithm.  In addition, the package has the command to express gcd of two
integers as a linear combination.  The Bezout's Identity can be verified for
any two integers using commands in the package.")
    (license license:lppl1.3c)))

(define-public texlive-luahyphenrules
  (package
    (name "texlive-luahyphenrules")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luahyphenrules/"
                                     "tex/lualatex/luahyphenrules/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a23bp4a7nix4lhi4dl6kwxp1bs6dvldxxrx143i1ps95l3clasj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luahyphenrules")
    (synopsis "Loading patterns in LuaLaTeX with @file{language.dat}")
    (description
     "Preloading hyphenation patterns (or hyphen rules) into any format based
upon LuaTeX is not required in LuaTeX and recent releases of Babel don't do it
anyway.  This package is addressed to those who just want to select the
languages and load their patterns by means of @file{language.dat} without
loading @code{babel}.")
    (license license:lppl1.3+)))

(define-public texlive-luaimageembed
  (package
    (name "texlive-luaimageembed")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luaimageembed/"
                                     "tex/lualatex/luaimageembed/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nn4vw7hjyjr8an04dd8xmaskf9qn3zjv29dj37pias3pjq7nqi5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luaimageembed")
    (synopsis "Embed images as base64-encoded strings")
    (description
     "This package embeds images directly as base64-encoded strings
into a LuaLaTeX document.  This can be useful, e.g., to package a document
with images into a single TeX file, or with automatically generated
graphics.")
    (license license:expat)))

(define-public texlive-luaindex
  (package
    (name "texlive-luaindex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luaindex/" "scripts/luaindex/"
                                     "source/lualatex/luaindex/"
                                     "tex/lualatex/luaindex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a2xfzrc663jmd2s5vi5p38pwd16mbm5602pxc3kszza8whqlfdn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:tex-format "lualatex"
           #:phases
           #~(modify-phases %standard-phases
               ;; FIXME: Building documentation requires shell-escape to be
               ;; allowed.  I couldn't find a way to generate the package
               ;; only.
               (delete 'build))))
    (home-page "https://ctan.org/pkg/luaindex")
    (synopsis "Create index using LuaLaTeX")
    (description
     "Luaindex provides (yet another) index processor, written in Lua.")
    (license license:lppl1.3+)))

(define-public texlive-luainputenc
  (package
    (name "texlive-luainputenc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luainputenc/"
                                     "source/lualatex/luainputenc/"
                                     "tex/lualatex/luainputenc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17xglqil5mbv47kjzklp22vvsn29vajf6q0v45af4pd6yk9kcc6w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luainputenc")
    (synopsis "Replacing @code{inputenc} for use in LuaTeX")
    (description
     "LuaTeX operates by default in UTF-8 input; thus LaTeX documents that
need 8-bit character-sets need special treatment.  The package, therefore,
replaces the LaTeX standard @code{inputenc} for use under LuaTeX.  With
a current LuaTeX,the package has the same behaviour with LuaTeX as
@code{inputenc} has under pdfTeX.")
    (license license:public-domain)))

(define-public texlive-luakeys
  (package
    (name "texlive-luakeys")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/luakeys/" "tex/luatex/luakeys/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nsd9d2rfwbjadnfykhi0c4wj39cscpx496acjcixg1irlxii7z8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luakeys")
    (synopsis "Lua module for parsing key-value options")
    (description
     "This package provides a Lua module that can parse key-value options like
the TeX packages @code{keyval}, @code{kvsetkeys}, @code{kvoptions},
@code{xkeyval}, @code{pgfkeys}, etc.")
    (license license:lppl1.3c)))

(define-public texlive-lualatex-truncate
  (package
    (name "texlive-lualatex-truncate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/lualatex-truncate/"
                                     "source/lualatex/lualatex-truncate/"
                                     "tex/lualatex/lualatex-truncate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ash4zy97qr9vl3j0gpf16srhi8ymfz3h9khlp59kyq9c921rcla"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lualatex-truncate")
    (synopsis "Wrapper for using the @code{truncate} package with LuaLaTeX")
    (description
     "This package provides a wrapper for the @code{truncate} package, thus
fixing issues related to LuaTeX's hyphenation algorithm.")
    (license license:lppl1.3c)))

(define-public texlive-lualinalg
  (package
    (name "texlive-lualinalg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/lualinalg/"
                                     "tex/lualatex/lualinalg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0im1cs2ghf8ac5p7k7ii84221gj84msy3b8zqvzaz5wnmqnsljz9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lualinalg")
    (synopsis "Linear algebra package for LaTeX")
    (description
     "The @code{lualinalg} package is developed to perform operations on
vectors and matrices defined over the field of real or complex numbers inside
LaTeX documents.  It provides flexible ways for defining and displaying
vectors and matrices.  No particular environment of LaTeX is required to use
commands in the package.  The package is written in Lua, and @file{.tex} file
is to be compiled with the LuaLaTeX engine.  It may also save users efforts to
copy vectors and matrices from other software (which may not be in
LaTeX-compatible format) and to use them in a TeX file.  The vectors and
matrices of reasonable size can be handled with ease.  The package can be
modified or extended by writing custom Lua programs.")
    (license license:lppl1.3c)))

(define-public texlive-luamathalign
  (package
    (name "texlive-luamathalign")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luamathalign/"
                                     "source/lualatex/luamathalign/"
                                     "tex/lualatex/luamathalign/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lj5lc6s30l9k83xrwfjva0v7c9ajv22ybsaz07hadgj17fxqbdn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luamathalign")
    (synopsis "More flexible alignment in @code{amsmath} environments")
    (description
     "This package allows aligning mathematical expressions on points where
directly using @samp{&} is not possible, especially in nested macros or
environments.")
    (license license:lppl1.3c)))

(define-public texlive-luamaths
  (package
    (name "texlive-luamaths")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luamaths/"
                                     "tex/lualatex/luamaths/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0f08sdd0yiwnkjj3gr5w2jismf3jmz79k585dd5qyr1303hf20a0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luamaths")
    (synopsis
     "Provide standard mathematical operations inside LaTeX documents using Lua")
    (description
     "The @code{luamaths} package is developed to perform standard
mathematical operations inside LaTeX documents using Lua.  It provides an easy
way to perform standard mathematical operations.  There is no particular
environment in the package for performing mathematical operations.  The
package commands can be used in any environment (including the mathematics
environment).")
    (license license:lppl1.3c)))

(define-public texlive-luamodulartables
  (package
    (name "texlive-luamodulartables")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luamodulartables/"
                                     "tex/lualatex/luamodulartables/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0n1ymrmhkay1xwybv017n206l2ic9ygxj1ga1lm3hyl1l7v478wr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luamodulartables")
    (synopsis "Generate modular addition and multiplication tables")
    (description
     "This package is developed to generate modular addition and
multiplication tables for positive integers.  It provides an easy way to
generate modular addition and modular multiplication tables for positive
integers in LaTeX documents.  The commands in the package have optional
arguments for the formatting of tables.  These commands can be used in an
environment similar to a tabular or array environment.  The commands can also
be used with the @code{booktabs} package, which provides nice formatting of
tables in LaTeX.")
    (license license:lppl1.3c)))

(define-public texlive-luamplib
  (package
    (name "texlive-luamplib")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/luamplib/"
                                     "source/luatex/luamplib/"
                                     "tex/luatex/luamplib/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05qpjcvl4pq41hm0w9nsxbybbpc3msbl75kk16ppxkyd0gg4yfl4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luamplib")
    (synopsis "Use LuaTeX's built-in MetaPost interpreter")
    (description
     "The package enables the user to specify MetaPost diagrams (which may
include colour specifications from the color or xcolor packages) into
a document, using LuaTeX's built-in MetaPost library.  The facility is only
available in PDF mode.")
    (license license:gpl2)))

(define-public texlive-luaoptions
  (package
    (name "texlive-luaoptions")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luaoptions/"
                                     "tex/lualatex/luaoptions/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "143cjll4dkjb3bp9755c5wsq447mvw8k043mqyi01qskz5wq45yf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luaoptions")
    (synopsis "Option handling for LuaLaTeX packages")
    (description
     "This LuaLaTeX package provides extensive support for handling options,
on package level and locally.  It allows the declaration of sets of options,
along with defaults, allowed values and limited type checking.  These options
can be enforced as package options, changed at any point during a document, or
overwritten locally by optional macro arguments.  It is also possible to
instantiate an Options object as an independent Lua object, without linking it
to a package.  Luaoptions can be used to enforce and prepopulate options, or
it can be used to simply handle the parsing of optional @samp{key=value}
arguments into proper Lua tables.")
    (license license:expat)))

(define-public texlive-luapackageloader
  (package
    (name "texlive-luapackageloader")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/luapackageloader/"
                                     "tex/luatex/luapackageloader/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cf2p4zhfvf7f10pbpp332chj46ajknqgb7a8i16v63ivvmgb8m3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-iftex))
    (home-page "https://ctan.org/pkg/luapackageloader")
    (synopsis "Allow LuaTeX to load external Lua packages")
    (description
     "This package allows LuaTeX to load packages from the default
@code{package.path} and @code{package.cpath} locations.  This could be useful
to load external Lua modules, including modules installed via LuaRocks.")
    (license license:lppl1.3c)))

(define-public texlive-luaprogtable
  (package
    (name "texlive-luaprogtable")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luaprogtable/"
                                     "tex/lualatex/luaprogtable/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vx4vsqa777hv4bdw8m7x8hrjg5p9h8d68z0l2ji60h67bziy161"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luaprogtable")
    (synopsis "Programmable table interface for LuaLaTeX")
    (description
     "This package allows you to modify a cell based on the contents of other
cells using LaTeX macros.")
    (license license:expat)))

(define-public texlive-luapstricks
  (package
    (name "texlive-luapstricks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luapstricks/"
                                     "fonts/opentype/public/luapstricks/"
                                     "tex/lualatex/luapstricks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m2pp4dmf8c7fyrc8w1x1ziqn0qa0qmqjadyfkkr9jgjcvmgk6mz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luapstricks")
    (synopsis "PSTricks backend for LuaLaTeX")
    (description
     "This package enables the use of PSTricks directly in LuaLaTeX documents,
without invoking external programmes, by implementing a PostScript interpreter
in Lua.  Therefore it does not require shell escape to be enabled or special
environments, and instead allows PSTricks to be used exactly like in Dvips
based documents.")
    (license license:lppl1.3+)))

(define-public texlive-luaquotes
  (package
    (name "texlive-luaquotes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luaquotes/"
                                     "tex/lualatex/luaquotes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lla3bd5prh5ld1p88f8c3mfck6c6jn241fq1fzz0a9vdhfsbpv0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luaquotes")
    (synopsis "Smart setting of quotation marks")
    (description
     "This package automatically generates quotation marks and punctuation
depending on the selected language.")
    (license (list license:lppl1.3c license:cc-by-sa3.0))))

(define-public texlive-luarandom
  (package
    (name "texlive-luarandom")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luarandom/"
                                     "tex/lualatex/luarandom/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wylb873xi0k808p204b8vfdp09f2i97wv8pf7wny36wkraj3rr4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luarandom")
    (synopsis "Create lists of random numbers")
    (description
     "This package can create lists of random numbers for any given interval.
It is possible to get lists with or without multiple numbers.  The random
generator will be initialized by the system time.")
    (license license:lppl1.3+)))

(define-public texlive-luaset
  (package
    (name "texlive-luaset")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luaset/"
                                     "tex/lualatex/luaset/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xnnir427r1wyf9w466gamz1slf1b401gj1xfcsn2747g17gjd03"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luaset")
    (synopsis "Set Operations inside LaTeX documents using Lua")
    (description
     "The @code{luaset} package is developed to define finite sets and perform
operations on them inside LaTeX documents.  There is no particular environment
in the package for performing set operations.  The package commands can be
used in any environment (including the mathematics environment).  It is
written in Lua, and the @file{.tex} file is to be compiled with the LuaLaTeX
engine.")
    (license license:lppl1.3c)))

(define-public texlive-luatexko
  (package
    (name "texlive-luatexko")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/luatexko/"
                                     "tex/luatex/luatexko/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14q1zrcqnhfz0g6s6274k0zlzkl27vwn61i2388wjgxzvxd9kphv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luatexko")
    (synopsis "Typeset Korean with Lua(La)TeX")
    (description
     "This is a Lua(La)TeX macro package that supports typesetting Korean
documents including Old Hangul texts.  As LuaTeX has opened up access to
almost all the hidden routines of TeX engine, users can obtain more beautiful
outcome using this package rather than other Hangul macros operating on other
engines.")
    (license license:lppl1.3c)))

(define-public texlive-luatextra
  (package
    (name "texlive-luatextra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luatextra/"
                                     "source/lualatex/luatextra/"
                                     "tex/lualatex/luatextra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i82x51rcdll5r6x63j5qqahb277a1xdrzpck30xlggwwlns0jdc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luatextra")
    (synopsis "Additional macros for Plain TeX and LaTeX in LuaTeX")
    (description
     "The package provides a coherent extended programming environment for use
with LuaTeX.  It loads packages @code{fontspec}, @code{luatexbase} and
@code{lualibs}, and provides additional user-level features and goodies.")
    (license license:public-domain)))

(define-public texlive-luatruthtable
  (package
    (name "texlive-luatruthtable")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luatruthtable/"
                                     "tex/lualatex/luatruthtable/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0320891nanq3jbybv6s50ygazzdnygzwa75n5yijv4mjl5as224l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luatruthtable")
    (synopsis "Generate truth tables of boolean values in LuaLaTeX")
    (description
     "This package provides an easy way for generating truth tables of boolean
values in LuaLaTeX. The time required for operations is no issue while
compiling with LuaLaTeX. The package supports nesting of commands for multiple
operations.  It can be modified or extended by writing custom lua programs.
There is no need to install lua on users system as TeX distributions (TeX Live
or MikTeX) come bundled with LuaLaTeX.")
    (license license:lppl1.3c)))

(define-public texlive-luavlna
  (package
    (name "texlive-luavlna")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/luavlna/" "tex/luatex/luavlna/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ca1vhl7grc8rsq8fb9ky374gcrcn3mmm42945q118qn3jny99ck"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luavlna")
    (synopsis
     "Prevent line breaks after single letter words, units, or academic titles")
    (description
     "In some languages, like Czech or Polish, there should be no single
letter words at the end of a line, according to typographical norms.  This
package handles such situations using LuaTeX's callback mechanism.  In doing
this, the package can detect languages used in the text and insert spaces only
in parts of the document where languages requiring this feature are used.
Another feature of this package is the inclusion of non-breakable space after
initials (like in personal names), after or before academic degrees, and
between numbers and units.  The package supports both plain LuaTeX and
LuaLaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-luaxml
  (package
    (name "texlive-luaxml")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/luaxml/" "tex/luatex/luaxml/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mi8ad57bxkpzakrf7b8vx23fp5fnlqf23km5rr0laqp5zk6889i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luaxml")
    (synopsis "Lua library for reading and serialising XML files")
    (description
     "LuaXML is a pure Lua library for reading and serializing XML files.  The
current release is aimed mainly at support for the @code{odsfile} package.")
    ;; It uses explicitly the same license as Lua.
    (license license:x11)))

(define-public texlive-lutabulartools
  (package
    (name "texlive-lutabulartools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/lutabulartools/"
                                     "tex/luatex/lutabulartools/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jmji51n6y6pkppdryxyj8297817jvz754h6pzl9rp3qr6bcb794"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lutabulartools")
    (synopsis "Some useful LuaLaTeX-based tabular tools")
    (description
     "This package provides some useful commands for tabular matter.  It uses
LuaLaTeX and offers the ability to combine the facilities of multirow and
makecell with an easy to use syntax.  It also adds some enhanced rules for the
@code{booktabs} package.")
    (license license:expat)))

(define-public texlive-makeplot
  (package
    (name "texlive-makeplot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/makeplot/"
                                     "source/latex/makeplot/"
                                     "tex/latex/makeplot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1w34508lvb6rjhp41k78ph2p609mk03n8sp4mfgmhdpay0qxyjz5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/makeplot")
    (synopsis "Easy plots from Matlab in LaTeX")
    (description
     "Makeplot is a LaTeX package that uses the PSTricks @code{pst-plot}
functions to plot data that it takes from Matlab output files.")
    (license license:lppl)))

(define-public texlive-minim
  (package
    (name "texlive-minim")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/minim/" "tex/luatex/minim/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13bsj3gliq3jxw13fwj6qjjr2307m86wh6a9016zyl77xpd5n1r6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/minim")
    (synopsis "Modern plain format for the LuaTeX engine")
    (description
     "This is a modern plain format for the LuaTeX engine, adding improved
low-level support for many LuaTeX extensions and newer PDF features.  While it
can be used as drop-in replacement for plain TeX, it probably is most useful
as a basis for your own formats.  Most features included in the format are
provided by separate packages that can be used on their own; this package
contains only their shared lowest-level programming interface, along with
their combined format.")
    (license license:eupl1.2)))

(define-public texlive-minim-math
  (package
    (name "texlive-minim-math")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/minim-math/"
                                     "tex/luatex/minim-math/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fqmsnn8fcl98wans018mm28l1svc8z8aq5kz48lw2av8hxg40b9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/minim-math")
    (synopsis "Extensive maths for LuaTeX")
    (description
     "This package provides a simple and highly configurable way to use
Unicode and OpenType mathematics with simple LuaTeX, taking advantage of most
of the engine's new capabilities in mathematical typesetting.  Also included
are the proper settings and definitions for almost all Unicode mathematical
characters.")
    (license license:eupl1.2)))

(define-public texlive-minim-mp
  (package
    (name "texlive-minim-mp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/minim-mp/" "metapost/minim-mp/"
                                     "tex/luatex/minim-mp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08i6z363fimql2g5fhdn79mz10yjfhb62jbr456ch7yf9x0zc9lh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/minim-mp")
    (synopsis "Low-level mplib integration for LuaTeX")
    (description
     "This package offers low-level mplib integration for plain LuaTeX and is
designed with the purpose of being easy to extend.  The use of multiple
simultaneous MetaPost instances is supported, as well as running TeX or lua
code from within MetaPost.  With the included @code{minim-mp} format file, you
can even use LuaTeX as a stand-alone MetaPost compiler.")
    (license license:eupl1.2)))

(define-public texlive-minim-pdf
  (package
    (name "texlive-minim-pdf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/minim-pdf/"
                                     "tex/luatex/minim-pdf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0495gig9a96gqpcmjm54diggg9f7kzjznl39hx6j9sjlzhrmmz8m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/minim-pdf")
    (synopsis "Low-level PDF integration for LuaTeX")
    (description
     "This package adds low-level support to plain LuaTeX for marking up the
structure of a PDF document.  The implementation is rather basic, but should
allow you to make your PDFs fully PDF/A-compliant.")
    (license license:eupl1.2)))

(define-public texlive-minim-xmp
  (package
    (name "texlive-minim-xmp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/luatex/minim-xmp/"
                                     "tex/luatex/minim-xmp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mvgmi685sfg0phw655z57gzbpizk6qjn742gabvjl44a6c3r54f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/minim-xmp")
    (synopsis "Embed XMP metadata in PDF with LuaTeX")
    (description
     "This package enables the inclusion of XMP (eXtensible Metadata Platform)
data in the pdf output generated by (plain) LuaTeX.  The use of XMP is
required by PDF standards such as PDF/A.")
    (license license:eupl1.2)))

(define-public texlive-babel-czech
  (package
    (name "texlive-babel-czech")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-czech/"
                                     "source/generic/babel-czech/"
                                     "tex/generic/babel-czech/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "036817g9dv7m0m1576igwv4mjk8b41klkih44zzwjigdgdjpwbn9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-czech")
    (synopsis "Babel support for Czech")
    (description
     "This package provides the language definition file for support of Czech
in @code{babel}.  Some shortcuts are defined, as well as translations to Czech
of standard LaTeX names.")
    (license license:lppl1.3+)))

(define-public texlive-babel-dutch
  (package
    (name "texlive-babel-dutch")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-dutch/"
                                     "source/generic/babel-dutch/"
                                     "tex/generic/babel-dutch/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1iqlhs2zh60n50r69yicxlklxx8msrb8k552j0ffmqf5kh64fpqh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-dutch")
    (synopsis "Babel contributed support for Dutch")
    (description
     "This package provides the language definition file for support of Dutch
in @code{babel}.  It provides all the necessary macros, definitions and
settings to typeset Dutch documents.")
    (license license:lppl1.3c+)))

(define-public texlive-babel-finnish
  (package
    (name "texlive-babel-finnish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-finnish/"
                                     "source/generic/babel-finnish/"
                                     "tex/generic/babel-finnish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zwrbcqjwhy31mks31vlc4kxci67d5cfm53jaikaabkd8q6grq6i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-finnish")
    (synopsis "Babel support for Finnish")
    (description
     "This package provides the language definition file for support of
Finnish in @code{babel}.  It provides all the necessary macros, definitions and
settings to typeset Finnish documents.")
    (license license:lppl1.3c+)))

(define-public texlive-babel-norsk
  (package
    (name "texlive-babel-norsk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-norsk/"
                                     "source/generic/babel-norsk/"
                                     "tex/generic/babel-norsk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19w3ys7mhm9kfkj9vf1nkiqnn30393mhzmfhq4zsw6d0mj0y94na"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-norsk")
    (synopsis "Babel support for Norwegian")
    (description
     "The package provides the language definition file for support of
Norwegian in Babel.  Some shortcuts are defined, as well as translations to
Norsk of standard LaTeX names.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-generic-babel-norsk texlive-babel-norsk)

(define-public texlive-babel-danish
  (package
    (name "texlive-babel-danish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-danish/"
                                     "source/generic/babel-danish/"
                                     "tex/generic/babel-danish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11fhmj850gahjm3l3rg5pg4l8j9x6mma59vgfpmnd4fkxj5acb0r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-danish")
    (synopsis "Babel contributed support for Danish")
    (description
     "This package provides the language definition file for support of
Danish in @code{babel}.  It provides all the necessary macros, definitions and
settings to typeset Danish documents.")
    (license license:lppl1.3c+)))

(define-public texlive-babel-polish
  (package
    (name "texlive-babel-polish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/babel-polish/"
                                     "source/generic/babel-polish/"
                                     "tex/generic/babel-polish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0j86l23y1rq1raq2n5azza07l7xjkpgw9nhm77pzy8xmifp3nzhb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/babel-polish")
    (synopsis "Babel support for Polish")
    (description
     "This package provides the language definition file for support of Polish
in @code{babel}.  Some shortcuts are defined, as well as translations to
Polish of standard LaTeX names.")
    (license license:lppl1.3+)))

(define-public texlive-mdframed
  (package
    (name "texlive-mdframed")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mdframed/" "source/latex/mdframed/"
                                     "tex/latex/mdframed/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i5rm946wg43rjckxlfhx79zfx5cgd3bxk71206hd1dqkrgpdpa8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mdframed")
    (synopsis "Framed environments that can split at page boundaries")
    (description
     "The @code{mdframed} package develops the facilities of @code{framed} in
providing breakable framed and coloured boxes.  The user may instruct the
package to perform its operations using default LaTeX commands, PStricks or
TikZ.")
    (license license:lppl)))

(define-public texlive-setspace
  (package
    (name "texlive-setspace")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/setspace/" "tex/latex/setspace/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bvspbka1jhpysyhh3sd1vkkm6xjj2ahj0mzv2inzqbrrbydr9gr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/setspace")
    (synopsis "Set space between lines")
    (description
     "The @code{setspace} package provides support for setting the spacing
between lines in a document.  Package options include @code{singlespacing},
@code{onehalfspacing}, and @code{doublespacing}.  Alternatively the spacing
can be changed as required with the @code{\\singlespacing},
@code{\\onehalfspacing}, and @code{\\doublespacing} commands.  Other size
spacings also available.")
    (license license:lppl1.3+)))

(define-public texlive-pgfgantt
  (package
    (name "texlive-pgfgantt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pgfgantt/" "source/latex/pgfgantt/"
                                     "tex/latex/pgfgantt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bm034iizk4sd7p5x7vkj7v57dc0bf2lswpsb32s4qlg4s7h6jqz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-pgf))
    (home-page "https://ctan.org/pkg/pgfgantt")
    (synopsis "Draw Gantt charts with TikZ")
    (description
     "The @code{pgfgantt} package provides an environment for drawing Gantt charts
that contain various elements (titles, bars, milestones, groups and links).
Several keys customize the appearance of the chart elements.")
    (license license:lppl1.3+)))

(define-public texlive-pdfcol
  (package
    (name "texlive-pdfcol")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdfcol/" "source/latex/pdfcol/"
                                     "tex/latex/pdfcol/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mr09kyan59xlnxl4a97w2avp1p09w5yyv6v3p498xpjbq3dbwih"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfcol")
    (synopsis "Macros for maintaining colour stacks under pdfTeX")
    (description
     "This package is intended for package writers.  It defines macros for
setting and maintaining new colour stacks.")
    (license license:lppl1.3c)))

(define-public texlive-pdfcolfoot
  (package
    (name "texlive-pdfcolfoot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdfcolfoot/"
                                     "source/latex/pdfcolfoot/"
                                     "tex/latex/pdfcolfoot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k3fwfyj56zb18fr4yay4bp66nbx3a0nb87i8mh8yxkm7qmnx95l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfcolfoot")
    (synopsis "Separate color stack for footnotes with pdfTeX")
    (description
     "Since version 1.40 pdfTeX supports several colour stacks.  This package
uses a separate colour stack for footnotes that can break across pages.")
    (license license:lppl1.3+)))

(define-public texlive-pdflscape
  (package
    (name "texlive-pdflscape")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdflscape/"
                                     "source/latex/pdflscape/"
                                     "tex/latex/pdflscape/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l1m97ai3w8lfdfndmcbwyd8sdwpw4wp7zn6c4iqkf8bqwrmqyk8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdflscape")
    (synopsis "Make landscape pages display as landscape")
    (description
     "The @code{pdflscape} package adds PDF support to the @code{landscape}
environment of package @code{lscape}, by setting the PDF @code{/Rotate} page
attribute.  Pages with this attribute will be displayed in landscape
orientation by conforming PDF viewers.")
    (license license:lppl1.3+)))

(define-public texlive-pdfmanagement-testphase
  (package
    (name "texlive-pdfmanagement-testphase")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdfmanagement-testphase/"
                                     "source/latex/pdfmanagement-testphase/"
                                     "tex/latex/pdfmanagement-testphase/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xlhkn5kjyjdqs9w26iffcvks0773nslrip3i3k2xrycp2m0ka2h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfmanagement-testphase")
    (synopsis "LaTeX PDF management testphase bundle")
    (description
     "This is a temporary package, which is used during a test phase to load
the new PDF management code of LaTeX.  The new PDF management code offers
backend-independent interfaces to central PDF dictionaries, tools to create
annotations, form Xobjects, to embed files, and to handle PDF standards.  The
code is provided, during a testphase, as an independent package to allow users
and package authors to safely test the code.  At a later stage it will be
integrated into the LaTeX kernel (or in parts into permanent support
packages), and the current testphase bundle will be removed.")
    (license license:lppl1.3c)))

(define-public texlive-pdftricks
  (package
    (name "texlive-pdftricks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdftricks/"
                                     "tex/latex/pdftricks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07vr97rgn0n73zb2b3sb3wkwxl0p6nbnjk0cgxd05drf1k8shxnp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdftricks")
    (synopsis "Support for PSTricks in pdfTeX")
    (description
     "The PSTricks macros cannot be used (directly) with pdfTeX, since
PSTricks uses PostScript arithmetic, which isn't part of PDF.  This package
circumvents this limitation so that the extensive facilities offered by the
powerful PSTricks package can be made use of in a pdfTeX document.  This is
done using the shell escape function available in current TeX implementations.
The package may also be used in support of other PostScript-output-only
packages, such as PSfrag.")
    (license license:gpl3+)))

(define-public texlive-pdftricks2
  (package
    (name "texlive-pdftricks2")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdftricks2/"
                                     "tex/latex/pdftricks2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0znq52nzknv0x16cqbpfi90gz89frzk74ww3sg7ibjacmbpfl3j0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdftricks2")
    (synopsis "Use PSTricks in pdfTeX")
    (description
     "The package provides the means of processing documents that contain
PSTricks graphics specifications.  The package is inspired by
@code{pdftricks}.")
    (license license:gpl2)))

(define-public texlive-pedigree-perl
  (package
    (name "texlive-pedigree-perl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/pedigree.1"
                                     "doc/man/man1/pedigree.man1.pdf"
                                     "doc/support/pedigree-perl/"
                                     "scripts/pedigree-perl/"
                                     "source/latex/pedigree-perl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0s2186j4hx5v12g5r8admif2ysi6nnm8d0xxpwq26brfcjrbbh7r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "pedigree.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/pedigree-perl")
    (synopsis "Generate TeX pedigree files from CSV files")
    (description
     "This program generates TeX commands to typeset pedigrees --- either TeX
fragments or full LaTeX files, to be processed by the @code{pst-pdgr} package.
The program has support for multilanguage pedigrees (at the present moment the
English and Russian languages are supported).")
    (license license:gpl2)))

(define-public texlive-psbao
  (package
    (name "texlive-psbao")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/psbao/" "tex/latex/psbao/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11gfnjvhrgic18s45pj6hn8slj9kmrmsrh4kqn83sfdxy2mr2y32"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/psbao")
    (synopsis "Draw Bao diagrams")
    (description
     "The package draws Bao diagrams in LaTeX.  The package is a development
of @code{psgo}, and uses PSTricks to draw the diagrams.")
    (license license:lppl)))

(define-public texlive-pslatex
  (package
    (name "texlive-pslatex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "fonts/map/dvips/pslatex/"
                                     "fonts/tfm/public/pslatex/"
                                     "fonts/vf/public/pslatex/"
                                     "source/latex/pslatex/fontinst/"
                                     "source/latex/pslatex/shell/"
                                     "tex/latex/pslatex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06qrlh8zbwkq9vn622d04d5dqcp3f8sc1wafbhh7ws5ah4p8b87a"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pslatex")
    (synopsis "Use PostScript fonts by default")
    (description
     "This package provides a small package that makes LaTeX default to
standard PostScript fonts.  It is basically a merger of the @code{times} and
the (obsolete) @code{mathptm} packages from the @code{psnfss} suite.  You must
have installed standard LaTeX and the @code{psnfss} PostScript fonts to use
this package.  The main novel feature is that the @code{pslatex} package tries
to compensate for the visual differences between the Adobe fonts by scaling
Helvetica by 90%, and condensing Courier (i.e.  scaling horizontally) by 85%.
The package is supplied with a (unix) shell file for a @command{pslatex}
command that allows standard LaTeX documents to be processed, without needing
to edit the file.  Note that current @code{psnfss} uses a different technique
for scaling Helvetica, and treats Courier as a lost cause (there are better
free fixed-width available now, than there were when @code{pslatex} was
designed).  As a result, @code{pslatex} is widely considered obsolete.")
    (license license:lppl)))

(define-public texlive-pspicture
  (package
    (name "texlive-pspicture")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pspicture/" "dvips/pspicture/"
                                     "source/latex/pspicture/"
                                     "tex/latex/pspicture/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06wlnwyn45873zghnbw16lzmfj98r9il218z84p1ixw6jwkwlkh8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pspicture")
    (synopsis "PostScript picture support")
    (description
     "This package provides a replacement for LaTeX's picture macros, that
uses PostScript @code{\\special} commands.  The package is now largely
superseded by @code{pict2e}.")
    (license license:lppl)))

(define-public texlive-datetime
  (package
    (name "texlive-datetime")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime/"
                                     "source/latex/datetime/"
                                     "tex/latex/datetime/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07rx0bcr8b73669xmvl1q3qy96jfqlfs2yv2khjcaf2yfid3c2vw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime")
    (synopsis "Change format of \\today with commands for current time")
    (description
     "This package provides various different formats for the text created by
the command @code{\\today}, and also provides commands for displaying the
current time (or any given time), in 12-hour, 24-hour or text format.  It
overrides Babel's date format, having its own library of date formats in
different languages.  This package is now obsolete and has been replaced by
@code{datetime2}.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2
  (package
    (name "texlive-datetime2")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2/"
                                     "source/latex/datetime2/"
                                     "tex/latex/datetime2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yjkpfic1ni4j2g61rrjj5hjyd43shc9c0sg1aivbbsmqh30dn33"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-etoolbox texlive-tracklang texlive-xkeyval))
    (home-page "https://ctan.org/pkg/datetime2")
    (synopsis "Formats for dates, times and time zones")
    (description
     "The @code{datetime2} package provides commands for formatting dates,
times and time zones and redefines @code{\\today} to use the same formatting
style.  In addition to @code{\\today}, you can also use
@code{\\DTMcurrenttime} (current time) or @code{\\DTMnow} (current date and
time).  Dates and times can be saved for later use.  The accompanying
@code{datetime2-calc} package can be used to convert date-times to UTC+00:00.
Language and regional support is provided by independently maintained and
installed modules.  The @code{datetime2-calc} package uses the
@code{pgfcalendar} package (part of the PGF/TikZ bundle).  This package
replaces @code{datetime.sty}, which is now obsolete.")
    (license license:lppl1.3+)))

(define-public texlive-tracklang
  (package
    (name "texlive-tracklang")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/tracklang/"
                                     "source/latex/tracklang/"
                                     "tex/generic/tracklang/"
                                     "tex/latex/tracklang/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y8kdr5v033dp79fqfdc1jpp1x3lv0yjz5fjd6yk2xxw30lps1s9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tracklang")
    (synopsis "Language and dialect tracker")
    (description
     "The @code{tracklang} package is provided for package developers who want
a simple interface to find out which languages the user has requested through
packages such as @code{babel} or @code{polyglossia}.  This package does not
provide any translations!  Its purpose is simply to track which languages have
been requested by the user.  Generic TeX code is in @file{tracklang.tex} for
non-LaTeX users.")
    (license license:lppl1.3+)))

(define-public texlive-ltablex
  (package
    (name "texlive-ltablex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ltablex/" "tex/latex/ltablex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14lmgj820j6zwj1xnd6ad38kzb9w132kp7sp55cv5bk9vhx3621w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ltablex")
    (synopsis "Table package extensions")
    (description
     "The @code{ltablex} package modifies the @code{tabularx} environment to
combine the features of the @code{tabularx} package (auto-sized columns in
a fixed-width table) with those of the @code{longtable} package (multi-page
tables).")
    (license license:lppl)))

(define-public texlive-ragged2e
  (package
    (name "texlive-ragged2e")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ragged2e/" "source/latex/ragged2e/"
                                     "tex/latex/ragged2e/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12grx6s15rhhgw969p8hxwgmkjy3mfdirn0yglhzivyiv5fx54ip"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/ragged2e")
    (synopsis "Alternative versions of ragged-type commands")
    (description
     "The @code{ragged2e} package defines new commands @code{\\Centering},
@code{\\RaggedLeft}, and @code{\\RaggedRight} and new environments
@code{Center}, @code{FlushLeft}, and @code{FlushRight}, which set ragged text
and are easily configurable to allow hyphenation (the corresponding commands
in LaTeX, all of whose names are lower-case, prevent hyphenation
altogether).")
    (license license:lppl1.3c)))

(define-public texlive-rcs
  (package
    (name "texlive-rcs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rcs/" "source/latex/rcs/"
                                     "tex/latex/rcs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lhb5njyk5y60lgbbggy804qqc0szcybbhndmwblpxhhyxiqvmi5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rcs")
    (synopsis "Use RCS (revision control system) tags in LaTeX documents")
    (description
     "The @code{rcs} package utilizes the inclusion of RCS supplied data in
LaTeX documents.  In particular, you can easily access values of every RCS
field in your document put the checkin date on the titlepage or put RCS fields
in a footline.  You can also typeset revision logs.  You can also configure
the @code{rcs} package easily to do special things for any keyword.")
    (license license:gpl3+)))

(define-public texlive-refstyle
  (package
    (name "texlive-refstyle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/refstyle/" "source/latex/refstyle/"
                                     "tex/latex/refstyle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0803kza5q4nz20aw1dcnalcvizpiry8wr3yqig93a4rrpkik5qhs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/refstyle")
    (synopsis "Advanced formatting of cross references")
    (description
     "The package provides a consistent way of producing references throughout
a project.  Enough flexibility is provided to make local changes to a single
reference.  The user can configure their own setup.  The package offers
a direct interface to varioref (for use, for example, in large projects such
as a series of books, or a multivolume thesis written as a series of
documents), and name references from the nameref package may be incorporated
with ease.  For large projects such as a series of books or a multi volume
thesis, written as freestanding documents, a facility is provided to interface
to the @code{xr} package for external document references.")
    (license license:lppl)))

(define-public texlive-relsize
  (package
    (name "texlive-relsize")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/relsize/" "tex/latex/relsize/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07g9wqxsh3a9rmfbppaqhyic82a1i1habizaf4hpdi3246w6nnby"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/relsize")
    (synopsis "Set the font size relative to the current font size")
    (description
     "The basic command of the package is @code{\\relsize}, whose argument is
a number of @code{\\magsteps} to change size; from this are defined commands
@code{\\larger}, @code{\\smaller}, @code{\\textlarger}, etc.")
    (license license:public-domain)))

(define-public texlive-russ
  (package
    (name "texlive-russ")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/russ/" "tex/latex/russ/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ixvdjvgrqn5z8glvbr1i9k4yw00n260d11n034x6j67srxph3rb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/russ")
    (synopsis "LaTeX in Russian, without Babel")
    (description
     "The package aims to facilitate Russian typesetting (based on input using
MicroSoft Code Page 1251).  Russian hyphenation is selected, and various
mathematical commands are set up in Russian style.  Furthermore all Cyrillic
letters catcodes are set to @samp{letter}, so that commands with Cyrillic
letters in their names may be defined.")
    (license license:lppl)))

(define-public texlive-everyhook
  (package
    (name "texlive-everyhook")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/everyhook/"
                                     "source/latex/everyhook/"
                                     "tex/latex/everyhook/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rcw2d5ncq8avk33nxika34q3da1v4kcmr6jqdxdg49bq4h8ljs7"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-bera
                  texlive-enumitem
                  texlive-etoolbox
                  texlive-hypdoc
                  texlive-inconsolata
                  texlive-lipsum
                  texlive-listings
                  texlive-mathpazo
                  texlive-microtype
                  texlive-palatino
                  texlive-svn-prov
                  texlive-upquote
                  texlive-xkeyval))))
    (home-page "https://ctan.org/pkg/everyhook")
    (synopsis "Hooks for standard TeX token lists")
    (description
     "The package takes control of the six TeX token registers @code{\\everypar},
@code{\\everymath}, @code{\\everydisplay}, @code{\\everyhbox},
@code{\\everyvbox} and @code{\\everycr}.  Real hooks for each of the registers
may be installed using a stack like interface.  For backwards compatibility,
each of the @code{\\everyX} token lists can be set without interfering with
the hooks.")
    (license license:lppl1.3+)))

(define-public texlive-everypage
  (package
    (name "texlive-everypage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/everypage/"
                                     "source/latex/everypage/"
                                     "tex/latex/everypage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kw7n7az823sc8gjrd4gjkkak1780yn76zswlnwapxmvl62pv9xk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/everypage")
    (synopsis "Provide hooks to be run on every page of a document")
    (description
     "The package provides hooks to perform actions on every page, or on the
current page.  Specifically, actions are performed after the page is composed,
but before it is shipped, so they can be used to prepare the output page in
tasks like putting watermarks in the background, or in setting the next page
layout, etc.")
    (license license:lppl1.3c)))

(define-public texlive-everysel
  (package
    (name "texlive-everysel")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/everysel/" "source/latex/everysel/"
                                     "tex/latex/everysel/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0skzm2qsk5vpjxgslclp4pvbbcrrnm1w3df8xfvfq252dyd7w8s5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/everysel")
    (synopsis "Provides hooks into @code{\\selectfont}")
    (description
     "The @code{everysel} package provided hooks whose arguments are executed
just after LaTeX has loaded a new font by means of @code{\\selectfont}.  It
has become obsolete with LaTeX versions 2021/01/05 or newer, since LaTeX now
provides its own hooks to fulfill this task.  For newer versions of LaTeX
@code{everysel} only provides macros using LaTeX's hook management due to
compatibility reasons.")
    (license license:lppl1.3c)))

(define-public texlive-everyshi
  (package
    (name "texlive-everyshi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/everyshi/" "source/latex/everyshi/"
                                     "tex/latex/everyshi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11y6xazv1nk0m2hzsainjr8ijn5cff04xfccm6a65hzg7ipggraj"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-firstaid"
                                               "texlive-l3kernel"
                                               "texlive-l3packages"
                                               "texlive-latex"
                                               "texlive-latex-fonts"
                                               "texlive-latexconfig"
                                               "texlive-metafont"
                                               "texlive-pdftex"
                                               "texlive-tex-ini-files"
                                               "texlive-unicode-data")))
    (build-system texlive-build-system)
    ;; Building `texlive-everyshi' requires "latex" format, provided by
    ;; `texlive-latex-bin'.  However, `texlive-everyshi' is also a propagated
    ;; input from `texlive-latex-bin'.  To work around this cycle, build
    ;; a temporary "latex.fmt" format file, and use it to build the package.
    ;; At the end of the process, remove that temporary format file.
    (arguments
     (list
      #:texlive-latex-bin? #f
      #:phases
      #~(modify-phases %standard-phases
          (add-before 'build 'create-latex-format
            (lambda* (#:key inputs #:allow-other-keys)
              (apply (assoc-ref %standard-phases 'create-formats)
                     (list #:inputs inputs #:create-formats '("latex")))))
          (replace 'build
            (lambda* (#:key inputs build-targets tex-engine #:allow-other-keys)
              (apply (assoc-ref %standard-phases 'build)
                     (list #:inputs inputs
                           #:build-targets build-targets
                           #:tex-engine tex-engine
                           #:tex-format (string-append (getcwd)
                                                       "/web2c/pdftex/latex")))))
          (add-after 'build 'remove-latex-format
            (lambda _
              (delete-file-recursively "web2c"))))))
    (native-inputs
     (list texlive-firstaid
           texlive-l3kernel
           texlive-l3packages
           texlive-latex
           texlive-latex-fonts
           texlive-latexconfig
           texlive-metafont
           texlive-pdftex
           texlive-tex-ini-files
           texlive-unicode-data))
    (home-page "https://ctan.org/pkg/everyshi")
    (synopsis "Take action at every @code{\\shipout}")
    (description
     "The @code{everyshi} package provides hooks into @code{\\sshipout} called
@code{\\EveryShipout} and @code{\\AtNextShipout} analogous to
@code{\\AtBeginDocument}.  With the introduction of the LaTeX hook management
this package became obsolete in 2020 and is only provided for backwards
compatibility.  For current versions of LaTeX it is only mapping the hooks to
the original @code{everyshi} macros.  In case you use an older LaTeX format,
@code{everyshi} will automatically fall back to its old implementation by
loading @code{everyshi-2001-05-15}.")
    (license license:lppl1.3c)))

(define-public texlive-abstract
  (package
    (name "texlive-abstract")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/abstract/" "source/latex/abstract/"
                                     "tex/latex/abstract/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1axm78qgrpml09pkh252g1hsjx9c2w7mbdrm9rdl4yqh5ppwq4y9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/abstract")
    (synopsis "Control the typesetting of the @code{abstract} environment")
    (description
     "The @code{abstract} package gives you control over the typesetting of
the @code{abstract} environment, and in particular provides for a one column
abstract in a two column paper.")
    (license license:lppl)))

(define-public texlive-bredzenie
  (package
    (name "texlive-bredzenie")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bredzenie/"
                                     "tex/latex/bredzenie/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07ixmdcg2kxnaf2wacq6imp6i159jmyy3xn16135j8ddl2kbxp4s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bredzenie")
    (synopsis
     "Polish version of ``lorem ipsum'' in the form of a LaTeX package")
    (description
     "This is a polish version of the classic pseudo-Latin ``lorem ipsum dolor
sit amet''.  It provides access to several paragraphs of pseudo-Polish
generated with Hidden Markov Models and Recurrent Neural Networks trained on
a corpus of Polish.")
    (license license:lppl1.3c)))

(define-public texlive-breqn
  (package
    (name "texlive-breqn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/breqn/" "source/latex/breqn/"
                                     "tex/latex/breqn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03iyxwcr94f2y7ar7qin5nzjcvmamhblv5lxb97dg6r79mk4wr75"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/breqn")
    (synopsis "Automatic line breaking of displayed equations")
    (description
     "This package provides solutions to a number of common difficulties in
writing displayed equations and getting high-quality output.  The single most
ambitious goal of the package is to support automatic linebreaking of
displayed equations.  The bundle also contains the @code{flexisym} and
@code{mathstyle} packages, which are both designated as support for
@code{breqn}.")
    (license license:lppl1.3+)))

(define-public texlive-breakurl
  (package
    (name "texlive-breakurl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/breakurl/" "source/latex/breakurl/"
                                     "tex/latex/breakurl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lihfrihf1i300sddz09rsn6gj30g299warn88gli9hbrfy6nvw5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/breakurl")
    (synopsis "Line-breakable links in @code{hyperref} for dvips/ps2pdf")
    (description
     "This package provides a command much like @code{hyperref}'s @code{\\url}
that typesets a URL using a typewriter-like font.  However, if the dvips
driver is being used, the original @code{\\url} doesn't allow line breaks in
the middle of the created link: the link comes in one atomic piece.  This
package allows such line breaks in the generated links.")
    (license license:lppl)))

(define-public texlive-cc-pl
  (package
    (name "texlive-cc-pl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/cc-pl/" "fonts/map/dvips/cc-pl/"
                                     "fonts/source/public/cc-pl/"
                                     "fonts/tfm/public/cc-pl/"
                                     "fonts/type1/public/cc-pl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wxpa4s2rx54z259zmg5km91ycydra4d9kn3y6mhkvjjif1yl8av"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-concrete"
                                               "texlive-pl")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-concrete texlive-metafont texlive-pl))
    (home-page "https://ctan.org/pkg/cc-pl")
    (synopsis "Polish extension of Computer Concrete fonts")
    (description
     "These Metafont sources rely on the availability of the Metafont Polish
fonts and of the Metafont sources of the original Concrete fonts.  Adobe Type
1 versions of the fonts are included.")
    (license license:public-domain)))

(define-public texlive-comment
  (package
    (name "texlive-comment")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/comment/" "tex/latex/comment/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c1mqziwxyf1bqzpw6ji65n7ypygm3lyknblxmf0c70w0ivw76pa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/comment")
    (synopsis "Selectively include/exclude portions of text")
    (description "This package provides environments for selectively including
or excluding pieces of text, allowing the user to define new, separately
controlled comment versions.")
    (license license:gpl2+)))

(define-public texlive-datatool
  (package
    (name "texlive-datatool")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/datatool/" "doc/latex/datatool/"
                                     "source/latex/datatool/" "tex/latex/datatool/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13v6g3i9pch63159ibpn1r8dwl6ip4hm4cv4z0jx6nn3x8kds5ks"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-fp texlive-substr texlive-xfor texlive-xkeyval))
    (home-page "https://ctan.org/pkg/datatool")
    (synopsis "Tools to load and manipulate data")
    (description
     "This package provides tools to create databases using LaTeX commands
or by importing external files.  Databases may be sorted, filtered, and
visualized using several kinds of configurable plots.  Particular support is
provided for mail merging, indexing, creating glossaries, manipulating
bibliographies, and displaying personal pronouns.")
    (license license:lppl1.3+)))

(define-public texlive-physics
  (package
    (name "texlive-physics")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/physics/" "tex/latex/physics/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wy58wwcv1pv18xs1n71abnm73dqnxqijxvhfxk0rcmvbc6wvwrb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/physics")
    (synopsis "Macros supporting the Mathematics of Physics")
    (description
     "The package defines simple and flexible macros for typesetting equations
in the languages of vector calculus and linear algebra, using Dirac
notation.")
    (license license:lppl)))

(define-public texlive-sourcesanspro
  (package
    (name "texlive-sourcesanspro")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sourcesanspro/"
                                     "fonts/enc/dvips/sourcesanspro/"
                                     "fonts/map/dvips/sourcesanspro/"
                                     "fonts/opentype/adobe/sourcesanspro/"
                                     ;; ^ It would be tempting to use our
                                     ;; font-adobe-source-sans-pro for these, but the version in
                                     ;; texlive could differ from our version: probably the
                                     ;; difference would be small, but debugging would not be
                                     ;; fun.  If the files are really identical, Guix will
                                     ;; hard-link them anyway.
                                     "fonts/tfm/adobe/sourcesanspro/"
                                     "fonts/type1/adobe/sourcesanspro/"
                                     "fonts/vf/adobe/sourcesanspro/"
                                     "tex/latex/sourcesanspro/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18z7ln8dyh0sp6v0vdvc6qqxnpg3h3ix0f5magjcjbpay54kl0i3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sourcesanspro")
    (synopsis "Use Source Sans Pro with TeX(-alike) systems")
    (description
     "This package provides the Source Sans Pro font family from Adobe in both
Adobe Type 1 and OpenType formats, plus macros supporting the use of the fonts
in LaTeX (Type 1) and XeLaTeX/LuaLaTeX (OTF).")
    (license (list license:lppl1.3+ license:silofl1.1))))

(define-public texlive-sourceserifpro
  (package
    (name "texlive-sourceserifpro")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sourceserifpro/"
                                     "fonts/enc/dvips/sourceserifpro/"
                                     "fonts/map/dvips/sourceserifpro/"
                                     "fonts/opentype/adobe/sourceserifpro/"
                                     ;; ^ See comment in `texlive-sourcesanspro'.
                                     "fonts/tfm/adobe/sourceserifpro/"
                                     "fonts/type1/adobe/sourceserifpro/"
                                     "fonts/vf/adobe/sourceserifpro/"
                                     "tex/latex/sourceserifpro/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18xxncg8ybv86r46zq5mvgkrfnvlhx93n55fy8nkk8vdmminrh8w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sourceserifpro")
    (synopsis "Use Source Serif Pro with TeX(-alike) systems")
    (description
     "This package provides the Source Serif Pro font family from Adobe in
both Adobe Type 1 and OpenType formats, plus macros supporting the use of the
fonts in LaTeX (Type 1) and XeLaTeX/LuaLaTeX (OTF).")
    (license (list license:lppl1.3+ license:silofl1.1))))

(define-public texlive-sourcecodepro
  (package
    (name "texlive-sourcecodepro")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sourcecodepro/"
                                     "fonts/enc/dvips/sourcecodepro/"
                                     "fonts/map/dvips/sourcecodepro/"
                                     "fonts/opentype/adobe/sourcecodepro/"
                                     ;; ^ See comment in `texlive-sourcesanspro'.
                                     "fonts/tfm/adobe/sourcecodepro/"
                                     "fonts/type1/adobe/sourcecodepro/"
                                     "fonts/vf/adobe/sourcecodepro/"
                                     "tex/latex/sourcecodepro/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "009v9y7d3vsljgq9nw5yx4kzyqavxbwrlvwhfjj83s6rmb9xcrmh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sourcecodepro")
    (synopsis "Use Source Code Pro with TeX(-alike) systems")
    (description "This package provides the Source Code Pro font family from
Adobe in both Adobe Type 1 and OpenType formats, plus macros supporting the
use of the fonts in LaTeX (Type 1) and XeLaTeX/LuaLaTeX (OTF).")
    (license (list license:lppl1.3+ license:silofl1.1))))

(define-public texlive-hyphenat
  (package
    (name "texlive-hyphenat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hyphenat/" "source/latex/hyphenat/"
                                     "tex/latex/hyphenat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gm7s7bidp9b4sfgylvwydban8jylfcskmqrf0sxlwxsqxqq5fy5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hyphenat")
    (synopsis "Disable/enable hyphenation")
    (description
     "This package can disable all hyphenation or enable hyphenation of
non-alphabetics or monospaced fonts.  The package can also enable hyphenation
within words that contain non-alphabetic characters (e.g., that include
underscores), and hyphenation of text typeset in monospaced (e.g.,
@code{cmtt}) fonts.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-hyphenat texlive-hyphenat)

(define-public texlive-lastpage
  (package
    (name "texlive-lastpage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lastpage/" "source/latex/lastpage/"
                                     "tex/latex/lastpage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0py14m79lc5p4bpyf6kvxq6gcfp141867s5bar012w6nbzn8pvb1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lastpage")
    (synopsis "Reference last page for Page N of M type footers")
    (description
     "This package enables referencing the number of pages in a LaTeX document
through the introduction of a new label which can be referenced like
@code{\\pageref{LastPage}} to give a reference to the last page of a document.
It is particularly useful in the page footer that says: @samp{Page N of M}.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-lastpage texlive-lastpage)

(define-public texlive-layaureo
  (package
    (name "texlive-layaureo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/layaureo/" "source/latex/layaureo/"
                                     "tex/latex/layaureo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "021dcqv8flqv665falbiq7ga56zpihzrdi6kc59nbk0l4jmxf1w9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/layaureo")
    (synopsis "Improve the A4 page layout")
    (description
     "This package produces a wide page layout for documents that use A4 paper
size.  Moreover, LayAureo provides both a simple hook for leaving an empty
space, which is required if pages are bundled by a press binding, and an
option called @code{big} that forces typearea to become maximum.")
    (license license:lppl)))

(define-public texlive-tabto-ltx
  (package
    (name "texlive-tabto-ltx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tabto-ltx/" "tex/latex/tabto-ltx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q0v1pc4hvj71nayfpkj6gfwcbi18s5c526r1k7j4p9m5fcqmbgm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tabto-ltx")
    (synopsis "Tab to a measured position in the line")
    (description
     "This package provides @code{\\tabto{<length>}}, which moves the
typesetting position to @code{<length>} from the left margin of the paragraph.
If the typesetting position is already further along, @code{\\tabto} starts
a new line; the command @code{\\tabto*} will move position backwards if
necessary, so that previous text may be overwritten.  In addition, the command
@code{\\TabPositions} may be used to define a set of tabbing positions, after
which the command @code{\\tab} advances typesetting position to the next
defined tab stop.")
    (license license:lppl1.3+)))

(define-deprecated-package texlive-latex-tabto-ltx texlive-tabto-ltx)

(define-public texlive-soul
  (package
    (name "texlive-soul")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/soul/" "source/generic/soul/"
                                     "tex/generic/soul/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q3h95da6n2wpriy54wkpc5ss47ikdslwf4a4pk3nl90sf3qsq15"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/soul")
    (synopsis "Hyphenation for letterspacing, underlining, and more")
    (description
     "The @code{soul} package enables hyphenatable spacing out (letterspacing),
underlining, striking out, etc., using the TeX hyphenation algorithm to find
the proper hyphens automatically.  The package also provides a mechanism that
can be used to implement similar tasks, that have to treat text syllable by
syllable.  This version is a merge of the original @code{soul} package and the
@code{soulutf8} package and supports also UTF-8.")
    (license license:lppl)))

(define-deprecated-package texlive-generic-soul texlive-soul)
(define-deprecated-package texlive-soulutf8 texlive-soul)

(define-public texlive-xstring
  (package
    (name "texlive-xstring")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/xstring/" "tex/generic/xstring/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rbd8l9xwzrik05jy7485wgin3yg0n37md8zndfiajkkw76lzxjx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xstring")
    (synopsis "String manipulation for (La)TeX")
    (description
     "The @code{xstring} package provides macros for manipulating strings, i.e.,
testing a string's contents, extracting substrings, substitution of substrings
and providing numbers such as string length, position of, or number of
recurrences of, a substring.  The package works equally in Plain TeX and
LaTeX (though e-TeX is always required).  The strings to be processed may
contain (expandable) macros.")
    (license license:lppl1.3c)))

(define-deprecated texlive-generic-xstring texlive-xstring)

(define-public texlive-substr
  (package
    (name "texlive-substr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/substr/" "tex/latex/substr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kfd4kq5yrg65f2mpric1cs1xr416wgj9bdixpibgjsdg5fb73sw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/substr")
    (synopsis "Deal with substrings in strings")
    (description
     "The package provides commands to deal with substrings of strings.
Macros are provided to determine if one string is a substring of another,
return the parts of a string before or after a substring, and count the number
of occurrences of a substring.")
    (license license:lppl1.0+)))

(define-public texlive-totcount
  (package
    (name "texlive-totcount")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/totcount/" "source/latex/totcount/"
                                     "tex/latex/totcount/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rj9ncip5h2cbdljjqwxqsg14pb4mimzhz290q872n32w7rxkp28"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/totcount")
    (synopsis "Find the last value of a counter")
    (description
     "This package records the value that was last set, for any counter of
interest.  Since most such counters are simply incremented when they are
changed, the recorded value will usually be the maximum value.")
    (license license:lppl1.3c+)))

(define-deprecated-package texlive-latex-totcount texlive-totcount)

(define-public texlive-totpages
  (package
    (name "texlive-totpages")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/totpages/" "source/latex/totpages/"
                                     "tex/latex/totpages/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mmya2fqdskyavw3hvdiygfyp9cll7bl4lpi7pl2jf9s7ds49j5a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/totpages")
    (synopsis "Count pages in a document, and report last page number")
    (description
     "The package counts the actual pages in the document (as opposed to
reporting the number of the last page, as does @code{lastpage}).  The counter
itself may be shipped out to the DVI file.")
    (license license:lppl)))

(define-public texlive-xdvi
  (package
    (name "texlive-xdvi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/man/man1/xdvi.1"
                                     "doc/man/man1/xdvi.man1.pdf" "dvips/xdvi/"
                                     "xdvi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1iidl3876vyi9k2dyfwd73q5kb53kwckivfyvvxh953n4axbqmi4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-xdvi-bin))
    (home-page "https://ctan.org/pkg/xdvi")
    (synopsis "DVI previewer for the X Window System")
    (description
     "Xdvi is the canonical DVI previewer for use on Unix and other X-windows
based systems.  The distribution has been integrated with that of Xdvik, so
that it will build with web2c out of the box.")
    ;; Xdvi is under MIT terms, whereas Xdvik extensions use BS2-2.
    (license (list license:expat license:bsd-2))))

(define-public texlive-xdvi-bin
  (package
    (inherit texlive-bin)
    (name "texlive-xdvi-bin")
    (source
     (origin
       (inherit (package-source texlive-source))
       (modules '((guix build utils)
                  (ice-9 ftw)))
       (snippet
        #~(let ((delete-other-directories
                 (lambda (root dirs)
                   (with-directory-excursion root
                     (for-each
                      delete-file-recursively
                      (scandir "."
                               (lambda (file)
                                 (and (not (member file (append '("." "..") dirs)))
                                      (eq? 'directory (stat:type (stat file)))))))))))
            (delete-other-directories "libs" '())
            (delete-other-directories "utils" '())
            (delete-other-directories "texk" '("xdvik"))))))
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons "--enable-xdvik" (delete "--enable-web2c" #$flags)))
       ((#:phases phases)
        #~(modify-phases #$phases
            (replace 'check
              (lambda* (#:key tests? #:allow-other-keys)
                (when tests?
                  (with-directory-excursion "texk/xdvik"
                    (invoke "make" "check")))))
            (replace 'install
              (lambda* (#:key inputs native-inputs #:allow-other-keys)
                (mkdir-p (string-append #$output "/bin"))
                (with-directory-excursion "texk/xdvik"
                  (invoke "make" "install"))))))))
    (native-inputs (list pkg-config))
    (inputs (list freetype ghostscript libxaw texlive-libkpathsea))
    (propagated-inputs '())
    (home-page (package-home-page texlive-xdvi))
    (synopsis "Binaries for @code{texlive-xdvi}}")
    (description
     "This package provides the binaries for @code{texlive-xdvi}}.")
    (license (package-license texlive-xdvi))))

(define-public texlive-xetexconfig
  (package
    (name "texlive-xetexconfig")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/xelatex/xetexconfig/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1253njshiwdayzq0xir9cmbi8syhjb3sc4pyrw9p6kzyqvckkcxm"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xetexconfig")
    (synopsis "@file{crop.cfg} for XeLaTeX")
    (description "The @file{crop.cfg} file attempts to persuade
@file{crop.sty} to work with XeTeX.")
    (license license:public-domain)))

(define-public texlive-xetex
  (package
    (name "texlive-xetex")
    (version "2024.2")
    (source  (origin
               (method svn-multi-fetch)
               (uri (svn-multi-reference
                     (url (texlive-packages-repository version))
                     (revision 70951)
                     (locations (list "doc/man/man1/xelatex-unsafe.1"
                                      "doc/man/man1/xelatex-unsafe.man1.pdf"
                                      "doc/man/man1/xelatex.1"
                                      "doc/man/man1/xelatex.man1.pdf"
                                      "doc/man/man1/xetex-unsafe.1"
                                      "doc/man/man1/xetex-unsafe.man1.pdf"
                                      "doc/man/man1/xetex.1"
                                      "doc/man/man1/xetex.man1.pdf"
                                      "doc/xetex/base/"
                                      "fonts/misc/xetex/fontmapping/base/"
                                      "scripts/texlive-extra/xelatex-unsafe.sh"
                                      "scripts/texlive-extra/xetex-unsafe.sh"))))
               (file-name (git-file-name name version))
               (sha256
                (base32
                 "18idq0h7s692vkmnk4gnfnmwg6jy003d4gpi2d19xwfafx5aii08"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts #~(list "xelatex-unsafe.sh" "xetex-unsafe.sh")
           #:create-formats #~(list "xelatex" "xetex")))
    (propagated-inputs
     (list texlive-babel
           texlive-cm
           texlive-dvipdfmx
           texlive-etex
           texlive-firstaid
           texlive-hyphen-base
           texlive-l3backend
           texlive-l3kernel
           texlive-latex
           texlive-latex-fonts
           texlive-lm
           texlive-plain
           texlive-tex-ini-files
           texlive-unicode-data
           texlive-xetex-bin
           texlive-xetexconfig))
    (home-page "https://ctan.org/pkg/xetex")
    (synopsis "Extended variant of TeX for use with Unicode sources")
    (description
     "XeTeX is a TeX typesetting engine using Unicode and supporting modern font
technologies such as OpenType, TrueType or Apple Advanced Typography (AAT),
including OpenType mathematics fonts.  XeTeX supports many extensions that
reflect its origins in linguistic research; it also supports micro-typography
(as available in pdfTeX).  XeTeX was developed by the SIL (the first version
was specifically developed for those studying linguistics, and using Macintosh
computers).  XeTeX's immediate output is an extended variant of DVI format,
which is ordinarily processed by a tightly bound processor (called
@code{xdvipdfmx}), that produces PDF.")
    (license license:x11)))

(define-public texlive-xetex-bin
  (package
    (inherit texlive-bin)
    (name "texlive-xetex-bin")
    (arguments
     (substitute-keyword-arguments (package-arguments texlive-bin)
       ((#:configure-flags flags)
        #~(cons* "--disable-web2c"
                 "--enable-xetex"
                 (delete "--disable-xetex"
                         (delete "--enable-web2c" #$flags))))
       ((#:phases phases)
        #~(modify-phases #$phases
            (add-after 'unpack 'set-default-xetex-outputdriver
              ;; XeTeX requires the "xdvipdfmx" binary to be available in the
              ;; same tree, so as to use it as a safe default "outputdriver".
              ;; Use the one from TEXLIVE-DVIPDFMX-BIN instead of reporting an
              ;; error each time "xelatex" is invoked.
              (lambda _
                (substitute* "texk/web2c/xetexdir/XeTeX_ext.c"
                  (("(\\*outputdriver = \")xdvipdfmx " _ prefix)
                   (string-append prefix
                                  #$(this-package-input "texlive-dvipdfmx-bin")
                                  "/bin/xdvipdfmx ")))))
            (replace 'install
              (lambda _
                (let ((bin (string-append #$output "/bin")))
                  (with-directory-excursion "texk/web2c"
                    (invoke "make" "xetex")
                    (install-file "xetex" bin))
                  (with-directory-excursion bin
                    (symlink "xetex" "xelatex")))))))))
    (native-inputs (list pkg-config))
    (inputs
     (modify-inputs (package-inputs texlive-bin)
       (append freetype teckit texlive-dvipdfmx-bin)))
    (home-page (package-home-page texlive-xetex))
    (synopsis "Binary for @code{texlive-xetex}")
    (description
     "This package provides the binary for @code{texlive-xetex}.")
    (license (package-license texlive-xetex))))

(define-public texlive-xfor
  (package
    (name "texlive-xfor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xfor/"
                                     "source/latex/xfor/"
                                     "tex/latex/xfor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1j241j8sixqkaj2xmcvmrfwm1sdw6xdssnzml1bjs54rqzyh768a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xfor")
    (synopsis "Reimplementation of the LaTeX @code{for-loop} macro")
    (description
     "The package redefines the LaTeX internal @code{\\@@for} macro so that
the loop may be prematurely terminated.  The action is akin to the C/Java
@code{break} statement, except that the loop does not terminate until the end
of the current iteration.")
    (license license:lppl)))

(define-public texlive-2up
  (package
    (name "texlive-2up")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/2up/" "tex/generic/2up/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b1fw8j91jdjq5jf2riq6q1qxxwzsv5vx5qsramzvk5cq391s1yg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/twoup-gen")
    (synopsis "Macros to print two-up")
    (description
     "The @code{2up} package offers considerable flexibility as to paper
size and layout, and produces a standard DVI file without involving
additional DVI or PostScript filters.")
    (license license:lppl)))

(define-public texlive-a0poster
  (package
    (name "texlive-a0poster")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/a0poster/" "tex/latex/a0poster/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11b6hcspl01w2w1dy4491nl7xyjxfydkzrbl55bis5j1a64pbixn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/a0poster")
    (synopsis "Support for designing posters on large paper")
    (description
     "This package provides fonts in sizes of 12pt up to 107pt and also
makes sure that in math formulas the symbols appear in the right size.
It can also create a PostScript header file for Dvips which ensures
that the poster will be printed in the right size.  The supported
sizes are DIN A0, DIN A1, DIN A2 and DIN A3.")
    (license license:lppl)))

(define-public texlive-a4wide
  (package
    (name "texlive-a4wide")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/a4wide/" "tex/latex/a4wide/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i0rwkfzvyd0d8809djli85df1085b9vi97n2c9ipc8kjls1vygi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/a4wide")
    (synopsis "Wide A4 layout")
    (description
     "This package increases the width of the typeset area of an A4 page.
This sort of operation is capable of producing typographically poor
results; the operation itself is better provided by the
@code{geometry} package.")
    (license license:lppl1.0+)))

(define-public texlive-a5comb
  (package
    (name "texlive-a5comb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/a5comb/" "tex/latex/a5comb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07ifhiza5ax2s6xlhz8q2xvb0q3acymfp0qhhpbhswygpqb0p75w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/a5comb")
    (synopsis "Support for A5 paper sizes")
    (description
     "This package provides support for A5 paper sizes.  It is superseded
by @code{geometry}.")
    (license license:public-domain)))

(define-public texlive-abraces
  (package
    (name "texlive-abraces")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/abraces/" "tex/latex/abraces/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02pdq877cb24vinqzl09wb0hyrvcijm2jjm5bqxb1jrd2nxcj8xh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/abraces")
    (synopsis "Asymmetric over-/underbraces in maths")
    (description
     "The package provides a character key-driven interface to supplement
new constructions of the traditional @code{\\overbrace} and
@code{\\underbrace} pairs in an asymmetric or arbitrary way.")
    (license license:lppl1.3+)))

(define-public texlive-abspos
  (package
    (name "texlive-abspos")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/abspos/" "source/latex/abspos/"
                                     "tex/latex/abspos/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ixcvfn13yqbpi082rgi6zwlmyyz6s61jizh0ym6skg2bx036w2y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/abspos")
    (synopsis "Absolute placement with coffins")
    (description
     "This package lets you place contents at an absolute position,
anchored at some specified part of the contents, similar to how TikZ
nodes work, though without using the two-pass strategy of TikZ.  It
also avoids messing with the order of Beamer overlays, which is what
happens when one uses the @code{textpos} package with the
@code{overlay} option.")
    (license license:expat)))

(define-public texlive-accessibility
  (package
    (name "texlive-accessibility")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/accessibility/"
                                     "source/latex/accessibility/"
                                     "tex/latex/accessibility/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xd8sps37fa96wzrcmnhr99wr12f1hx5z6j5gzwcn073gxdr8wxh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/accessibility")
    (synopsis "Create tagged and structured PDF files")
    (description
     "The @code{accessibility} package is intended to create tagged,
structured PDF documents from LaTeX source code.  This package is
predominantly targeted at documents produced using the KOMA-Script
document classes.  However, according to its author using the package
in its current implementation is discouraged.")
    (license license:lppl1.3c)))

(define-public texlive-achemso
  (package
    (name "texlive-achemso")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/achemso/" "doc/latex/achemso/"
                                     "source/latex/achemso/" "tex/latex/achemso/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15zsz8abbrccz41vgg5x9d00fisa3dsl18gya2mqqkhclbh4rmmy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/achemso")
    (synopsis "Support for American Chemical Society journal submissions")
    (description
     "The bundle provides the official macros (@file{achemso.cls}) and
BibTeX styles (@file{achemso.bst} and @file{biochem.bst}) for
submission to the journals of the American Chemical Society.  The
@code{natmove} package, which moves citations relative to punctuation,
is distributed as part of the bundle.")
    (license license:lppl1.3c)))

(define-public texlive-acro
  (package
    (name "texlive-acro")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/acro/" "tex/latex/acro/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c0gyc3q2qz24zjxplfcxswgh1sd9xw5fa0zwk33gahbzm1vbkqb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-etoolbox texlive-l3kernel
                             texlive-l3packages))
    (home-page "https://ctan.org/pkg/acro")
    (synopsis "Typeset acronyms")
    (description
     "The package enables the author to create acronyms in a simple way,
and provides means to add them to different classes of acronyms.
Lists can be created of separate acronym classes.  The package option
@code{single} instructs the package to ignore acronyms that are used
only once in the whole document.  As an experimental feature the
package also offers the option sort which automatically sorts the list
created by @code{\\printacronyms}.")
    (license license:lppl1.3c)))

(define-public texlive-acroterm
  (package
    (name "texlive-acroterm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/acroterm/"
                                     "source/latex/acroterm/"
                                     "tex/latex/acroterm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04ickn8igj226vdjffgpx9ysvlcl5d61m565ijcs3zln02w5c06y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/acroterm")
    (synopsis "Manage and index acronyms and terms")
    (description
     "This is yet another package for acronyms: it offers simple markup of
acronyms and technical terms in the text, giving an index each of
terms and acronyms with their expanded form.")
    (license license:lppl1.3+)))

(define-public texlive-actuarialangle
  (package
    (name "texlive-actuarialangle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/actuarialangle/"
                                     "source/latex/actuarialangle/"
                                     "tex/latex/actuarialangle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0j8z47n0aawhvz2s4i0pwfp7yq1vqsxbd2sjx7f955n6k2f54hhw"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-enumitem
                  texlive-etoolbox
                  texlive-framed
                  texlive-hypdoc
                  texlive-helvetic
                  texlive-inconsolata
                  texlive-mathpazo
                  texlive-microtype
                  texlive-natbib
                  texlive-pict2e
                  texlive-upquote
                  texlive-xcolor
                  texlive-xkeyval))))
    (home-page "https://ctan.org/pkg/actuarialangle")
    (synopsis
     "Angle symbol denoting a duration in actuarial and financial notation")
    (description
     "This package provides commands to typeset the angle symbol denoting
a duration in actuarial notation, such as in symbols for the present value of
certain or life annuities, and an over angle square bracket used to emphasize
joint status in symbols of life contingencies.")
    (license license:lppl1.3c)))

(define-public texlive-actuarialsymbol
  (package
    (name "texlive-actuarialsymbol")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/actuarialsymbol/"
                                     "source/latex/actuarialsymbol/"
                                     "tex/latex/actuarialsymbol/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rnipnm3crv9qmcf7icymizkp4bkkaa1p50qfni04aq89csqnkwq"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:tex-format "latex"
      #:phases
      #~(modify-phases %standard-phases
          ;; Build process requires an image from "doc/", so we need
          ;; to point to it so it can be found.  Unfortunately, it is
          ;; a JPG file, therefore missing a bounding box.  Add
          ;; missing informations, too.
          (add-before 'build 'fix-build
            (lambda _
              (substitute* "source/latex/actuarialsymbol/actuarialsymbol.dtx"
                (("\\\\includegraphics.*\\{mosaic\\}")
                 (string-append "\\includegraphics[bb=0 0 1000 300]{"
                                (getcwd) "/doc/latex/actuarialsymbol/mosaic.jpg"
                                "}"))))))))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-actuarialangle
                  texlive-booktabs
                  texlive-enumitem
                  texlive-etoolbox
                  texlive-framed
                  texlive-helvetic
                  texlive-hypdoc
                  texlive-inconsolata
                  texlive-mathpazo
                  texlive-metalogo
                  texlive-microtype
                  texlive-natbib
                  texlive-upquote
                  texlive-pict2e
                  texlive-rsfso
                  texlive-xcolor
                  texlive-xkeyval))))
    (home-page "https://ctan.org/pkg/actuarialsymbol")
    (synopsis
     "Actuarial symbols of life contingencies and financial mathematics")
    (description
     "This package provides commands to compose actuarial symbols of life
contingencies and financial mathematics characterized by subscripts and
superscripts on both sides of a principal symbol.  The package also features
commands to easily and consistently position precedence numbers above or below
statuses in symbols for multiple lives contracts.  Since the actuarial
notation can get quite involved, the package defines a number of shortcut
macros to ease entry of the most common elements.")
    (license license:lppl1.3c)))

(define-public texlive-addfont
  (package
    (name "texlive-addfont")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/addfont/" "tex/latex/addfont/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wwjvqgidayw5s6av67k36l6ahbcwwyyn186r3frrgravyshld20"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/addfont")
    (synopsis "Easier use of fonts without LaTeX support")
    (description
     "This package is intended for use by users who know about fonts.  It is
a quick-fix for fonts which do not have genuine LaTeX support.  It is not
meant as a replacement of the LaTeX font definition files.  It is meant as
something more usable for LaTeX users than the @code{\\newfont} command.
With @code{addfont} the loaded font scales along with the usual LaTeX size
selection.  Using this package still requires some knowledge on how to use
fonts with LaTeX.")
    (license license:gpl3+)))

(define-public texlive-addlines
  (package
    (name "texlive-addlines")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/addlines/"
                                     "source/latex/addlines/"
                                     "tex/latex/addlines/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hn7xhzr6qxfv5rp7hlb3ln3zfm52g5hb006f4gdwc17c0j25h48"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/addlines")
    (synopsis "Wrapper around @code{\\enlargethispage}")
    (description
     "This small package provides the command @code{\\addlines} for adding or
removing space in the textblock of the page it's used on.  E.g., adding an
extra line of text to the page so that a section fits better on the next page.
It will also add space to the facing page in a two-sided document.")
    (license license:lppl1.3c)))

(define-public texlive-adjmulticol
  (package
    (name "texlive-adjmulticol")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/adjmulticol/"
                                     "source/latex/adjmulticol/"
                                     "tex/latex/adjmulticol/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0f7z43b2jx0v2zfxmalbhvh7jd9ln41ldy6zncj7s0x5j0p45gfv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/adjmulticol")
    (synopsis "Adjusting margins for multicolumn and single column output")
    (description
     "The package adds, to the @code{multicol} package, the option to change the
margins for multicolumn and unicolumn layout.  The package understands the
difference between the even and odd margins for two side printing.")
    (license license:lppl1.3+)))

(define-public texlive-adrconv
  (package
    (name "texlive-adrconv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/adrconv/" "doc/latex/adrconv/"
                                     "source/latex/adrconv/" "tex/latex/adrconv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ssjws7rvmv97s13qnx3xiakgrr1wyndv7d6zfji73cqck27q2kf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/adrconv")
    (synopsis "BibTeX styles to implement an address database")
    (description
     "The bundle provides a collection of BibTeX style files to turn an address
database stored in the @file{.bib} format into files suitable for printing as
address books or included into letter classes like @code{akletter} or
@code{scrletter2}.  The data may be sorted either by name or birthday and
output provides files in various formats for address books or time planners.")
    (license license:lppl1.3+)))

(define-public texlive-advdate
  (package
    (name "texlive-advdate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/advdate/" "tex/latex/advdate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ixgswmsiy81d9dsrk1w36qlwrsgqmcs2kkvlymgb73n8jfh8n02"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/advdate")
    (synopsis "Print a date relative to today")
    (description
     "This package provides macros which can add a specified number of days to the
current date (as specified in @code{\\today}), to save, set and restore the
current date and to print it.  The package has only been tested with Czech
dates.")
    (license license:lppl1.3+)))
(define-public texlive-akktex
  (package
    (name "texlive-akktex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/akktex/" "tex/latex/akktex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1inwr5s2n9a8a0j8v7ngzcxg9dmg24vlyjcchjgd5x808ril98wx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/akktex")
    (synopsis "Collection of packages and classes")
    (description
     "The bundle provides new document classes for technical documents,
thesis works, manuscripts and lecture notes; many mathematical packages
providing a large number of macros for mathematical texts; layout providing
a non-empty parskip with extended length corrections and new section
definition commands; easy label creation for counters; and German language
tools and predefined abbreviations.")
    (license license:lppl)))

(define-public texlive-akletter
  (package
    (name "texlive-akletter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/akletter/" "tex/latex/akletter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zk48az12ifl90c75bwm9cxbl4sxc73z9gxkj7qd551npr2ry7j1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/akletter")
    (synopsis "Comprehensive letter support")
    (description
     "This is an advanced letter document class which extends LaTeX's usual
@code{letter} class, providing support for building your own letterhead and
marking fold points for window envelopes.  The class supersedes an earlier
class called @code{myletter}.")
    (license license:lppl)))

(define-public texlive-alchemist
  (package
    (name "texlive-alchemist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/alchemist/"
                                     "tex/latex/alchemist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vbkzmg6ilyz31xa14mzh08m758vrqb1c0qfii9cxzp7sdn1706w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/alchemist")
    (synopsis "Typeset alchemist and astrological symbols")
    (description
     "This style file makes the alchemical and astrological symbols
accessible in Unicode.")
    (license (list license:gpl3+ license:lppl))))

(define-public texlive-alertmessage
  (package
    (name "texlive-alertmessage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/alertmessage/"
                                     "source/latex/alertmessage/"
                                     "tex/latex/alertmessage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03pbkpbkgxx4c91b43bbykh931ncvm92mzjms9cpb5msf6yjk2wq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/alertmessage")
    (synopsis "Alert messages for LaTeX")
    (description
     "This package provides some macros to display alert messages (information,
errors, warnings and success messages).")
    (license license:lppl1.3+)))

(define-public texlive-alnumsec
  (package
    (name "texlive-alnumsec")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/alnumsec/"
                                     "source/latex/alnumsec/"
                                     "tex/latex/alnumsec/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c70939fnp251g9p9ksqabjjsfngkp155h5grq21mpx1m7x4zlcb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/alnumsec")
    (synopsis "Alphanumeric section numbering")
    (description
     "This package allows you to use alphanumeric section numbering.  Its output is
similar to @code{alphanum}, but you can use the standard LaTeX sectioning
commands, so that it is possible to switch numbering schemes easily.  Greek
letters, double letters (@samp{bb}) and different delimiters around them are
supported.")
    (license license:lppl)))

(define-public texlive-alterqcm
  (package
    (name "texlive-alterqcm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/alterqcm/" "tex/latex/alterqcm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ag9dxw5x95mk5mjd5jlvk4p0ddjxxzvica669hr4habyiyjmcm1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/alterqcm")
    (synopsis "Multiple choice questionnaires in two column tables")
    (description
     "The alterqcm package is a LaTeX2e package, for making multiple choices
questionnaires in a table with two columns.  The aim is to provide some useful
macros to build QCM in tables.")
    (license license:lppl1.3+)))

(define-public texlive-altfont
  (package
    (name "texlive-altfont")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/altfont/" "source/latex/altfont/"
                                     "tex/latex/altfont/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03rr2j5pbld5wd0ici53m870mlmf44g5h9xgf6qnkra1assgi0sj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/altfont")
    (synopsis "Alternative font handling in LaTeX")
    (description
     "The package provides a replacement for that part of @code{psnfss} and
@code{mfnfss} that changes the default font.  The package is distributed
together with the @code{psfont} package.")
    (license license:gpl3+)))

(define-public texlive-altsubsup
  (package
    (name "texlive-altsubsup")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/altsubsup/"
                                     "source/latex/altsubsup/"
                                     "tex/latex/altsubsup/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c30v7pxlfxvkygli3xkzx9sbn99xkaqvs2s4ansz4wxzamsziiz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/altsubsup")
    (synopsis "Subscripts and superscripts with square brackets")
    (description
     "This is a LaTeX package to write alternative and customisable subscripts and
superscripts, with square brackets in the source code.")
    (license license:lppl1.3+)))

(define-public texlive-amsaddr
  (package
    (name "texlive-amsaddr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/amsaddr/" "source/latex/amsaddr/"
                                     "tex/latex/amsaddr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04y34raa9vfrl66jw566rbb00q5xjbm2zh6k6hjs9nlqhndk62k5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/amsaddr")
    (synopsis "Alter the position of affiliations in @code{amsart}")
    (description
     "The package is to be used with the @code{amsart} document class.  It lets you
move the authors affiliations either just below the authors names on the front
page or as footnotes on the first page.  The email addresses are always listed
as a footnote on the front page.")
    (license license:lppl)))

(define-public texlive-animate
  (package
    (name "texlive-animate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/animate/" "source/latex/animate/"
                                     "tex/latex/animate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10ly46cdfrmlag2l9dkls90fcv50dam2yii7d5q0sjrm739cy04d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/animate")
    (synopsis
     "Create PDF and SVG animations from graphics files and inline graphics")
    (description
     "The package provides an interface to create portable, JavaScript driven PDF
and SVG animations from sets of graphics files or from inline graphics, such
as LaTeX picture environment, PSTricks or PGF/TikZ generated pictures, or just
from typeset text.")
    (license license:lppl)))

(define-public texlive-anonchap
  (package
    (name "texlive-anonchap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/anonchap/" "tex/latex/anonchap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c606nyp8ybik8vjk821hrvfp8ci5f4dwnllqb932xgnqgibr5rf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/anonchap")
    (synopsis "Make chapters be typeset like sections")
    (description
     "The command @code{\\simplechapter} sets up the @code{\\chapter} command not to number chapters,
though they may possibly have a prefix, and a suffix (the
@code{\\simplechapterdelim} command, which the user may alter).  The
@code{\\restorechapter} command restores the status quo ante.")
    (license license:lppl)))

(define-public texlive-answers
  (package
    (name "texlive-answers")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/answers/" "source/latex/answers/"
                                     "tex/latex/answers/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cbjkzahi11wqylylxa4gxc3hi5bz2k2pm91brzxsg1sk3d1f4cn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/answers")
    (synopsis "Setting questions (or exercises) and answers")
    (description
     "The package allows a lot of flexibility in constructing question and answer
sheets.")
    (license license:lppl)))

(define-public texlive-appendixnumberbeamer
  (package
    (name "texlive-appendixnumberbeamer")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/appendixnumberbeamer/"
                                     "tex/latex/appendixnumberbeamer/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11cv55lzk9s5nnkad41s793qfnin5fpz3gl2h43rsswnqhmisxls"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/appendixnumberbeamer")
    (synopsis "Manage frame numbering in appendixes in beamer")
    (description
     "This package fixes the frame numbering in Beamer when using an appendix such
that the slides from the appendix are not counted in the total frame number of
the main part of the document.  The total frame number counter is reset to
0 when entering the appendix.")
    (license license:gpl3)))

(define-public texlive-apptools
  (package
    (name "texlive-apptools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/apptools/"
                                     "source/latex/apptools/"
                                     "tex/latex/apptools/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vd1gzz5yiidknzpzhdrw500666m0b881qbv6dwdb3qc9k3gbbnb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/apptools")
    (synopsis "Tools for customising appendices")
    (description
     "The package provides an @code{\\AtAppendix} command to add code to a hook
that is executed when \\appendix is called by the user.  Additionally, a TeX
conditional @code{\\ifappendix} and a LaTeX-style conditional
@code{\\IfAppendix} are provided to check if @code{\\appendix} has already
been called.")
    (license license:lppl1.3+)))

(define-public texlive-arabicfront
  (package
    (name "texlive-arabicfront")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/arabicfront/"
                                     "tex/latex/arabicfront/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cmsv10yn7351nkxs0mjl7xj3xlshg5hj6pyykb9i8yqm8h4jwcn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/arabicfront")
    (synopsis "Frontmatter with Arabic page numbers")
    (description
     "This package modifies the definitions of @code{\\frontmatter} and
@code{\\mainmatter} so that page numbering starts in Arabic style from the
front matter while preserving the rest of the original definitions.  For it to
work, @code{\\pagenumbering} has to be inside these macros --- most of classes
do that, but there are exceptions like @code{memoir}.")
    (license license:expat)))

(define-public texlive-arcs
  (package
    (name "texlive-arcs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/arcs/" "source/latex/arcs/"
                                     "tex/latex/arcs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08a20d8qgpvisfini220g3hw1hivrbp13ngsfd47dpdqwn12n98s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/arcs")
    (synopsis "Draw arcs over and under text")
    (description
     "The package provides two commands for placing an arc over (@code{\\overarc})
or under (@code{\\underarc}) a piece of text. (The text may be up to three
letters long.)  The commands generate an @code{\\hbox}, and may be used both
in text and in maths formulae.")
    (license license:lppl)))

(define-public texlive-arraycols
  (package
    (name "texlive-arraycols")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/arraycols/"
                                     "source/latex/arraycols/"
                                     "tex/latex/arraycols/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gxv3gflgvpv616a27sbbk1v799apvy8b2l54m5g4agrq9rch8rc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/arraycols")
    (synopsis
     "New column types for @code{array} and @code{tabular} environments")
    (description
     "This small package provides new column types for @code{array} and
@code{tabular} environments, horizontally and vertically centered, or with
adjusted height for big mathematical expressions.  The columns width can be
fixed or calculated like in tabularx environments.  Macros for drawing
vertical and horizontal rules of variable thickness are also provided.")
    (license license:lppl1.3+)))

(define-public texlive-arrayjobx
  (package
    (name "texlive-arrayjobx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/arrayjobx/"
                                     "tex/generic/arrayjobx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0w7wvq1wvxvdhd196hl16c3lgzl4b8x05dhv5dy576cr4xc9chgw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/arrayjobx")
    (synopsis "Array data structures for (La)TeX")
    (description
     "This package provides array data structures in @code{(La)TeX,} in the meaning
of the classical procedural programming languages like Fortran, Ada or C, and
macros to manipulate them.  Arrays can be mono or bi-dimensional.  This is
useful for applications which require high level programming techniques, like
algorithmic graphics programmed in the TeX language.  The package supersedes
the @code{arrayjob} package.")
    (license license:lppl)))

(define-public texlive-arraysort
  (package
    (name "texlive-arraysort")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/arraysort/"
                                     "source/latex/arraysort/"
                                     "tex/latex/arraysort/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nbxpny8vhc7kdhbbbv43xkf8iy23j90bz25aapgz7q3k2865hl0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/arraysort")
    (synopsis "Sort arrays (or portions of them)")
    (description
     "The package provides a mechanism for sorting arrays (or portions of them);
the arrays should have been created using the @code{arrayjobx} package.")
    (license license:lppl1.2+)))

(define-public texlive-arydshln
  (package
    (name "texlive-arydshln")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/arydshln/"
                                     "source/latex/arydshln/"
                                     "tex/latex/arydshln/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zhn8fq92ghkci457qmls90yd2q55zfgqd6rxyhzl5nsfhamcrvh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/arydshln")
    (synopsis "Draw dash-lines in array/tabular")
    (description
     "The package is to draw dash-lines in @code{array} and @code{tabular}
environments.  Horizontal lines are drawn by @code{\\hdashline} and
@code{\\cdashline} while vertical ones can be specified as a part of the
preamble using @samp{:}.  The shape of dash-lines may be controlled through
style parameters or optional arguments.")
    (license license:lppl1.0+)))

(define-public texlive-asciilist
  (package
    (name "texlive-asciilist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/asciilist/"
                                     "source/latex/asciilist/"
                                     "tex/latex/asciilist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07jygmvm5jjzj4mxcxj60q73ihc7zgi9g1v7w99xh458x6a0nsys"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/asciilist")
    (synopsis
     "Environments @code{AsciiList} and @code{AsciiDocList} for prototyping nested
lists in LaTeX")
    (description
     "The @code{asciilist} package provides the environments @code{AsciiList} and
@code{AsciiDocList}, which enable quickly typesetting nested lists in LaTeX
without having to type individual item macros or opening/closing list
environments.  The package provides auxiliary functionality for loading such
lists from files and provides macros for configuring the use of the list
environments and the appearance of the typeset results.")
    (license license:lppl1.2+)))

(define-public texlive-askinclude
  (package
    (name "texlive-askinclude")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/askinclude/"
                                     "source/latex/askinclude/"
                                     "tex/latex/askinclude/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bygb2xlxmazjv3ihag1j4xa8mdrj6n3wmrf0qsz8fksfajxmxks"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/askinclude")
    (synopsis "Interactive use of @code{\\includeonly}")
    (description
     "The package asks the user which files to put in a @code{\\includeonly}
command.  There is provision for answering ``same as last time'' or ``all
files''.")
    (license license:lppl1.3+)))

(define-public texlive-assignment
  (package
    (name "texlive-assignment")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/assignment/"
                                     "tex/latex/assignment/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "182q447ng23vhw3d27dr3dnpqfrp3y8jl7j2l2l6angg9fslp0g0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/assignment")
    (synopsis "Class file for typesetting homework and lab assignments")
    (description
     "This package provides a class file for typesetting homework and lab
assignments.")
    (license license:lppl)))

(define-public texlive-assoccnt
  (package
    (name "texlive-assoccnt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/assoccnt/" "tex/latex/assoccnt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a7mwmsqj3vyvgcwxyyhawiylj9qkyggmgzar0517b2wrmqy7iyk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/assoccnt")
    (synopsis "Associate counters, making them step when a master steps")
    (description
     "The package provides the means of declaring a set of counters to be stepped,
each time some master counter is stepped.")
    (license license:lppl1.3+)))

(define-public texlive-association-matrix
  (package
    (name "texlive-association-matrix")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/association-matrix/"
                                     "tex/latex/association-matrix/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19fzimmprv08hiwgdxrgayjf9mxp07ris54yc6wj50nah8qirghw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/association-matrix")
    (synopsis "LaTeX support for creating association matrices")
    (description
     "This package allows the creation of association matrices in an clear and
concise fashion, without having to deal with manually generating and modifying
the tables while working.  All you have to do is define the rows and the
columns by their unique identifier, and then specify which cells should be
marked as associated.  Then, the @code{\\amxgenerate} command generates
a table that shows in the cells with a blip (*) where the association was
added.")
    (license license:lppl1.3c)))

(define-public texlive-atendofenv
  (package
    (name "texlive-atendofenv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/atendofenv/"
                                     "source/latex/atendofenv/"
                                     "tex/latex/atendofenv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07djyllkw3fdwcmvs23j31msm2n18k6b8wbqhan93m1kfwcyyyfx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/atendofenv")
    (synopsis "Add a custom symbol at the end of an environment")
    (description
     "This package allows adding a custom symbol at the end of an environment (e.g.
theorems, definitions, remarks).")
    (license license:public-domain)))

(define-public texlive-aurl
  (package
    (name "texlive-aurl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/aurl/" "tex/latex/aurl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01ra6hs6x5imnrjkdv05lairssh7a85bhxq9ghg086jy8lzrgf4c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/aurl")
    (synopsis
     "Extends the @code{hyperref} package with a mechanism for hyperlinked URLs
abbreviated with prefixes")
    (description
     "Semantic Web resource URLs are often abbreviated with prefixes, like
@samp{owl:Class} or @samp{rdf:type}.  The abbreviated URL (@code{aurl})
package provides the correct hyperlinks for those URLs.  The 1000 most common
prefixes are predefined and more can be added.")
    (license license:public-domain)))

(define-public texlive-authoraftertitle
  (package
    (name "texlive-authoraftertitle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/authoraftertitle/"
                                     "tex/latex/authoraftertitle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x5b17a8xx0wv2zzsgzq5f3farpil4hwyhw070f5rhdzp2h7xcl1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/authoraftertitle")
    (synopsis "Make author, etc., available after @code{\\maketitle}")
    (description
     "This package makes the author, title and date of the package available to the
user (as @code{\\MyAuthor}, etc) after the @code{\\maketitle} command has been
executed.")
    (license license:cc0)))

(define-public texlive-authorarchive
  (package
    (name "texlive-authorarchive")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/authorarchive/"
                                     "tex/latex/authorarchive/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lqz5bb7hz42ja7kmbkgq0l25ram9axj1kgvv6cyhzxdf0b0hxwn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/authorarchive")
    (synopsis "Adds self-archiving information to scientific papers")
    (description
     "This is a LaTeX style for producing author self-archiving copies of
(academic) papers.  The following layout-styles are pre-defined: ACMfor the
two-column layout used by many ACM conferences, IEEE for the two-column layout
used by many IEEE conferences, LNCS for the LNCS layout (as used by Springer),
and LNI for the Lecture Notes in Informatics, published by the GI ENTCS for
the Elsevier ENTCS layout")
    (license (list license:lppl1.3c license:bsd-2))))

(define-public texlive-authorindex
  (package
    (name "texlive-authorindex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/authorindex/"
                                     "scripts/authorindex/"
                                     "tex/latex/authorindex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hadz4qwaks604mp9zb2cklx77v626vbjri7h0gs847mch35mrnw"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "authorindex")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/authorindex")
    (synopsis "Index citations by author names")
    (description
     "This package allows the user to create an index of all authors cited in
a LaTeX document.  Each author entry in the index contains the pages where
these citations occur.  Alternatively, the package can list the labels of the
citations that appear in the references rather than the text pages.  The
package relies on BibTeX being used to handle citations.")
    (license license:lppl)))

(define-public texlive-autofancyhdr
  (package
    (name "texlive-autofancyhdr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/autofancyhdr/"
                                     "tex/latex/autofancyhdr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vm2gcacdr5pjz80kfbzkg72sdmrdj94siks9sgr83r82710k9c5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/autofancyhdr")
    (synopsis
     "Automatically compute @samp{headlength} for @code{fancyhdr} package")
    (description
     "The package automatically computes @samp{headlength} for the @code{fancyhdr}
package.")
    (license license:lppl1.3c)))

(define-public texlive-autonum
  (package
    (name "texlive-autonum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/autonum/" "source/latex/autonum/"
                                     "tex/latex/autonum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xlxkmnar4ylprf4zcz59ia9xb9nb2r14hbg7ar4in5rsxsiih4j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/autonum")
    (synopsis "Automatic equation references")
    (description
     "The package arranges that equation numbers are applied only to those
equations that are referenced.  This operation is similar to the
@samp{showonlyrefs} option of the package @code{mathtools}.")
    (license license:lppl1.3+)))

(define-public texlive-autopdf
  (package
    (name "texlive-autopdf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/autopdf/" "source/latex/autopdf/"
                                     "tex/latex/autopdf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sdlazmx6g530ava1ip8mafbd2p57i7mf8sdlg3y1m4bvq244v4m"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "pdflatex"))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-catchfile
                  texlive-cm-super
                  texlive-etoolbox
                  texlive-hypdoc))))
    (home-page "https://ctan.org/pkg/autopdf")
    (synopsis "Conversion of graphics to pdfLaTeX-compatible formats")
    (description
     "The package facilitates the on-the-fly conversion of various graphics formats
to formats supported by pdfLaTeX (e.g., PDF).  It uses a range of external
programs, and therefore requires that the LaTeX run starts with @samp{write18}
enabled.")
    (license license:lppl1.2+)))

(define-public texlive-autopuncitems
  (package
    (name "texlive-autopuncitems")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/autopuncitems/"
                                     "tex/lualatex/autopuncitems/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i7i2yjlh85gmqna19r7j6wz35yrkkmmc2kzv4r2mhhbag25j8iy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/autopuncitems")
    (synopsis "Automatically punctuate lists")
    (description
     "This package provides the @code{autopunc} option in the @code{enumitem}
environments @code{itemize}, @code{enumerate}, and @code{description} to
automatically punctuate the items.  It uses Lua pattern matching to modify the
environment's contents.")
    (license license:expat)))

(define-public texlive-avremu
  (package
    (name "texlive-avremu")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/avremu/" "source/latex/avremu/"
                                     "tex/latex/avremu/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fmbmkqy4icbpprgwl9rbb5k44pcymjlqgggcxw9s58slfynsh20"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/avremu")
    (synopsis "8-Bit micro-controller simulator written in LaTeX")
    (description
     "This package provides a fully working package to simulate a microprocessor in
pure LaTeX.  The simulator is able to calculate complex pictures, like
Mandelbrot sets.")
    (license license:lppl1.3+)))

(define-public texlive-axessibility
  (package
    (name "texlive-axessibility")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/axessibility/"
                                     "source/latex/axessibility/"
                                     "tex/latex/axessibility/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h8f4kbgvmb63qdxrq9pjsaqrhl24kcvp75i215bqki9fs4q47vg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/axessibility")
    (synopsis "Access to formulas in PDF files by assistive technologies")
    (description
     "PDF documents containing formulas generated by LaTeX are usually not
accessible by assistive technologies for visually impaired people and people
with special educational needs (i.e., by screen readers and braille displays).
The @code{axessibility} package manages this issue, allowing to create a PDF
document where the formulas are read by these assistive technologies, since it
automatically generates hidden comments in the PDF document (by means of the
@code{/ActualText} attribute or suitable tags) in correspondence to each
formula.")
    (license license:lppl1.3+)))

(define-public texlive-background
  (package
    (name "texlive-background")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/background/"
                                     "source/latex/background/"
                                     "tex/latex/background/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hbz78mvpjd9ac86lxcnbbqlnsgp3p21iv3cl4jwriqp930ipwcg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/background")
    (synopsis "Placement of background material on pages of a document")
    (description
     "The package offers the placement of background material on the pages of
a document.  The user can control many aspects (contents, position, color,
opacity) of the background material that will be displayed; all placement and
attribute settings are controlled by setting key values.")
    (license license:lppl)))

(define-public texlive-bankstatement
  (package
    (name "texlive-bankstatement")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bankstatement/"
                                     "tex/latex/bankstatement/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q2pgz8hvn50dp2i1krbc13zayan5p3mikvzg2h9fyjqc1xxg58g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bankstatement")
    (synopsis "LaTeX class for bank statements based on CSV data")
    (description
     "More and more banks allow their customers to download posting records in
various formats.  By using the @code{bankstatement} class, you can create bank
statements, as long as a CSV format is available.  At the moment, the
CSV-mt940 and CSV-camt formats --- used by many German @emph{Sparkassen} ---
are supported.  You can quite easily add support for other CSV formats.
Simply define the order of the keys in the CSV data file and how to use them.
The terminology in this class --- such as @acronym{BIC, Business Identifier
Code} or @acronym{IBAN, International Bank Account Number} --- is based on
usage in the @acronym{SEPA, Single Euro Payments Area}.  The user may adjust
the terminology to suit local needs.")
    (license license:lppl)))

(define-public texlive-bashful
  (package
    (name "texlive-bashful")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bashful/" "tex/latex/bashful/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08r2yvzck2gngl6sc9giridfmqsbrpdfpv5n9pkwsx0yfx0lk30c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bashful")
    (synopsis "Invoke Bash commands from within LaTeX")
    (description
     "The package makes it possible to execute Unix Bash shell scripts from within
LaTeX.  The main application is in writing computer-science texts, in which
you want to make sure the programs listed in the document are executed
directly from the input.  The package may use other shells than Bash.")
    (license license:lppl1.3+)))

(define-public texlive-basicarith
  (package
    (name "texlive-basicarith")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/basicarith/"
                                     "source/latex/basicarith/"
                                     "tex/latex/basicarith/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01hlnzwmw3013fi0flm3r3basybz2pbrcxr1pmc042w9nmd53q4b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/basicarith")
    (synopsis "Macros for typesetting basic arithmetic")
    (description
     "The package provides macros for typesetting basic arithmetic, in the style
typically found in textbooks.  It focuses on the American style of performing
these algorithms.")
    (license license:lppl1.3+)))

(define-public texlive-bchart
  (package
    (name "texlive-bchart")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bchart/" "tex/latex/bchart/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kz2iijyfbnhr3i8fsiva96h5jazzdwsfbywg1a410imwacb54y9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bchart")
    (synopsis "Draw simple bar charts in LaTeX")
    (description
     "The package provides horizontal bar charts, drawn using TikZ on a numeric
X-axis.  The focus of the package is simplicity and aesthetics.")
    (license license:expat)))

(define-public texlive-beamer-rl
  (package
    (name "texlive-beamer-rl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/beamer-rl/"
                                     "tex/lualatex/beamer-rl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "039r0p5p5f9vmai2vvxlcz9gpbihbcyb8b3vr6w4vn3hrklp6p9m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamer-rl")
    (synopsis "Right to left presentation with beamer and babel")
    (description
     "This class provides patches of some Beamer templates and commands for
presentation from right to left.  It requires Babel with the LuaTeX engine.")
    (license license:lppl1.3c)))

(define-public texlive-beamer2thesis
  (package
    (name "texlive-beamer2thesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamer2thesis/"
                                     "tex/latex/beamer2thesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zk46yxxjc55vbvz17fnwbi02545vywjdaiza9165kxpvhmw75vi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamer2thesis")
    (synopsis "Thesis presentations using Beamer")
    (description
     "The package specifies a Beamer theme for presenting a thesis.")
    (license license:lppl)))

(define-public texlive-beamerappendixnote
  (package
    (name "texlive-beamerappendixnote")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamerappendixnote/"
                                     "source/latex/beamerappendixnote/"
                                     "tex/latex/beamerappendixnote/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cn3hygzahvprhhl9vn95iqkaywp19q61caa6rvyq2krq5m7r5wy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamerappendixnote")
    (synopsis "Create notes on appendix frames in beamer")
    (description
     "This package introduces the @code{\\appxnote} command, which puts the note's
content on a separate Beamer frame shown by the command
@code{\\printappxnotes}.  It also creates interactive buttons to move back and
forth between the two frames.")
    (license license:lppl1.3c)))

(define-public texlive-beameraudience
  (package
    (name "texlive-beameraudience")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beameraudience/"
                                     "tex/latex/beameraudience/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rv01005p9x247ra1kmky8ifxjs2q9jgqc82hn7v2wn9v1a60qla"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beameraudience")
    (synopsis "Assembling Beamer frames according to audience")
    (description
     "The Beamer Audience package provides macros to easily assemble frames
according to different audiences.  It enables to pick up the frames for
a specific audience while leaving their order according to a logical structure
in the LaTeX source.")
    (license license:lppl)))

(define-public texlive-beamerauxtheme
  (package
    (name "texlive-beamerauxtheme")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamerauxtheme/"
                                     "tex/latex/beamerauxtheme/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zm2s4f5gjd4r72nrzwlg40232hmmnaa94zqjlz4nxwqlrbw5n6i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamerauxtheme")
    (synopsis "Supplementary outer and inner themes for Beamer")
    (description
     "This bundle provides a collection of inner and outer themes as supplements to
the default themes in the Beamer distribution.  These themes can be used in
combination with existing inner, outer, and color themes.")
    (license license:lppl1.3c)))

(define-public texlive-beamercolorthemeowl
  (package
    (name "texlive-beamercolorthemeowl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamercolorthemeowl/"
                                     "source/latex/beamercolorthemeowl/"
                                     "tex/latex/beamercolorthemeowl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0z7vj2mmz5na4dflgkflf599kdv0l5mhnd61zacwbnabyzjiyl32"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamercolorthemeowl")
    (synopsis "Flexible Beamer color theme to maximize visibility")
    (description
     "This package provides a flexible dark or light colour theme designed for maximum
readability in environments where most themes fall flat.  Its main features are:
@itemize

@item dark color theme for presenting in low-light conditions;

@item optional light color theme for presenting in bright ambient light;

@item redefines color names @samp{red}, @samp{green}, @samp{blue},
@samp{yellow} to values that are visible when displayed by certain projectors,
particularly those with a very bright green channel and dim red and blue
channels.  This behaviour can be optionally disabled, with the provided
colours also available as @code{OwlRed}, @code{OwlGreen}, etc.

@end itemize")
    (license license:lppl1.3+)))

(define-public texlive-beamerdarkthemes
  (package
    (name "texlive-beamerdarkthemes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamerdarkthemes/"
                                     "tex/latex/beamerdarkthemes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08w0qqzy9ibi48ah7f2mpzlgfb7wnn202gcrbj0n82w3sxn8lilc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamerdarkthemes")
    (synopsis "Dark color themes for Beamer")
    (description
     "This package provides a package with three dark color themes for Beamer,
designed for presentations with pictures and/or for bright rooms without
screen.  These themes mix one dominant foreground colour and a black
background.  Cormorant stands for green, Frigatebird for red and Magpie for
blue.")
    (license (list license:lppl1.3+ license:cc-by4.0))))

(define-public texlive-beamerposter
  (package
    (name "texlive-beamerposter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamerposter/"
                                     "tex/latex/beamerposter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xp8a6d82n1kgagdc7mm7hjihdzn1k7y4lijy924hjdvnvdmqa2i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamerposter")
    (synopsis "Extend Beamer and @code{a0poster} for custom sized posters")
    (description
     "The package enables the user to use Beamer style operations on a canvas of
the sizes provided by @code{a0poster}; font scaling is available (using
packages such as @code{type1cm} if necessary).  In addition, the package
allows the user to benefit from the nice colour box handling and alignment
provided by the Beamer class (for example, with rounded corners and shadows).
Good looking posters may be created very rapidly.")
    (license (list license:lppl license:gpl3+))))

(define-public texlive-beamersubframe
  (package
    (name "texlive-beamersubframe")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamersubframe/"
                                     "source/latex/beamersubframe/"
                                     "tex/latex/beamersubframe/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z1bgrbpfcxr66ldnp2ymr4l6qmmc06v5k91q2av4kfjvanb9bi3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'no-example-file
            (lambda _
              (substitute* "source/latex/beamersubframe/beamersubframe.ins"
                (("\\\\generateexampletrue") "\\generateexamplefalse")))))))
    (home-page "https://ctan.org/pkg/beamersubframe")
    (synopsis "Reorder frames in the PDF file")
    (description
     "The package provides a method to reorder frames in the PDF file without
reordering the source.  Its principal use is to embed or append frames with
details on some subject.")
    (license license:lppl)))

(define-public texlive-beamertheme-arguelles
  (package
    (name "texlive-beamertheme-arguelles")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamertheme-arguelles/"
                                     "tex/latex/beamertheme-arguelles/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0shwf7ygk587rxd8cmvmrhfdcas6m628d0gydr2nv67gdzd0h287"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamertheme-arguelles")
    (synopsis "Simple, typographic Beamer theme")
    (description
     "Arguelles is a Beamer theme that helps you create beautiful presentations.
It aims for simplicity and readability by following best practices of graphic
design.  The layout is elegant but subtle, so as to keep the audience's
attention on your content.")
    (license license:expat)))

(define-public texlive-beamertheme-cuerna
  (package
    (name "texlive-beamertheme-cuerna")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamertheme-cuerna/"
                                     "source/latex/beamertheme-cuerna/"
                                     "tex/latex/beamertheme-cuerna/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1w3vycn4a7ibkamnz6c3rpqy7ccl1zwjakh7dgdcnrcrsl9qvflg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamertheme-cuerna")
    (synopsis "Beamer theme with four colour palettes")
    (description
     "The package contains a theme for Beamer which is referenced as Cuerna inside
Beamer and has four basic colour themes.  The title page shows rectangles that
represent the Fibonacci sequence, and spiral is drawn on top of the
rectangles.  Besides that the rest of the graphic elements in the slides are
scarce to keep it clean.")
    (license license:lppl1.3+)))

(define-public texlive-beamertheme-detlevcm
  (package
    (name "texlive-beamertheme-detlevcm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamertheme-detlevcm/"
                                     "tex/latex/beamertheme-detlevcm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1069xkzznmx0nyi9wk1qj7c2l932fg6s2mvxh9hjhxxdk3dds1l5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamertheme-detlevcm")
    (synopsis "Beamer theme designed for use in the University of Leeds")
    (description
     "The bundle provides a simple theme that has been used in the author's
department.")
    (license license:gpl3+)))

(define-public texlive-beamertheme-epyt
  (package
    (name "texlive-beamertheme-epyt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamertheme-epyt/"
                                     "tex/latex/beamertheme-epyt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "008n9g6zs375cpxvkd245xkfq82d6agdxvrcs84wlvisp1g795a4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamertheme-epyt")
    (synopsis "Simple and clean theme for LaTeX Beamer class")
    (description
     "This package provides a simple but nice theme for Beamer, with the following
features:

@itemize

@item simple structure: with page numbers at footer, no head bar and side
bar ;

@item simple templates: displaying theorems with traditional inline style;

@item simple colors: using only several foreground and background colors.

@end itemize")
    (license license:lppl1.3+)))

(define-public texlive-beamertheme-focus
  (package
    (name "texlive-beamertheme-focus")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamertheme-focus/"
                                     "tex/latex/beamertheme-focus/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10ncd5sc00k1r3ji0q47i21r07inqwfmn7axm8zr396ngqbndv0k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamertheme-focus")
    (synopsis "Minimalist presentation theme for LaTeX Beamer")
    (description
     "This package provides a presentation theme for LaTeX Beamer that aims at
a clean and minimalist design, so to minimize distractions and put the focus
directly on the content.")
    (license license:gpl3)))

(define-public texlive-beamertheme-light
  (package
    (name "texlive-beamertheme-light")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamertheme-light/"
                                     "tex/latex/beamertheme-light/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yknbvp325d3xkgnb76a4ndk2c99mnig6ylmpqrn9srgj1h4ckiw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamertheme-light")
    (synopsis "Minimal Beamer style")
    (description
     "The LaTeX package @code{beamertheme-light} provides an aesthetic and minimal
Beamer style by redefining colors and fonts.")
    (license license:gpl3)))

(define-public texlive-beamertheme-metropolis
  (package
    (name "texlive-beamertheme-metropolis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamertheme-metropolis/"
                                     "source/latex/beamertheme-metropolis/"
                                     "tex/latex/beamertheme-metropolis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vx9w44d5vjb6nr1ic14hknm1j38i02v0nbawwa3xn1z3i4xs8cj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamertheme-metropolis")
    (synopsis "Modern LaTeX beamer theme")
    (description
     "The package provides a simple, modern Beamer theme for anyone to use.  It
tries to minimize noise and maximize space for content.")
    (license license:cc-by-sa4.0)))

(define-public texlive-beamertheme-npbt
  (package
    (name "texlive-beamertheme-npbt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamertheme-npbt/"
                                     "tex/latex/beamertheme-npbt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0za5481fssy2inp6bga83c6gm9klr516scnvnpwl92ad11gzd2cg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamertheme-npbt")
    (synopsis "Collection of LaTeX Beamer themes")
    (description
     "@acronym{NPBT, Norman's Pandoc Beamer Themes} includes three Beamer themes:
Sefiroth Consulting, FOM, FOM ifes and eufom.")
    (license (list license:gpl3 license:public-domain))))

(define-public texlive-beamertheme-phnompenh
  (package
    (name "texlive-beamertheme-phnompenh")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamertheme-phnompenh/"
                                     "tex/latex/beamertheme-phnompenh/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d373v9a2x1kxz48j1c1vfgv6jimp08f1wc9wnh9ahaxf6796qds"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamertheme-phnompenh")
    (synopsis "Simple Beamer theme")
    (description
     "The package provides a simple theme, similar to some others, but designed to
be attractive.")
    (license license:gpl3+)))

(define-public texlive-beamertheme-pure-minimalistic
  (package
    (name "texlive-beamertheme-pure-minimalistic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamertheme-pure-minimalistic/"
                                     "tex/latex/beamertheme-pure-minimalistic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zn8a4jjq5m9d1v0jqr7c4yrhjbhnz5rspbady1cgwn14hpa0xpg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamertheme-pure-minimalistic")
    (synopsis "Minimalistic presentation theme for LaTeX Beamer")
    (description
     "The main features of this minimalistic Beamer theme are:
@itemize
@item easily use own logos;
@item customizable;
@item looks good in a 4:3 and 16:9 aspect ratio;
@item provides an environment for vertically-spaced items;
@item provides light and dark mode;
@item is designed to be purely minimalistic without any distractions.
@end itemize")
    (license license:gpl3+)))

(define-public texlive-beamertheme-saintpetersburg
  (package
    (name "texlive-beamertheme-saintpetersburg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamertheme-saintpetersburg/"
                                     "source/latex/beamertheme-saintpetersburg/"
                                     "tex/latex/beamertheme-saintpetersburg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wnhl4l07x88bw1xps6xygmr704513k2b8jq7g9magq3hjv0bkp0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamertheme-saintpetersburg")
    (synopsis
     "Beamer theme with colours and fonts of Saint Petersburg State University")
    (description
     "This minimalistic beamer Theme incorporates Saint Petersburg State University
colours and fonts.  It is suitable for both presentations and posters.")
    (license license:lppl1.3c)))

(define-public texlive-beamertheme-simpledarkblue
  (package
    (name "texlive-beamertheme-simpledarkblue")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamertheme-simpledarkblue/"
                                     "tex/latex/beamertheme-simpledarkblue/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kp3grbjgkgqqx01lca5afn5s30xi7r04ij9436w97gv15jva2ap"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamertheme-simpledarkblue")
    (synopsis "Template for a simple presentation")
    (description
     "This is a simple but nice theme for Beamer.  Its features are: a simple
structure, with page numbers in footer, no side bar, and simple colors, using
only several foreground and background colors.")
    (license license:public-domain)))

(define-public texlive-beamertheme-simpleplus
  (package
    (name "texlive-beamertheme-simpleplus")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamertheme-simpleplus/"
                                     "tex/latex/beamertheme-simpleplus/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l92d8siv19kdwvaq8mv2jdw3y7vsficmgk1y46q64dakxfwsr9a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamertheme-simpleplus")
    (synopsis "Simple and clean theme for LaTeX beamer")
    (description
     "This package provides a simple and clean theme for LaTeX Beamer.  It can be
used for academic and scientific presentations.")
    (license license:public-domain)))

(define-public texlive-beamertheme-tcolorbox
  (package
    (name "texlive-beamertheme-tcolorbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamertheme-tcolorbox/"
                                     "tex/latex/beamertheme-tcolorbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "153csa3afzb9ys92kjxwcr3npwgczbswpnjypvz6sgjc396rabwj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamertheme-tcolorbox")
    (synopsis
     "Beamer inner theme which reproduces standard Beamer blocks using
@code{tcolorboxes}")
    (description
     "This package provides an inner theme for Beamer which reproduces standard
Beamer blocks using @code{tcolorboxes}.  The look and feel (rounded/sharp
corners, shadows and colours) will automatically adapt to which other themes
are loaded.")
    (license license:lppl1.3c)))

(define-public texlive-beamertheme-trigon
  (package
    (name "texlive-beamertheme-trigon")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamertheme-trigon/"
                                     "source/latex/beamertheme-trigon/"
                                     "tex/latex/beamertheme-trigon/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0djzmf35prnba81k376cj49xmy3scnjbml9aggm31x3crz438f4v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamertheme-trigon")
    (synopsis "Modern, elegant, and versatile theme for Beamer")
    (description
     "This package provides a modern, elegant and versatile theme for Beamer, with
a high degree of customization.  Trigon found its origin and inspiration in
the graphical guidelines resulting from the visual identity overhaul of the
University of Liege.  Although directly inspired from these guidelines, the
theme was stripped out of any mention or specificities related to the
University and its faculties.  This makes the Trigon theme perfectly suitable
for many different contexts.

The main design focuses on triangular shapes for major layout elements and
noise minimization for the main body of the work.  The theme's implementation
is heavily inspired from the Metropolis theme.  Most options from Metropolis
have been ported to Trigon in order to improve customization and ease-of-use.
Trigon also includes different styles and layouts for the main title page, the
section page and the default slide background.")
    (license license:cc-by-sa4.0)))

(define-public texlive-beamertheme-upenn-bc
  (package
    (name "texlive-beamertheme-upenn-bc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamertheme-upenn-bc/"
                                     "tex/latex/beamertheme-upenn-bc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xlknz4y6gklpdsrxiqssgl3fakrs4jqqps8yk689lvg1gqj942c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamertheme-upenn-bc")
    (synopsis
     "Beamer themes for Boston College and the University of Pennsylvania")
    (description
     "This package provides Beamer themes in the colors of the University of
Pennsylvania, USA, and Boston College, USA.  Both were tested for the
presentation theme Warsaw.")
    (license license:lppl)))

(define-public texlive-beamerthemeamurmaple
  (package
    (name "texlive-beamerthemeamurmaple")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamerthemeamurmaple/"
                                     "tex/latex/beamerthemeamurmaple/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1h9hd1rwhgji8f0ca116pvbn2zy0isd1xdxb29y61nxhzf9kffjg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamerthemeamurmaple")
    (synopsis "Modern Beamer theme")
    (description
     "This Beamer theme is a suitable theme for presentations in applied
mathematics research.")
    (license license:lppl1.3+)))

(define-public texlive-beamerthemejltree
  (package
    (name "texlive-beamerthemejltree")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/latex/beamerthemejltree/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02ccd8qqyjkvqqyxr94p1gc6qjryl83vpa72wcm5ywr8gmxci0pi"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamerthemejltree")
    (synopsis "Contributed Beamer theme")
    (description "This package provides a theme for Beamer presentations.")
    (license license:gpl3+)))

(define-public texlive-beamerthemelalic
  (package
    (name "texlive-beamerthemelalic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamerthemelalic/"
                                     "tex/latex/beamerthemelalic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1l3ivw1g2bdjlhs2q8dj95mc7ybylqsqf6l9df56zjys6pd8zwh9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamerthemelalic")
    (synopsis "Beamer theme for LALIC")
    (description
     "This package provides the Beamer theme for @acronym{LALIC, Laboratorio de
Linguistica e Inteligencia Computacional} of the Federal University of Sao
Carlos, Brazil.")
    (license license:gpl3+)))

(define-public texlive-beamerthemenirma
  (package
    (name "texlive-beamerthemenirma")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamerthemenirma/"
                                     "tex/latex/beamerthemenirma/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09p6ip8di5i2gfms3s0iy17175y50v09v23pl5w6977l30wwyyas"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamerthemenirma")
    (synopsis "Beamer theme for academic presentations")
    (description
     "The package is developed for academic purposes.  The distribution includes
nothing more than style file needed for preparing presentations.")
    (license license:lppl)))

(define-public texlive-beamerthemenord
  (package
    (name "texlive-beamerthemenord")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beamerthemenord/"
                                     "tex/latex/beamerthemenord/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wb62lqlzaim5lbc0293cjrg1sxp6knrnsqdb7p2rqqlf46wjh34"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/beamerthemenord")
    (synopsis "Simple Beamer theme using the Nord color theme")
    (description
     "This package provides a simple Beamer theme using the Nord color theme.")
    (license license:lppl1.3c)))

(define-public texlive-bearwear
  (package
    (name "texlive-bearwear")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bearwear/"
                                     "source/latex/bearwear/"
                                     "tex/latex/bearwear/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1brqpn1j62nxg2gj904sm00m7rmkm9q54vdnn1sn4fw4w0y9hg10"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bearwear")
    (synopsis "Shirts to dress TikZbears")
    (description
     "The package offers tools to create shirts for TikZbears from the TikZlings
package.")
    (license license:lppl1.3c)))

(define-public texlive-beaulivre
  (package
    (name "texlive-beaulivre")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beaulivre/"
                                     "tex/latex/beaulivre/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b9i4f8l9cm7bp4wrapyfcgysaa1zas3fzrxx5bvpbyk8jwvrbiw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-colorist))
    (home-page "https://ctan.org/pkg/beaulivre")
    (synopsis "Write your books in a colorful way")
    (description
     "This package provides a LaTeX class for typesetting books with a colorful
design.  Currently, it has native support for Chinese (both simplified and
traditional), English, French, German, Italian, Japanese, Portuguese (European
and Brazilian), Russian and Spanish typesetting.  It compiles with either
@code{XeLaTeX} or @code{LuaLaTeX.} This is part of the colorist class series and
depends on colorist.sty from the colorist package.  The package name \"beaulivre\"
is taken from the French words \"beau\" (= \"beautiful\") and \"livre\" (= \"book\").")
    (license license:lppl1.3c)))

(define-public texlive-beton
  (package
    (name "texlive-beton")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/beton/" "source/latex/beton/"
                                     "tex/latex/beton/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0z5wz89s2jw6c4alkgaqbbr5rglh3m88nbay9ab732s991ln6b50"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/beton")
    (synopsis "Use Concrete fonts")
    (description
     "This package typesets a LaTeX document with the Concrete fonts designed by
Don Knuth and used in his book @emph{Concrete Mathematics}.")
    (license license:lppl)))

(define-public texlive-bewerbung
  (package
    (name "texlive-bewerbung")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bewerbung/"
                                     "source/latex/bewerbung/"
                                     "tex/latex/bewerbung/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nimbimwk5z0y7vaw29dn77vr2hfd8wzv1rqdj8vqwk5lf2jsf67"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bewerbung")
    (synopsis "Typesetting job applications")
    (description
     "The package provides packages and classes for typesetting applications with
titlepage, cover letter, CV and additional documents in just a single
document.  There is also a class for printing a table of the latest
applications that can be shown to the German authorities.  The data for these
applications can be maintained in a simple CSV file.")
    (license license:lppl1.3+)))

(define-public texlive-bez123
  (package
    (name "texlive-bez123")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bez123/" "source/latex/bez123/"
                                     "tex/latex/bez123/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "140caf7ng0ivhiqk0njwpqbivwmv54il7nh5ks2rji765zvsg2h5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bez123")
    (synopsis "Support for Bezier curves")
    (description
     "This package provides additional facilities in a @code{picture} environment
for drawing linear, cubic, and rational quadratic Bezier curves (standard
LaTeX only offers non-rational quadratic splines).  It also ships with the
LaTeX package @code{multiply} that provides a command for multiplication of
a length without numerical overflow.")
    (license license:lppl1.3+)))

(define-public texlive-bhcexam
  (package
    (name "texlive-bhcexam")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/bhcexam/"
                                     "tex/xelatex/bhcexam/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hcj2xjgcmi0ck8mj44sr9jqk6rw639kq4wmyr1afb5i36qdja05"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bhcexam")
    (synopsis "@code{exam} class for mathematics teachers in China")
    (description
     "This @code{exam} class is specially designed for mathematics teachers in
China.  Using BHCexam you can separate the format and the content very well;
export both teacher paper and student paper; typeset multiple choice questions
with 3-6 options keeping adaptively neat alignment; typeset cloze questions
with a customizable underline; typeset questions with subquestions in lists;
group questions in a list to control whether to show score, leave spacing,
initialize question number; and more.")
    (license license:lppl1.3+)))

(define-public texlive-bibletext
  (package
    (name "texlive-bibletext")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bibletext/"
                                     "tex/latex/bibletext/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1w7w1wf4ll77fjkwjb0akvms8hyyrs1gp84zk69f9z97330iapms"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bibletext")
    (synopsis "Insert @emph{Bible} passages by their reference")
    (description
     "The package allows inserting @emph{Bible} texts in a document by specifying
references.")
    (license license:expat)))

(define-public texlive-bigints
  (package
    (name "texlive-bigints")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bigints/" "tex/latex/bigints/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ly9kqyi954gd41rjmpdml60s4my0d8b7ldq3crcc3i7sqjnc4fw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bigints")
    (synopsis "Writing big integrals")
    (description
     "The package provides facilities for drawing big integral signs when needed.
An example would be when the integrand is a matrix.")
    (license license:lppl)))

(define-public texlive-bilingualpages
  (package
    (name "texlive-bilingualpages")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bilingualpages/"
                                     "tex/latex/bilingualpages/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0byjjkbswy7m80qdw2q3k9nqkgkyw4ary40ccgrq7m1dnirrnb48"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bilingualpages")
    (synopsis "Typeset two columns in parallel")
    (description
     "This is a simple wrapper for the @code{paracol} package for setting
two-column parallel text.")
    (license license:lppl1.3c)))

(define-public texlive-biochemistry-colors
  (package
    (name "texlive-biochemistry-colors")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/biochemistry-colors/"
                                     "tex/latex/biochemistry-colors/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10c7gw5ldsniz7bkzw9a8nzza1zgyphdjk6n8laf0rryjhwriml2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/biochemistry-colors")
    (synopsis
     "Colors used to display amino acids, nucleotides, sugars or atoms in
biochemistry")
    (description
     "@file{Biochemistry-colors.sty} defines the standard colors of biochemistry
for use with the @code{color} package and the @code{xcolor} package.  Colors
include:

@itemize
@item Shapely-colors for amino acids and nucleotides;
@item CPK-Colors (Corey, Pauling and Koltun) of elements;
@item Jmol-colors of elements, important isotopes and structures;
@item Glycopedia colors for sugars.
@end itemize")
    (license (list license:lppl license:gpl3+))))

(define-public texlive-bithesis
  (package
    (name "texlive-bithesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bithesis/"
                                     "source/latex/bithesis/"
                                     "tex/latex/bithesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0x3i7m7nwqpw9msznn1a4imc5iza6i78jd0zk4fzkvad029l3nm4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bithesis")
    (synopsis "Templates for the Beijing Institute of Technology")
    (description
     "This package establishes a simple and easy-to-use LaTeX template for Beijing
Institute of Technology dissertations, including general undergraduate theses
and master theses.")
    (license license:lppl1.3c)))

(define-public texlive-bizcard
  (package
    (name "texlive-bizcard")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bizcard/" "source/latex/bizcard/"
                                     "tex/latex/bizcard/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b5rnh1jm125yak8nd36nf0zk456pxmakr77z7fbq2h9a6q8fbzb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bizcard")
    (synopsis "Typeset business cards")
    (description
     "This package helps typesetting business cards.  It produces cards at the
normal US card size, 76.2mm x 50.8mm.")
    (license license:gpl3+)))

(define-public texlive-blkarray
  (package
    (name "texlive-blkarray")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/blkarray/" "tex/latex/blkarray/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ra2incawl5909lvwdiq08rhpcppv2hcwsaswqmhf8m1q4p1i57r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/blkarray")
    (synopsis "Extended @code{array} and @code{tabular}")
    (description
     "This is an experimental package which implements an environment,
@code{blockarray}, that may be used in the same way as the @code{array} or
@code{tabular} environments of standard LaTeX, or their extended versions
defined in @code{array}.  If used in math-mode, @code{blockarray} acts like
@code{array}, otherwise it acts like @code{tabular}.  The package implements
a new method of defining column types, and also @code{block} and @code{block*}
environments, for specifying sub-arrays of the main array.  What's more, the
@code{\\footnote} command works inside a @code{blockarray}.")
    (license license:lppl)))

(define-public texlive-block
  (package
    (name "texlive-block")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/block/" "tex/latex/block/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02pvrxjds8qwqjq3ncqf1s9z96pmci98v3nj6dc9xy98gvc6r1h9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/block")
    (synopsis "Block letter style for the @code{letter} class")
    (description
     "This package provides a style file for use with the @code{letter} class that
overwrites the @code{\\opening} and @code{\\closing} macros so that letters
can be styled with the block letter style instead of the default style.  Thus,
the return address, the closing, and the signature appear flushed on the left
margin.")
    (license license:public-domain)))

(define-public texlive-blowup
  (package
    (name "texlive-blowup")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/blowup/" "source/latex/blowup/"
                                     "tex/latex/blowup/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1d81c5y89ssc153dg2yx8lbmwcpa2day3wbavppbymjfcsz1qs6h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/blowup")
    (synopsis "Upscale or downscale all pages of a document")
    (description
     "The package @code{blowup} only defines the user-level macro @code{\\blowUp},
which can be used to upscale or downscale all pages of a document.  It is
similar to the TeX primitive @code{\\magnification} but more accurate and
user-friendly.")
    (license license:lppl1.3+)))

(define-public texlive-bnumexpr
  (package
    (name "texlive-bnumexpr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bnumexpr/"
                                     "source/latex/bnumexpr/"
                                     "tex/latex/bnumexpr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01d91gb1f6iqzh6krc21fc1akvh8w2v3flpq02kig915w7w9r4sn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bnumexpr")
    (synopsis
     "Extends eTeX's @code{\\numexpr...\\relax} construct to big integers")
    (description
     "The package extends e-TeX @code{\\numexpr...\\relax} operation to allow big
integers, powers, factorials, truncated division and its associated modulo.")
    (license license:lppl1.3c)))

(define-public texlive-boites
  (package
    (name "texlive-boites")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/boites/" "source/latex/boites/"
                                     "tex/latex/boites/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dinh5p4vvm7g9hdki329ik8v6d3ci5v20hpiv2960cq0l99bf08"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/boites")
    (synopsis "Boxes that may break across pages")
    (description
     "This package defines environments that allow page breaks inside framed boxes
whose edges may be variously fancy.  The bundle includes a few
examples (shaded box, box with a wavy line on its side, etc).")
    (license license:gpl3+)))

(define-public texlive-bold-extra
  (package
    (name "texlive-bold-extra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bold-extra/"
                                     "tex/latex/bold-extra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zxrgc51w0bx8bsgwy9qymfjskhnhycg0lrq47jmzfcglawp5137"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bold-extra")
    (synopsis "Use bold small caps and typewriter fonts")
    (description
     "This package allows access to extra bold fonts for Computer Modern OT1
encoding (the fonts are available in Metafont source).  Since there is more
than one bold tt-family font set, the version required is selected by
a package option.")
    (license license:lppl)))

(define-public texlive-book-of-common-prayer
  (package
    (name "texlive-book-of-common-prayer")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/book-of-common-prayer/"
                                     "tex/latex/book-of-common-prayer/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b2wbvyh2z9yy9gj5wp553dgfm6zq9l7x8bxr8cippcplcmnz6rr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/book-of-common-prayer")
    (synopsis "Typeset in the style of @emph{Book of Common Prayer}")
    (description
     "This a package for the typesetting of liturgical documents in the style of
the 1979 @emph{Book of Common Prayer}.  It provides macros for common
liturgical situations (e.g., versicle and response, longer prayers, etc.).
This package is designed to work with the Sabon font, but it is not necessary
to run the macros.")
    (license license:lppl1.3c)))

(define-public texlive-bookest
  (package
    (name "texlive-bookest")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bookest/" "tex/latex/bookest/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0izmdkyi3laiaapksd81imk6hfqc6b0f6m70bx2xl9mcc592adw4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bookest")
    (synopsis "Extended @code{book} class")
    (description
     "The class extends the standard @code{book} class, in the areas of colour
scheme management, document layout, headings and footers, front page layout,
and other minor items.")
    (license license:lppl)))

(define-public texlive-booklet
  (package
    (name "texlive-booklet")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/booklet/" "source/latex/booklet/"
                                     "tex/latex/booklet/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hb1xhw2zssrhk3yipari2a7g1nhz7f48s52b0a6c5fl9l0bpk64"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/booklet")
    (synopsis "Aids for printing simple booklets")
    (description
     "Pages of a document processed with the booklet package will be reordered and
scaled so that they can be printed as four pages per physical sheet of paper,
two pages per side.  The resulting sheets will, when folded in half, assemble
into a booklet.")
    (license license:lppl1.3+)))

(define-public texlive-bookshelf
  (package
    (name "texlive-bookshelf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bookshelf/"
                                     "source/latex/bookshelf/"
                                     "tex/latex/bookshelf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1md1mlm2yc64nmrjcpn754k5akc25273yvi68pgxj9gc86v5167a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bookshelf")
    (synopsis "Create a nice image from a BibTeX file")
    (description
     "This package turns a BibTeX bibliography file into a randomly-coloured,
randomly-sized shelf of books, with the title and author in a randomly-chosen
typeface.")
    (license license:lppl1.3+)))

(define-public texlive-boolexpr
  (package
    (name "texlive-boolexpr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/boolexpr/"
                                     "source/latex/boolexpr/"
                                     "tex/latex/boolexpr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1274l5q5nn1la2c5cbgvwmkpqhb28a94vsz92d3rsqgcahjdgapq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/boolexpr")
    (synopsis "Boolean expression evaluator and a switch command")
    (description
     "The @code{\\boolexpr} macro evaluates boolean expressions in a purely
expandable way.  @samp{\\boolexpr@{ A \\OR B \\AND C @}} expands to 0 if the
logical expression is TRUE.  A, B, C may be:

@itemize

@item numeric expressions such as: @samp{x=y}, @samp{x<>y}, @samp{x>y} or
@samp{x<y};

@item boolean switches: @samp{\\iftrue 0\\else 1\\fi};

@item conditionals: @samp{\\ifcsname whatsit\\endcsname 0\\else 1\\fi};

@item another @code{\\boolexpr}: @samp{\\boolexpr@{ D \\OR E \\AND F @}}.

@end itemize

@code{\\boolexpr} may be used with @code{\\ifcase}.

The @code{\\switch} command (which is also expandable) has the form:
@samp{\\switch \\case@{<boolean expression>@} ... \\case@{<boolean
expression>@} ...  ... \\otherwise ... \\endswitch}.")
    (license license:lppl)))

(define-public texlive-bophook
  (package
    (name "texlive-bophook")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bophook/" "source/latex/bophook/"
                                     "tex/latex/bophook/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zxaxrgjs4rpdsb2mbk4zslhy64md2m7ngc5p7w8cyjf1f7swb2h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/bophook")
    (synopsis "Provides an @code{\\AtBeginPage} hook")
    (description
     "Using the @code{\\AtBeginPage} hook provided by this package, you can add
material in the background of a page.  @code{\\PageLayout} can be used to give
page makeup commands to be executed on every page (e.g., depending on the page
style).")
    (license license:lppl)))

(define-public texlive-boxedminipage
  (package
    (name "texlive-boxedminipage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/boxedminipage/"
                                     "source/latex/boxedminipage/"
                                     "tex/latex/boxedminipage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jbgvacs81wvd3f9k969r3rj2z6lfsimqzpyp4j3h4db4qhc0w8d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/boxedminipage")
    (synopsis
     "Framed minipages of a specified total width (text and frame combined)")
    (description
     "The package essentially just wraps a @code{minipage} within an @code{\\fbox}.
However, while
@samp{\\fbox@{\\begin@{minipage@}@{\\linewidth@}...\\end@{minipage@}@}} juts
out into the margin, @samp{\\begin@{boxedminipage@}...\\end@{boxedminipage@}}
does not.  Instead, it subtracts the frame's dimensions from the specified
dimensions of the @code{minipage} before typesetting the @code{minipage}.")
    (license license:lppl1.3c)))

(define-public texlive-boxhandler
  (package
    (name "texlive-boxhandler")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/boxhandler/"
                                     "source/latex/boxhandler/"
                                     "tex/latex/boxhandler/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19vyasxd17akk5dvrw37pn3s8gjkpgr8qwsqqbxij5hf5qix6qqf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/boxhandler")
    (synopsis "Flexible captioning and deferred box/list printing")
    (description
     "The package allows the user to optimise presentation of LaTeX tables and
figures.  Boxhandler will lay out table and figure captions with a variety of
stylistic apperances, and will also allow figures and tables to be wrapped in
a manner consistent with many business and government documents.  For
a document that might appear in different venues with different formatting,
boxhandler permits the creation of a LaTeX source document that can, with
a single-line change in the source code, produce an output that has very
different layout from the baseline configuration, not only in terms of caption
style, but more importantly in terms of the locations where figures, tables
and lists appear (or not) in the document.  Deferral routines also allow one
to keep all figure and table data in a separate source file, while nonetheless
producing a document with figures and tables appearing in the desired
location.")
    (license license:lppl)))

(define-public texlive-bracketkey
  (package
    (name "texlive-bracketkey")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bracketkey/"
                                     "tex/latex/bracketkey/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07gkjxcbycfy39wylm880wnkcw6p6sm5by47vhdlwraqkbx65a94"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bracketkey")
    (synopsis "Produce bracketed identification keys")
    (description
     "The package provides an environment @code{bracketkey} for use when producing
lists of species.")
    (license license:lppl1.3+)))

(define-public texlive-braket
  (package
    (name "texlive-braket")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/braket/" "tex/latex/braket/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "092wk3zc6zajgi6l9h9zna3ksk6k6y4gi8slnfk6vldndcg5sbqn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/braket")
    (synopsis "Dirac bra-ket and set notations")
    (description
     "This package provides macros to typeset bra-ket notation, as well as set
specifiers, with a single (@samp{|}) or a double (@samp{||} or @samp{\\|})
vertical bar specifier in between two bracketed parts.  Each macro comes in
a fixed-size version and an expanding version.")
    (license license:public-domain)))

(define-public texlive-bubblesort
  (package
    (name "texlive-bubblesort")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bubblesort/"
                                     "source/latex/bubblesort/"
                                     "tex/latex/bubblesort/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gmrw2m0gr082xj5qmjr6bc0gk7wqqzs38mrf3nmymbd7nv21crd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bubblesort")
    (synopsis "Bubble sorts a list")
    (description
     "This package sorts a list of TeX items in increasing order where increasing
is determined by a comparator macro.  By default it sorts real numbers with
the usual meaning of increasing but some other examples are discussed in the
documentation.  A second macro is included which sorts one list and applies
the same permutation to a second list.")
    (license license:lppl1.3c)))

(define-public texlive-bullcntr
  (package
    (name "texlive-bullcntr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bullcntr/"
                                     "source/latex/bullcntr/"
                                     "tex/latex/bullcntr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pbyp7s1ylrpv13d9m5wk949rjk15xh4hqdi278wf1qav8w71h66"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:phases
           #~(modify-phases %standard-phases
               ;; Build process displays an infobox and waits for
               ;; user's input.  Skip this part.
               (add-before 'build 'skip-infobox
                 (lambda _
                   (substitute* "source/latex/bullcntr/bullcntr.ins"
                     (("\\Ask.*") "")
                     (("\\(your .*? will be ignored\\).*") "")))))))
    (home-page "https://ctan.org/pkg/bullcntr")
    (synopsis "Display list item counter as regular pattern of bullets")
    (description
     "The @code{bullcntr} package defines the command @code{\\bullcntr},
which may be thought of as an analogue of the @code{\\fnsymbol} command: like
the latter, it displays the value of a counter lying between 1 and 9, but
uses, for the purpose, a regular pattern of bullets.")
    (license license:lppl1.3+)))

(define-public texlive-bxcalc
  (package
    (name "texlive-bxcalc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bxcalc/" "tex/latex/bxcalc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bfg0pg5xk3k9wxzvwssr9xb9z94ij24h17jc0mri25c05asng3y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bxcalc")
    (synopsis "Extend the functionality of the @code{calc} package")
    (description
     "This package bundle consists of the following packages: @code{bxcalcize}, to
make @code{calc} expressions available in more places, and @code{bxcalcux}, to
add user-defined units to the @code{calc} syntax.

In addition, this bundle provides the @code{bxcalc} package, which simply
loads the above-mentioned packages internally.")
    (license license:expat)))

(define-public texlive-bxdpx-beamer
  (package
    (name "texlive-bxdpx-beamer")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bxdpx-beamer/"
                                     "tex/latex/bxdpx-beamer/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "067s7qvz5hzq6kvwkc00na0myhgwws111mhx8xsgkpcl5a2ja7cz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bxdpx-beamer")
    (synopsis "Dvipdfmx extras for use with Beamer")
    (description
     "The package is a driver to support Beamer navigation symbols and
@code{\\framezoomed} regions when using @command{dvipdfmx} as PDF
generator (e.g., as part of e-pTeX).  The package does not define any user
commands.")
    (license license:expat)))

(define-public texlive-bxdvidriver
  (package
    (name "texlive-bxdvidriver")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bxdvidriver/"
                                     "tex/latex/bxdvidriver/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x5ah28mlimw9923xm5sz03vzzhharjw0hgbp63fvbj45ihmbxnm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bxdvidriver")
    (synopsis
     "Enables specifying a driver option effective only in DVI output")
    (description
     "This single-function package enables authors to specify a global driver option
(dvips, dvipdfmx, etc) which is applied only when the engine outputs a DVI
file.  It is useful to create special document- templates that can be compiled
in both PDF-mode and DVI-mode.")
    (license license:expat)))

(define-public texlive-bxenclose
  (package
    (name "texlive-bxenclose")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bxenclose/"
                                     "tex/latex/bxenclose/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0s9xy8bp56bhi94djx0vxh6qsyz5nvqm8zkgag0900vfj2d339dh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bxenclose")
    (synopsis "Enclose the document body with some pieces of code")
    (description
     "The package enables authors to designate in the preamble to make the document
body enclosed with the given pieces of code.  As is known, there are already
various mechanisms provided by LaTeX kernel or packages that attach hooks at
the beginning and end of documents.")
    (license license:expat)))

(define-public texlive-bxnewfont
  (package
    (name "texlive-bxnewfont")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bxnewfont/"
                                     "tex/latex/bxnewfont/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b37y0bpsxwiygd5ffm1r5h8rakdrmz5xxkd0lgrjf3v73hsbvzv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bxnewfont")
    (synopsis "Enhanced @code{\\newfont} command")
    (description
     "This package provides a new command @code{\\newfontx}.  It is similar to the
old (and deprecated) command @code{\\newfont} in function, but is more
compatible with NFSS.  In particular, one can safely change font size after
invoking a font command defined by @code{\\newfontx}.")
    (license license:expat)))

(define-public texlive-bxpapersize
  (package
    (name "texlive-bxpapersize")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bxpapersize/"
                                     "tex/latex/bxpapersize/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1133p7xl0dqakqsh3cvhd7yx0j8zcqmwhf82fmphsclvbgwycyhs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bxpapersize")
    (synopsis "Synchronize output paper size with layout paper size")
    (description
     "As is well known, in LaTeX processing layout paper size specified by document
class options is not automatically applied to output paper size.  This package
enables LaTeX authors to synchronize both kinds of paper sizes.")
    (license license:expat)))

(define-public texlive-bxpdfver
  (package
    (name "texlive-bxpdfver")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bxpdfver/" "tex/latex/bxpdfver/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l5hzmr3agpvwnnifqhrb8381gdkryr88r639f890gdiz1qdizad"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bxpdfver")
    (synopsis "Specify version and compression level of output PDF files")
    (description
     "This package enables users to specify in their sources the following settings
on the PDF document to output: PDF version (1.4, 1.5 etc.); whether or not to
compress streams; whether or not to use object streams.  This package supports
all major PDF-output engines and @command{dvipdfmx}.")
    (license license:expat)))

(define-public texlive-bxtexlogo
  (package
    (name "texlive-bxtexlogo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/bxtexlogo/"
                                     "tex/latex/bxtexlogo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kd2gyz8a5pkqh8am7ydcndykcrmjlcg0bwsabz61aklyrvaxsdv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/bxtexlogo")
    (synopsis "Additional TeX-family logos")
    (description
     "The @code{hologo} package provides many useful logos of popular (and not so
popular) TeX-family software.  However, its interface is a bit cumbersome
because you must type @code{\\hologo{BibTeX}} instead of @code{\\BibTeX}.
This package makes it possible to import some of the logos provided by
@code{hologo} as single commands, such as @code{\\BibTeX}.

Additionally, the package provides logos of some TeX-family software that is
popular mainly in Japan.  These logos can be imported in the same way as those
provided by the @code{\\hologo} command.")
    (license license:expat)))

(define-public texlive-calcage
  (package
    (name "texlive-calcage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/calcage/" "source/latex/calcage/"
                                     "tex/latex/calcage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zk85kmgh7rkmgib6pqccdf4wpr3kpwkszcx5dni2g9np4ggpijs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/calcage")
    (synopsis "Calculate the age of something, in years")
    (description
     "The package calculates the age of someone or something in years.  Internally
it uses the @code{datenumber} package to calculate the age in days; conversion
from days to years is then performed, taking care of leap years and such odd
things.")
    (license license:lppl1.3+)))

(define-public texlive-calctab
  (package
    (name "texlive-calctab")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/calctab/" "tex/latex/calctab/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fv5rc42v4ijrrhydq8r79lk3pviqd3adv4nxcbd6px89l6ni6x4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/calctab")
    (synopsis "Language for numeric tables")
    (description
     "The @code{calctab} package helps the user to typeset a kind of economic table
such as invoices, expense notes and liquidation, or other tabular material
with a values column.  The code computes sum and percentage with floating
point numeric methods and builds the render table task.")
    (license license:lppl)))

(define-public texlive-calculator
  (package
    (name "texlive-calculator")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/calculator/"
                                     "source/latex/calculator/"
                                     "tex/latex/calculator/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ji8i6nnd024924cxgg3563c19wrmy7gw8rpp7ddk7zbjwn492m7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/calculator")
    (synopsis "Use LaTeX as a scientific calculator")
    (description
     "The @code{calculator} and @code{calculus} packages define several
instructions which allow us to realise algebraic operations and to evaluate
elementary functions and derivatives in our documents.  The package's main
goal is to define the arithmetic and functional calculations needed in the
package @code{xpicture}, but the numeric abilities of @code{calculator} and
@code{calculus} may be useful in other contexts.")
    (license license:lppl1.3+)))

(define-public texlive-cals
  (package
    (name "texlive-cals")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cals/" "source/latex/cals/"
                                     "tex/latex/cals/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zjh44f5sknz0lj0zn9mslyj7aw5wnjwnlb6427r4lqf2ph31jlq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cals")
    (synopsis "Multipage tables with wide range of features")
    (description
     "The package is a set of macros to typeset multipage tables with repeatable
headers and footers, with cells spanned over rows and columns.  Decorations are
supported: padding, background color, width of separation rules.")
    (license license:lppl1.3+)))

(define-public texlive-calxxxx-yyyy
  (package
    (name "texlive-calxxxx-yyyy")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/calxxxx-yyyy/"
                                     "tex/latex/calxxxx-yyyy/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ys5wplskpa2bxlbaab8lsfz5qa2z4f31hs6ld3b4xi4n6kk4zbq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/calxxxx-yyyy")
    (synopsis "Print a calendar for a group of years")
    (description
     "The package prints a calendar for two or more years, according to a language
selection.  The package is also culture dependent in the sense that it will
start weeks according to local rules: e.g., weeks conventionally start on
Monday in the English-speaking world.")
    (license license:lppl1.3c)))

(define-public texlive-cancel
  (package
    (name "texlive-cancel")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cancel/" "tex/latex/cancel/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yb0mwmkdh3p1rsj3d37nkxll24ign348gfdbb7j97i9d6mlaamy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cancel")
    (synopsis "Place lines through maths formulae")
    (description
     "This package draws diagonal lines (``cancelling'' a term) and arrows with
limits (cancelling a term ``to a value'') through parts of maths formulae.")
    (license license:public-domain)))

(define-public texlive-canoniclayout
  (package
    (name "texlive-canoniclayout")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/canoniclayout/"
                                     "source/latex/canoniclayout/"
                                     "tex/latex/canoniclayout/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cy2h0j7jarvfwdviy248laq6h9dyrj902kwd78m7l9lhmcpdkx6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/canoniclayout")
    (synopsis "Create canonical page layouts with @code{memoir}")
    (description
     "This package provides a canonic text layout has specified relations to
a circle inscribed within the enclosing page.  The package allows the user to
use a canonic layout with the @code{memoir} class.")
    (license license:lppl1.3+)))

(define-public texlive-captcont
  (package
    (name "texlive-captcont")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/captcont/"
                                     "source/latex/captcont/"
                                     "tex/latex/captcont/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00k6ks2nwqwm37pk9m0zl755q8cvdg8kcwbbw5vwiyrqpifpmwyc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'fix-build
            ;; This phase is necessary because the build phase is reluctant to
            ;; generate "ltxdoc.cfg" since there is another one among the
            ;; inputs already.
            (lambda _
              (substitute* "source/latex/captcont/captcont.ins"
                (("\\\\generateFile\\{ltxdoc\\.cfg\\}\\{t\\}")
                 "\\generateFile{ltxdoc.cfg}{f}")))))))
    (home-page "https://ctan.org/pkg/captcont")
    (synopsis "Retain float number across several floats")
    (description
     "The @code{captcont} package provides the ability to continue the numbering in
your float environment with minimal overhead.  This package adds three
commands: @code{\\caption*}, @code{\\captcont}, and @code{\\captcont*}.")
    (license license:lppl)))

(define-public texlive-captdef
  (package
    (name "texlive-captdef")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/captdef/" "tex/latex/captdef/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0arj6qqzq6idhbp1zm51z0ad8jyghkrp4yg34ybl7zshaxnm4ixn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/captdef")
    (synopsis "Declare free-standing @code{\\caption} commands")
    (description
     "The @code{\\DeclareCaption} command defines a class of caption command
associated with the counter specified to the command.  These commands are
free-standing (i.e., don't need to be inside a float environment).  The
package uses @code{\\DeclareCaption} to define @code{\\figcaption} and
@code{\\tabcaption}, which can be used outside @code{figure} or @code{table}
environments.")
    (license license:lppl)))

(define-public texlive-carbohydrates
  (package
    (name "texlive-carbohydrates")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/carbohydrates/"
                                     "tex/latex/carbohydrates/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bczdi2wykragsl4ncy955wi7fdn8y4ppk51jprlvx9bg67g4wjv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/carbohydrates")
    (synopsis "Carbohydrate molecules with @code{chemfig}")
    (description
     "This package offers macros that make the preparation of exercise sheets for
teaching carbohydrate chemistry a lot less tedious.  It uses @code{chemfig}
for drawing the formulas.  Different representation models (Fischer, Haworth,
chair...) are supported as well as alpha, beta, and chain isomers.")
    (license license:lppl1.3+)))

(define-public texlive-cases
  (package
    (name "texlive-cases")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cases/" "tex/latex/cases/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0n108l0k9xla9fd5dvnfgvy7pzdy0rzq8p86a6m7ia6kwn3gjwgp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cases")
    (synopsis "Numbered cases environment")
    (description
     "This package provides a LaTeX environment @code{numcases} to produce
multi-case equations with a separate equation number for each case.  There is
also a @code{subnumcases} environment which numbers each case with the overall
equation number plus a letter.")
    ;; These macros may be freely transmitted, reproduced, or modified
    ;; provided that this notice is left intact.
    (license (license:fsf-free "file://doc/latex/cases/README"))))

(define-public texlive-casyl
  (package
    (name "texlive-casyl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/casyl/"
                                     "fonts/source/public/casyl/"
                                     "fonts/tfm/public/casyl/" "tex/latex/casyl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dxl04m0inilv4jhq4w6haw0g7hd3svyhy3g9x946xydf7zrfjg6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/casyl")
    (synopsis "Typeset Cree/Inuktitut in Canadian Aboriginal syllabics")
    (description
     "The bundle constitutes a font (as Metafont source) and LaTeX macros for its
use within a document.")
    (license license:public-domain)))

(define-public texlive-catchfilebetweentags
  (package
    (name "texlive-catchfilebetweentags")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/catchfilebetweentags/"
                                     "source/latex/catchfilebetweentags/"
                                     "tex/latex/catchfilebetweentags/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11zkhb69gaabcdi1h41iz5yfkq90ch9zfkpnfqf1slvrfy8d8bzc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/catchfilebetweentags")
    (synopsis "Catch text delimited by @code{docstrip} tags")
    (description
     "This package provides a macro @code{\\catchfilebetweentags} acts like the
original @code{\\catchfile} but only extracts a portion of the file instead of
the complete file.  The extracted portion can be delimited by strings or by
docstrip tags.")
    (license license:lppl1.3+)))

(define-public texlive-catechis
  (package
    (name "texlive-catechis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/catechis/"
                                     "source/latex/catechis/"
                                     "tex/latex/catechis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08h5cd1nrvmxw6nbb3z676lxl72zqplnws3bc5vq3j3sjdirgxlg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/catechis")
    (synopsis "Macros for typesetting catechisms")
    (description
     "The macros include: format for question-and-answer; comments on answers;
lengthier explanations of answers; citations.  The formatting of all the macros
is highly (and simply) customizable.")
    (license license:lppl1.3+)))

(define-public texlive-catoptions
  (package
    (name "texlive-catoptions")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/catoptions/"
                                     "tex/latex/catoptions/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gppgs5i1c2xqrrya6r71r95dsbi4wfrqrsz05611lmrddg4imv4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/catoptions")
    (synopsis "Preserving and recalling standard catcodes")
    (description
     "The package changes package loading internals so that all subsequently loaded
packages can rely on normal/standard catcodes of all ASCII characters.  The
package defines canonical control sequences to represent all the visible ASCII
characters.  It also provides robust option parsing mechanisms
@code{(XDeclareOption}, @code{XExecuteOptions} and @code{XProcessOptions},
which will be used by @code{\\documentclass} if the package has already been
loaded).  The package also provides a range of other TeX programming tools.")
    (license license:lppl1.3+)))

(define-public texlive-cbcoptic
  (package
    (name "texlive-cbcoptic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cbcoptic/"
                                     "fonts/source/public/cbcoptic/"
                                     "fonts/tfm/public/cbcoptic/"
                                     "fonts/type1/public/cbcoptic/"
                                     "tex/latex/cbcoptic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d5g6qxvjm7qzkg0i4xqr674nbs4hvw06582mdv7qc9gsf1m4wl4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/cbcoptic")
    (synopsis
     "Coptic fonts and LaTeX macros for general usage and for philology")
    (description
     "CBcoptic is a bundle of files for typesetting Coptic philological text with
the proper fonts and hyphenation.  The fonts are based on, but much extend,
the fonts of the original @code{coptic} bundle.  The CBcoptic bundle includes
font description files, Metafont sources and equivalent Adobe Type 1 fonts in
PFB format.  The bundle also includes a package that provides some macros of
philological interest.")
    (license license:lppl)))

(define-public texlive-ccaption
  (package
    (name "texlive-ccaption")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ccaption/"
                                     "source/latex/ccaption/"
                                     "tex/latex/ccaption/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c211xqpfdkrg6xax9zab706gr0ws4lypsb67q81pw6lpjsl20ya"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ccaption")
    (synopsis "Continuation headings and legends for floats")
    (description
     "This package provides a package providing commands for continuation captions,
unnumbered captions, and also a non-specific legend heading for any
environment.  Methods are also provided to define captions for use outside
float (e.g., @code{figure} and @code{table}) environments, and to define new
float environments and lists of floats.  Tools are provided for specifying
your own captioning styles.")
    (license license:lppl1.3+)))

(define-public texlive-cclicenses
  (package
    (name "texlive-cclicenses")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cclicenses/"
                                     "source/latex/cclicenses/"
                                     "tex/latex/cclicenses/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "166pis25x18plpqm7y1ir4lwsm4ahxvn6q44gh686rsf49f4ky6p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cclicenses")
    (synopsis "Typeset Creative Commons licence logos")
    (description
     "The @code{cclicenses} package helps users typesetting Creative Commons logos
in LaTeX. It defines some commands useful to quickly write these logos,
related to CC licences versions 1.0 and 2.0.")
    (license license:lppl)))

(define-public texlive-cd
  (package
    (name "texlive-cd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cd/" "source/latex/cd/"
                                     "tex/latex/cd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19r5xhrdjsvxhci440apwb85srbw0lrs43hgfipjjzvx8i92n2ab"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cd")
    (synopsis "Typeset CD covers")
    (description
     "This package helps typesetting CD covers.  Normal usage will ordinarily
require no more than a simple data file per cover; the package will make
a full insert for a CD case (it copes with both normal and slim cases).")
    (license license:gpl3+)))

(define-public texlive-cd-cover
  (package
    (name "texlive-cd-cover")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cd-cover/"
                                     "source/latex/cd-cover/"
                                     "tex/latex/cd-cover/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r9msar7x87ibjw3wgh9m6xnrw01khnsdc20g0jhhrn53fyrxhg9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cdcover")
    (synopsis "Typeset CD covers")
    (description
     "The CD-cover class will typeset front and back cover sheets for CD jewel
cases, or an entire paper cover, or a label for a plastic slip-cover.")
    (license license:gpl3+)))

(define-public texlive-cdcmd
  (package
    (name "texlive-cdcmd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cdcmd/" "source/latex/cdcmd/"
                                     "tex/latex/cdcmd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11qd65ag4bsj1s5b7x11y5444pa0za4vh5n7gl9cw4zy10ccl2rz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cdcmd")
    (synopsis "Expandable conditional commands for LaTeX")
    (description
     "This package provides some conditional commands, just like the
@code{styledcmd} package.  The difference is that cdcmd can define expandable
conditional commands.")
    (license license:lppl1.3c)))

(define-public texlive-cdpbundl
  (package
    (name "texlive-cdpbundl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cdpbundl/"
                                     "source/latex/cdpbundl/"
                                     "tex/latex/cdpbundl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rqrfpmwjw1vri6lcqm01jhnfhwxs6p8w9x3998calrffiiglasv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          (add-after 'unpack 'non-interactive-build
            ;; When it realizes it cannot employ the usedir directive,
            ;; the build process stops and waits for an input before
            ;; inserting generated files in the working directory.  Do
            ;; not ask for an input.
            (lambda _
              (substitute* "source/latex/cdpbundl/cdpbundl.ins"
                (("\\Ask.*") "")
                (("\\(your .*? will be ignored\\).*") "")))))))
    (home-page "https://ctan.org/pkg/cdpbundl")
    (synopsis "Business letters in the Italian style")
    (description
     "The C.D.P. Bundle can be used to typeset high-quality business letters
formatted according to Italian style conventions.  It is highly configurable,
and its modular structure provides you with building blocks of increasing
level, by means of which you can compose a large variety of letters.  It is
also possible to write letters divided into sections and paragraphs, to
include floating figures and tables, and to have the relevant indexes compiled
automatically.  A single input file can contain several letters, and each
letter will have its own table of contents, etc., independent from the other
ones.")
    (license license:lppl)))

(define-public texlive-cellprops
  (package
    (name "texlive-cellprops")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cellprops/"
                                     "source/latex/cellprops/"
                                     "tex/latex/cellprops/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1k30rg5v170x195da08a7gvagzwf6c0w4izqnrhdkfbxkw8w3450"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cellprops")
    (synopsis "Accept CSS-like selectors in @code{tabular}, @code{array}, etc")
    (description
     "This package reworks the internals of @code{tabular}, @code{array},
and similar constructs, and adds a @code{\\cellprops} command accepting
CSS-like selectors and properties.")
    (license license:gpl3+)))

(define-public texlive-cellspace
  (package
    (name "texlive-cellspace")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cellspace/"
                                     "tex/latex/cellspace/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l5kz97vqmd6zrq5i9s7zxss7jlp8c5fviw2rfh132yydm6w9arf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cellspace")
    (synopsis "Ensure minimal spacing of table cells")
    (description
     "It is well known that high or deep cells tend to touch the @code{\\hlines} of
a tabular.  This package provides a modifier @samp{S} acting on usual column
types so that to ensure a minimal distance that can be controlled through two
parameters @code{\\cellspacetoplimit} and @code{\\cellspacebottomlimit}.")
    (license license:lppl)))

(define-public texlive-censor
  (package
    (name "texlive-censor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/censor/" "tex/latex/censor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c46zzjzkf6s10x9vg52bxfz9y2s1c86a3q4a04azyz68sgmn6ks"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/censor")
    (synopsis "Tools for producing redacted documents")
    (description
     "This package provides simple tools for creating redacted documents with
blacked-out text.  Its tools are useful both for creating documents in
a restricted environment (for redacted release in an unrestricted environment)
as well as in an unrestricted environment (for eventual transfer and
completion in the restricted environment).")
    (license license:lppl1.3+)))

(define-public texlive-centeredline
  (package
    (name "texlive-centeredline")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/centeredline/"
                                     "tex/latex/centeredline/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04m40vpikcrxaak3z8xyp7kn4ndzg3w90ma8333qv4k7ck2h2sh3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/centeredline")
    (synopsis "Macro for centering lines")
    (description
     "This package provides a macro @code{\\centeredline}, which allows one to
conveniently center a line inside a paragraph while allowing usage therein of
@code{\\verb} or other macros changing catcodes.  It works nicely in list
environments, and material whose natural width exceeds the current line width
will get properly centered too.")
    (license license:lppl1.3c)))

(define-public texlive-centerlastline
  (package
    (name "texlive-centerlastline")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/centerlastline/"
                                     "source/latex/centerlastline/"
                                     "tex/latex/centerlastline/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dcprnm2wmajwbm2njin2yycyfs31w2c2b9cmah5f7xb3388mhhq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/centerlastline")
    (synopsis
     "Paragraphs with last line centered, known as Spanish paragraphs")
    (description
     "This LaTeX package provides a command @code{\\centerlastline} and an
environment @code{centerlastline} that typeset Spanish paragraphs, that is
paragraphs without indentation, and last line centered, useful to finish
a large paragraph of text at the end of chapters, prologues, etc.")
    (license license:lppl1.2+)))

(define-public texlive-changelayout
  (package
    (name "texlive-changelayout")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/changelayout/"
                                     "tex/latex/changelayout/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "125szym91d35di3w44kb6as10fckvpg873m432sznrk06swfikds"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/changelayout")
    (synopsis "Change the layout of individual pages and their text")
    (description
     "The package is an extension of the @code{changepage} package to permit the
user to change the layout of individual pages and their texts.")
    (license license:lppl)))

(define-public texlive-changelog
  (package
    (name "texlive-changelog")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/changelog/"
                                     "tex/latex/changelog/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fbjsdkg7ngk9syb3jbjzln2gkwi1fx39zfa0i5ngxjy2ch9q8n8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/changelog")
    (synopsis "Typesetting @url{keepachangelog.com} style change logs")
    (description
     "This package provides a @code{changelog} environment (which itself provides
a @code{version} environment) to represent a change log.  The package supports
multiple authors, unreleased changes, and yanked (revoked) releases.")
    (license license:lppl1.3c)))

(define-public texlive-changes
  (package
    (name "texlive-changes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/changes/" "scripts/changes/"
                                     "source/latex/changes/" "tex/latex/changes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vi8fjvnchz6711fb1knh6yy3p7yhjphc32rpga1jbrmj33ycg43"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:phases
           ;; "changes.ins" writes files to "./examples" and "./regression".
           ;; Create these directories first to prevent an error.
           #~(modify-phases %standard-phases
               (add-before 'build 'fix-build
                 (lambda _
                   (for-each mkdir-p
                             '("build/examples/" "build/regression")))))))
    (home-page "https://ctan.org/pkg/changes")
    (synopsis "Manual change markup")
    (description
     "The package allows the user to manually markup changes of text, such as
additions, deletions, or replacements.  Changed text is shown in a different
color; deleted text is striked out.  Additionally, text can be highlighted
and/or commented.  The package allows free definition of additional authors
and their associated color.  It also allows you to change the markup of
changes, authors, highlights or comments.  A Python script is provided for
removing the changes.")
    (license license:lppl1.3+)))

(define-public texlive-chappg
  (package
    (name "texlive-chappg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chappg/" "source/latex/chappg/"
                                     "tex/latex/chappg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14dx6ivfsjmffwarkdfq7wa93llbsmm3x7vsabikwvp899l0x4f3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chappg")
    (synopsis "Page numbering by chapter")
    (description
     "The package provides for @code{chapterno-pageno} or @code{chaptername-pageno}
page numbering.  Provision is made for front- and backmatter in @code{book}
class.")
    (license license:lppl)))

(define-public texlive-chapterfolder
  (package
    (name "texlive-chapterfolder")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chapterfolder/"
                                     "source/latex/chapterfolder/"
                                     "tex/latex/chapterfolder/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08xbv40s637synfl7qajl1imj93kh2l0r3r0fncx55p9x4b75037"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chapterfolder")
    (synopsis "Package for working with complicated folder structures")
    (description
     "This package simplifies working with folder structures that match the
chapter/section/subsection structure.  It provides macros to define a folder
that contains the file for a chapter/section/subsection, and provides macros
that allow inclusion without using the full path, rather the path relative to
the current folder of the chapter/section/subsection.  It makes easy changing
the name of a folder, for example.")
    (license license:lppl)))

(define-public texlive-cheatsheet
  (package
    (name "texlive-cheatsheet")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cheatsheet/"
                                     "source/latex/cheatsheet/"
                                     "tex/latex/cheatsheet/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09v25l1xcjrm1bnvfwqa7scr7r9hz6qy9l4pr1haww0ma1fj0rba"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cheatsheet")
    (synopsis "Simple cheat sheet class")
    (description
     "The package provides a clean, multi-column design intended for cheat sheets.")
    (license license:expat)))

(define-public texlive-checkend
  (package
    (name "texlive-checkend")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/checkend/" "tex/latex/checkend/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0p3zs72kqfdqzcksjiap6n2nzj4awcr78bhkmjvrshrn2gkhzl6k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/checkend")
    (synopsis "Extend ``improperly closed environment'' messages")
    (description
     "When an environment is left open, LaTeX gives an error at the end of the
document.  However it only informs about the first of them, while the rest are
shown with meaningless errors: (``\\end occurred inside a group at level N'')
This package replaces these errors with more useful messages which show which
environments (in reverse order) were not closed.  There are no user macros:
just use the package.")
    (license license:expat)))

(define-public texlive-chet
  (package
    (name "texlive-chet")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/chet/" "doc/latex/chet/"
                                     "tex/latex/chet/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gkpp94l6843hxgana60rgs08qifdj7j68dv834p132hc3n08cbn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chet")
    (synopsis "LaTeX layout inspired by @code{harvmac}")
    (description
     "The package aims to streamline the work of typesetting, and to provide the
look and feel of @code{harvmac} for readers.")
    (license license:lppl1.3+)))

(define-public texlive-chextras
  (package
    (name "texlive-chextras")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chextras/"
                                     "source/latex/chextras/"
                                     "tex/latex/chextras/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nz3fwn7r8bp4i8yd1brmcsffnfljfmlsgyn7gq7vynaf53d28d3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chextras")
    (synopsis "Companion package for the Swiss typesetter")
    (description
     "The package simplifies the preparation of Swiss documents and letters by
setting up linguistic and common packages.  While it is a useful addition to
the @code{chletter} document class, it is not tied to it and may be used as
a general purpose package.")
    (license license:lppl1.3+)))

(define-public texlive-childdoc
  (package
    (name "texlive-childdoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/childdoc/"
                                     "source/latex/childdoc/"
                                     "tex/latex/childdoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15l1jv13c8lprhlqw698zkzz1h54h4nyqvvlhgafkfzrh6jrf6cq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/childdoc")
    (synopsis "Directly compile @code{\\include}'d child documents")
    (description
     "This LaTeX2e package enables the direct compilation of document sections
included by @code{\\include} to individual files.")
    (license license:lppl1.3+)))

(define-public texlive-chkfloat
  (package
    (name "texlive-chkfloat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chkfloat/" "tex/latex/chkfloat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0v58qcv4vpphgx6n4kgcgn6rknsbksji0bsldwk8lnc01maxrvnl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chkfloat")
    (synopsis "Warn whenever a float is placed ``too far away''")
    (description
     "The package checks for floats that are placed too far from their origin.")
    (license license:lppl1.3+)))

(define-public texlive-chletter
  (package
    (name "texlive-chletter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chletter/"
                                     "source/latex/chletter/"
                                     "tex/latex/chletter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0i54z0241r29ibrizcqi8wsg7q08b24igb2c1fa452z1hajl8hfm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chletter")
    (synopsis "Class for typesetting letters to Swiss rules")
    (description
     "The class enables composition of letters fitting into Swiss C5 & C6/5
windowed envelopes.  No assumption is made about the language used.  The class
is based on the standard LaTeX classes and is compatible with the LaTeX
@code{letter} class.  It is not limited to letters and may be used as
a generic document class; it is used with the @code{chextras} package.")
    (license license:lppl)))

(define-public texlive-chronology
  (package
    (name "texlive-chronology")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/chronology/"
                                     "tex/latex/chronology/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0is43g6x0z66zjhrs3zbp4ql38lcsa1xk90pv9r7105fgn6cjcah"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/chronology")
    (synopsis "Provides a horizontal timeline")
    (description
     "This package provides a timeline package that allows labelling of events with
per-day granularity.  Other features include relative positioning with unit
specification, adjustable tick mark step size, and scaling to specified
width.")
    (license license:lppl1.3+)))

(define-public texlive-circ
  (package
    (name "texlive-circ")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/circ/"
                                     "fonts/source/public/circ/"
                                     "fonts/tfm/public/circ/"
                                     "source/latex/circ/" "tex/latex/circ/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i2x3xvrfnr5b24sl2w6szds7754d5ji4w79y1p8h2c3gcvj6qmm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/circ")
    (synopsis "Macros for typesetting circuit diagrams")
    (description
     "Several electrical symbols like resistor, capacitor, transistors etc., are
defined.  The symbols can be connected with wires.  The package also contains
an American resistor symbol for those of us on that side of the Atlantic.  The
package also has simple facilities for producing optics diagrams; however,
no-one would deny that the PSTricks @code{pst-optic} package, or the MetaPost
@code{makecirc} package do the job better.")
    (license license:gpl3+)))

(define-public texlive-circledsteps
  (package
    (name "texlive-circledsteps")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/circledsteps/"
                                     "tex/latex/circledsteps/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r8qswdj3iw47pgx6nlkv7vf05i73kmvn841qjdplhv2xvf8g2ib"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/circledsteps")
    (synopsis "Typeset circled numbers")
    (description
     "This package generates circled numbers (or other kinds of markers or small
text) to mark steps in procedures, exercises, and so on.")
    (license license:lppl1.3c)))

(define-public texlive-circledtext
  (package
    (name "texlive-circledtext")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/circledtext/"
                                     "tex/latex/circledtext/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0i6xc6y38chrwn0kw0ngvbb95hahwqm1fh5mpady9d1ziw7nxydf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/circledtext")
    (synopsis "Create circled text")
    (description
     "This LaTeX package provides a macro @code{\\circledtext} to typeset circled
text.  Its starred version can produce an inverted version.")
    (license license:lppl1.3c)))

(define-public texlive-classics
  (package
    (name "texlive-classics")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/classics/" "tex/latex/classics/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wgpa5l9s28kvihwvgprhnh5vcp2bn98bzwhrcdwjv9n1inxwinm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/classics")
    (synopsis "Cite classic works")
    (description
     "The package provides a basic framework to cite classic works (specially from
authors such as Homer, Plato, Aristotle, Descartes, Hume, and Kant) in
accordance with traditional pagination systems.  It may be used in conjunction
with other citation packages.")
    (license license:lppl1.3+)))

(define-public texlive-classpack
  (package
    (name "texlive-classpack")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/classpack/"
                                     "source/support/classpack/"
                                     "tex/latex/classpack/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "134bv6g8yynzw76i496wvb58bng2vrz0b9krqgwpjfj2hqlfhwbl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/classpack")
    (synopsis "XML mastering for LaTeX classes and packages")
    (description
     "The package provides an experiment in using XML (specifically DocBook 5) to
mark up and maintain LaTeX classes and packages.  XSLT 2 styleheets generate
the @file{.dtx} and @file{.ins} distribution files expected by end users.")
    (license license:lppl1.3+)))

(define-public texlive-clefval
  (package
    (name "texlive-clefval")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/clefval/" "source/latex/clefval/"
                                     "tex/latex/clefval/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kvj80c3kw5zyhqgrwjb9p362635gw553dkj0wfk4ylyksvrjqqj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/clefval")
    (synopsis "Key/value support with a hash")
    (description
     "This package provides only two macros, @code{\\TheKey} and @code{\\TheValue},
to define then use pairs of key/value and gives a semblance of a hash.")
    (license license:lppl1.3c)))

(define-public texlive-clicks
  (package
    (name "texlive-clicks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/clicks/" "source/latex/clicks/"
                                     "tex/latex/clicks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dpx6xb68rfr6mmqzzm2rx98k6l0s6z53brrds62sm5bqn1rl550"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-etoolbox texlive-xkeyval))
    (home-page "https://ctan.org/pkg/clicks")
    (synopsis "Slide deck animation")
    (description
     "With the help of this package you can simulate animation in your slide deck,
making it look similar to what PowerPoint can do.")
    (license license:expat)))

(define-public texlive-clipboard
  (package
    (name "texlive-clipboard")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/clipboard/"
                                     "tex/latex/clipboard/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rmbhb82n6lbp4iq40dr7xcwm91j0za1s7cd1n6l80a5klrcj1xw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/clipboard")
    (synopsis "Copy and paste into and across documents")
    (description
     "The clipboard package provides a basic framework for copying and pasting text
and commands into and across multiple documents.  It replaces the
@code{copypaste} package.")
    (license license:lppl1.3+)))

(define-public texlive-clistmap
  (package
    (name "texlive-clistmap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/clistmap/"
                                     "source/latex/clistmap/"
                                     "tex/latex/clistmap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19chjqjmfcllaf6i1i5zspjvh6j5ljr6lh6w12f9b6h4941ncx58"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/clistmap")
    (synopsis "Map and iterate over LaTeX3 clists")
    (description
     "This package provides a key-based interface for defining templates whose job
is to partition LaTeX3 clists and map differentiatedly across its components.")
    (license license:lppl1.3c)))

(define-public texlive-clock
  (package
    (name "texlive-clock")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/clock/"
                                     "fonts/source/public/clock/"
                                     "fonts/tfm/public/clock/" "tex/latex/clock/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "187k0pljafh3mnrwk5wapq8hq6lyny1j7wyjidp4r1df62l6111z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/clock")
    (synopsis "Graphical and textual clocks for TeX and LaTeX")
    (description
     "Features graphical clocks (with a classical 12h dial and two hands) and text
clocks (in 24h format) which can show system time or any time the user
desires.  The clock faces (appearances of the dial) are easily expandable; the
default uses a custom Metafont font.")
    (license license:gpl2)))

(define-public texlive-clrdblpg
  (package
    (name "texlive-clrdblpg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/clrdblpg/"
                                     "source/latex/clrdblpg/"
                                     "tex/latex/clrdblpg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wsrfp7ahyzk3v52b6miv5vk4w37bfy9pywlknldmh5h5f5d9ip8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/clrdblpg")
    (synopsis "Control page style of pages left blank by @code{\\cleardoublepage}")
    (description
     "This tiny package allows easy manipulation of the headers and footers on
pages left blank by @code{\\cleardoublepage}.  By default, LaTeX has no easy
facilities for this.")
    (license license:lppl1.3+)))

(define-public texlive-clrstrip
  (package
    (name "texlive-clrstrip")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/clrstrip/"
                                     "source/latex/clrstrip/"
                                     "tex/latex/clrstrip/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cinjd401r60sbn6qh7rqkrkkng1g3azw1zjrfpz59z9h9ckdlwz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/clrstrip")
    (synopsis "Place contents into a full width colour strip")
    (description
     "This lightweight package provides the @code{colorstrip} environment, that
places its contents into a full page width colour strip.")
    (license license:lppl1.3c)))

(define-public texlive-cmdstring
  (package
    (name "texlive-cmdstring")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cmdstring/"
                                     "tex/latex/cmdstring/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "102xjy2bx76f4h7vv9az62bm5qbf6qpv3simykwpdd4ivaxfzy8l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cmdstring")
    (synopsis "Get command name reliably")
    (description
     "This package extracts the letters of a command's name (e.g., @samp{foo} for
command @samp{\\foo}), in a reliable way.")
    (license license:lppl)))

(define-public texlive-cmdtrack
  (package
    (name "texlive-cmdtrack")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cmdtrack/"
                                     "source/latex/cmdtrack/"
                                     "tex/latex/cmdtrack/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dmmz5pmp5ql9wq9vlh888hn2q6djjpia3h8c2580yxs5pwk1hrq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cmdtrack")
    (synopsis "Check used commands")
    (description
     "The package keeps track of whether a command defined in a document preamble
is actually used somewhere in the document.  After the package is loaded in
the preamble of a document, all @code{\\newcommand} (and similar command
definitions) between that point and the beginning of the document will be
marked for logging.  At the end of the document a report of command usage will
be printed in the TeX log.")
    (license license:lppl1.0+)))

(define-public texlive-cmsd
  (package
    (name "texlive-cmsd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cmsd/" "tex/latex/cmsd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cqfwknx1y0l0ws888m45m8adxqxbvgnzmyjl69y5pjkdxah1yxi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cmsd")
    (synopsis "Interfaces to the CM Sans Serif Bold fonts")
    (description
     "Thr purpose of the package is to provide an alternative interface to the CM
Sans Serif boldface fonts.  The EC (T1, Cork) encoded versions of the CM Sans
Serif boldface extended fonts differ considerably from the traditionally (OT1)
encoded ones: at large sizes, above 10pt, they have thinner strokes and are
much wider.  At 25pt they are hardly to be recognized as being boldface'.
This package attempts to make these T1 fonts look like the traditional ones
did.  You do not need any new fonts; the package just changes the way LaTeX
makes use of the current ones.")
    (license license:lppl)))

(define-public texlive-cnltx
  (package
    (name "texlive-cnltx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/cnltx/" "doc/latex/cnltx/"
                                     "makeindex/cnltx/" "tex/latex/cnltx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0g4i658pflc3ak9vi12gkg68ijq6r4cnahhw06j6nqcx7rnc33gd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cnltx")
    (synopsis "LaTeX tools and documenting facilities")
    (description
     "This is a versatile bundle of packages and classes for consistent formatting
of control sequences, package options, source code examples, and writing
a package manual (including an index containing the explained control
sequences, options, ldots).  The bundle also provides several other small
ideas of mine such as a mechansim for providing abbreviations etc.  Not at
least it provides a number of programming tools.")
    (license license:lppl1.3+)))

(define-public texlive-cntformats
  (package
    (name "texlive-cntformats")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cntformats/"
                                     "tex/latex/cntformats/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09j0acva6hx3ny2k76j7psmykfyqb40mvr08cl2gndqmx24j1s3l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cntformats")
    (synopsis "Different way to read counters")
    (description
     "The package offers package or class authors a way to format counters with
patterns.  These patterns do not affect normal LaTeX treatment of counters.")
    (license license:lppl1.3+)))

(define-public texlive-cntperchap
  (package
    (name "texlive-cntperchap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cntperchap/"
                                     "tex/latex/cntperchap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06af0861m7fsvznpjc5kylbz0dvv9kwcmwk09iv4yy7lrp43a5b7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cntperchap")
    (synopsis "Store counter values per chapter")
    (description
     "This package stores values of counters (which have been registered
beforehand) on a per chapter base and provides the values on demand in the
second LaTeX compilation run.  In this way it is possible to know how many
sections etc., there are lying ahead and to react to these counter values, if
needed.")
    (license license:lppl1.3+)))

(define-public texlive-codebox
  (package
    (name "texlive-codebox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/codebox/" "tex/latex/codebox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0w79im9qssaz1bnnkhm2a1sn5cabnsfzk9f3r65fmxxn7wagj7a8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/codebox")
    (synopsis "Highlighted source code in a fancy box")
    (description
     "This LaTeX3 package provides environments @code{codebox} and @code{codeview}
to typset with an environment body, and macros @code{\\codefile} and
@code{\\cvfile} to typeset programming source code from a file in a fancy box.
Starred versions of these environments and macros are provided to add
a comment at the bottom of the fancy box.")
    (license license:lppl1.3c)))

(define-public texlive-codedoc
  (package
    (name "texlive-codedoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/codedoc/" "tex/latex/codedoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "052l9xznmm01y946wlxyrq9srqys343yrq39kwsd2xxvzi3zm159"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/codedoc")
    (synopsis "LaTeX code and documentation in LaTeX-format file")
    (description
     "The CodeDoc class is an alternative to DocStrip (and others) to produce LaTeX
code along with its documentation without departing from LaTeX's ordinary
syntax.  The documentation is prepared like any other LaTeX document and the
code to be commented verbatim is simply delimited by an environment.  When an
option is turned on in the class options, this code is written to the desired
file(s).  The class also includes fully customizable verbatim environments
which provide the author with separate commands to typeset the material and/or
to execute it.")
    (license license:lppl)))

(define-public texlive-codehigh
  (package
    (name "texlive-codehigh")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/codehigh/" "tex/latex/codehigh/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dcfppnav8zf3zlmdjhq5hl54vgg6whsh2apbsxw9sy55j0yxabb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/codehigh")
    (synopsis "Highlight code and demos with @code{l3regex} and @code{lpeg}")
    (description
     "This package uses the @code{l3regex} package from the LaTeX3 programming
layer to parse and highlight source code and demos.  It is more powerful than
the @code{listings} package, and more easy to use than @code{minted}.  But it
is slower than both of them.  Therefore in LuaTeX the package provides another
way to highlight code: using LPeg (Parsing Expression Grammars for Lua).  LPeg
is much more powerful and faster than @code{l3regex}.")
    (license license:lppl1.3c)))

(define-public texlive-codepage
  (package
    (name "texlive-codepage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/codepage/"
                                     "source/latex/codepage/"
                                     "tex/latex/codepage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1y223jd20issbl4p4rf14130iix75r29kszknglkshdhb3lqzg4c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/codepage")
    (synopsis "Support for variant code pages")
    (description
     "The package provides a mechanism for inputting non-ASCII text.  Nowadays, the
job is mostly done by the @code{inputenc} package in the LaTeX distribution.")
    (license license:bsd-3)))

(define-public texlive-codesection
  (package
    (name "texlive-codesection")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/codesection/"
                                     "source/latex/codesection/"
                                     "tex/latex/codesection/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m3lq9rap7a5qxflypmv0546n7hyavm2p0z4yf3rp5rp769161fb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/codesection")
    (synopsis "Provides an environment that may be conditionally included")
    (description
     "This package provides an environment to switch a section of code on or off.
The code may be placed anywhere in the file (it is not limited to the document
or the preamble).  The motivation for this package was to have commands which
allow preselection based on whether sections of code in a preamble of
a template are executed.")
    (license license:lppl1.3+)))

(define-public texlive-collcell
  (package
    (name "texlive-collcell")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/collcell/"
                                     "source/latex/collcell/"
                                     "tex/latex/collcell/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nqxqq2vncxvjm1xwnsznsn451ngcqs046f9ldy1c7h6n4dxq3xc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/collcell")
    (synopsis "Collect contents of a tabular cell as argument to a macro")
    (description
     "The package provides macros that collect the content of a tabular cell, and
offer them as an argument to a macro.  Special care is taken to remove all
aligning macros inserted by tabular from the cell content.  The macros also
work in the last column of a table, but do not support verbatim material
inside the cells.")
    (license license:lppl1.3+)))

(define-public texlive-colophon
  (package
    (name "texlive-colophon")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/colophon/"
                                     "source/latex/colophon/"
                                     "tex/latex/colophon/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sxj99ifah1gv4f84m4i48849npips0ypl997cdaq7k7ycidq41r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/colophon")
    (synopsis "Provides commands for producing a colophon")
    (description
     "Colophons are a once-common design device by which a book (or document)
designer gave some information to his readers about the design and makeup of
the text.  It typically includes the publisher (if not included elsewhere in
the document), font size, leading size, measure, and of course font face
identification.  Sometimes it includes information about the tools used, as
well.  This package provides some highly configurable macros, with sensible
defaults, for producing colophons without having to muck around with a lot of
manual code.")
    (license license:lppl1.3+)))

(define-public texlive-color-edits
  (package
    (name "texlive-color-edits")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/color-edits/"
                                     "source/latex/color-edits/"
                                     "tex/latex/color-edits/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16x695xaaifx621m7jqacm16wh2x96d1lrnp06hk4cg9llvfn00x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/color-edits")
    (synopsis "Colorful edits for multiple authors of a shared document")
    (description
     "This package provides a fairly light-weight solution for annotating LaTeX
source code with color to show additions/changes, replacements, deletions, and
comments.  This is particularly useful when a document is being edited by
multiple authors.  Two package options allow the quick suppression of all
colorful edits and comments, and showing text whose deletion was proposed.")
    (license license:lppl1.3+)))

(define-public texlive-colordoc
  (package
    (name "texlive-colordoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/colordoc/"
                                     "source/latex/colordoc/"
                                     "tex/latex/colordoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qyqhryazrwja3hxs6wjrlg6q0jv6qpbwy4mqi6sxdrvxq2flw97"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/colordoc")
    (synopsis "Coloured syntax highlights in documentation")
    (description
     "The package is used in documentation files; with it the code listings will
highlight (for example) pairs of curly braces with matching colors.  Other
delimiters like @samp{\\if ... \\fi}, are highlighted, as are the names of new
commands.  All this makes code a little more readable, and helps during
process of writing.  Three options are provided, including a non-color option
designed for printing (which numbers delimiters and underlines new commands).")
    (license license:lppl1.0+)))

(define-public texlive-colorframed
  (package
    (name "texlive-colorframed")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/colorframed/"
                                     "tex/latex/colorframed/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sfg6rkyhh9i13003xdm6mnskj4nlngwq268ra4ik9vrb11s70g9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/colorframed")
    (synopsis "Fix color problems with the package @code{framed}")
    (description
     "This package fixes problems with colour loss that occurres in the
environments of the @code{framed} package.")
    (license license:lppl1.3c)))

(define-public texlive-colorinfo
  (package
    (name "texlive-colorinfo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/colorinfo/"
                                     "tex/latex/colorinfo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1v283sq2xkxix614f2sgblgz4m1xzvv8lcng2ykasvcasq62zcyc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/colorinfo")
    (synopsis "Retrieve colour model and values for defined colours")
    (description
     "This package retrieves colour model and values for defined colours.")
    (license license:lppl)))

(define-public texlive-coloring
  (package
    (name "texlive-coloring")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/coloring/" "tex/latex/coloring/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d98jvf9p1j4brjsj4g7jfnw6dnh7js906advipmlcvdnp8wzqbk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/coloring")
    (synopsis "Define missing colors by their names")
    (description
     "This package makes it possible to define colors automatically by their names.
This can be useful in drawing TikZ pictures and designing Beamer themes.
Using the package, you don't need to write @code{\\definecolor} before using
a color.")
    (license license:lppl1.3+)))

(define-public texlive-colorspace
  (package
    (name "texlive-colorspace")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/colorspace/"
                                     "tex/latex/colorspace/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1am4qhzhqk9qf6d3bfxpw51lgx9nz25vxdm6y823hpdk06ipq2yi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/colorspace")
    (synopsis "Provides PDF color spaces")
    (description
     "The package provides PDF color spaces.  Currently, only spot colors and
overprinting are supported.")
    (license license:expat)))

(define-public texlive-colortab
  (package
    (name "texlive-colortab")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/colortab/"
                                     "tex/generic/colortab/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xk4rkbfs65bavnigmzdbhs894h3xmq5y2x8nd81ysh7ba93jr5y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/colortab")
    (synopsis "Shade cells of tables and halign")
    (description
     "The package lets you shade or colour the cells in the alignment environments
such as @code{\\halign} and LaTeX's @code{tabular} and @code{array}
environments.  The @code{colortbl} package is to be preferred today with
LaTeX (it assures compatibility with the @code{longtable} package, which is no
longer true with @code{colortab}); another modern option is the
table-colouring option of the @code{xcolor}.  However, @code{colortab} remains
an adequate solution for use with Plain TeX.")
    (license license:lppl)))

(define-public texlive-colorwav
  (package
    (name "texlive-colorwav")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/colorwav/"
                                     "source/latex/colorwav/"
                                     "tex/latex/colorwav/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0aqf15z3h7b7dj295y6sjkpd6vhskzvmg2hpr1gjmcj24q2iw0yh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/colorwav")
    (synopsis "Colours by wavelength of visible light")
    (description
     "The package allows the user to obtain an RGB value (suitable for use in the
@code{color} package) from a wavelength of light.  The default unit is
nanometres, but other units may be used.  Note that this function is also
available within @code{xcolor}.")
    ;; "colorwav.sty" mentions "This package is released under the GNU
    ;; LGPL." Assume the latest one.
    (license license:lgpl3+)))

(define-public texlive-colorweb
  (package
    (name "texlive-colorweb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/colorweb/"
                                     "source/latex/colorweb/"
                                     "tex/latex/colorweb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hm2xwnyl3ycnmc8lq28cw79pwm7h5dj0f5z0569mc21p4dgmcg8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/colorweb")
    (synopsis "Extend the @code{color} package colour space")
    (description
     "The package makes the 216 ``web-safe colours'' available to the standard
@code{color} package.")
    (license license:lppl1.3+)))

(define-public texlive-colourchange
  (package
    (name "texlive-colourchange")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/colourchange/"
                                     "tex/latex/colourchange/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1366p2y9a2ls5mdyvar4c1s3qzpb0ghjn4dzvnsnmd36cgyqjcmc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/colourchange")
    (synopsis "Change colors in a Beamer presentation")
    (description
     "The package allows you to change the colour of the structural elements (inner
theme and outer theme) of your Beamer presentation during the presentation.
There is a manual option but there is also the option to have your structure
colour change from one colour to another as a function of how far through the
presentation you are.")
    (license license:gpl3)))

(define-public texlive-combelow
  (package
    (name "texlive-combelow")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/combelow/" "tex/latex/combelow/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ya26afw6n94k5hm0miznk5my9zxdfx54396ip4n87dkgs9n827a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/combelow")
    (synopsis "Typeset comma-below letters, as in Romanian")
    (description
     "The package defines a command @code{\\cb} that positions a comma below
a letter, as required (for example) in Romanian typesetting.  The command is
robust, but interferes with hyphenation.")
    (license license:lppl1.3+)))

(define-public texlive-combine
  (package
    (name "texlive-combine")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/combine/" "source/latex/combine/"
                                     "tex/latex/combine/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1v0qs274sqdx63md9xmpibnry0pj44r3rylfyrxaxr8q69i983vc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/combine")
    (synopsis "Bundle individual documents into a single document")
    (description
     "The @code{combine} class lets you bundle individual documents into a single
document, such as when preparing a conference proceedings.  The auxiliary
@code{combinet} package puts the titles and authors from @code{\\maketitle}
commands into the main document's table of contents.  The package cooperates
with the @code{abstract} and @code{titling} packages.")
    (license license:lppl1.3+)))

(define-public texlive-comma
  (package
    (name "texlive-comma")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/comma/" "tex/latex/comma/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16rbqna7jngahi9crnv74jkvlnmfr3rz7gbrz24ginh19bax7pi1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/comma")
    (synopsis "Formats a number by inserting commas")
    (description
     "This package provides a flexible package that allows commas (or anything
else) to be inserted every three digits in a number, as in @samp{1,234}.")
    (license license:lppl)))

(define-public texlive-commado
  (package
    (name "texlive-commado")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/commado/"
                                     "source/generic/commado/"
                                     "tex/generic/commado/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rqiivfc6248yydz3199z8s9i61my70y4l48caa2lvxsvnb1pf7l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/commado")
    (synopsis "Expandable iteration on comma-separated and filename lists")
    (description
     "The bundle provides two packages: @code{commado} and @code{filesdo}.  The
package @code{commado} provides the command @code{\\DoWithCSL}, which applies
an existing one-parameter macro to each item in a list in which terms are
separated by commas.

The package @code{filesdo} provides the command @code{\\DoWithBasesExts},
which runs the single parameter command on each file whose base and extension
are provided through two comma-separated lists.

These loop'-like commands are (themselves) entirely expandable.")
    (license license:lppl1.3+)))

(define-public texlive-commedit
  (package
    (name "texlive-commedit")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/commedit/"
                                     "source/latex/commedit/"
                                     "tex/latex/commedit/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h8jqizvnl9hxpxmk5g60fy24b5n5n9jjjrmm9zi5azkscjqjfdg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/commedit")
    (synopsis "Commented editions with LaTeX")
    (description
     "The package is intended for commented editions.  An example of commented
edition is a teacher's book based on a student's textbook.  Each page of
a teacher's book is a page from the textbook and comments for the teacher.")
    (license license:lppl1.3+)))

(define-public texlive-commonunicode
  (package
    (name "texlive-commonunicode")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/commonunicode/"
                                     "tex/latex/commonunicode/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1s0kni4gc8jr102ikk96igxiriikccm21zml08kwiv17vy4n50mb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/commonunicode")
    (synopsis "Convert common Unicode symbols to LaTeX code")
    (description
     "The aim of this LaTeX package is to provide a complete as possible list of
common Unicode symbols with their translations to LaTeX code.  This is useful
in the development of templates which are intended to work with modern TeX
engines (LuaTeX, XeTeX) as well as traditional ones (TeX, pdfTeX).")
    (license license:expat)))

(define-public texlive-competences
  (package
    (name "texlive-competences")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/competences/"
                                     "source/latex/competences/"
                                     "tex/latex/competences/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1f4nkhi152410v0zl8priw71s135i2rm9f54dcwqcrkm0d1ijca2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/competences")
    (synopsis "Track skills of classroom checks")
    (description
     "This package is an attempt to track skills assessed during a classroom check.
Each question can be associated with one or more skills and be assigned
a number of points to be earned.  At the end of the text, a table set
summarizes the skills assessed, and in what proportions.")
    (license license:lppl1.3+)))

(define-public texlive-concepts
  (package
    (name "texlive-concepts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/concepts/" "tex/latex/concepts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r6dals4iqmp0r79gck81dw6fdympnpjmz6n23la376dpxwj15lx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/concepts")
    (synopsis "Keeping track of formal concepts for a particular field")
    (description
     "The package helps to keep track of formal concepts for a specific field or
document.  This is particularly useful for scientific papers (for example, in
physics, mathematics or computer science), which may introduce several concepts
(with their own symbols).  The package's commands allow the user to define
a concept (typically, near its first use), and will ensure consistent use
throughout the document.")
    (license license:lppl)))

(define-public texlive-concprog
  (package
    (name "texlive-concprog")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/concprog/" "tex/latex/concprog/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i47w63gqiczygvmwq7pdym7l2hi2fw4maan3c0psfqm6wh0mz0w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/concprog")
    (synopsis "Concert programmes")
    (description
     "This package provides a class which provides the necessary macros to prepare a
(classical) concert programme; a sample is provided.")
    (license license:gpl3+)))

(define-public texlive-conditext
  (package
    (name "texlive-conditext")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/conditext/"
                                     "tex/latex/conditext/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b07ydmkqd4jfkqjvs073g9ansx5w378wv95qfpgrqqx7pc9215s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/conditext")
    (synopsis "Define and manage conditional content")
    (description
     "This package provides some commands to define and manage conditional content
in a LaTeX source document.  A conditional content, in the sense within this
is understood in this package, is a text (including mathematical or other
formulas) and/or a graphical element (diagram, figure, image...) as
substitutable forms, which, according to a condition test, may or may not
appear in the generated document.  One of the most common forms of conditional
content management is multilingual; but it can also include versioning,
confidentiality levels, and so on.

The philosophy of this package is based on the respective notions of condition
field, condition property and condition space.  With this package, any
substitutable form in a source document is identified by a condition field and
a condition property.  The condition field is a functional theme that allows
you to group together substitutable forms for the same conditional management.
The condition property is a functional characterization specific to each
substitutable form of a single condition domain.  The condition space is used
to designate the substitutable form(s) that must appear in the generated
document.  A condition space is defined by specifying a condition domain and
a condition property to match with one or more substitutable forms.")
    (license license:lppl1.3c)))

(define-public texlive-constants
  (package
    (name "texlive-constants")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/constants/"
                                     "source/latex/constants/"
                                     "tex/latex/constants/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ykg2q3mbgc705v7c14pldz57g4qjm4z5cw8jw3fi2254fzdb2h4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/constants")
    (synopsis "Automatic numbering of constants")
    (description
     "The package provides a way to number constants in a mathematical proof
automatically, with a system for labelling/referencing.  In addition, several
families of constants (with different symbols) may be defined.")
    (license license:lppl)))

(define-public texlive-continue
  (package
    (name "texlive-continue")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/continue/"
                                     "source/latex/continue/"
                                     "tex/latex/continue/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c9yz5lm9y0jzad0mx36axww9p3b4gfbjdnddpky9w12kv0xn66f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/continue")
    (synopsis "Prints continuation marks on pages of multipage documents")
    (description
     "This package provides for a variety of continuation indicators on pages when
the text continues on the following page.  The default is to only mark odd
pages, but all pages can be marked and the marking can be stopped or started
at any point.")
    (license license:lppl1.3+)))

(define-public texlive-contour
  (package
    (name "texlive-contour")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/contour/" "source/latex/contour/"
                                     "tex/latex/contour/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "026pz6nrrls53srs4qch9nmpzx62ii9airnbcdi3yq1ly2hqay4y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/contour")
    (synopsis "Print a coloured contour around text")
    (description
     "This package generates a coloured contour around a given text in order to
enable printing text over a background without the need of a coloured box
around the text.")
    (license license:lppl)))

(define-public texlive-contracard
  (package
    (name "texlive-contracard")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/contracard/"
                                     "source/latex/contracard/"
                                     "tex/latex/contracard/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07f3wq4zqc8l0mm1i0p6i225313haw9ccnha0jl937yqrzhsk5cl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/contracard")
    (synopsis "Generate calling cards for dances")
    (description
     "This package provides a package and a class used to typeset traditional
country dances, such as contra and square dances, and to create calling cards
for the same.")
    (license license:lppl1.3c)))

(define-public texlive-conv-xkv
  (package
    (name "texlive-conv-xkv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/conv-xkv/"
                                     "source/latex/conv-xkv/"
                                     "tex/latex/conv-xkv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fwcq7y67dn2j2002kqibphpx30q7d5jay62gi5pwk39d6vrmp5w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/conv-xkv")
    (synopsis "Create new key-value syntax")
    (description
     "This small package supports key-value syntax other than the standard LaTeX
syntax of @samp{<key>=<value>}.  Using this package, create key-values of the
form @samp{<key>:<value>} or @samp{<key>-><value>}, for example.  The package
converts the new notation to @code{xkeyval} notation and passes it on to
@code{xkeyval}.")
    (license license:lppl1.2+)))

(define-public texlive-cooking
  (package
    (name "texlive-cooking")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cooking/" "source/latex/cooking/"
                                     "tex/latex/cooking/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0spf9493hw5iqp9hbh5y0imi2z61bxwz51v0c0v3r43pv8cscgpf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cooking")
    (synopsis "Typeset recipes")
    (description
     "The package typesets recipes according to the style used in a well-respected
German cookery book.")
    (license license:gpl3+)))

(define-public texlive-cooking-units
  (package
    (name "texlive-cooking-units")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cooking-units/"
                                     "source/latex/cooking-units/"
                                     "tex/latex/cooking-units/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0i8h804gpdpi4ax60hm2fr54dcqfawkzjg64xj9za74zw24ga90v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cooking-units")
    (synopsis "Typeset and convert units for cookery books and recipes")
    (description
     "The package provides commands to typeset amounts and units consistently and
offers an easy-to-use key-value syntax to convert one unit into another (for
example @samp{dag} to @samp{g}).")
    (license license:lppl1.3c)))

(define-public texlive-cool
  (package
    (name "texlive-cool")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cool/" "source/latex/cool/"
                                     "tex/latex/cool/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "162x27s72s4xg0cq5wwzsrr8b3522paiqvsirk2xksvn479ghhcm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cool")
    (synopsis "COntent-Oriented LaTeX")
    (description
     "The package (COntent Oriented LaTeX) gives LaTeX the power to retain
mathematical meaning of its expressions in addition to the typsetting
instructions; essentially separating style from the content of the math.  One
advantage of keeping mathematical meaning is that conversion of LaTeX
documents to other executable formats (such as Content MathML or Mathematica
code) is greatly simplified.")
    ;; "This package is released under the GNU LGPL."  Assume latest.
    (license license:lgpl3+)))

(define-public texlive-coolfn
  (package
    (name "texlive-coolfn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/coolfn/" "tex/latex/coolfn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10s3j52jzin65yxiy8wrgsh6c4cviicxwwqk9h0324nsyblslcli"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/coolfn")
    (synopsis "Typeset long legal footnotes")
    (description
     "This package provides formatting for footnotes in long legal documents, using
hanging indents to make them look nicer.")
    (license license:lppl1.3c)))

(define-public texlive-coollist
  (package
    (name "texlive-coollist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/coollist/"
                                     "source/latex/coollist/"
                                     "tex/latex/coollist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bwfyx9iaby0ypm2s9qx68whhvsxlcyghh6p9fizzr2jibyakq40"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/coollist")
    (synopsis "Manipulate COntent Oriented LaTeX Lists")
    (description
     "Lists are defined as a sequence of tokens separated by a comma.
The @code{coollist} package allows the user to access certain elements of the
list while neglecting others --- essentially turning lists into a sort of
array.  List elements are accessed by specifying the position of the object
within the list (the index of the item).")
    ;; "This package is released under the GNU LGPL."  Assume latest.
    (license license:lgpl3+)))

(define-public texlive-coolstr
  (package
    (name "texlive-coolstr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/coolstr/" "source/latex/coolstr/"
                                     "tex/latex/coolstr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01lx9x0iggqcy6bhr24xw67mrd4gx5q6s6riwc0bl19krijcw721"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/coolstr")
    (synopsis "String manipulation in LaTeX")
    (description
     "Coolstr is a subpackage of the @code{cool} bundle that deals with the
manipulation of strings.  A string is defined as a sequence of characters (not
tokens).  The package provides the ability to access a specific character of
a string, as well as determine if the string contains numeric or integer
data.")
    ;; "This package is released under the GNU LGPL."  Assume latest.
    (license license:lgpl3+)))

(define-public texlive-coolthms
  (package
    (name "texlive-coolthms")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/coolthms/"
                                     "source/latex/coolthms/"
                                     "tex/latex/coolthms/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1274lmvwq0mhmk0kdnnvivzkrrly2b43jdrmvjh28hpms299bc42"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/coolthms")
    (synopsis "Reference items in a theorem environment")
    (description
     "The package provides the means to directly reference items of lists nested in
@code{theorem}-like environments (e.g., as @samp{Theorem 1 a}).  The package
extends the @code{ntheorem} and @code{cleveref} packages.  The package also
provides other theorem markup commands.")
    (license license:lppl)))

(define-public texlive-cooltooltips
  (package
    (name "texlive-cooltooltips")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cooltooltips/"
                                     "source/latex/cooltooltips/"
                                     "tex/latex/cooltooltips/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jar70g61p7k4xw7bqir13l0lrfnaka2fvw61k4jiq4v8lic8i4i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cooltooltips")
    (synopsis "Associate a pop-up window and tooltip with PDF hyperlinks")
    (description
     "The @code{cooltooltips} package enables a document to contain hyperlinks that
pop up a brief tooltip when the mouse moves over them and also open a small
window containing additional text.  @code{cooltooltips} provides the mechanism
used by the Visual LaTeX FAQ to indicate the question that each hyperlink
answers.")
    (license license:lppl)))

(define-public texlive-coop-writing
  (package
    (name "texlive-coop-writing")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/coop-writing/"
                                     "source/latex/coop-writing/"
                                     "tex/latex/coop-writing/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gv4sjhipfiq0h8ygy5ynfarzy4cn6sa240xbh0r1377hrn3mhy2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/coop-writing")
    (synopsis "Support for cooperative writing and editorial comments")
    (description
     "This package for cooperative writing supports editorial comments and gives
some extra support for writing and submitting papers, such as anonymization
commands for any document that involves more than one author or editor.  The
general behavior of this package is to provide different ways of marking your
text, for example with comments or to-do-notes, suggestions to add, remove or
change text that can be totally suppressed from the output when desired.
Mostly, this can be easily done using one of the three main option states:
@code{editing}, @code{submit}, and @code{publish}.  Users should use the
@code{editing} state most of the time.  In this state, all markings will
appear and anonymization will be off.  When submitting, the @code{submit}
state will provide a clean article, without any markings, but anonymized.  It
is possible to use the options @code{submit} and @code{noanonymize} together.
@code{Publish} will never anonymize.  The goal is to make the submit and
publish documents states minimally invasive, to avoid any clash with
publishers styles.")
    (license license:expat)))

(define-public texlive-coordsys
  (package
    (name "texlive-coordsys")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/coordsys/"
                                     "source/latex/coordsys/"
                                     "tex/latex/coordsys/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c2p4358g9ggpx92bs7r95mlm8r4a1n6bnsdilhzrm1lnb1gb6ls"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/coordsys")
    (synopsis "Draw cartesian coordinate systems")
    (description
     "The package provides commands for typesetting number lines (coordinate axes),
coordinate systems and grids in the @code{picture} environment.  The package
may be integrated with other drawing mechanisms: the documentation shows
examples of drawing graphs (coordinate tables created by Maple), using the
@code{eepic} package's drawing capabilities.")
    (license license:lppl)))

(define-public texlive-copyedit
  (package
    (name "texlive-copyedit")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/copyedit/"
                                     "source/latex/copyedit/"
                                     "tex/latex/copyedit/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0irvq05mk4hf2m04hvg4viryhp1b7zn3qnqcss342vhcdrrf87ih"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/copyedit")
    (synopsis "Copyediting support for LaTeX documents")
    (description
     "This package implements copyediting support for LaTeX documents.  Authors
can enjoy the freedom of using, for example, words with US or UK or Canadian or
Australian spelling in a mixed way, yet, they can choose any one of the usage
forms for their entire document irrespective of kinds of spelling they have
adopted.  In the same fashion, the users can have the benefit of the following
features available in the package:
@itemize
@item localization --- British-American-Australian-Canadian,
@item close-up, hyphenation, and spaced words,
@item Latin abbreviations,
@item acronyms and abbreviations,
@item itemization, nonlocal lists and labels,
@item parenthetical and serial commas,
@item non-local tokenization in language through abbreviations and pronouns.
@end itemize")
    (license license:lppl1.3+)))

(define-public texlive-copyrightbox
  (package
    (name "texlive-copyrightbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/copyrightbox/"
                                     "tex/latex/copyrightbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jyd3ij1zc93hpjwc61bpkcr7xhjr2q6i88909mwjfkqf5w8bdh2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/copyrightbox")
    (synopsis "Provide copyright notices for images in a document")
    (description
     "The package command @code{\\copyrightbox}, which places the text as
a copyright notice relating to the matter created by the image command.")
    (license license:lppl)))

(define-public texlive-coseoul
  (package
    (name "texlive-coseoul")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/coseoul/" "tex/latex/coseoul/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xf93pskygb26p47m0063y1q57kgg2gjwwrxg89b5rgmamawjwyw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/coseoul")
    (synopsis "Context sensitive outline elements")
    (description
     "The package provides relative commands that may be used in place of @code{\\chapter},
@code{\\section}, etc.")
    (license license:lppl1.3+)))

(define-public texlive-counttexruns
  (package
    (name "texlive-counttexruns")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/counttexruns/"
                                     "source/latex/counttexruns/"
                                     "tex/latex/counttexruns/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ppy8qfpjq4vcq2w53ms63khsmw09vrg1psxd6ylr8rp2m3mrdgy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/counttexruns")
    (synopsis "Count compilations of a document")
    (description
     "The package counts how often a LaTeX document is compiled, keeping the data
in an external file.  To print the count, can use the macro
@code{\\thecounttexruns}.")
    (license license:lppl1.3+)))

(define-public texlive-courseoutline
  (package
    (name "texlive-courseoutline")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/courseoutline/"
                                     "tex/latex/courseoutline/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xp3cdvpbldn86a8zmsck223m4120r5qr408097jnq01wrycij98"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/courseoutline")
    (synopsis "Prepare university course outlines")
    (description
     "Courseoutline is a class designed to minimise markup in a tedious task that
needs to be repeated often.")
    ;; "Feel free to copy, modify, and distribute."
    (license
     (license:non-copyleft
      "file://tex/latex/courseoutline/courseoutline.cls"))))

(define-public texlive-coursepaper
  (package
    (name "texlive-coursepaper")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/coursepaper/"
                                     "tex/latex/coursepaper/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h625m8blq1a3ga9m2c0bkv5n1wfwgy9kbgs89jh7yqy262z2cs3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/coursepaper")
    (synopsis "Prepare university course papers")
    (description
     "Coursepaper is a class with which students can provide simple course papers,
in a uniform design to ease the task of marking.")
    ;; "Feel free to copy, modify, and distribute."
    (license
     (license:non-copyleft
      "file://tex/latex/coursepaper/coursepaper.cls"))))

(define-public texlive-coverpage
  (package
    (name "texlive-coverpage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/coverpage/"
                                     "source/latex/coverpage/"
                                     "tex/latex/coverpage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m7a9dm5a8wvch096g5wfjmw9p435jvpnbxn2qxv5bvnihxigdh7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/coverpage")
    (synopsis "Automatic cover page creation for scientific papers")
    (description
     "The package CoverPage was created to supplement scientific papers with
a cover page containing bibliographical information, a copyright notice,
and/or some logos of the author's institution.  The cover page is
created (almost) automatically; this is done by parsing BibTeX information
corresponding to the main document and reading a configuration file in which
the author can set information like the affiliation he or she is associated
with.  The cover page consists of header, body and footer; all three are
macros which can be redefined using @code{\\renewcommand}, thus allowing easy
customization of the package.  Additionally, it should be stressed that the
cover page layout is totally independent of the main document and its page
layout.")
    (license license:lppl1.2+)))

(define-public texlive-cprotect
  (package
    (name "texlive-cprotect")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cprotect/"
                                     "source/latex/cprotect/"
                                     "tex/latex/cprotect/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0i7x6mz106c5jgb3z5h9ma0srjyjh89w1c5p7jfxc882c2w02lha"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cprotect")
    (synopsis "Allow verbatim, etc., in macro arguments")
    (description
     "The package defines the macro @code{\\cprotect} that makes a following macro
proof against verbatim in its argument.  A similar macro
@code{\\cprotEnv} (applied to the @code{\\begin} of an environment) sanitises
the behavior of fragile environments.  Moving arguments, and corresponding
``tables of ...'' work happily.")
    (license license:lppl1.3+)))

(define-public texlive-cprotectinside
  (package
    (name "texlive-cprotectinside")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cprotectinside/"
                                     "tex/latex/cprotectinside/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pa9j8v61xvrcmqgarzlwpg55l5qr3qi6nw2v3rdvvfg65ri6vf5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cprotectinside")
    (synopsis "Use @code{cprotect} arbitrarily nested")
    (description
     "This package extends the @code{cprotect} package to allow users to use
verbatim-like commands inside arbitrary parameters.")
    (license license:lppl1.3c)))

(define-public texlive-crbox
  (package
    (name "texlive-crbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/crbox/" "tex/latex/crbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zw0dzmnzn42xsy8c2as4gnssj74s4ilivwrc1phvsfvlinjah9n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/crbox")
    (synopsis "Boxes with crossed corners")
    (description
     "The package implements a @code{\\crbox} command which produces boxes with
crossing lines at the corners.")
    (license license:lppl)))

(define-public texlive-crossreference
  (package
    (name "texlive-crossreference")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/crossreference/"
                                     "source/latex/crossreference/"
                                     "tex/latex/crossreference/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wxf4iz6mz7jm24dzbxnr3rhrlnfxs80dzd2avqyis1a9ln91cby"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/crossreference")
    (synopsis "Crossreferences within documents")
    (description
     "The package defines cross-references (essentially grand label references),
which may be listed in a table of cross-references.")
    (license license:lppl)))

(define-public texlive-crossreftools
  (package
    (name "texlive-crossreftools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/crossreftools/"
                                     "tex/latex/crossreftools/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rqv8km9l5yxl60vs9cyx41yfpw56djxynlm0p2ykxpncppipxrs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/crossreftools")
    (synopsis "Expandable extraction of @code{cleveref} data")
    (description
     "This package extracts information from cross-referencing labels, especially
those from @code{cleveref}, in an expandable manner.")
    (license license:lppl1.3+)))

(define-public texlive-css-colors
  (package
    (name "texlive-css-colors")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/css-colors/"
                                     "tex/latex/css-colors/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "141bsypli8ibaqwwmip6rynikk6kx8gi12jfap6hy5sjylq93ndj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/css-colors")
    (synopsis "Named colors for web-safe design")
    (description
     "This package defines web-safe colors for use with @code{color} package.
It is intended for both authors and package writers (e.g., to create Beamer
color themes).")
    (license (list license:lppl license:gpl3+))))

(define-public texlive-csvmerge
  (package
    (name "texlive-csvmerge")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/csvmerge/"
                                     "source/latex/csvmerge/"
                                     "tex/latex/csvmerge/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rbh4z8xw849v79jl5xnvrbsgkgc7dcv59qm3fna08ilhjnhgxz1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/csvmerge")
    (synopsis "Merge TeX code with CSV data")
    (description
     "This package provides macros for processing a CSV spreadsheet file with
a minimum of configuration for the CSV file.  The first row names the columns
and the remaining rows are data.  This data can be merged with TeX code
residing in an auxiliary file and the process repeated for each data row.
There is one macro to set things up, one to extract the data, and one to tell
if the field is empty or not.")
    (license license:lppl1.3+)))

(define-public texlive-csvsimple
  (package
    (name "texlive-csvsimple")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/csvsimple/"
                                     "tex/latex/csvsimple/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k24l19yj695y1j90whdpapjblgnzyc4593bv46b4xpnqhi08ga0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/csvsimple")
    (synopsis "Simple CSV file processing")
    (description
     "The package provides a simple LaTeX interface for the processing of files
with comma separated values (CSV); it relies on the key value syntax supported
by @code{pgfkeys} to simplify usage.  Filtering and table generation are
especially supported; however, this lightweight tool offers no support for
data sorting or data base storage.")
    (license license:lppl1.3+)))

(define-public texlive-cuisine
  (package
    (name "texlive-cuisine")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cuisine/" "source/latex/cuisine/"
                                     "tex/latex/cuisine/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zlp0ravbzb75z99zr3qdga00a5lb9xk7mp67nbj68pn9arb97zd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cuisine")
    (synopsis "Typeset recipes")
    (description
     "This package typesets recipes with the ingredients lined up with their method
step (somewhat similarly to the layout used in cooking).")
    (license license:lppl)))

(define-public texlive-currency
  (package
    (name "texlive-currency")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/currency/"
                                     "source/latex/currency/"
                                     "tex/latex/currency/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xzpgqifdk77ch39gcpfdzrm9vdyxkh3mz7nfh1j1pk2jw5vg3k7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/currency")
    (synopsis "Format currencies in a consistent way")
    (description
     "The package facilitates the formatting of currencies (amounts and units) with
various formatting capabilities.")
    (license license:lppl1.3+)))

(define-public texlive-currvita
  (package
    (name "texlive-currvita")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/currvita/"
                                     "source/latex/currvita/"
                                     "tex/latex/currvita/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0416lw6r1dqv5xbjn6xw07dk0dd4ra5w7qvkawmfqmll2wvjq8is"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/currvita")
    (synopsis "Typeset a curriculum vitae")
    (description
     "Currvita is a package rather than a class (like most other curriculum vitae
offerings).  The author considers that a curriculum vitae can quite reasonably
form part of another document (such as a letter, or a dissertation).")
    (license license:gpl3+)))

(define-public texlive-cutwin
  (package
    (name "texlive-cutwin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cutwin/" "source/latex/cutwin/"
                                     "tex/latex/cutwin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a49y75ihs4f4bvh5kmlmz3ywd2ppgph0c7zpy35lnbz3ycfgj06"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cutwin")
    (synopsis "Cut a window in a paragraph, typeset material in it")
    (description
     "The package provides facilities to cut windows out of paragraphs, and to
typeset text or other material in the window.  The window may be rectangular,
or may have other sorts of shape.")
    (license license:lppl1.3+)))

(define-public texlive-cv
  (package
    (name "texlive-cv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cv/" "tex/latex/cv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "129akrpdlggi8xmg06ans9csdyv95wrj72lhciis209j698m8scs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cv")
    (synopsis "Package for creating a curriculum vitae")
    (description
     "The package can be used for creating a curriculum vitae.  Note that @code{cv}
is just a package: you choose the overall formatting by deciding which class
to use, while the package provides the detailed formatting.")
    (license license:gpl3+)))

(define-public texlive-cv4tw
  (package
    (name "texlive-cv4tw")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cv4tw/" "tex/latex/cv4tw/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xd9r0ywx90f7iwk4955gm957jlays56d1n7i3mkvh6incs78asj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cv4tw")
    (synopsis "LaTeX CV class, with extended details")
    (description
     "The class offers entries for assets and social networks; customizable styles
are provided.  The class comes with no documentation, but a worked example
offers some guidance.")
    (license license:expat)))

(define-public texlive-cweb-latex
  (package
    (name "texlive-cweb-latex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cweb-latex/"
                                     "tex/latex/cweb-latex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0f3fxjl92qh1q5d3lc04lrgxlbgrj8gkxvsdwcqfskax8zkmqrcr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cweb-latex")
    (synopsis "LaTeX version of CWEB")
    (description
     "This bundle allows marking-up of CWEB code in LaTeX. The distribution
includes the ``Counting Words'' program distributed with CWEB, edited to run
with LaTeX.")
    (license license:gpl3+)))

(define-public texlive-cyber
  (package
    (name "texlive-cyber")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cyber/" "source/latex/cyber/"
                                     "tex/latex/cyber/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xh3bs6rf2mf8nrh3cjqqlgcpcjwr2zjxhid94vgbsli9r6alfbq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cyber")
    (synopsis "Annotate compliance with cybersecurity requirements")
    (description
     "This LaTeX package helps you write documents indicating your compliance with
cybersecurity requirements.  It also helps you format your document in a form
suitable inside the U.S. Department of Defense, by attaching distribution
statements, destruction notices, organization logos, and security labels to
it.")
    (license license:expat)))

(define-public texlive-cybercic
  (package
    (name "texlive-cybercic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/cybercic/"
                                     "source/latex/cybercic/"
                                     "tex/latex/cybercic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nbg4pj8dkwwkjwmd8xixgz0hx1b0sf6s7j0d372dzfgr57712cq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/cybercic")
    (synopsis "``Controls in contents'' for the @code{cyber} package")
    (description
     "This package is used in concert with the @code{cyber} package to make
documents with annotations of compliance with cybersecurity requirements.
When you include this package, some notations of compliance are added to
section names as seen in the table of contents of the final document.  It also
makes your document more brittle in unexpected ways: for example, when you use
@code{cybercic} in the same document as @code{hyperref}, you cannot use any
formatting in your section titles.  So don't use cybercic unless you need to.")
    (license license:expat)))

(define-public texlive-darkmode
  (package
    (name "texlive-darkmode")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/darkmode/"
                                     "source/latex/darkmode/"
                                     "tex/latex/darkmode/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n21gyqkwmz4hd77v27ziyiqlr2wh4c9br8wnswrkznzkp1lmgky"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/darkmode")
    (synopsis "General dark mode support for LaTeX documents")
    (description
     "This package provides an API for template and package developers to create
dynamic color schemes for light- and dark modes.  For those unaware: we refer
to dark mode when a document has a dark background with a light font and to
light mode if it has a dark font with a light background.")
    (license license:lppl1.3+)))

(define-public texlive-dashbox
  (package
    (name "texlive-dashbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dashbox/" "source/latex/dashbox/"
                                     "tex/latex/dashbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0w2vdyxikizfp3qcnjsl5nxyb2igq79d9f88sip0hllyzl6fy5k2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dashbox")
    (synopsis "Draw dashed boxes")
    (description
     "The package can draw boxes that perform like @code{\\framebox} or
@code{\\fbox}, but use dashed lines.  The package can also draw (an illusion
of) vertical stacks of boxes.")
    (license license:lppl)))

(define-public texlive-dashundergaps
  (package
    (name "texlive-dashundergaps")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dashundergaps/"
                                     "source/latex/dashundergaps/"
                                     "tex/latex/dashundergaps/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xwidvm2n1bbsv13apkd0q6sydpfkqsphc63gn0vvddh1rm63x82"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dashundergaps")
    (synopsis "Produce gaps that are underlined, dotted or dashed")
    (description
     "The package provides commands (@code{\\underline}, @code{\\dotuline} and
@code{\\dashuline}) each of which underlines its argument with one of the
styles the package is capable of.  A phantom mode is provided, where the
underline (of whatever form) can serve for a fill-in block for student
evaluation sheets.")
    (license license:lppl1.3c)))

(define-public texlive-dataref
  (package
    (name "texlive-dataref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dataref/" "tex/latex/dataref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xnj6b2amf5nm8llyf1nwnbv8akv4zv0c7fsnj1lv5fqm6p8kys1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dataref")
    (synopsis "Manage references to experimental data")
    (description
     "The package provides a mechanism that maintains a fixed symbolic reference to
numerical results; such results may vary as the project proceeds (and hence
the project report develops).")
    (license license:lppl1.3+)))

(define-public texlive-datax
  (package
    (name "texlive-datax")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datax/" "source/latex/datax/"
                                     "tex/latex/datax/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09zhrgxwh9s0ah65lw557d0b6hqahhsba850fxcchmww4dqfan9d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datax")
    (synopsis "Import individual data from script files")
    (description
     "This LaTeX package uses pgfkeys to retrieve individual data points generated
in some script.  Analogous to how one might generate graphics in a script and
import those graphics into a LaTeX document.")
    (license license:lppl1.3+)))

(define-public texlive-dateiliste
  (package
    (name "texlive-dateiliste")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dateiliste/"
                                     "source/latex/dateiliste/"
                                     "tex/latex/dateiliste/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15dc7dm9jbcaia29v1sxxb83sgr937pmrzwnx6gkbcmmjvwc0ii0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dateiliste")
    (synopsis "Extensions of the @code{\\listfiles} concept")
    (description
     "The package provides a file list (similar to that offered by
@code{\\listfiles}), neatly laid out as a table.  The main document can be
included in the list, and a command is available for providing RCS-maintained
data for printing in the file list.")
    (license license:lppl)))

(define-public texlive-datenumber
  (package
    (name "texlive-datenumber")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datenumber/"
                                     "source/latex/datenumber/"
                                     "tex/latex/datenumber/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0626lnhy8gv3a703kfg8w267zs50hv5hhwsjmppyfq8g01j2542s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datenumber")
    (synopsis "Convert a date into a number and vice versa")
    (description
     "This package provides commands to convert a date into a number and vice versa.
Additionally there are commands for incrementing and decrementing a date.
Leap years and the Gregorian calendar reform are considered.")
    (license license:lppl1.2+)))

(define-public texlive-datestamp
  (package
    (name "texlive-datestamp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/datestamp/"
                                     "source/lualatex/datestamp/"
                                     "tex/lualatex/datestamp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ldrdjypypdbddazj2h3jyzhwf57q4fnssnbfy9rdqlggw30mh34"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datestamp")
    (synopsis "Fixed date-stamps with LuaLaTeX")
    (description
     "This package adds fixed date-stamps with simple and customizable @file{.aux}
files and LuaLaTeX.  As long as the @file{.aux} file is not deleted/modified
the date-stamp generated with this package remains intact.")
    (license (list license:gpl3+ license:fdl1.3+))))

(define-public texlive-datetime2-bahasai
  (package
    (name "texlive-datetime2-bahasai")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-bahasai/"
                                     "source/latex/datetime2-bahasai/"
                                     "tex/latex/datetime2-bahasai/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15rmkxsi1d3c74m0z1hnn9jw5mgqxyglfwbck92l87ha7zmj2ncf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-bahasai")
    (synopsis "Bahasai language module for the @code{datetime2} package")
    (description
     "This module provides the @code{bahasai} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-basque
  (package
    (name "texlive-datetime2-basque")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-basque/"
                                     "source/latex/datetime2-basque/"
                                     "tex/latex/datetime2-basque/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17wy1d12ix13a1nnsi7n60jmj2jj32jbn9cnbin30pld38b5a7j3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-basque")
    (synopsis "Basque language module for the @code{datetime2} package")
    (description
     "This module provides the @code{basque} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-breton
  (package
    (name "texlive-datetime2-breton")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-breton/"
                                     "source/latex/datetime2-breton/"
                                     "tex/latex/datetime2-breton/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10kgrdvr4psyhc3bjpgq0idj6zzfcfvsxrql2hvy5gqn4gzncbla"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-breton")
    (synopsis "Breton language module for the @code{datetime2} package")
    (description
     "This module provides the @code{breton} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-bulgarian
  (package
    (name "texlive-datetime2-bulgarian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-bulgarian/"
                                     "source/latex/datetime2-bulgarian/"
                                     "tex/latex/datetime2-bulgarian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0s203lbaijjqji6kycni17vwmn5dy2az54r7bri5i7ys5ylff0cr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-bulgarian")
    (synopsis "Bulgarian language module for the @code{datetime2} package")
    (description
     "This module provides the @code{bulgarian} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-catalan
  (package
    (name "texlive-datetime2-catalan")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-catalan/"
                                     "source/latex/datetime2-catalan/"
                                     "tex/latex/datetime2-catalan/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gpzbfiig2180ybdz998qfxlvj7i9qn0b8qikbmfdx980a9y4kd2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-catalan")
    (synopsis "Catalan language module for the @code{datetime2} package")
    (description
     "This module provides the @code{catalan} style that can be set using
\\DTMsetstyle provided by datetime2.sty.  This package is currently
unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-croatian
  (package
    (name "texlive-datetime2-croatian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-croatian/"
                                     "source/latex/datetime2-croatian/"
                                     "tex/latex/datetime2-croatian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kmhwg1kcq5n8sq8a8h0q0izblm94b7wjdymsvdnaxj9z9xniwih"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-croatian")
    (synopsis "Croatian language module for the @code{datetime2} package")
    (description
     "This module provides the @code{croatian} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-czech
  (package
    (name "texlive-datetime2-czech")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-czech/"
                                     "source/latex/datetime2-czech/"
                                     "tex/latex/datetime2-czech/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03zk1qjqxanmdli8rnb15g847gslczz265smjl0b5w5nw5cs7nlh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-czech")
    (synopsis "Czech language module for the @code{datetime2} package")
    (description
     "This module provides the @code{czech} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-danish
  (package
    (name "texlive-datetime2-danish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-danish/"
                                     "source/latex/datetime2-danish/"
                                     "tex/latex/datetime2-danish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0inz6afkhknmdm2g38hyzndkcfp5pkdkysw0hnv9ackavpgsa12c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-danish")
    (synopsis "Danish language module for the @code{datetime2} package")
    (description
     "This module provides the @code{danish} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-dutch
  (package
    (name "texlive-datetime2-dutch")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-dutch/"
                                     "source/latex/datetime2-dutch/"
                                     "tex/latex/datetime2-dutch/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ad2pf6ycf164lh59kr94lkqmqgf2lhay2y4dkd0ycgifypizi07"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-dutch")
    (synopsis "Dutch language module for the @code{datetime2} package")
    (description
     "This module provides the @code{dutch} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-en-fulltext
  (package
    (name "texlive-datetime2-en-fulltext")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-en-fulltext/"
                                     "source/latex/datetime2-en-fulltext/"
                                     "tex/latex/datetime2-en-fulltext/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06zqgqd1pxnwi672460x0xxm2q0yk9kbzwa3hpwrpdsc16xa87j1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-en-fulltext")
    (synopsis "English full text styles for the @code{datetime2} package")
    (description
     "This package provides English date and time styles that use words for the
numbers and ordinals.  This package provides the following date and time
styles: @code{en-fulltext}, @code{en-FullText}, @code{en-FULLTEXT}, and the
additional time style @code{en-Fulltext}. (The date equivalent can be obtained
through commands like @code{\\Today}.)

Unlike the base styles provided by @file{datetime2.sty}, these styles aren't
expandable styles.  This means that you can't use the date or time in PDF
bookmarks or in the argument of certain commands, such as
@code{\\MakeUppercase}, while these styles are in use.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-english
  (package
    (name "texlive-datetime2-english")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-english/"
                                     "source/latex/datetime2-english/"
                                     "tex/latex/datetime2-english/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fdr2i49ximm0hy0gcbi2c00brxrr5mlrw4y1zvc6phjfis1ld8b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-english")
    (synopsis "English language module for the @code{datetime2} package")
    (description
     "This module provides the following styles that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  The region not only
determines the date/time format but also the time zone abbreviations if the
zone mapping setting is on.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-esperanto
  (package
    (name "texlive-datetime2-esperanto")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-esperanto/"
                                     "source/latex/datetime2-esperanto/"
                                     "tex/latex/datetime2-esperanto/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cf8zvnrfp5s4q3gy4c2kjzldg5k50k45klzq0b72n7fq4w2r3r9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-esperanto")
    (synopsis "Esperanto language module for the @code{datetime2} package")
    (description
     "This module provides the @code{esperanto} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-estonian
  (package
    (name "texlive-datetime2-estonian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-estonian/"
                                     "source/latex/datetime2-estonian/"
                                     "tex/latex/datetime2-estonian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fkdxp8s6gd9644z9vw7a9gnw7anrm4l0yawa59qdnv1yf8pyssp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-estonian")
    (synopsis "Estonian language module for the @code{datetime2} package")
    (description
     "This module provides the @code{estonian} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-finnish
  (package
    (name "texlive-datetime2-finnish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-finnish/"
                                     "source/latex/datetime2-finnish/"
                                     "tex/latex/datetime2-finnish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lhacj7bbzppxhj1mp030prapi9d0rg1bx80fzd0bjj1qsl0v0xp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-finnish")
    (synopsis "Finnish language module for the @code{datetime2} package")
    (description
     "This module provides the @code{finnish} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-french
  (package
    (name "texlive-datetime2-french")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-french/"
                                     "source/latex/datetime2-french/"
                                     "tex/latex/datetime2-french/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m5vkdhclrz2j25xjg0syj5xxa78vil164n1779vc68g68dm8mam"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-french")
    (synopsis "French language module for the @code{datetime2} package")
    (description
     "This module provides the @code{french} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-galician
  (package
    (name "texlive-datetime2-galician")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-galician/"
                                     "source/latex/datetime2-galician/"
                                     "tex/latex/datetime2-galician/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b91mi3qj8a6jn56qz9r5hl88vjm5vi4f38v1xjlvqdm2b9p1023"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-galician")
    (synopsis "Galician language module for the @code{datetime2} package")
    (description
     "This module provides the @code{galician} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-german
  (package
    (name "texlive-datetime2-german")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-german/"
                                     "source/latex/datetime2-german/"
                                     "tex/latex/datetime2-german/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14vr043hh0ay5qy1gz3g9dhv397nkvjhzavslyb7kw85cpz5c2i5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-german")
    (synopsis "German language module for the @code{datetime2} package")
    (description
     "This module provides the @code{german} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.")
    (license license:lppl1.3c)))

(define-public texlive-datetime2-greek
  (package
    (name "texlive-datetime2-greek")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-greek/"
                                     "source/latex/datetime2-greek/"
                                     "tex/latex/datetime2-greek/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ai22nlgfsrqz5fz5diq5jjykrh2qqchw6r0cxmpmv9pv0vyba2s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-greek")
    (synopsis "Greek language module for the @code{datetime2} package")
    (description
     "This module provides the @code{greek} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-hebrew
  (package
    (name "texlive-datetime2-hebrew")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-hebrew/"
                                     "source/latex/datetime2-hebrew/"
                                     "tex/latex/datetime2-hebrew/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0n7kw2qmjvdxcnvvh2xv6n86dggmglz7ffvlg3ca2k95gzdw0z5d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-hebrew")
    (synopsis "Hebrew language module for the @code{datetime2} package")
    (description
     "This module provides the @code{hebrew} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-icelandic
  (package
    (name "texlive-datetime2-icelandic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-icelandic/"
                                     "source/latex/datetime2-icelandic/"
                                     "tex/latex/datetime2-icelandic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1s7pz7wnm83hw1jya873cc84r69vg6bxfh9131yy52rw8ppk20zg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-icelandic")
    (synopsis "Icelandic language module for the @code{datetime2} package")
    (description
     "This module provides the @code{icelandic} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-irish
  (package
    (name "texlive-datetime2-irish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-irish/"
                                     "source/latex/datetime2-irish/"
                                     "tex/latex/datetime2-irish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lm9kh5q5rc9hgi7mddxhyjn9r52l3sgcz6i99iylz0gjcpcl2h5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-irish")
    (synopsis "Irish Gaelic language module for the @code{datetime2} Package")
    (description
     "This module provides the @code{irish} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-it-fulltext
  (package
    (name "texlive-datetime2-it-fulltext")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-it-fulltext/"
                                     "source/latex/datetime2-it-fulltext/"
                                     "tex/latex/datetime2-it-fulltext/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04y6ivyj8wdyhqc2psaqljg73vz0ss0hdqivnlxb3l9b3m21vrlv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-iftex))
    (home-page "https://ctan.org/pkg/datetime2-it-fulltext")
    (synopsis "Italian full text styles for the @code{datetime2} package")
    (description
     "This package provides Italian date and time styles that use words for the
numbers and ordinals.  This package includes the following date and time
styles: @code{itfulltext} and @code{it-fulltext-twenty-four}.  The first style
uses a format ``am pm'', the second a format ``24 hours''.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-italian
  (package
    (name "texlive-datetime2-italian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-italian/"
                                     "source/latex/datetime2-italian/"
                                     "tex/latex/datetime2-italian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00bdgp7z7dgqzb6d693bs80x3qldbw7pnfcclkyyifgb8i1zg1ll"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-italian")
    (synopsis "Italian language module for the @code{datetime2} package")
    (description
     "This module provides the @code{italian} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-latin
  (package
    (name "texlive-datetime2-latin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-latin/"
                                     "source/latex/datetime2-latin/"
                                     "tex/latex/datetime2-latin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "160vqgsrifdhl4v62znbanbmpl3cqq1r8isl9lk4wb9yx31ww3qz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-latin")
    (synopsis "Latin language module for the @code{datetime2} package")
    (description
     "This module provides the @code{latin} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-lsorbian
  (package
    (name "texlive-datetime2-lsorbian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-lsorbian/"
                                     "source/latex/datetime2-lsorbian/"
                                     "tex/latex/datetime2-lsorbian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h7fk0xgppscml7sl7sn3c4yrnr131a8v1zxng88af3xr2xlsb37"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-lsorbian")
    (synopsis "Lower Sorbian language module for the @code{datetime2} package")
    (description
     "This module provides the @code{lsorbian} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-magyar
  (package
    (name "texlive-datetime2-magyar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-magyar/"
                                     "source/latex/datetime2-magyar/"
                                     "tex/latex/datetime2-magyar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vy50gl9r2ga0a1m1z9b0hcc35iq5xgr2sl0ifyd48s8zadxrxz4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-magyar")
    (synopsis "Magyar language module for the @code{datetime2} package")
    (description
     "This module provides the @code{magyar} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-norsk
  (package
    (name "texlive-datetime2-norsk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-norsk/"
                                     "source/latex/datetime2-norsk/"
                                     "tex/latex/datetime2-norsk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qan02np4jayqbs7ss92jlldsmmvwxjj7jjngipq3ik7dw035796"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-norsk")
    (synopsis "Norsk language module for the @code{datetime2} package")
    (description
     "This module provides the @code{norsk} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-polish
  (package
    (name "texlive-datetime2-polish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-polish/"
                                     "source/latex/datetime2-polish/"
                                     "tex/latex/datetime2-polish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ip6d2h13ra048qiya02jcrvm907780c339pxlxn289xxvv01mzm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-polish")
    (synopsis "Polish language module for the @code{datetime2} package")
    (description
     "This module provides the @code{polish} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-portuges
  (package
    (name "texlive-datetime2-portuges")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-portuges/"
                                     "source/latex/datetime2-portuges/"
                                     "tex/latex/datetime2-portuges/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y964bkkrjpixq8yvknrwgdi4xc88q5v2jxxaav88ng26gb776ck"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-portuges")
    (synopsis "Portuguese language module for the @code{datetime2} package")
    (description
     "This module provides the @code{portuges} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-romanian
  (package
    (name "texlive-datetime2-romanian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-romanian/"
                                     "source/latex/datetime2-romanian/"
                                     "tex/latex/datetime2-romanian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sqignidr6p7fn2nmxm2k07dcnpghcv9ji613hydgh4slq6lp562"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-romanian")
    (synopsis "Romanian language module for the @code{datetime2} package")
    (description
     "This module provides the @code{romanian} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-russian
  (package
    (name "texlive-datetime2-russian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-russian/"
                                     "source/latex/datetime2-russian/"
                                     "tex/latex/datetime2-russian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "044fw83nr0izxdnyjyk46g8p2m2xq7gwvars4srvbrxr6ra79828"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-russian")
    (synopsis "Russian language module for the @code{datetime2} package")
    (description
     "This module provides the @code{russian} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-samin
  (package
    (name "texlive-datetime2-samin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-samin/"
                                     "source/latex/datetime2-samin/"
                                     "tex/latex/datetime2-samin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mzinlw6qqam9b65whp6ddg8j4jjk0v4arxdizsfzsfda1v18lpg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-samin")
    (synopsis "Northern Sami language module for the @code{datetime2} package")
    (description
     "This module provides the @code{samin} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-scottish
  (package
    (name "texlive-datetime2-scottish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-scottish/"
                                     "source/latex/datetime2-scottish/"
                                     "tex/latex/datetime2-scottish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p9zir361i5gwwiaw2fr9h5ckiilaaxc2p8gfy8xcg6q41lqa6rr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-scottish")
    (synopsis "Scottish Gaelic Language Module for the @code{datetime2} Package")
    (description
     "This module provides the @code{scottish} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-serbian
  (package
    (name "texlive-datetime2-serbian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-serbian/"
                                     "source/latex/datetime2-serbian/"
                                     "tex/latex/datetime2-serbian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05wwhd66k50wzfyypv5sg4n43xfgn1hgvdm3782vq3l3s94bkbnf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-serbian")
    (synopsis "Serbian language module for the @code{datetime2} package")
    (description
     "This module provides the @code{serbian} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  It provides both
Cyrillic and Latin, Ekavian and Ijekavian variants of Serbian date formats,
regionalized and non-regionalized.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-slovak
  (package
    (name "texlive-datetime2-slovak")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-slovak/"
                                     "source/latex/datetime2-slovak/"
                                     "tex/latex/datetime2-slovak/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0whrbsybflccvrnljh5vj73m4lk44njm15sjhj6arq30qal9fqly"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-slovak")
    (synopsis "Slovak language module for the @code{datetime2} package")
    (description
     "This module provides the @code{slovak} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-slovene
  (package
    (name "texlive-datetime2-slovene")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-slovene/"
                                     "source/latex/datetime2-slovene/"
                                     "tex/latex/datetime2-slovene/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sjn20af64gcv3frxizzr3g5kpy50miy1yd1rfq18gyipabyyv6h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-slovene")
    (synopsis "Slovene language module for the @code{datetime2} package")
    (description
     "This module provides the @code{slovene} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-spanish
  (package
    (name "texlive-datetime2-spanish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-spanish/"
                                     "source/latex/datetime2-spanish/"
                                     "tex/latex/datetime2-spanish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14wh1hwnyr9pwc90hm0w17br9m3xbwb27h307m2r552hj0g0da51"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-spanish")
    (synopsis "Spanish language module for the @code{datetime2} package")
    (description
     "This module provides the @code{spanish} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-swedish
  (package
    (name "texlive-datetime2-swedish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-swedish/"
                                     "source/latex/datetime2-swedish/"
                                     "tex/latex/datetime2-swedish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1y13b6553rrh8229z4wb1gd01kyz6208iqwb44dnj3dxyvxhsshz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-swedish")
    (synopsis "Swedish language module for the @code{datetime2} package")
    (description
     "This module provides the @code{swedish} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-turkish
  (package
    (name "texlive-datetime2-turkish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-turkish/"
                                     "source/latex/datetime2-turkish/"
                                     "tex/latex/datetime2-turkish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xhv08gkn4sj305szvvfflprag43qg437bfwhc19la93g79yx16k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-turkish")
    (synopsis "Turkish language module for the @code{datetime2} package")
    (description
     "This module provides the @code{turkish} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-ukrainian
  (package
    (name "texlive-datetime2-ukrainian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-ukrainian/"
                                     "source/latex/datetime2-ukrainian/"
                                     "tex/latex/datetime2-ukrainian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19m3866mwm61r3chpil0xilzirql52igajwdz2v0d3m3x3g12ngs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-ukrainian")
    (synopsis "Ukrainian language module for the @code{datetime2} package")
    (description
     "This module provides the @code{ukrainian} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-usorbian
  (package
    (name "texlive-datetime2-usorbian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-usorbian/"
                                     "source/latex/datetime2-usorbian/"
                                     "tex/latex/datetime2-usorbian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p7mwmwrk1cc9sijc7rv5knzqrzbwig9yfm6nghmnxsqi3czglhq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-usorbian")
    (synopsis "Upper Sorbian language module for the @code{datetime2} package")
    (description
     "This module provides the @code{usorbian} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-datetime2-welsh
  (package
    (name "texlive-datetime2-welsh")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/datetime2-welsh/"
                                     "source/latex/datetime2-welsh/"
                                     "tex/latex/datetime2-welsh/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05lblhk0ja9jyyqrfgy58m6laj9qjj7rxvj4bniv9kw1g05r6si7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/datetime2-welsh")
    (synopsis "Welsh language module for the @code{datetime2} package")
    (description
     "This module provides the @code{welsh} style that can be set using
@code{\\DTMsetstyle} provided by @file{datetime2.sty}.  This package is
currently unmaintained.")
    (license license:lppl1.3+)))

(define-public texlive-dblfloatfix
  (package
    (name "texlive-dblfloatfix")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dblfloatfix/"
                                     "tex/latex/dblfloatfix/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pga2fs38f5fh8dms7a2zy8lv25qw86j920d72wy42adn0l3f5gd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dblfloatfix")
    (synopsis "Fixes for twocolumn floats")
    (description
     "The package solves two problems: floats in a two-column document come out in
the right order and allowed float positions are now @samp{[tbp]}.  The package
actually merges facilities from @code{fixltx2e} and @code{stfloats}.")
    (license license:lppl1.3+)))

(define-public texlive-dbshow
  (package
    (name "texlive-dbshow")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dbshow/" "source/latex/dbshow/"
                                     "tex/latex/dbshow/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1av2zsk0c2wlzcrrr6pv9j5fhw9g77r2gj6ia4hyn0v6q5lfxx2g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dbshow")
    (synopsis
     "Store and display data with custom filters, orders, and styles")
    (description
     "The package provides four core functions: data storage and display, data
filtering, data sorting and data display.  All data is saved once and then you
can display these data with custom filters, orders and styles.  The package
can be used, for example, to record and display something you'd like to
review, maybe the question you always answered incorrectly or some forgettable
knowledge.  But obviously, the package is much more powerful and extensible
for more interesting tasks depending on the individual.")
    (license license:lppl1.3c)))

(define-public texlive-debate
  (package
    (name "texlive-debate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/debate/" "source/latex/debate/"
                                     "tex/latex/debate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1509mb8li2c9ih67bp2d10iz2i1fcwyfkcxq2y9qhddnam0rf48h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-listings
           texlive-listingsutf8
           texlive-pdfcol
           texlive-tcolorbox
           texlive-xcolor
           texlive-xkeyval))
    (home-page "https://ctan.org/pkg/debate")
    (synopsis "Debates between reviewers")
    (description
     "This package helps to organize debates between multiple reviewers of a paper
within the text.")
    (license license:expat)))

(define-public texlive-decimal
  (package
    (name "texlive-decimal")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/decimal/" "source/latex/decimal/"
                                     "tex/latex/decimal/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16ixjiddz4qvwv0rir7l8amz4bc9ldacm2y4cssmb4053kvc9pxw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/decimal")
    (synopsis "LaTeX package for the English raised decimal point")
    (description
     "This LaTeX package should be used by people who need the traditional English
raised decimal point, instead of the American-style period.")
    (license license:lppl1.0+)))

(define-public texlive-decorule
  (package
    (name "texlive-decorule")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/decorule/"
                                     "source/latex/decorule/"
                                     "tex/latex/decorule/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07l723zd20ds5sa70vk5hhrd7a90jqy3hf70wm5q1gnmbjszj1da"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/decorule")
    (synopsis "Decorative swelled rule using font character")
    (description
     "The package implements a decorative swelled rule using only a symbol from
a font installed with all distributions of TeX, so it works independently,
without the need to install any additional software or fonts.")
    (license license:lppl1.3+)))

(define-public texlive-delimtxt
  (package
    (name "texlive-delimtxt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/delimtxt/"
                                     "source/latex/delimtxt/"
                                     "tex/latex/delimtxt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zj7r4igpw5qw40klx17k4w7fmp1w4j0v3gk6h14qw58y9d0wffw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/delimtxt")
    (synopsis "Read and parse text tables")
    (description
     "This experimental package can read and parse text tables delimited by
user-defined tokens (e.g., @samp{Tab}).  It can be used for serial letters and
the like, making it easier to export the data file from MS-Excel/MS-Word")
    (license license:lppl)))

(define-public texlive-democodetools
  (package
    (name "texlive-democodetools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/democodetools/"
                                     "tex/latex/democodetools/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fr37dqqvccr8vfkkqmgds7da0cwhlwlrgh4vzx49kq9l66m78n3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/democodetools")
    (synopsis "Package for LaTeX code documentation")
    (description
     "This is yet another doc/docx/doc3 package for LaTeX code documentation.")
    (license (list license:lppl1.3c license:gpl3+))))

(define-public texlive-diabetes-logbook
  (package
    (name "texlive-diabetes-logbook")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/diabetes-logbook/"
                                     "tex/latex/diabetes-logbook/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kadfz9vq0awzdzp829rri1kw77awi9x96vfqn3nxjwwkdba7nd5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/diabetes-logbook")
    (synopsis "Logbook for people with type one diabetes")
    (description
     "Initally a logbook for me, a person with type one diabetes mellitus, this
evolved over time into a TeX project, making it prettier and easier to use.
I've made it simple to use, while not forgoing the document's beauty or the
speed of input.  The logbook, with slight commenting out and editing, could be
used as a journal by anybody, although the template and graphing functionality
are set up for people using insulin injections and blood glucose teststrips,
as well as counting/estimating carbs, protein, and fat.")
    (license license:gpl3)))

(define-public texlive-diagnose
  (package
    (name "texlive-diagnose")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/diagnose/" "tex/latex/diagnose/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qvnl8cvyh7000191akgx15mdhqwmabfm7bdwwsn1kdq091csa4a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/diagnose")
    (synopsis "Diagnostic tool for a TeX installation")
    (description
     "This package provides macros to assist evaluation of the capabilities of
a TeX installation (i.e., what extensions it supports).  An example document
that examines the installation is available.")
    (license license:gpl3+)))

(define-public texlive-dialogl
  (package
    (name "texlive-dialogl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dialogl/" "source/latex/dialogl/"
                                     "tex/latex/dialogl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vhv7jkc1ll9f4rzg8db83ksbispy7lqvjfywplpx7k1va1qp816"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/dialogl")
    (synopsis "Macros for constructing interactive LaTeX scripts")
    (description
     "This package gathers together a bunch of code and examples about how
to write macros to carry on a dialogue with the user.")
    (license license:lppl)))

(define-public texlive-dichokey
  (package
    (name "texlive-dichokey")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dichokey/" "tex/latex/dichokey/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ncfxvkky0p0ff5bl378464zxvjdq3wg2acy0dmgvxh3zyc8925k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dichokey")
    (synopsis "Construct dichotomous identification keys")
    (description
     "The package can be used to construct dichotomous identification keys (used
especially in biology for species identification), taking care of numbering
and indentation of successive key steps automatically.")
    (license license:public-domain)))

(define-public texlive-dimnum
  (package
    (name "texlive-dimnum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dimnum/" "source/latex/dimnum/"
                                     "tex/latex/dimnum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kknxp8b64z9h5xpazb1684x1hy1431nv6wcc89h0knf7pimdizj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dimnum")
    (synopsis "Commands for dimensionless numbers")
    (description
     "This package simplifies the calling of dimensionless numbers in math or text
mode.")
    (license license:lppl1.3+)))

(define-public texlive-directory
  (package
    (name "texlive-directory")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/directory/"
                                     "bibtex/bst/directory/"
                                     "doc/latex/directory/"
                                     "tex/latex/directory/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03h3vskri5hcvna92spvagig4na8pmr52jmdclis58d903pmm6wp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/directory")
    (synopsis "Address book using BibTeX")
    (description
     "This package for LaTeX and BibTeX facilitates the construction,
maintenance and exploitation of an address book-like database.")
    (license license:lppl)))

(define-public texlive-dirtytalk
  (package
    (name "texlive-dirtytalk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dirtytalk/"
                                     "source/latex/dirtytalk/"
                                     "tex/latex/dirtytalk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rm3y5bwxg7s8db10pzkskgcp54qlkz93g6kif732n9j5c17d9ca"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dirtytalk")
    (synopsis "Typeset quotations easier")
    (description
     "The package provides a macro to typeset quotations, using the command
@code{\\say}.  The quotation mark glyphs are inserted by the macro; nested
quotations are detected.")
    (license license:public-domain)))

(define-public texlive-dlfltxb
  (package
    (name "texlive-dlfltxb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/dlfltxb/" "doc/latex/dlfltxb/"
                                     "tex/latex/dlfltxb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "036szsm6al1b5vrkcvabjwlz465j3bp63fdqsisb1j7153wqfc0g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dlfltxb")
    (synopsis "Macros related to @emph{Introdktion til LaTeX}")
    (description
     "The bundle contains various macros either used for creating the author's book
@emph{Introduktion til LaTeX} (in Danish), or presented in the book as code
tips.  The bundle comprises:

@itemize

@item @code{dlfltxbcodetips}: various macros helpful in typesetting
mathematics;

@item @code{dlfltxbmarkup}: provides macros used throughout, for registering
macro names, packages etc., in the text, in the margin and in the index, all
by using categorised keys;

@item @code{dlfltxbtocconfig}: macros for the two tables of contents that the
book has;

@item @code{dlfltxbmisc}: various macros for typesetting LaTeX arguments, and
the macro used in the bibliography that can wrap a URL up into a BibTeX entry.

@end itemize")
    (license license:lppl)))

(define-public texlive-dnaseq
  (package
    (name "texlive-dnaseq")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dnaseq/" "source/latex/dnaseq/"
                                     "tex/latex/dnaseq/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07g0197v6kyvzmxa3xl96adjki19whmmsj4pjqprpbaqm6nlhn19"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dnaseq")
    (synopsis "Format DNA base sequences")
    (description
     "This package defines a means of specifying sequences of bases.  The bases may
be numbered (per line) and you may specify that subsequences be coloured.  For
a more vanilla-flavoured way of typesetting base sequences, the user might
consider the @code{seqsplit} package.")
    (license license:lppl)))

(define-public texlive-doclicense
  (package
    (name "texlive-doclicense")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/doclicense/"
                                     "source/latex/doclicense/"
                                     "tex/latex/doclicense/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19198684m1088jlnjcn8ahxq6v933ahs9vmjf20h1csz2yqvvc4r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/doclicense")
    (synopsis "Support for putting documents under a license")
    (description
     "This package allows you to put your document under a license and include
a link to read about the license or include an icon or image of the license.
Currently, only Creative Commons is supported, but this package is designed to
handle all kinds of licenses.")
    (license (list license:cc0 license:lppl1.3c))))

(define-public texlive-docmfp
  (package
    (name "texlive-docmfp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/docmfp/" "source/latex/docmfp/"
                                     "tex/latex/docmfp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bqjgd7pj14bxxi37mlqvwp30zmslg019h9bihh3kjp26iz813yr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/docmfp")
    (synopsis "Document non-LaTeX code")
    (description
     "This package extends the @code{doc} package to cater for documenting
non-LaTeX code, such as Metafont or MetaPost, or other programming languages.")
    (license license:lppl)))

(define-public texlive-docmute
  (package
    (name "texlive-docmute")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/docmute/" "source/latex/docmute/"
                                     "tex/latex/docmute/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r1anq3hcddsnzj2vxa8kiax7vazl4zd4ny1a03jzmaljlildrjq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/docmute")
    (synopsis "Input files ignoring LaTeX preamble, etc")
    (description
     "This package inputs or includes stand-alone LaTeX documents, ignoring
everything but the material between @code{\\begin@{document@}} and
@code{\\end@{document@}}.")
    (license license:lppl1.3+)))

(define-public texlive-docshots
  (package
    (name "texlive-docshots")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/docshots/"
                                     "source/latex/docshots/"
                                     "tex/latex/docshots/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19y556cipczh8ihc3zz63ciq07vspgm5w769wj7zc8an1yh0pkx3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-fancyvrb texlive-iexec texlive-pdfcrop
                             texlive-pgf texlive-pgf-blur))
    (home-page "https://ctan.org/pkg/docshots")
    (synopsis "TeX samples next to their PDF Snapshots")
    (description
     "This LaTeX package helps you show TeX code next to the corresponding PDF
snapshots, in two-column formatting.  You can use it either in @file{.dtx}
documentation or in @file{.tex} files.")
    (license license:expat)))

(define-public texlive-doctools
  (package
    (name "texlive-doctools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/doctools/"
                                     "source/latex/doctools/"
                                     "tex/latex/doctools/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zsw9cj27lmjjsqibskfxizbsbcqwrdbd87s283j8pkdsqda8fc4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/doctools")
    (synopsis "Tools for the documentation of LaTeX code")
    (description
     "The package provides a collection of tools for use either in an ordinary
LaTeX document, or within a @file{.dtx} file.")
    (license license:lppl1.3+)))

(define-public texlive-documentation
  (package
    (name "texlive-documentation")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/documentation/"
                                     "source/latex/documentation/"
                                     "tex/latex/documentation/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05f93m7sjjml6cdzw7j02vjxr9ij0079iql6vn5d3xwfx51l9pzl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/documentation")
    (synopsis "Documentation support for C, Java and assembler code")
    (description
     "The package provides a simple means of typesetting computer programs such
that the result is acceptable for inclusion in reports, etc.")
    (license license:lppl1.2+)))

(define-public texlive-docutils
  (package
    (name "texlive-docutils")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/docutils/" "tex/latex/docutils/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01rh5w1dicjszp51vkk5zcs5lzrdmgddfm6dy3nv666gxq12jrf7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/docutils")
    (synopsis
     "Helper commands and element definitions for Docutils LaTeX output")
    (description
     "The package is intended for use with LaTeX documents generated from
reStructuredText sources with Docutils.  When generating LaTeX documents,
specify this package with the stylesheet configuration option, e.g.,
@samp{rst2latex --stylesheet=docutils exampledocument.txt}.")
    (license license:bsd-2)))

(define-public texlive-dotarrow
  (package
    (name "texlive-dotarrow")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dotarrow/"
                                     "source/latex/dotarrow/"
                                     "tex/latex/dotarrow/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10zw1j5adkw0nz2ym1kll47sv1wxmwxkbas5cnyhpg818wzagckf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dotarrow")
    (synopsis "Extendable dotted arrows")
    (description
     "The package can draw dotted arrows that are extendable, in the same was as
@code{\\xrightarrow}.")
    (license license:lppl)))

(define-public texlive-dotlessi
  (package
    (name "texlive-dotlessi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dotlessi/" "tex/latex/dotlessi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "096xlk6r297y4qpwqvpas38anw2q33g9g3xv3msq5qs0xyirask9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dotlessi")
    (synopsis "Provides dotless @samp{i} and @samp{j} for use in any math font")
    (description
     "The package provides two commands: @code{\\dotlessi} and @code{\\dotlessj},
which give access to dotless @samp{i} and @samp{j} in math mode.  They are
intended for symbols in non English languages.")
    (license license:expat)))

(define-public texlive-dotseqn
  (package
    (name "texlive-dotseqn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dotseqn/" "source/latex/dotseqn/"
                                     "tex/latex/dotseqn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ggi0zsnd1prfnvwx41hb37rvmwyq95p4a5qyjq1pms2haniija4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      ;; "dotseqn.ins" is a partial file, so use ".dtx" instead.
      #:build-targets #~(list "dotseqn.dtx")
      #:tex-format "latex"
      #:phases
      #~(modify-phases %standard-phases
          (add-before 'build 'non-interactive-build
            (lambda _
              (substitute* "source/latex/dotseqn/dotseqn.dtx"
                (("(\\\\type(in|out)|\\\\edef\\\\answer).*") "")
                (("\\\\ifodd\\\\answer\n")
                 "\\ifodd89\n")         ;create "dotseqn.sty"
                (("\\\\ifodd\\\\answer \\\\else \\\\OnlyDescription \\\\fi")
                 "\\OnlyDescription"))))))) ;no documentation.
    (home-page "https://ctan.org/pkg/dotseqn")
    (synopsis "Flush left equations with dotted leaders to the numbers")
    (description
     "The package provides a different format for typesetting equations,
one reportedly used in old style Britsh books: equations aligned on the left,
with dots on the right leading to the equation number.  In default of an
equation number, the package operates much like the @code{fleqn} class
option (no leaders).")
    (license license:knuth)))

(define-public texlive-download
  (package
    (name "texlive-download")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/download/"
                                     "source/latex/download/"
                                     "tex/latex/download/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08zkmj9n9k6d2nx4b3q8579f1jgz6mqyxvzx81hi6l3qi4f01phs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/download")
    (synopsis "Allow LaTeX to download files using an external process")
    (description
     "The package allows the user to download files, from within a document.  To
run the external commands, LaTeX (or whatever) needs to be run with the
@code{--shell-escape} flag.")
    (license license:lppl1.3+)))

(define-public texlive-dox
  (package
    (name "texlive-dox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dox/" "source/latex/dox/"
                                     "tex/latex/dox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vzvrr45npkl86bwqc216b0wcsj8rm9dz4ms1b8ydqpg8nv6594d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/dox")
    (synopsis "Extend the doc package")
    (description
     "The @code{doc} package provides LaTeX developers with means to describe the
usage and the definition of new macros and environments.  However, there is no
simple way to extend this functionality to other items (options or counters,
for instance).  The DoX package is designed to circumvent this limitation.")
    (license license:lppl1.3+)))

(define-public texlive-dpfloat
  (package
    (name "texlive-dpfloat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dpfloat/" "tex/latex/dpfloat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xkdnjc3b65kq558yyb2yj1xb0r1cqfyxfgsvmxj79p6naxw7jnc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dpfloat")
    (synopsis "Support for double-page floats")
    (description
     "This package provides @code{fullpage} and @code{leftfullpage} environments,
that may be used inside a @code{figure}, @code{table}, or other float
environment.  If the first of a 2-page spread uses a @code{leftfullpage}
environment, the float will only be typeset on an even-numbered page, and the
two floats will appear side-by-side in a two-sided document.")
    (license license:lppl)))

(define-public texlive-dprogress
  (package
    (name "texlive-dprogress")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dprogress/"
                                     "source/latex/dprogress/"
                                     "tex/latex/dprogress/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g3x1pqbpm6krv9p21jslbprrz9zxmjj33qa62cnpyd4sp1h5ppn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dprogress")
    (synopsis "LaTeX-relevant log information for debugging")
    (description
     "The package logs LaTeX's progress through the file, making the LaTeX output
more verbose.  This helps to make LaTeX debugging easier, as it is simpler to
find where exactly LaTeX failed.  The package outputs the typesetting of
section, subsection and subsubsection headers and (if @code{amsmath} is
loaded) details of the @code{align} environment.")
    (license license:lppl)))

(define-public texlive-drac
  (package
    (name "texlive-drac")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/drac/" "source/latex/drac/"
                                     "tex/latex/drac/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0clkdwjk28vqqzvzby9v28ysmhg7avfqkf093844p8bfjs2i3csw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/drac")
    (synopsis "Declare active character substitution, robustly")
    (description
     "The package provides macros @code{\\DeclareRobustActChar} and
@code{\\ReDeclareRobActChar}.  One uses @code{\\DeclareRobustActChar} in the
same way one would use @code{\\DeclareRobustCommand}; the macro
@code{\\protects} the active character when it appears in a moving argument.
@code{\\ReDeclareRobActChar} redefines an active character previously defined
with @code{\\DeclareRobustActChar}, in the same way that @code{\\renewcommand}
works for ordinary commands.")
    (license license:lppl)))

(define-public texlive-draftcopy
  (package
    (name "texlive-draftcopy")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/draftcopy/"
                                     "source/latex/draftcopy/"
                                     "tex/latex/draftcopy/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vxmpwmyqmzijp73akianjci6kw27dh6hsahh8b3glxh38mz3qm7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:phases
           #~(modify-phases %standard-phases
               ;; Build process generates the package from
               ;; "draftcopy.doc", located in "doc/".  Bring it in the
               ;; working directory.
               (add-after 'unpack 'move-data
                 (lambda _
                   (install-file "doc/latex/draftcopy/draftcopy.doc"
                                 "build/"))))))
    (home-page "https://ctan.org/pkg/draftcopy")
    (synopsis "Identify draft copies")
    (description
     "Places the word @samp{DRAFT} (or other words) in light grey diagonally across
the background (or at the bottom) of each (or selected) pages of the document.
The package uses PostScript @code{\\special} commands, and may not therefore
be used with pdfLaTeX.  For that usage, consider the @code{wallpaper} or
@code{draftwatermark} packages.")
    (license license:lppl)))

(define-public texlive-draftfigure
  (package
    (name "texlive-draftfigure")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/draftfigure/"
                                     "tex/latex/draftfigure/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08akqd8hw2f5rybl1yj7gb8jv0z3ipwvr1gc6bz5rk1676vyfwdz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/draftfigure")
    (synopsis "Replace figures with a white box and additional features")
    (description
     "With this package you can control the outcome of a figure which is set to
draft and modify the display with various options.")
    (license license:lppl1.3+)))

(define-public texlive-dtk
  (package
    (name "texlive-dtk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dtk/" "tex/latex/dtk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17gi7f8mzgss7hzb3fw3apbv6dlrpa6n9i8zqqyqrdwyabk7cwq9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dtk")
    (synopsis "Document class for the journal of DANTE")
    (description
     "The bundle provides a class and style file for typesetting @emph{Die
TeXnische Komodie} --- the communications of the German TeX Users Group DANTE
e.V.  The arrangement means that the class may be used by article writers to
typeset a single article, as well as to produce the complete journal.")
    (license license:lppl1.3c)))

(define-public texlive-dtxdescribe
  (package
    (name "texlive-dtxdescribe")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dtxdescribe/"
                                     "source/latex/dtxdescribe/"
                                     "tex/latex/dtxdescribe/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "190xwr38b403fy5l56yg51r940izs7cv0ixk8h1jwjkcvjw6inyd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dtxdescribe")
    (synopsis "Describe additional object types in @file{.dtx} source files")
    (description
     "The @code{doc} package includes tools for describing macros and environments
in LaTeX source @file{.dtx} format.  The @code{dtxdescribe} package adds tools
for describing booleans, lengths, counters, keys, packages, classes, options,
files, commands, arguments, and other objects, and also works with the
standard document classes as well, for those who do not wish to use the
@file{.dtx} format.

Each item is given a margin tag similar to @code{\\DescribeEnv}, and is listed
in the index by itself and also by category.  Each item may be sorted further
by an optional class.  All index entries except code lines are hyperlinked.
The dtxexample environment is provided for typesetting example code and its
results.  Contents are displayed verbatim along with a caption and
cross-referencing.  They are then input and executed, and the result is shown.
Environments are also provided for displaying verbatim or formatted source
code, user-interface displays, and sidebars with titles.  Macros are provided
for formatting the names of inline LaTeX objects such as packages and
booleans, as well as program and file names, file types, internet objects, the
names of certain programs, a number of logos, and inline dashes and slashes.")
    (license license:lppl1.3+)))

(define-public texlive-dtxgallery
  (package
    (name "texlive-dtxgallery")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dtxgallery/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07c403zbx7sxkhhrwrfw3np20xlqhdk893b4bd6r8lqb0zipp5b5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dtxgallery")
    (synopsis "Small collection of minimal @file{.dtx} examples")
    (description
     "This package provides a collection of files that demonstrate simple things
that are possible with the flexible and under-appreciated @code{docstrip} file
format.  Each file of the collection is provided as a @file{.dtx} file and as
the corresponding @file{.pdf}.")
    (license license:lppl)))

(define-public texlive-ducksay
  (package
    (name "texlive-ducksay")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ducksay/" "source/latex/ducksay/"
                                     "tex/latex/ducksay/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qq3iw1bbxjlc0yc6lcz6wpmgkbmx02sagfal4rima6gg06yp346"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ducksay")
    (synopsis "Draw ASCII art of animals saying a specified message")
    (description
     "The package draws ASCII art of animals saying a specified message.  The
following macros are available: @code{\\ducksay}, @code{\\duckthink},
@code{\\DefaultAnimal}, @code{\\AddAnimal}, and @code{\\DucksayOptions}.
Multi-line messages are fully supported.")
    (license license:lppl1.3c)))

(define-public texlive-duckuments
  (package
    (name "texlive-duckuments")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/duckuments/"
                                     "source/latex/duckuments/"
                                     "tex/latex/duckuments/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03yp3icmzg9plvr3pdjv7qkad528mv0lw95b90a9rq16smkhqnw4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/duckuments")
    (synopsis "Create duckified dummy content")
    (description
     "The package provides facilities to create duckified dummy contents.  The
following macros are available:

@itemize

@item @code{\\duckument} prints a short duckument;

@item @code{\\blindduck} prints a paragraph;

@item @code{\\ducklist} creates a list of a given type;

@item @code{\\ducklistlist} creates nested lists;

@item @code{\\duckitemize}, @code{\\duckenumerate} and
@code{\\duckdescription} are shortcuts for, respectively,
@code{\\ducklist@{itemize@}}, @code{\\ducklist@{enumerate@}} and
@code{\\ducklist@{description@}};

@item @code{\\duckumentsCreateExampleFile};

@item  @code{\\duckumentsDrawRandomDucks}.

@end itemize")
    (license license:lppl1.3c)))

(define-public texlive-dvdcoll
  (package
    (name "texlive-dvdcoll")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/dvdcoll/" "doc/latex/dvdcoll/"
                                     "tex/latex/dvdcoll/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vjsv46yffnibsr1g5wzg0bim3db1wqrxqvwp7fm6bxskfsvy4mq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dvdcoll")
    (synopsis "Class for typesetting DVD archives")
    (description
     "Having lost the overview of my DVD archives, I simply could not remember if
I already recorded the documentary running on TV that day.  I chose to
recreate the index using LaTeX: the design aim was a hyperlinked and fully
searchable PDF-document, listing my DVDs with all titles, lengths and so on.
Further requirements were support for seasons of TV series and a list with all
faulty or missing programs for rerecording.  The @code{dvdcoll} class supports
all these requirements.

@file{dvdcoll.cls} follows the structure @samp{<number><title><length>}.  As
a result, the class is not limited to DVDs --- you can of course typeset
archives of CD-ROMs, Audio-CDs and so on.  Supported languages at the moment:
English, French, German, Italian, Polish, Portuguese, Spanish.")
    (license license:lppl)))

(define-public texlive-dynamicnumber
  (package
    (name "texlive-dynamicnumber")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dynamicnumber/"
                                     "source/latex/dynamicnumber/"
                                     "tex/latex/dynamicnumber/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15fxlihdsnv2mqivv9bjzhdlzprdjgfkcmpa0v2gy60c4nvymi6x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dynamicnumber")
    (synopsis
     "Dynamically typeset numbers and values in LaTeX through ``symbolic links''")
    (description
     "This package dynamically typesets values generated by different kinds of
scripts in LaTeX through the use of ``symbolic links'' (which are not in any
way related to the symbolic links used in UNIX systems!).  The aim is to
reduce errors resulting from out-of-date numbers by directly setting them in
the number generating file and importing a ``symbolic link'' into the LaTeX
source file.  It can be used to import not only numerical values, but strings
and pieces of code are also possible.  Currently only MATLAB and Python are
supported to produce dynamic number list files.")
    (license license:expat)))

(define-public texlive-dynblocks
  (package
    (name "texlive-dynblocks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/dynblocks/"
                                     "tex/latex/dynblocks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jmwkxa4s37cqanpfnzvcq80ic3dvnal5x0g5749c0b410f7x3im"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/dynblocks")
    (synopsis "Simple way to create dynamic blocks for Beamer")
    (description
     "The package provides full customisation of the aspect and dimensions of
blocks inside a presentation.")
    (license license:lppl1.3+)))

(define-public texlive-ean13isbn
  (package
    (name "texlive-ean13isbn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ean13isbn/"
                                     "tex/latex/ean13isbn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ls2i412f2kmipm9ibir8mazy3jhg1plcbzwf780r3hsc8i68fib"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ean13isbn")
    (synopsis "Print EAN13 for ISBN")
    (description
     "The package provides the means to typeset ISBN codes with EAN-13; it uses the
(generic) package @file{ean13.tex} to typeset the actual barcode.")
    (license license:lppl1.3+)))

(define-public texlive-easy
  (package
    (name "texlive-easy")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/easy/" "tex/latex/easy/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dig68199whwprq1g4fdn504vlzyrcmdjdy6y1fvpsz9qfhvkgq7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/easy")
    (synopsis "Collection of easy-to-use macros")
    (description
     "This package provides a collection of macros:

@itemize

@item @code{easybib}, support for customising bibliographies;

@item @code{easybmat}, support for composing block matrices;

@item @code{easyeqn}, support for various aspects of equations;

@item @code{easymat}, support for composing matrices;

@item @code{easytable}, support for writing tables;

@item @code{easyvector}, a C-like syntax for writing vectors.

@end itemize")
    (license license:lppl)))

(define-public texlive-easy-todo
  (package
    (name "texlive-easy-todo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/easy-todo/"
                                     "tex/latex/easy-todo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wzpqd8pq5cpxdaqfwz5knpvrjjhwpvl6yq25h86zk3jxmyag88r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/easy-todo")
    (synopsis "To-do notes in a document")
    (description
     "The package provides to-do notes throughout a document, and will provide an
index of things to do.")
    (license license:asl2.0)))

(define-public texlive-easybook
  (package
    (name "texlive-easybook")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/easybook/"
                                     "source/latex/easybook/"
                                     "tex/latex/easybook/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g4waqpkdswlimmnd4cxla5x1sjd1rig0wxczknxjl5b4lw8bh74"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/easybook")
    (synopsis "Easily typesetting Chinese theses or books")
    (description
     "@code{easybook} is a pure academic template based on the @code{ctexbook} book
document class.  It also has the functions of @code{book} and @code{article}
document class, combined with the general framework design of the dissertation
of many universities in China.  It provides multiple commands and interfaces
allowing users to easily customize the thesis template.  Its basic macro
package @code{easybase} can also be used with CTeX and standard document
classes.")
    (license license:lppl1.3c)))

(define-public texlive-easyfig
  (package
    (name "texlive-easyfig")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/easyfig/" "source/latex/easyfig/"
                                     "tex/latex/easyfig/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xkc0syipviic3cfc4y3lx5zza13cs8ykmbcvcn30ls17y50rmkm"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ydoc")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ydoc))
    (home-page "https://ctan.org/pkg/easyfig")
    (synopsis "Simplifying the use of common figures")
    (description
     "The package provides the command @code{\\Figure} to simplify the business of
including an image as figure in the most common form (centred and with caption
and label).  The package uses the package @code{adjustbox} to center an image
and to simplify further modifications.  As @code{adjustbox} now provides keys
to turn images or other material into floats or non-floats, including
captions, @code{easyfig} has become quite redundant.")
    (license license:lppl1.3+)))

(define-public texlive-easyfloats
  (package
    (name "texlive-easyfloats")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/easyfloats/"
                                     "source/latex/easyfloats/"
                                     "tex/latex/easyfloats/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lp0bflj0m05rxbg5514mg87ipkanrpypvijhqa6qwj08c7gvahk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-caption texlive-environ texlive-etoolbox
                             texlive-float texlive-pgf))
    (home-page "https://ctan.org/pkg/easyfloats")
    (synopsis
     "Easier interface to insert figures, tables and other objects in LaTeX")
    (description
     "In standard LaTeX inserting objects like figures or tables requires too
much knowledge for beginners and too much typing effort and hardcoding for
people like me.  This package aims to make insertion of figures and tables
easier for both beginners and experts.  Despite the term floats in it's name it
also allows disabling floating of such objects.")
    (license license:lppl1.3+)))

(define-public texlive-easyformat
  (package
    (name "texlive-easyformat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/easyformat/"
                                     "tex/latex/easyformat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1y7064ckcbc70a921m8q1rjqz7y9ahmg0dihvf1jqvnhwbjrnxmi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/easyformat")
    (synopsis "Easily add boldface, italics and smallcaps")
    (description
     "This package allows the use of underscores and circumflexes to begin,
respectively, end, italic, bold or small-caps formatting.  The meaning of
underscore and circumflex in math mode remain the same.")
    (license license:gpl3+)))

(define-public texlive-easylist
  (package
    (name "texlive-easylist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/easylist/" "tex/latex/easylist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sj2sn0hwk16819qqyy2bfxslpqxhd4i7zbng2abqbmw1vdvqb2p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/easylist")
    (synopsis "Lists using a single active character")
    (description
     "This package allows you to create lists of numbered items with a single
active character as the only command.  A variety of parameters are available
to configure the appearance of the list; lists may be nested (effectively to
unlimited depth).")
    (license license:lppl)))

(define-public texlive-easyreview
  (package
    (name "texlive-easyreview")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/easyreview/"
                                     "source/latex/easyreview/"
                                     "tex/latex/easyreview/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r0mqqvqn0sd3cv0lhch3v0lkh68z8qx7887zh7i828fkm5x29sm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/easyreview")
    (synopsis
     "Provide a way to review (or perform editorial process) in LaTeX")
    (description
     "The easyReview package provides a way to review (or perform editorial
process) in LaTeX.  You can use the provided commands to claim attention in
different ways to part of the text, or even to indicate that a text was added,
needs to be removed, needs to be replaced and add comments to the text.")
    (license license:lppl)))

(define-public texlive-ebezier
  (package
    (name "texlive-ebezier")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ebezier/" "source/latex/ebezier/"
                                     "tex/latex/ebezier/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cmmlm6sx9xc3ail8dfcwx7afx6by0384ac5hhxp6mry52x0j9ki"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ebezier")
    (synopsis "Device independent picture environment enhancement")
    (description
     "Ebezier is a device independent extension for the standard @code{picture}
environment.  Linear, quadratic, and cubic bezier curves are supplied in
connection with higher level circle drawing commands.  Additionally some
macros for the calculation of curve lengths are part of this package.")
    (license license:lppl)))

(define-public texlive-ecclesiastic
  (package
    (name "texlive-ecclesiastic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ecclesiastic/"
                                     "source/latex/ecclesiastic/"
                                     "tex/latex/ecclesiastic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14kd3f3adf5c5x2aw38rq95m9cbsy675jq4dmpaqhzz9mxy3f1wh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ecclesiastic")
    (synopsis "Typesetting ecclesiastic Latin")
    (description
     "The package modifies the way the @code{latin} option to Babel operates when
typesetting Latin.  The style is somewhat frenchified in respect of
punctuation spacings and footnote style; shortcuts are available in order to
set accents on all vowels, including y and the diphthongs @samp{ae} and
@samp{oe}.")
    (license license:lppl1.3+)))

(define-public texlive-econlipsum
  (package
    (name "texlive-econlipsum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/econlipsum/"
                                     "source/latex/econlipsum/"
                                     "tex/latex/econlipsum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14ijwmfvxcf9lnd1g8ywyn49jl074fsvj5nzfpyb37k3392qhhs8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/econlipsum")
    (synopsis "Generate sentences from economic articles")
    (description
     "This package is a blind text generator that outputs sentences inferred from
abstracts of economic articles.  All the paragraphs are taken with permission
from @url{https://ipsum.mwt.me/}.")
    (license license:lppl1.3c)))

(define-public texlive-ecv
  (package
    (name "texlive-ecv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ecv/" "source/latex/ecv/"
                                     "tex/latex/ecv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17y590j1sp228g9ma7a8i3rr6c4yrnwdzln9j0vzj1fnddvf9n0l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ecv")
    (synopsis "Fancy curriculum vitae class")
    (description
     "The class provides an environment for creating a fancily laid out tabular
curriculum vitae inspired by the european curriculum vitae.  The distribution
comes with a German and an English template.")
    (license license:lppl1.3+)))

(define-public texlive-ed
  (package
    (name "texlive-ed")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ed/" "source/latex/ed/"
                                     "tex/latex/ed/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i6nc3k58f81gk3dg4cgnvccj951p3ffc6xan8j644a4bxlclr8z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ed")
    (synopsis "Editorial notes for LaTeX documents")
    (description
     "This package defines a couple of editorial notes that simplify collaboration
on a LaTeX text.  These allow authors to annotate status information in the
source.  In draft mode, the annotations are shown for communication, and in
publication mode these are suppressed.")
    (license license:lppl1.0+)))

(define-public texlive-edichokey
  (package
    (name "texlive-edichokey")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/edichokey/"
                                     "tex/latex/edichokey/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hc04ckwiw2kwy2r7cs517wlig594fczlmags1yd8hw3wlxcz17n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/edichokey")
    (synopsis "Typeset dichotomous identification keys")
    (description
     "This is a LaTeX package for typesetting dichotomous identification key in
indented style.  It can be considered as an extended version of package
@code{dichokey}, as @code{edichokey} is more capable of dealing with complex
keys.")
    (license license:lppl1.3c)))

(define-public texlive-edmargin
  (package
    (name "texlive-edmargin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/edmargin/"
                                     "source/latex/edmargin/"
                                     "tex/latex/edmargin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04wcwf60jdnw09cg02qb85q7ca1f4pm87h9f67k0pdm9rb4kbbs0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/edmargin")
    (synopsis "Multiple series of endnotes for critical editions")
    (description
     "Edmargin provides a very simple scheme for endnote sections for critical
editions.  Endnotes can either be marked in the text, or with marginal
references to the page in the note sections where the note is to be found.
Notes can be set in individual paragraphs, or in block paragraph mode (where
there are many short notes).")
    (license license:lppl)))

(define-public texlive-eemeir
  (package
    (name "texlive-eemeir")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/eemeir/" "source/latex/eemeir/"
                                     "tex/latex/eemeir/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gqj1rmagd4vy8pw9c6w5bsxbicq1in8ksp3vprj8c0akskndnzp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eemeir")
    (synopsis "Adjust the gender of words in a document")
    (description
     "This package defines macros for third-person singular pronouns
(@code{\\E}, @code{\\Em}, @code{\\Eir}, @code{\\Eirs}), which expand
differently according to a masculine/feminine switch. (If the switch is
masculine, they would expand to @samp{he}, @samp{him}, @samp{his} and
@samp{his}; if feminine, they would expand to @samp{she}, @samp{her},
@samp{her} and @samp{hers}.  Apart from the pronouns, one can define word
pairs, such as mother/father, daughter/son, and so on.  Gender may be defined
once per document, as an environment, or may be flipped on the fly.")
    (license license:lppl)))

(define-public texlive-efbox
  (package
    (name "texlive-efbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/efbox/" "source/latex/efbox/"
                                     "tex/latex/efbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qjm824njz81fp0v91vgid8zlgaj9r4cx2z0i44rlall31z26vpm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/efbox")
    (synopsis "Extension of @code{\\fbox}, with controllable frames and colours")
    (description
     "The package defines the @code{\\efbox} command, which creates a box just wide
enough to hold the text created by its argument.  The command optionally puts
a (possibly partial) frame around the box, and allows setting the box
background colour.")
    (license license:lppl1.3+)))

(define-public texlive-egplot
  (package
    (name "texlive-egplot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/egplot/" "source/latex/egplot/"
                                     "tex/latex/egplot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i6wqnskp55i6gfkiz6gj4flq4mcah9vyqxvf2knrwly6s362pwj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/egplot")
    (synopsis "Encapsulate Gnuplot sources in LaTeX documents")
    (description
     "This package provides a package to encapsulate Gnuplot commands in a LaTeX
source file, so that a document's figures are maintained in parallel with the
document source itself.")
    (license license:gpl3+)))

(define-public texlive-ehhline
  (package
    (name "texlive-ehhline")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ehhline/" "tex/latex/ehhline/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11xyd7qj0k9rvggslpx762x0g2x2y5y3rw36580ih5mj8z9n217n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ehhline")
    (synopsis "Extend the @code{\\hhline} command")
    (description
     "This package extends the @code{\\hhline} command with a @samp{!@{...@}}
token, which allows creating lines with arbitrary LaTeX commands.")
    (license license:expat)))

(define-public texlive-elements
  (package
    (name "texlive-elements")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/elements/" "tex/latex/elements/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z08kqxgdnqwdpzrnixy4rdb0jmyvzy7kvxsm1d6whc0nraiza0j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/elements")
    (synopsis "Provides properties of chemical elements")
    (description
     "The package provides means for retrieving properties of chemical elements
like atomic number, element symbol, element name, electron distribution or
isotope number.  Properties are defined for the elements up to the atomic
number 112.")
    (license license:lppl1.3c)))

(define-public texlive-ellipsis
  (package
    (name "texlive-ellipsis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ellipsis/"
                                     "source/latex/ellipsis/"
                                     "tex/latex/ellipsis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0saxqs2g911w7fqz8k1vs54wg61pjaqivryx9nvy5ik8p2pb30bs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ellipsis")
    (synopsis "Fix uneven spacing around ellipses in LaTeX text mode")
    (description
     "This is a simple package that fixes a problem in the way LaTeX handles
ellipses: it always puts a tiny bit more space after @code{\\dots} in text
mode than before it, which results in the ellipsis being off-center when used
between two words.")
    (license license:lppl1.3c)))

(define-public texlive-elmath
  (package
    (name "texlive-elmath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/elmath/" "source/latex/elmath/"
                                     "tex/latex/elmath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jrykbfpi1iq6zdfq5263676szj9xv6gqh94qfg22jhga7ckgpma"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/elmath")
    (synopsis "Mathematics in Greek texts")
    (description
     "This package has been designed to facilitate the use of Greek letters in
mathematical mode.  The package allows one to directly type in Greek letters (in
ISO 8859-7 encoding) in math mode.")
    (license license:lppl)))

(define-public texlive-elpres
  (package
    (name "texlive-elpres")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/elpres/" "tex/latex/elpres/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mx36x88rcgjga1pqqf0rnyyq81lc4728gzjkp2scwz26yn6b6zv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/elpres")
    (synopsis "Simple class for electronic presentations")
    (description
     "The @code{elpres} class is intended to be used for presentations on a screen
or with a beamer/projector.  It is derived from LaTeX's @code{article} class
and can be used with with LaTeX, pdfLaTeX, and LuaLaTeX.  The default
``virtual paper size'' of presentations generated by this class corresponds to
a 4:3 (width:height) aspect ratio.  Other aspect ratios for widescreen
monitors (16:9, 16:10) may be selected.")
    (license license:lppl)))

(define-public texlive-elzcards
  (package
    (name "texlive-elzcards")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/elzcards/"
                                     "source/latex/elzcards/"
                                     "tex/latex/elzcards/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0r0n3l55wsf8zmdzxwljh13np8y9sigrn051yijnhxrn2y83mj4v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/elzcards")
    (synopsis "Typeset business cards, index cards and flash cards easily")
    (description
     "This package provides a LaTeX package for typesetting business cards,
index cards, and flash cards in an easy and flexible way, optionally also the
reverse side.  You will have to furnish the paper size, the desired size of
your card, the printable area of your printer, and the design of the card.
Everything else is taken care of by @code{elzcards}.")
    (license license:lppl1.3+)))

(define-public texlive-emarks
  (package
    (name "texlive-emarks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/emarks/" "source/latex/emarks/"
                                     "tex/latex/emarks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0snd4wc0fl64b9k4mzdjklcw6z549rx3l7jw34fa2ibmf5zcmr2p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/emarks")
    (synopsis "Named mark registers with e-TeX")
    (description
     "E-TeX provides 32 768 mark registers; using this facility is far more
comfortable than LaTeX tricks with @code{\\markright}, @code{\\markboth},
@code{\\leftmark} and @code{\\rightmark}.  The package provides two commands
for marking: @code{\\marksthe} and @code{\\marksthecs}, which have starred
forms which disable expansion; new mark registers are allocated as needed.
Syntax is closely modelled on the @code{\\marks} primitive.  Four commands are
provided for retrieving the marks registers content: @code{\\thefirstmarks},
@code{\\thebotmarks}, @code{\\thetopmarks} and @code{\\getthemarks}; and the
command @code{\\ifmarksequal} is available for comparing the content of marks
registers.  The package requires an e-TeX enabled engine, and the @code{etex}
package.")
    (license license:lppl1.3+)))

(define-public texlive-embedall
  (package
    (name "texlive-embedall")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/embedall/"
                                     "source/latex/embedall/"
                                     "tex/latex/embedall/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03q3qkgbl3yqnk84gpnp9421vbxrjk6fvnvhaxqn8wqz6v3wijk0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/embedall")
    (synopsis "Embed source files into the generated PDF")
    (description
     "The package provides a means of storing a project, without losing anything.
It uses the @code{embedfile} package to attach to the generated PDF all files
used in creating your project.  In particular, it can embed images, external
TeX files, and external codes.")
    (license license:lppl1.2+)))

(define-public texlive-embedfile
  (package
    (name "texlive-embedfile")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/embedfile/"
                                     "source/latex/embedfile/"
                                     "tex/generic/embedfile/"
                                     "tex/latex/embedfile/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0khpr65fap1rr7rgyv9wbfjpiij2wpazf9xarkzn62wp25yzplag"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/embedfile")
    (synopsis "Embed files into PDF")
    (description
     "This package embeds files in a PDF document, using the PDF format's embedding
operation (note the contrast with the attach operation used by the
@code{attachfile} and @code{attachfile2} packages).  Currently only pdfTeX, in
PDF mode, is supported.")
    (license license:lppl1.3c)))

(define-public texlive-embrac
  (package
    (name "texlive-embrac")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/embrac/" "tex/latex/embrac/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hdgh9gqhb18xj3y203v1prpvc8lhkzjzbgzq1xxb0gvj2bsy187"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/embrac")
    (synopsis "Upright brackets in emphasised text")
    (description
     "The package redefines the commands @code{\\emph} and @code{\\textit} so that
parentheses and square brackets are typeset in an upright font in their
arguments.")
    (license license:lppl1.3+)))

(define-public texlive-emptypage
  (package
    (name "texlive-emptypage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/emptypage/"
                                     "source/latex/emptypage/"
                                     "tex/latex/emptypage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dwf5x4260wa1zl3zn7zl3jlk5jr3jlgflc943lx4m5mpdr85wvj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/emptypage")
    (synopsis "Make empty pages really empty")
    (description
     "This package prevents page numbers and headings from appearing on empty
pages.")
    (license license:lppl1.2+)))

(define-public texlive-emulateapj
  (package
    (name "texlive-emulateapj")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/emulateapj/"
                                     "tex/latex/emulateapj/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13d84pxy67qwdb9wnma05ivk9iv7ky8pfmi8801cw8sc2c2sfz9j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/emulateapj")
    (synopsis "Produce output similar to that of APJ")
    (description
     "This package provides a LaTeX class (based on current RevTeX) to produce
preprints with the page layout similar to that of the @emph{Astrophysical
Journal}.")
    (license license:lppl)))

(define-public texlive-endheads
  (package
    (name "texlive-endheads")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/endheads/"
                                     "source/latex/endheads/"
                                     "tex/latex/endheads/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pbqp5bkak62bqfnh9glk9g37ciachi80m1aavl9s9ahj1dk6af8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/endheads")
    (synopsis "Running headers of the form @samp{Notes to pp.xx-yy}")
    (description
     "Endheads provides running headers of the form @samp{Notes to pp.  xx-yy} for
endnotes sections.  It also enables one to reset the endnotes counter, and put
a line marking the chapter change in the endnotes, at the beginning of every
chapter.")
    (license license:lppl)))

(define-public texlive-endnotes-hy
  (package
    (name "texlive-endnotes-hy")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/endnotes-hy/"
                                     "source/latex/endnotes-hy/"
                                     "tex/latex/endnotes-hy/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05mr1i91znfvgv94rma445s497663qbapv2fx9399kr0kp5zmxyx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/endnotes-hy")
    (synopsis
     "Patches the @code{endnotes} package to create hypertext links to the correct
anchors")
    (description
     "The package supports the creation of hypertext links in support of the
@code{endnotes} package.  The package modifies the syntax of the
@code{\\endnote} command.")
    (license license:lppl1.2+)))

(define-public texlive-engpron
  (package
    (name "texlive-engpron")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/engpron/" "source/latex/engpron/"
                                     "tex/latex/engpron/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gj67i6snlfhkycmrjkn16qw664qi59z5wgmrr22m44hv495yf47"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/engpron")
    (synopsis "Helps to type the pronunciation of English words")
    (description
     "This package provides macros beginning with the PS character, made active,
which enable us to write the British or American English pronunciation as one
can find it in the @emph{English Pronouncing Dictionary} by Daniel Jones.
There is an option to typeset the pronunciation in the style of Harrap's
dictionary.")
    (license license:lppl)))

(define-public texlive-engrec
  (package
    (name "texlive-engrec")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/engrec/" "source/latex/engrec/"
                                     "tex/latex/engrec/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qal8bildiah9h67p69ixy9q2c11v6x8p9lsl4fwyhjm3zvmz8qb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/engrec")
    (synopsis "@code{enumerate} with lower- or uppercase Greek letters")
    (description
     "This package provides two macros @code{\\engrec} and @code{\\EnGrec} to
convert number arguments to lower case or upper case Greek letters.  Options
are provided to work with the @code{upgreek} and @code{fourier} packages.")
    (license license:lppl)))

(define-public texlive-enumitem-zref
  (package
    (name "texlive-enumitem-zref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/enumitem-zref/"
                                     "source/latex/enumitem-zref/"
                                     "tex/latex/enumitem-zref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05chqdbbis649b1dgclz0hylgp8nbhapc6p16aqb91bpbcms7a6b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/enumitem-zref")
    (synopsis "Extended references to items for @code{enumitem} package")
    (description
     "The package is a companion for the @code{enumitem} package; it makes it
possible to reference any item in lists formatted by @code{enumitem} lists,
viz., @code{enumerated}, @code{itemize} and @code{description} lists, and any
list defined (or customised) with @code{\\newlist} or @code{\\setlist}.
References may be typeset differently with options/properties and even
arbitrary text.  With @code{hyperref}, anchors are added for each item to
enable hyperlinks within the document or even to external documents.  Three
schemes are provided to make reference names (including the standard
@code{\\label} command).

The package is currently broken, cf.@:
@url{https://tex.stackexchange.com/q/664886/1090}.")
    (license license:lppl1.3+)))

(define-public texlive-envbig
  (package
    (name "texlive-envbig")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/envbig/" "tex/latex/envbig/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0s09py3cdrhpx4p23zax9lc45bjgv08wkvpp9kw6k7j9wpqgdskf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/envbig")
    (synopsis "Printing addresses on envelopes")
    (description
     "This simple package prints both from and to addresses.")
    (license license:lppl)))

(define-public texlive-envlab
  (package
    (name "texlive-envlab")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/envlab/" "source/latex/envlab/"
                                     "tex/latex/envlab/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08qqvbs12b5fbx2wa86591nr6jhzh42f6y0ch06lxywpy1lgrqrb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:build-targets #~(list "envlab.ins")))
    (home-page "https://ctan.org/pkg/envlab")
    (synopsis "Addresses on envelopes or mailing labels")
    (description
     "This LaTeX package produces mailing envelopes and labels, including barcodes
and address formatting according to the US Postal Service rules.")
    (license license:lppl)))

(define-public texlive-epigraph
  (package
    (name "texlive-epigraph")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/epigraph/"
                                     "source/latex/epigraph/"
                                     "tex/latex/epigraph/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0swqk1wad1ipv4ki8innsgvij88b6mrmrcjshxv3jb9s6j2w5b7g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/epigraph")
    (synopsis "Typeset epigraphs")
    (description
     "Epigraphs are the pithy quotations often found at the start (or end) of
a chapter.  Both single epigraphs and lists of epigraphs are catered for.
Various aspects are easily configurable.")
    (license license:lppl1.3c)))

(define-public texlive-epigraph-keys
  (package
    (name "texlive-epigraph-keys")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/epigraph-keys/"
                                     "tex/latex/epigraph-keys/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0agba7zsi2yafihbwfk40k4rbdalq945n3c6racg4gvi6a5wk2kh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/epigraph-keys")
    (synopsis "Epigraphs using key values")
    (description
     "This package lays out epigraphs: quotations across a page, usually to open or
close a chapter.  It is intended as a simple replacement for the more
sophisticated @code{epigraph} package.")
    (license license:lppl1.3c)))

(define-public texlive-epiolmec
  (package
    (name "texlive-epiolmec")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/epiolmec/"
                                     "fonts/map/dvips/epiolmec/"
                                     "fonts/tfm/public/epiolmec/"
                                     "fonts/type1/public/epiolmec/"
                                     "source/latex/epiolmec/"
                                     "tex/latex/epiolmec/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vz61v5hdkwsdcjcbq7z7gzszxd3liib52sndyas10fqk675hs60"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/epiolmec")
    (synopsis "Typesetting the Epi-Olmec language")
    (description
     "The package contains all the necessary files to typeset Epi-Olmec documents,
in a script used in Southern Middle America until about 500 AD.")
    (license license:lppl)))

(define-public texlive-eq-pin2corr
  (package
    (name "texlive-eq-pin2corr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/eq-pin2corr/"
                                     "source/latex/eq-pin2corr/"
                                     "tex/latex/eq-pin2corr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gh9r6f9l3dxd5fldglnnrx3c0x4s2s4r10igg8crqd4zzas5kp1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eq-pin2corr")
    (synopsis
     "Add PIN security to the @emph{Correct} button of a quiz created by
@code{exerquiz}")
    (description
     "This package is an add-on to the @code{quiz} environment of the
@code{exerquiz} package.  It adds PIN security to a quiz created by the
@code{quiz} environment.  To correct a quiz, the document consumer must press
the @emph{Correct} button of the quiz and successfully enter the correct PIN
number.  The PIN security is designed for the instructor to mark and record
the student's effort on that quiz.")
    (license license:lppl1.2+)))

(define-public texlive-eqell
  (package
    (name "texlive-eqell")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/eqell/" "tex/latex/eqell/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x50b4yfph5707d9xw94fyjrhnih3rp31g4ay4mp7p7m6dgq2q32"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eqell")
    (synopsis "Sympathetically spaced ellipsis after punctuation")
    (description
     "The package provides commands that give a well-spaced ellipsis after
@samp{!}, @samp{?}, @samp{!?} or @samp{?!}.")
    (license license:gpl3+)))

(define-public texlive-eqlist
  (package
    (name "texlive-eqlist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/eqlist/" "source/latex/eqlist/"
                                     "tex/latex/eqlist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13gsz9ixw55mq2i43d80pn967jl3j86l5gkarzqliwc5ni6yn71c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eqlist")
    (synopsis "@code{description} lists with equal indentation")
    (description
     "This package provides a list environment which sets a @code{description}-like
list in which the indentation corresponds to the longest item of the list.")
    (license license:lppl)))

(define-public texlive-eqnalign
  (package
    (name "texlive-eqnalign")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/eqnalign/"
                                     "source/latex/eqnalign/"
                                     "tex/latex/eqnalign/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fnpis9yr7b3h4rnxcgap96fr8dxpk2ziiil9vk3xf18fmzr6b8d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eqnalign")
    (synopsis "Make @code{eqnarray} behave like @code{align}")
    (description
     "The package makes @code{eqnarray} environment behave like @code{align} from
@code{amsmath}.  It is intended for quick-fixing documents that use
@code{eqnarray}.  In cases where it fails, manual conversion to @code{align}
is required, but these cases should be seldom.")
    (license license:lppl1.3+)))

(define-public texlive-eqname
  (package
    (name "texlive-eqname")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/latex/eqname/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qryjgmn2cw2indmmybgzrcrakqi6a3crvdcyvj769mciz8lsdwy"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eqname")
    (synopsis "Name tags for equations")
    (description
     "The @code{\\eqname} command provides a name tag for the current equation, in
place of an equation number.  The name tag will be picked up by a subsequent
@code{\\label} command.")
    ;; "You may freely use, modify and/or distribute this file."
    (license (license:non-copyleft "file://tex/latex/eqname/eqname.sty"))))

(define-public texlive-errata
  (package
    (name "texlive-errata")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/errata/" "source/latex/errata/"
                                     "tex/latex/errata/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lslyh03p99zwkrfr5fj099wpcn6gbymnmx5dw4gmb4a1lab82fk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/errata")
    (synopsis "Error markup for LaTeX documents")
    (description
     "This package provides a simple infrastructure for recording errata in LaTeX
documents.  This allows the user to maintain an updated version of the
document (with all errors corrected) and to automatically generate an errata
document highlighting the difference to the published version.")
    (license license:lppl1.0+)))

(define-public texlive-erw-l3
  (package
    (name "texlive-erw-l3")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/erw-l3/" "source/latex/erw-l3/"
                                     "tex/latex/erw-l3/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m1bynihwzrwzs2mxa3w1rg6b8f9lb17p7j6j9a0g9g0f117hrlp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/erw-l3")
    (synopsis "Utilities based on LaTeX3")
    (description
     "This package provides utilities based on LaTeX3, in particular
@code{\\erw_merge_sort}.")
    (license license:lppl1.3c)))

(define-public texlive-esami
  (package
    (name "texlive-esami")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/esami/" "tex/latex/esami/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fhl6y96s2g0rz9p2r1gcbrpbrhcapqnq7ksryg7q796h1ixd1iw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/esami")
    (synopsis "Typeset exams with scrambled questions and answers")
    (description
     "The package enables the user to typeset exams with multiple choice, open
questions and many other types of exercise.  Both questions and answers may be
randomly distributed within the exam, and the solutions are typeset
automatically.  Exercises may contain a wide number of random parameters and
it is possible to do arithmetical operations on them.  The package is
localised in Italian, English, French, German, Greek, Serbian, and Spanish.")
    (license license:lppl)))

(define-public texlive-esdiff
  (package
    (name "texlive-esdiff")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/esdiff/" "source/latex/esdiff/"
                                     "tex/latex/esdiff/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p55w91d08r3r7x1kjapbgfpq94n40c09nv0cf2ivmwqvrr1qr0a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/esdiff")
    (synopsis "Simplify typesetting of derivatives")
    (description
     "The package makes writing derivatives very easy.  It offers macros for
derivatives, partial derivatives and multiple derivatives, and allows
specification of the point at which the value is calculated.  Some typographic
alternatives may be selected by package options")
    (license license:lppl1.0+)))

(define-public texlive-esieecv
  (package
    (name "texlive-esieecv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/esieecv/" "source/latex/esieecv/"
                                     "tex/latex/esieecv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1d3dx97q7lq5sgixki18vpgjlkgvkljbydi03r10ypnjxidrcxcf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/esieecv")
    (synopsis "Curriculum vitae for French use")
    (description
     "The package allows the user to set up a curriculum vitae as a French employer
will expect.")
    (license license:lppl)))

(define-public texlive-esindex
  (package
    (name "texlive-esindex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/esindex/" "tex/latex/esindex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12jirxg7nijnagn8gszi0bj3sdiyvb9sb2sdpjpj1yk2ngfb41m1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/esindex")
    (synopsis "Typset index entries in Spanish documents")
    (description
     "This package helps you to create indexes in Spanish.  With @code{esindex} you
can write, say, @code{\\esindex@{canon@}} and the entry will be correctly
alphabetized in the index.  This release of @code{esindex} works with accented
characters in any encoding, and without Babel.")
    (license license:expat)))

(define-public texlive-esint
  (package
    (name "texlive-esint")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/esint/"
                                     "fonts/source/public/esint/"
                                     "fonts/tfm/public/esint/"
                                     "source/latex/esint/" "tex/latex/esint/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "172c4ggjkpysfvg0kgcx77lr8md58nvppv0pj6fnrx3lnrvpzvzk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/esint")
    (synopsis "Extended set of integrals for Computer Modern")
    (description
     "The esint package permits access to alternate integral symbols when you are
using the Computer Modern fonts.  In the original set, several integral
symbols are missing, such as @code{\\oiint}.  Many of these symbols are
available in other font sets (@code{pxfonts}, @code{txfonts}, etc.), but there
is no good solution if you want to use Computer Modern.  The package provides
Metafont source and LaTeX macro support.")
    (license license:lppl)))

(define-public texlive-esint-type1
  (package
    (name "texlive-esint-type1")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/esint-type1/"
                                     "dvips/esint-type1/"
                                     "fonts/map/dvips/esint-type1/"
                                     "fonts/type1/public/esint-type1/"
                                     "tex/plain/esint-type1/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qxdbp6xlychk4rxypc52s5qyf6p3fzzqzw5077lwkwgqx89jfhm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-esint))
    (home-page "https://ctan.org/pkg/esint-type1")
    (synopsis "Font @code{esint10} in Type 1 format")
    (description
     "This is Eddie Saudrais's font @code{esint10} in Adobe Type 1 format.")
    (license license:public-domain)))

(define-public texlive-etaremune
  (package
    (name "texlive-etaremune")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/etaremune/"
                                     "source/latex/etaremune/"
                                     "tex/latex/etaremune/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12ljghlhh7li8pgpaa39gnsvvn4l4bmww74zik4q3qmirkhvi949"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-etoolbox
                  texlive-filecontents
                  texlive-footmisc
                  texlive-fourier
                  texlive-hypdoc
                  texlive-listings
                  texlive-xcolor
                  texlive-xkeyval))))
    (home-page "https://ctan.org/pkg/etaremune")
    (synopsis "Reverse-counting @code{enumerate} environment")
    (description
     "The package implements the @code{etaremune} environment which is an
@code{enumerate} environment in which the labels decrease instead of
increasing.  The package is noticeably more efficient than the @code{revnum}
package, which uses painfully many counters.")
    (license license:lppl)))

(define-public texlive-etl
  (package
    (name "texlive-etl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/etl/" "source/latex/etl/"
                                     "tex/latex/etl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1aln59faads7yh432q62kd44idlhc0wfwrxk5y8sbdhql5s6hk7l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/etl")
    (synopsis "Expandable token list operations")
    (description
     "This package provides expandable token list operations for which @code{l3tl}
only has unexpandable variants.  These expandable versions are typically
slower than the unexpandable code.  Unlike the @code{l3tl} versions, the
functions in this module may contain braces and macro parameter tokens in
their arguments, but as a drawback they cannot distinguish some tokens and do
not consider the character code of group-begin and group-end tokens.
Additionally a general map to token lists is provided, modelled after the
@code{expl3} internal @code{__tl_act:NNNn} but with additional features.  The
package has no immediate use for document authors; it only contains
@code{expl3} functions intended for programmers.")
    (license license:lppl1.3c)))

(define-public texlive-eulerpx
  (package
    (name "texlive-eulerpx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/eulerpx/" "tex/latex/eulerpx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lwyi35vzx21cg9kmg94c9z73af3dqf63klzzs86ahbz4f7lvp66"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/eulerpx")
    (synopsis "Modern interface for the Euler math fonts")
    (description
     "This package provides the @code{eulerpx} font, which started as a hybrid of
multiple other font packages, notably @code{eulervm} and @code{newpxmath}.
This package was put together with the intent to use it with the Palatino and
Optima fonts, but it may work with other combinations, too.")
    (license license:lppl1.3+)))

(define-public texlive-europasscv
  (package
    (name "texlive-europasscv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/europasscv/"
                                     "tex/latex/europasscv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q9nj9p87np8p55p3fl0ffhaqlazvn2xh82lmk4fdlhc593mbhpy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/europasscv")
    (synopsis
     "Unofficial class for the new version of the Europass curriculum vitae")
    (description
     "This class is an unofficial LaTeX implementation of the Europass CV, the
standard model for curriculum vitae as recommended by the European Commission.
It includes the major style updates that came out in 2013, featuring a neater,
more compact and somewhat fancier layout.")
    (license license:lppl1.3+)))

(define-public texlive-europecv
  (package
    (name "texlive-europecv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/europecv/" "tex/latex/europecv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mm90scibziailf1a6w9bhncfc9i73lh8hdpsjdzy2fqp73442q4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/europecv")
    (synopsis "Unofficial class for European curricula vitae")
    (description
     "The europecv class is an unofficial LaTeX implementation of the standard
model for curricula vitae (the ``Europass CV'') as recommended by the European
Commission.  Although primarily intended for users in the European Union, the
class is flexible enough to be used for any kind of curriculum vitae.  The
class has localisations for all the official languages of the EU (plus
Catalan), as well as options permitting input in UTF-8 and koi8-r.")
    (license license:lppl)))

(define-public texlive-exam
  (package
    (name "texlive-exam")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/exam/" "tex/latex/exam/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bsckrvhrhjv1gsa5d8z8gqbchw9zay4kh74mjvdp02k3154zklg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/exam")
    (synopsis "Typeset exam scripts")
    (description
     "This package provides a class @file{exam.cls}, which eases production of
exams.  Simple commands are provided to:

@itemize

@item create questions, parts of questions, subparts of parts, and subsubparts
of subparts, all with optional point values;

@item create a grading table, indexed either by question number (listing each
question and the total possible points for that question) or by page
number (listing each page with points and the total possible points for that
page);

@item create headers and footers that are each specified in three parts: one
part to be left justified, one part to be centered, and one part to be right
justified, in the manner of @code{fancyhdr}.

@end itemize

Headers and/or footers can be different on the first page of the exam, can be
different on the last page of the exam, and can vary depending on whether the
page number is odd or even, or on whether the current page continues
a question from a previous page, or on whether the last question on the
current page continues onto the following page.

Multiple line headers and/or footers are allowed, and it's easy to increase
the part of the page devoted to headers and/or footers to allow for this.

Note that the bundle @code{exams} also provides a file @file{exam.cls}; the
two bundles therefore clash, and should not be installed on the same system.")
    (license license:lppl1.3+)))

(define-public texlive-exam-lite
  (package
    (name "texlive-exam-lite")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/exam-lite/"
                                     "tex/latex/exam-lite/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nbwlpj68cc6vqg9bmlwwc1vax6fi3rl885a0dvbqmlznrga5ach"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/exam-lite")
    (synopsis "Quicker preparation of exams in LaTeX")
    (description
     "This template is devoted to the quicker preparation of exams in LaTeX.
Its main features are:

@itemize

@item minimalistic design;

@item include the custom logo of the affiliation;

@item predefined commands for a subject, study year, study program, exam type,
place of exam, date;

@item many macros contained in this package speed up the process of preparing
the necessary ingredients for the exam;

@item automatic calculation of total points.

@end itemize")
    (license license:cc-by-sa4.0)))

(define-public texlive-exam-n
  (package
    (name "texlive-exam-n")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/exam-n/" "source/latex/exam-n/"
                                     "tex/latex/exam-n/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nzg6w0rd3hlpkihkg44qljavha1zkp8wggpivd7q54l1hyib07s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/exam-n")
    (synopsis "Exam class, focused on collaborative authoring")
    (description
     "The class design offers:

@itemize

@item direct support for collaborative development of an exam, using a model
in which a departmental exams convener or exam chair coordinates multiple
authors writing individual questions (the class file and associated process is
in regular use within a physics and astronomy department);

@item all of the traditional exam paper features such as sectioning, per-part
running marks, ``Question n continued'' catchwords, and so on;

@item readily configured local adaptation.

@end itemize")
    (license license:lppl1.3c)))

(define-public texlive-exam-randomizechoices
  (package
    (name "texlive-exam-randomizechoices")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/exam-randomizechoices/"
                                     "tex/latex/exam-randomizechoices/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zaiaxvz91qsjxfiyzfn9i6nrmf95qwdl28s81az20kyn45k18x4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/exam-randomizechoices")
    (synopsis
     "Randomize multiple choices questions using the @code{exam} class")
    (description
     "This package is an extension to the @code{exam} document class.
It provides the user with four new multiple choice typesetting environments
which place their content in a random order.  It can (only) be used in
combination with the @code{exam} class.  The questions themselves cannot be
randomized with this package.  Furthermore, the package provides a simple
answer key table typesetter and has a command for writing the answer keys to
an external file.")
    (license license:lppl1.3+)))

(define-public texlive-examdesign
  (package
    (name "texlive-examdesign")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/examdesign/"
                                     "source/latex/examdesign/"
                                     "tex/latex/examdesign/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xj1n67rnlfwila22bbx1wbv1ffawln7ncnmrr35j92wxykd6vw4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/examdesign")
    (synopsis "LaTeX class for typesetting exams")
    (description
     "This bundle provides a class @code{examdesign}.  The class provides several
features useful for designing tests or question sets: it allows for explicit
markup of questions and answers; the class will, at the user's request,
automatically generate answer keys; multiple versions of the same test can be
generated automatically, with the ordering of questions within each section
randomly permuted so as to minimize cheating; the generated answer keys can be
constructed either with or without the questions included; environments are
provided to assist in constructing the most common types of test question:
matching, true/false, multiple-choice, fill-in-the-blank, and short
answer/essay questions.")
    (license license:gpl3+)))

(define-public texlive-example
  (package
    (name "texlive-example")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/latex/example/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06ld0b9gi8s7y6igijylfvj2qvj3d45z2ml9wd1zfzkpf32pghmy"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/example")
    (synopsis "Typeset examples for TeX courses")
    (description
     "The package makes it easier to produce examples for TeX course.  It provides
an example environment, which typesets its contents on the left of the page,
and prints it verbatim on the right.")
    (license license:gpl3+)))

(define-public texlive-exceltex
  (package
    (name "texlive-exceltex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/exceltex/" "scripts/exceltex/"
                                     "tex/latex/exceltex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i5l1a7ay63b0lqzqsc10ywlqqi1byng7zr4fn7g28v99831wmp4"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "exceltex")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/exceltex")
    (synopsis "Get data from Excel files into LaTeX")
    (description
     "@code{exceltex} is a LaTeX package combined with a helper program
written in Perl.  It provides an easy to use yet powerful and flexible way to
get data from spreadsheets into LaTeX. In contrast to other solutions,
@code{exceltex} does not seek to make the creation of tables in LaTeX easier,
but to get data from spreadsheets into LaTeX as easily as possible.  The Excel
file format only acts as an interface between the spreadsheet application and
@code{exceltex} because it is easily accessible (via the
@code{Spreadsheet::ParseExcel} Perl module) and because most spreadsheet
applications are able to read and write Excel files.")
    (license license:gpl3+)))

(define-public texlive-excludeonly
  (package
    (name "texlive-excludeonly")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/excludeonly/"
                                     "tex/latex/excludeonly/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ya7f51h9m207nqiacb1a2kvrlrla8q0gyrv9dzm9k0k01458iyz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/excludeonly")
    (synopsis "Prevent files being @code{\\include}-ed")
    (description
     "The package defines an @code{\\excludeonly} command, which is the opposite of
@code{\\includeonly}.  If both @code{\\includeonly} and @code{\\excludeonly}
exist in a document, only files allowed by both will be included.  The package
redefines the internal @code{\\@@include} command, so it conflicts with
packages that do the same.")
    (license license:public-domain)))

(define-public texlive-exercise
  (package
    (name "texlive-exercise")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/exercise/"
                                     "source/latex/exercise/"
                                     "tex/latex/exercise/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01i4gagm7d3fqjp6cczw7xsvavlir7wm1i2qxrdxc9fa1xsixq1z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/exercise")
    (synopsis "Typeset exercises, problems, etc. and their answers")
    (description
     "The package helps to typeset exercises or list of exercises within any
document.  Exercises, questions and sub-questions are automatically numbered.
It is possible to put answers in the same document, and display them
immediately, later in the document or not to print answers at all.  The layout
of exercises is fully customisable.  It is possible to typeset long problems,
short exercises, questionnaires, etc.  Usage of the Babel package is detected,
but not fully supported yet (only English and French are implemented).")
    (license license:gpl2)))

(define-public texlive-exercisebank
  (package
    (name "texlive-exercisebank")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/exercisebank/"
                                     "tex/latex/exercisebank/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1im5c6xgf89nk9bx5vrjlhwrgdj9ih23kgvc46lk9qa91ivsa3h9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/exercisebank")
    (synopsis
     "Creating and managing exercises, and reusing them as composed sets")
    (description
     "This package makes it easier to maintain and edit your exercise sets.
Exercises are saved as separate files containing part problems.  These files
can be used to make sets, and you can cherry-pick or exclude certain part
problems as you see fit.")
    (license license:lppl1.3c)))

(define-public texlive-exercisepoints
  (package
    (name "texlive-exercisepoints")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/exercisepoints/"
                                     "tex/latex/exercisepoints/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1309j3aafkkzxpn2sy109xp7vgwn5hrsa35xxcq203lgh58x12ff"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/exercisepoints")
    (synopsis "LaTeX package to count exercises and points")
    (description
     "The package can be used to facilitate exercise counting and exercise point
counting in a LaTeX document.  It counts the number of exercises and it sums
all the points of the exercises in a document.  Especially for exams it is
also common to have an overview of all exercises and their maximal points.
This is also supported by this package by providing a macro to retrieve the
points of each exercise.")
    (license license:lppl1.3+)))

(define-public texlive-exercises
  (package
    (name "texlive-exercises")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/exercises/"
                                     "source/latex/exercises/"
                                     "tex/latex/exercises/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rvlink5l3nqz9x5vvjxh9xgijxba3c1sdzynx86bhxynb0ffnx1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/exercises")
    (synopsis
     "Typeset exercises and solutions with automatic addition of points")
    (description
     "This package defines the environments exercise and solution.
The layout of these environments can be customized.  The -- optional -- points
in the exercises can be added automatically.  The package also permits hiding
the solutions.")
    (license license:lppl1.2+)))

(define-public texlive-exesheet
  (package
    (name "texlive-exesheet")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/exesheet/"
                                     "source/latex/exesheet/"
                                     "tex/latex/exesheet/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1h8sckkw29fzyk4ssr7aywxd05qj7nj1i4qiv05g3mkzdx8bva44"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/exesheet")
    (synopsis "Typesetting exercise or exam sheets")
    (description
     "This package is used for typesetting exercise or exam sheets.  In addition,
the @code{exesheet} class loads the @code{schooldocs} package.  The package
provides: macros to mark out exercises and subparts, specific settings for
enumeration lists, environments for questions and answers, with conditional
display, macros for marking schemes with detailed comments.")
    (license license:lppl1.3+)))

(define-public texlive-exframe
  (package
    (name "texlive-exframe")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/exframe/" "source/latex/exframe/"
                                     "tex/latex/exframe/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rbmhnn5ndy5dsjlfc2v7l88ryxi854z6ifd8m7w99x1akrif379"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/exframe")
    (synopsis "Framework for exercise problems")
    (description
     "This LaTeX2e package provides a general purpose framework to describe and
typeset exercises and exam questions along with their solutions.  The package
features mechanisms to hide or postpone solutions, to assign and handle
points, to collect problems on exercise sheets, to store and use metadata, and
to implement a consistent numbering.  It also provides a very flexible
interface for configuring and customising the formatting, layout, and
representation of the exercise content.")
    (license license:lppl1.3+)))

(define-public texlive-exp-testopt
  (package
    (name "texlive-exp-testopt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/exp-testopt/"
                                     "source/latex/exp-testopt/"
                                     "tex/latex/exp-testopt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b28paxhpnl7s2yi6dlf81z2hpyg7hjd8ixs04wygk6q5ll4bcds"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/exp-testopt")
    (synopsis "Expandable @code{\\@@testopt} (and related) macros")
    (description
     "The package provides an expandable variant of the LaTeX kernel command
@code{\\@@testopt}, named @code{\\@@expandable@@testopt}, and a more general
@code{\\@@expandable@@ifopt}, both intended for package writers.  Also we have
a variant of @code{\\newcommand} which uses these macros to check for optional
arguments.")
    (license license:lppl)))

(define-public texlive-export
  (package
    (name "texlive-export")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/export/" "source/latex/export/"
                                     "tex/latex/export/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0axk0z4pdypwg0bdxyyrk0wvwby9xzq7im0a0r62lriimy53cfdw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/export")
    (synopsis "Import and export values of LaTeX registers")
    (description
     "The package allows the user to export/import the values of LaTeX
registers (counters, rigid and rubber lengths only).  It is not for
faint-hearted users.  The package may be used, for example, to communicate
between documents for the purposes of Dvipaste.")
    (license license:lppl)))

(define-public texlive-exsheets
  (package
    (name "texlive-exsheets")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/exsheets/" "tex/latex/exsheets/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wyld65ghidmiivvx7yan3x8wbx6ma5baw4w6imzdbkvdbp4dxms"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/exsheets")
    (synopsis "Create exercise sheets and exams")
    (description
     "The package provides the means to create exercises or questions and their
corresponding solutions.  The questions may be divided into classes and/or
topics and may be printed selectively.  Meta-data to questions can be added
and recovered.  The solutions may be printed where they are, or collected and
printed at a later point in the document all together, section-wise or
selectively by ID. The package provides the means to selectively include
questions from an external file, and to control the style of headings of both
questions and solutions.

This package has been superseded by its official successor @code{xsim}.
@code{exsheets} itself is now considered obsolete, but will stay alive, and
will continue to receive bugfix releases.  However, new features will not be
added any more.")
    (license license:lppl1.3+)))

(define-public texlive-exsol
  (package
    (name "texlive-exsol")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/exsol/" "source/latex/exsol/"
                                     "tex/latex/exsol/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mygabr121dmm65wc4klmq0v6v0lqjvy9klqami125ffhxs5r8al"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/exsol")
    (synopsis "Exercises and solutions from the same source, into a book")
    (description
     "This package provides macros to allow for embedding exercises and solutions
in the LaTeX source of an instructional text (e.g., a book or a course text)
while generating the following separate documents: your original text that
only contains the exercises, and a solution book that contains only the
solutions to the exercises (optionally, the exercises themselves can also be
copied to the solution book).  The exercise data are generated when running
LaTeX on your document; the first run also writes the solutions to a secondary
file that may be included in a simple document harness, may be processed by
LaTeX, to generate a nice solution book.")
    (license license:lppl1.3+)))

(define-public texlive-extract
  (package
    (name "texlive-extract")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/extract/" "source/latex/extract/"
                                     "tex/latex/extract/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1w2nsgfyhjzg0gwr3rzhq13jh7lj63lh36qjv16hayd2kxrcpb62"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments
     (list #:tex-format "latex"
           #:phases
           #~(modify-phases %standard-phases
               ;; FIXME: Build fails with "LaTeX socket Error: Sockets can
               ;; only be declared at top-level!".  Skip build.
               (delete 'build))))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-etoolbox
                  texlive-float
                  texlive-fourier
                  texlive-hypdoc
                  texlive-listings
                  texlive-pgf
                  texlive-pst-text
                  texlive-pstricks
                  texlive-xcolor
                  texlive-xkeyval))))
    (home-page "https://ctan.org/pkg/extract")
    (synopsis "Extract parts of a document and write to another document")
    (description
     "The package provides the means to extract specific content from a source
document and write that to a target document.  One could, for instance, use
this to extract all exercises from lecture notes and generate an exercises
book on the fly.  The package also provides an environment which writes its
body entirely to the target file.  Another environment will write to the
target file, but will also execute the body.  This allows sharing code (for
instance, a preamble) between the source document and the target file.
Finally, the package provides an interface to conditionally extract content.
With a single package option, one can specify exactly which commands (counted
from the start of the document) should be extracted and which not.  This might
be useful for extracting specific slides from a presentation and use them in
a new file.")
    (license license:lppl1.3+)))

(define-public texlive-facsimile
  (package
    (name "texlive-facsimile")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/facsimile/"
                                     "source/latex/facsimile/"
                                     "tex/latex/facsimile/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sr4avyrkqwq6gh7f5alclnj0z2n8p2q7263jdqb8jlvq80b9pdd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/facsimile")
    (synopsis "Document class for preparing faxes")
    (description
     "The @code{facsimile} class provides a simple interface for creating
a document for sending as a fax, with LaTeX.  The class covers two areas.
First, a title page is created with a detailed fax header; second, every page
gets headers and footers so that the recipient can be sure that every page has
been received and all pages are complete, and in the correct order.  The class
evolved from the @code{fax} package, and provides much better language
support.")
    (license license:lppl)))

(define-public texlive-factura
  (package
    (name "texlive-factura")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/factura/" "source/latex/factura/"
                                     "tex/latex/factura/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kv6lqfd75lsbj413wxjx7zvxhs0s466263g1p4wik1ry3h0bj71"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/factura")
    (synopsis "Typeset and calculate invoices according to Venezuelan law")
    (description
     "@code{factura} is a LaTeX class for typesetting and calculating invoices,
taking into account requirements of SENIAT legislation (tax collector entity
on the Bolivarian Republic of Venezuela).  However, its use is not restricted
to Venezuela because all variables and the displayed text can be redefined by
invoking commands or editing.")
    (license license:lppl1.3c)))

(define-public texlive-familytree
  (package
    (name "texlive-familytree")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/familytree/"
                                     "source/latex/familytree/"
                                     "tex/latex/familytree/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p3rivync409ngvpyp8x754d704rkczpg793hbxh2ws96c73ljw5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/familytree")
    (synopsis "Draw family trees")
    (description
     "This package draws family trees.  Boxes describe individuals; lines
connecting boxes represent sibling or parent-child relationships, or
marriages.  Excluding the marriage box, you can get a maleline/patrilineal
tree, or a femaleline/matrilineal tree.  For Japanese, the @file{jlreq.cls}
vertical option (@emph{tate}) is supported.")
    (license license:gpl2+)))

(define-public texlive-fancyhandout
  (package
    (name "texlive-fancyhandout")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fancyhandout/"
                                     "tex/latex/fancyhandout/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1y59v6kivaqbzc2zms1bzjvkz6xz13rmiqzsm6w9diw5wbfd2q9m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fancyhandout")
    (synopsis "LaTeX class for producing nice-looking handouts")
    (description
     "This package breaks with some of LaTeX's principles and redefines basic LaTeX
commands with the aim of producing well-designed and clearly structured
handouts: a sans-serif font is used by default; sections are not numbered, but
highlighted by underlining; head- and footline display document information;
and in order to avoid too much whitespace around the text the margin sizes are
adjusted to smaller values.  All in all, @code{fancyhandout} provides a means
of typesetting documents not exclusively consisting of running text in
a beautiful way.")
    (license license:lppl1.3c)))

(define-public texlive-fancylabel
  (package
    (name "texlive-fancylabel")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fancylabel/"
                                     "source/latex/fancylabel/"
                                     "tex/latex/fancylabel/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0haf3jjdrfxqnrzahq073j3sv9h7q4wmrxg30xay5w1dq6pkvp4r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fancylabel")
    (synopsis "Complex labelling with LaTeX")
    (description
     "The package provides a complex labelling scheme.  It is designed to support
the needs of the @code{chemschemex} package")
    (license license:lppl1.2+)))

(define-public texlive-fancynum
  (package
    (name "texlive-fancynum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fancynum/"
                                     "source/latex/fancynum/"
                                     "tex/latex/fancynum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15l6sq848pppcp67gg36y0aa2z7vhgxs59ggcpkgfck21g73i28a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fancynum")
    (synopsis "Typeset numbers")
    (description
     "This package provides a LaTeX package for typesetting numbers, in particular
floating point numbers, such as you find in program output.")
    (license license:lppl1.0+)))

(define-public texlive-fancypar
  (package
    (name "texlive-fancypar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fancypar/"
                                     "source/latex/fancypar/"
                                     "tex/latex/fancypar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10m9l4wm8vhzzafvsn1yqan5bv79jm339wznh2w0dxrc82rbzgv6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fancypar")
    (synopsis "Decoration of individual paragraphs")
    (description
     "Decorates individual paragraphs of a document, offering five pre-defined styles.
 The command offers an optional key-value argument with the user may define
parameters of the selected style.  Predefined styles offer a spiral-notebook,
a zebra-like, a dashed, a marked design, and an underlined style.  Users may
also define their own styles.  Decorated paragraphs may not include displayed
mathematics.")
    (license license:lppl1.3+)))

(define-public texlive-fancyqr
  (package
    (name "texlive-fancyqr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fancyqr/" "tex/latex/fancyqr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p5dpk1cr8wssakylmnghjd965dr4grcs8gahmcigjsbwib97ksm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fancyqr")
    (synopsis "Fancy QR-Codes with TikZ")
    (description
     "This package provides a simple package to create fancy QR-codes with the help
of the @code{qrcode} package.")
    (license license:gpl3)))

(define-public texlive-fancyslides
  (package
    (name "texlive-fancyslides")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fancyslides/"
                                     "tex/latex/fancyslides/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0z233j16v6rgrz7y3wlsnp8ff93ybp0154vayh8p0pwh9vvvmkzw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fancyslides")
    (synopsis "Custom presentation class built upon LaTeX Beamer")
    (description
     "This class is prepared for short presentations with a modern look & feel.  It
offers the following features: custom background for each slide, predefined
types of slides, simplified commands (e.g. for starting and ending slide).
The class is built upon LaTeX Beamer, so all Beamer commands should work.")
    (license license:lppl1.3+)))

(define-public texlive-fancytabs
  (package
    (name "texlive-fancytabs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fancytabs/"
                                     "source/latex/fancytabs/"
                                     "tex/latex/fancytabs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09d293nl925sp1nfgnbpqb0xps6d0wa3q566p458qxyzadvfadvk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fancytabs")
    (synopsis "Fancy page border tabs")
    (description
     "The package can typeset tabs on the side of a page.  It requires TikZ from
the PGF bundle.")
    (license license:lppl1.3+)))

(define-public texlive-fancytooltips
  (package
    (name "texlive-fancytooltips")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fancytooltips/"
                                     "source/latex/fancytooltips/"
                                     "tex/latex/fancytooltips/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0f5kznmg8pdsnfyn90pc9kns7fw05p3yr59wrdhrvfdl3nmz76xx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fancytooltips")
    (synopsis "Include a wide range of material in PDF tooltips")
    (description
     "The package was inspired by the @code{cooltooltips} package.  In contrast to
@code{cooltooltips}, @code{fancytooltips} allows inclusion of tooltips which
contain arbitrary TeX material or a series of TeX materials (animated
graphics) from an external PDF file.  To see the tooltips, you have to open
the files in Adobe Reader.  The links and JavaScripts are inserted using
@code{eforms} package from the AcroTeX bundle.")
    (license license:lppl1.2+)))

(define-public texlive-fbox
  (package
    (name "texlive-fbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fbox/" "tex/latex/fbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hr0dz0vwp2131mb58nyqm6smpzb7729ywzxp4mvwgsihxdwxq9w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fbox")
    (synopsis "Extended @code{\\fbox} macro from standard LaTeX")
    (description
     "This package redefines @code{\\fbox} to allow an optional argument for
different frames.  It can be any combination of l)eft, r)ight, t)op, and
b)ottom, for example: @samp{\\fbox[lt]@{foo@}}.  Using uppercase letters or
a combination of lowercase and uppercase is also possible.")
    (license license:lppl1.3c)))

(define-public texlive-fcolumn
  (package
    (name "texlive-fcolumn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fcolumn/" "source/latex/fcolumn/"
                                     "tex/latex/fcolumn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0szvwky690pfm2z80vl01gxxn645zh5hyzy1bwmkisn7lia3k4jr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fcolumn")
    (synopsis "Typesetting financial tables")
    (description
     "In financial reports, text and currency amounts are regularly put in one
table, e.g., a year balance or a profit-and-loss overview.  This package
provides the settings for automatically typesetting such columns, including
the sum line (preceded by a rule of the correct width) using the specifier
@samp{f}.")
    (license license:lppl1.3+)))

(define-public texlive-fetchcls
  (package
    (name "texlive-fetchcls")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fetchcls/"
                                     "source/latex/fetchcls/"
                                     "tex/latex/fetchcls/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03wiyp91x2y93l50rbla4b6qpc3h5zjz36j392r1slxlhplm6m7p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/fetchcls")
    (synopsis "Fetch the current class name")
    (description
     "With standard LaTeX you are able to check for the class in use invoking the
kernel command @code{\\@@ifclassloaded}.  However, doing so you cannot get the
explicit class name, unless you want to loop over every possible class name
until @code{\\@@ifclassloaded} returns true --- don't do that!  With the help
of the present package you can obtain the name of the current class with
significantly less effort.  Just load the package as usual, then, the control
sequence @code{\\classname} will hold the name you were looking for.")
    (license license:lppl1.3c)))

(define-public texlive-fewerfloatpages
  (package
    (name "texlive-fewerfloatpages")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fewerfloatpages/"
                                     "source/latex/fewerfloatpages/"
                                     "tex/latex/fewerfloatpages/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qvyjgigrm3nqcn795v992zifnhs77nhxj9hgxsalf2r668nlw2v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fewerfloatpages")
    (synopsis "Reduce the number of unnecessary float pages")
    (description
     "This package implements a float algorithm extension for handling float pages.
It attempts to reduce the number of unnecessary (fairly empty) float pages
while making sure that floats nevertheless stay close to their call-outs.
Several aspects of the algorithm behavior are adjustable.")
    (license license:lppl1.3c)))

(define-public texlive-ffcode
  (package
    (name "texlive-ffcode")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ffcode/" "source/latex/ffcode/"
                                     "tex/latex/ffcode/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13aia1yffaz1y4k2r4q4pw67bs8isqjd7jsmffysgvm0pbh2p8a0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-environ
           texlive-microtype
           texlive-minted
           texlive-pgf
           texlive-tcolorbox
           texlive-xkeyval))
    (home-page "https://ctan.org/pkg/ffcode")
    (synopsis "Fixed-font code blocks formatted nicely")
    (description
     "This LaTeX package helps you write source code in your academic papers and
make it looks neat.  It uses @code{minted} and @code{tcolorbox}, configuring
them the right way, to ensure that code fragments and code blocks look nicer.")
    (license license:expat)))

(define-public texlive-ffslides
  (package
    (name "texlive-ffslides")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ffslides/" "tex/latex/ffslides/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yd6hy15gr1la5wdxl726xdp0nbnh1agf1w0nrixjfr95qidapxf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ffslides")
    (synopsis "Freeform slides based on the @code{article} class")
    (description
     "The @code{ffslides} (``freeform slides'') class is intended to make it easier
to place various types of content freely on the page, and therefore easier to
design documents with a strong visual component: presentations, posters,
research or lecture notes, and so on.  The goal of the class is to be less
rigid and less complex than some of the popular presentation-making options.
It is essentially a small set of macros added to the @code{article} class.")
    (license license:lppl1.3+)))

(define-public texlive-fgruler
  (package
    (name "texlive-fgruler")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fgruler/" "source/latex/fgruler/"
                                     "tex/latex/fgruler/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1drp8s7hlfbyy5ndam5jqhn8ihy7pm64zz40q8vv2v9a1h0z0p8k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fgruler")
    (synopsis "Draw rulers on the foreground or in the text")
    (description
     "This package draws horizontal and vertical rulers on the foreground of
every (or the current) page at absolute positions.  In this way, you can check
the page layout dimensions.  You can also draw various rulers in the text.")
    (license license:lppl1.3+)))

(define-public texlive-fifo-stack
  (package
    (name "texlive-fifo-stack")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fifo-stack/"
                                     "source/latex/fifo-stack/"
                                     "tex/latex/fifo-stack/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h0s0dfw0p94n2rf5bng2i79cv76vkz0xjwb5pm2gzwimshm0anw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fifo-stack")
    (synopsis "FIFO and stack implementation for package writers")
    (description
     "This package provides a LaTeX implementation of a combined FIFO Stack
modified from the existing @code{stack} package.  The package renames the
original's @code{\\Push} and @code{\\Pop} commands @code{\\FSPush} and
@code{\\FSPop} (which work on the top/end of the FIFO/Stack), and adds the
ability to @code{\\FSUnshift} and @code{\\FSShift} from the bottom (front) of
the FIFO/Stack.")
    (license license:lppl)))

(define-public texlive-figsize
  (package
    (name "texlive-figsize")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/figsize/" "tex/latex/figsize/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10gy0r3dcrl3ghc7rxwfvklanygv2qg6wqh6m96nybnzibgcirxw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/figsize")
    (synopsis "Auto-size graphics")
    (description
     "The FigSize package enables automatic sizing of graphics, especially when
including graphics with the @code{graphicx} package.  The user only has to
specify the number of graphics that should fit to a page or fraction there of
and the package will dynamically calculate the correct graphics sizes relative
to the page size.  Thus, graphics can be auto-sized to fill a whole page or
fraction and manual changes of graphic sizes are never needed when changing
document layouts.  Finally, the package's dynamic lengths can be used to allow
other document element sizes to be dynamic.")
    (license license:lppl)))

(define-public texlive-filedate
  (package
    (name "texlive-filedate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/filedate/"
                                     "source/latex/filedate/"
                                     "tex/latex/filedate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0j7ccirlpda8rqzjpfqlgj6r72z0693y02anaf1izvhyk339fxg2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/filedate")
    (synopsis "Access and compare info and modification dates")
    (description
     "The package provides basic access to the date of a LaTeX source file
according to its @code{\\Provides}...  entry (the ``info date'') as well as to
its modification date according to @code{\\pdffilemoddate} if the latter is
available.")
    (license license:lppl)))

(define-public texlive-fileinfo
  (package
    (name "texlive-fileinfo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fileinfo/"
                                     "source/latex/fileinfo/"
                                     "tex/latex/fileinfo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i6nvxkzh67bkkqhd64bl2ivqd9v3y1qkw4qxy8pk49hc57mpc4b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fileinfo")
    (synopsis "Enhanced display of LaTeX File Information")
    (description
     "The bundle provides two packages, @code{readprov} and @code{myfilist}.  The
@code{readprov} package provides a means of reading file information without
loading the body of the file.  The @code{myfilist} package uses
@code{readprov} and controls what @code{\\listfiles} will report.")
    (license license:lppl1.3+)))

(define-public texlive-fink
  (package
    (name "texlive-fink")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fink/" "source/latex/fink/"
                                     "tex/latex/fink/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mj7hjmyx83wv9hm8qsz889bh8p0kdx5a01nbgx0qdxm9wqqyxx0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/fink")
    (synopsis "LaTeX2e file name keeper")
    (description
     "This package keeps track of files included in your document, with
@code{\\input} or @code{\\include}.  You then have permanent access to the
name of the file currently being processed through the macro
@code{\\finkfile}.

FiNK has been deprecated and is not maintained anymore.  People
interested in FiNK's functionality are invited to use a package named
@code{currfile} instead.")
    (license license:lppl)))

(define-public texlive-finstrut
  (package
    (name "texlive-finstrut")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/finstrut/"
                                     "source/latex/finstrut/"
                                     "tex/latex/finstrut/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zpyn492xq5h50jh6wwdlj10xwvnkdhxnljqjfkiw429lgaw7qfi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/finstrut")
    (synopsis "Adjust behaviour of the ends of footnotes")
    (description
     "The LaTeX internal command @code{\\@@finalstrut} is used automatically used
at the end of footnote texts to insert a strut to avoid mis-spacing of
multiple footnotes.  Unfortunately the command can cause a blank line at the
end of a footnote.  The package provides a solution to this problem.")
    (license license:lppl1.3+)))

(define-public texlive-fistrum
  (package
    (name "texlive-fistrum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fistrum/" "source/latex/fistrum/"
                                     "tex/latex/fistrum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12jqys8aa6cjyw1g7hf61hcmn5psvhdr7nxdgq03wx11263ci6zf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fistrum")
    (synopsis "Access to 150 paragraphs of Lorem Fistrum very dummy text")
    (description
     "Fistrum is a LaTeX package forked from @code{lipsum} that produces dummy text
for use in documents and examples.  The paragraphs were taken with permission
from @url{https://www.chiquitoipsum.com/}.")
    (license license:lppl1.3+)))

(define-public texlive-fithesis
  (package
    (name "texlive-fithesis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fithesis/"
                                     "source/latex/fithesis/"
                                     "tex/latex/fithesis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jc179rwax3kpg5a8r3ly197f8z5kvac194r151whkg2zgijl02s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      ;; "fithesis.ins" expects some directories in "build".  Create them
      ;; first to prevent an error.
      #~(modify-phases %standard-phases
          (add-before 'build 'fix-build
            (lambda _
              (mkdir-p "build/mu")
              (with-directory-excursion "build/mu"
                (for-each mkdir-p
                          '("econ"
                            "fi"
                            "fsps"
                            "fss"
                            "law"
                            "med"
                            "ped"
                            "pharm"
                            "phil"
                            "sci"))))))))
    (home-page "https://ctan.org/pkg/fithesis")
    (synopsis
     "Thesis class and template for Masaryk University (Brno, Czech Republic)")
    (description
     "This package provides a document class for the typesetting of theses at the
Masaryk University (Brno, Czech Republic).  The class has been designed for
easy extensibility by style and locale files of other academic institutions.")
    (license license:lppl1.3+)))

(define-public texlive-fixcmex
  (package
    (name "texlive-fixcmex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fixcmex/" "source/latex/fixcmex/"
                                     "tex/latex/fixcmex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00wrjvy0n8181a5ki644z40l8i4f2vlhbwkg0zc9yqsby17dl43r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fixcmex")
    (synopsis "Fully scalable version of Computer Modern Math Extension font")
    (description
     "This package provides a fully scalable version of the Computer Modern Math
Extension font for curing sizing problems mainly with @code{lmodern}.  It can
be used when the main font of the document is Computer Modern (or European
Modern, if T1 encoding is selected), or Latin Modern.  It redefines the math
extension font so that it becomes arbitrarily scalable, using the optical size
fonts provided by the AMS together with the original @code{cmex10} font.")
    (license license:lppl1.3c)))

(define-public texlive-fixme
  (package
    (name "texlive-fixme")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fixme/" "source/latex/fixme/"
                                     "tex/latex/fixme/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mgx9v7c0l572lz6ysbpg0hrqk4lpy5sn9kcyrpf71zp28szf81s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:tex-format "latex"
           #:phases
           ;; Build process requires some directories to be created
           ;; beforehand.  Create those to prevent an error.
           #~(modify-phases %standard-phases
               (add-before 'build 'fix-build
                 (lambda _
                   (for-each mkdir-p
                             '("build/layouts/env"
                               "build/layouts/target"
                               "build/themes/")))))))
    (home-page "https://ctan.org/pkg/fixme")
    (synopsis "Collaborative annotation tool for LaTeX")
    (description
     "FiXme is a collaborative annotation tool for LaTeX documents.
Annotating a document here refers to inserting meta-notes, that is, notes that
do not belong to the document itself, but rather to its development or
reviewing process.  Such notes may involve things of different importance
levels, ranging from simple ``fix the spelling'' flags to critical ``this
paragraph is a lie'' mentions.  Annotations like this should be visible during
the development or reviewing phase, but should normally disappear in the final
version of the document.  FiXme is designed to ease and automate the process
of managing collaborative annotations, by offering a set of predefined note
levels and layouts, the possibility to register multiple authors, to reference
annotations by listing and indexing etc.")
    (license license:lppl1.3+)))

(define-public texlive-fixmetodonotes
  (package
    (name "texlive-fixmetodonotes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fixmetodonotes/"
                                     "source/latex/fixmetodonotes/"
                                     "tex/latex/fixmetodonotes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "100rxmm6v99v02n76rfiahmv5947v1cfnkch4ylax11ipd3s9jnk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fixmetodonotes")
    (synopsis "Add notes on document development")
    (description
     "The package provides tools to highlight @samp{FIXME} and @samp{TODO}
annotations.  The command @code{\\listofnotes} prints a list of outstanding
notes, with links to the pages on which they appear.")
    (license license:public-domain)))

(define-public texlive-fjodor
  (package
    (name "texlive-fjodor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fjodor/" "tex/latex/fjodor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0s0aaf5h1rm18hyav988rqvsq4xzyszr41p7sqnl92xxi5xzg86h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fjodor")
    (synopsis "Selection of layout styles")
    (description
     "The package provides several page layouts, selectable by package options.")
    (license license:gpl3+)))

(define-public texlive-flabels
  (package
    (name "texlive-flabels")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/flabels/" "source/latex/flabels/"
                                     "tex/latex/flabels/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1s2yggjvbsbbzryxqy8kdy6yw38q0wnzr82hjwfcpip83f4mm123"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/flabels")
    (synopsis "Labels for files and folders")
    (description
     "This package provides macros for typesetting pretty labels (optionally
colored) for the back of files or binders (currently only the special A4
@emph{Leitz-Ordner} ring binder is supported).")
    (license license:lppl)))

(define-public texlive-flacards
  (package
    (name "texlive-flacards")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/flacards/" "tex/latex/flacards/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "048fl0hhd0vh558wzi4lbsnhaxwzg77x5c4x94pn7pmqfn8zlcz0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/flacards")
    (synopsis "Generate flashcards for printing")
    (description
     "The @code{flacards} class provides an easy interface to produce flashcards.
It will print several cards per page, on both sides of the paper.")
    (license license:gpl3+)))

(define-public texlive-flagderiv
  (package
    (name "texlive-flagderiv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/flagderiv/"
                                     "source/latex/flagderiv/"
                                     "tex/latex/flagderiv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gzcanvbpz8scnlkchs2fyw3mphzmswp8p723kwifncvab41i9nk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/flagderiv")
    (synopsis "Flag style derivation package")
    (description
     "The @code{flagderiv} package is used to create mathematical derivations using
the flag/flagpole notation.  The package features an intuitive command syntax,
opening and closing multiple flagpoles, different comment styles, customizable
symbols and label namespaces.")
    (license license:gpl3+)))

(define-public texlive-flashcards
  (package
    (name "texlive-flashcards")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/flashcards/"
                                     "source/latex/flashcards/"
                                     "tex/latex/flashcards/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l70bz1dng1drilp6mk9998n38zbd5d9jlxnw0g5gp1p0hrlmzmb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/flashcards")
    (synopsis "Class for typesetting flashcards")
    (description
     "The FlashCards class provides for the typesetting of flash cards.  By flash
card, we mean a two sided card which has a prompt or a question on one side
and the response or the answer on the flip (back) side.  Flash cards come in
many sizes depending on the nature of the information they contain.")
    (license license:gpl2+)))

(define-public texlive-flashmovie
  (package
    (name "texlive-flashmovie")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/flashmovie/"
                                     "tex/latex/flashmovie/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16m9ql650w70vi3iwqf4988v9yz14pimr88c87cgxwdmvzz0ak3j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/flashmovie")
    (synopsis "Directly embed flash movies into PDF files")
    (description
     "The package allows direct embedding of flash movies into PDF files.  It is
designed for use with pdfLaTeX.  The package takes advantage of the embedded
Adobe Flash player in Adobe Reader 9; the reader is invoked with the rich
media annotation feature.  This method of embedding movies is attractive since
it removes all platform dependencies; however, the user is required to use
Acrobat 9.")
    (license license:lppl1.3+)))

(define-public texlive-flexipage
  (package
    (name "texlive-flexipage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/flexipage/"
                                     "source/latex/flexipage/"
                                     "tex/latex/flexipage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0j9ffmvb5yrkcf3f1yily6a44jivpzblss9psj6ycba88wnj5ccj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/flexipage")
    (synopsis "Flexible page geometry with marginalia")
    (description
     "The package @code{flexipage} allows easy page layout if marginalia is
required.  Mid document changes are possible such as: new marginal width, full
width text, and landscape text without marginal.  It partners well with the
package @code{sidenotesplus}.  The package also aids the layout for book
printing, allowing for binding corrections and adding page bleed, if
required.")
    (license license:lppl1.3c)))

(define-public texlive-flipbook
  (package
    (name "texlive-flipbook")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/flipbook/" "tex/latex/flipbook/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jy388pxrlmw1spvhznrggwz76b0nfmigp954skm74fpdzhwalmd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/flipbook")
    (synopsis "Typeset flipbook animations, in the corners of documents")
    (description
     "The package provides techniques for adding flip book animations in the corner
of your LaTeX documents (using images or ASCII art).  Animations are defined
as a set of numbered files (e.g., @file{im1.pdf}, @file{im2.pdf}, ...).  The
package relies on @code{fancyhdr} to control the corners.")
    (license license:lppl)))

(define-public texlive-flippdf
  (package
    (name "texlive-flippdf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/flippdf/" "source/latex/flippdf/"
                                     "tex/latex/flippdf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bjac3nddii4g9q8b02z43slab1wnl707jqpyy8f8zmns4l04ws5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/flippdf")
    (synopsis "Horizontal flipping of pages with pdfLaTeX")
    (description
     "The package allows the production of a document with pages mirrored.  This is
sometimes required by publishers who want camera-ready documents to be printed
on transparent film (to be viewed from the ``wrong'' side).  The package only
works with pdfLaTeX or LuaLaTeX in PDF output mode.")
    (license license:lppl1.3c)))

(define-public texlive-floatrow
  (package
    (name "texlive-floatrow")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/floatrow/"
                                     "source/latex/floatrow/"
                                     "tex/latex/floatrow/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wqg4qikbrmf2q1f4nxv3lfqg6w03n06v3gzxm7xdda4nj7ppc07"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/floatrow")
    (synopsis "Modifying the layout of floats")
    (description
     "The @code{floatrow} package provides many ways to customize layouts of
floating environments and has code to cooperate with the @code{caption}
package.  The package offers mechanisms to put floats side by side, and to put
the caption beside its float.  The @code{floatrow} settings could be expanded
to the floats created by packages @code{rotating}, @code{wrapfig},
@code{subfig} (in the case of rows of subfloats), and @code{longtable}.")
    (license license:lppl)))

(define-public texlive-flowfram
  (package
    (name "texlive-flowfram")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/flowfram/" "scripts/flowfram/"
                                     "source/latex/flowfram/"
                                     "tex/latex/flowfram/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1y3r1g9ycxq7r839ca7xzjpk628jvnc1fc0qgp6f6wb99ps79pzc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/flowfram")
    (synopsis "Create text frames for posters, brochures or magazines")
    (description
     "The @code{flowfram} package enables you to create frames in a document such
that the contents of the document environment flow from one frame to the next
in the order in which they were defined.  This is useful for creating posters
or magazines, indeed any form of document that does not conform to the
standard one or two column layout.")
    (license license:lppl1.3+)))

(define-public texlive-fmp
  (package
    (name "texlive-fmp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fmp/" "source/latex/fmp/"
                                     "tex/latex/fmp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sccyi1bnz882qyvxjrzl988fgkip5dv64fn3ns377vq4sydcx2m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:build-targets #~(list "fmp.sty")))
    (home-page "https://ctan.org/pkg/fmp")
    (synopsis "Include functional MetaPost in LaTeX")
    (description "This package allows including functional MetaPost in LaTeX.")
    (license license:lppl)))

(define-public texlive-fn2end
  (package
    (name "texlive-fn2end")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fn2end/" "tex/latex/fn2end/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1d1gpl3inhimzylrkx0pjl1xjczf2qp9m3823kj8s8kw0y54bg61"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fn2end")
    (synopsis "Convert footnotes to endnotes")
    (description
     "This package defines macros @code{\\makeendnotes}, which converts
@code{\\footnote} to produce endnotes; and @code{\\theendnotes} which prints
them out.")
    (license license:public-domain)))

(define-public texlive-fnbreak
  (package
    (name "texlive-fnbreak")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fnbreak/" "source/latex/fnbreak/"
                                     "tex/latex/fnbreak/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06in9iq69iyhvs3rc5hfdbqay8p955hraa5lln2fzl6p17xgr3r3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fnbreak")
    (synopsis "Warn for split footnotes")
    (description
     "This package detects footnotes that are split over several pages, and writes
a warning to the log file.")
    (license license:lppl)))

(define-public texlive-fncylab
  (package
    (name "texlive-fncylab")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fncylab/" "tex/latex/fncylab/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yk1byhczzjnig7x5g0aidsk64nh4shbwn66v4j0bm0ps6ya2b9v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fncylab")
    (synopsis "Alter the format of @code{\\label} references")
    (description
     "LaTeX provides a mechanism for altering the appearance of references to
labels, but it's somewhat flawed, and requires that the user manipulate
internal commands.  The package solves the problem, by providing
a @code{\\labelformat} command for changing the format of references to
labels.  The package also provides a @code{\\Ref} command to make reference to
such redefined labels at the start of a sentence.")
    (license license:lppl)))

(define-public texlive-fnpara
  (package
    (name "texlive-fnpara")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fnpara/" "tex/latex/fnpara/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rc8r9dq23fvjygk44mpk74fzcdl55134sql91wc663z7yaz35xc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fnpara")
    (synopsis "Footnotes in paragraphs")
    (description
     "Typeset footnotes in run-on paragraphs, instead of one above another; this is
a re-seating, for the LaTeX environment, of an example in the @emph{TeXbook}.
The same basic code, improved for use in e-TeX-based LaTeX, appears in the
comprehensive footnote package @code{footmisc}, and superior versions are also
available in the @code{manyfoot} and @code{bigfoot} packages.")
    (license license:lppl1.3+)))

(define-public texlive-fnpct
  (package
    (name "texlive-fnpct")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fnpct/" "tex/latex/fnpct/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z1r5q6j5gb4x6sw579irasymk52wr4fdjh4rbgz118h0z4izivk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fnpct")
    (synopsis "Manage footnote marks interaction with punctuation")
    (description
     "The package moves footnote marks after following punctuation (comma or full
stop), and adjusts kerning as appropriate.  As a side effect, a change to the
handling of multiple footnotes is provided.")
    (license license:lppl1.3c)))

(define-public texlive-fnumprint
  (package
    (name "texlive-fnumprint")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fnumprint/"
                                     "source/latex/fnumprint/"
                                     "tex/latex/fnumprint/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ni19n3g4qhj1cf5602jrrwkzfz89jz2yfvplynk3dsfrxnrm78x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fnumprint")
    (synopsis "Print a number in ``appropriate'' format")
    (description
     "The package defines two macros which decide to typeset a number either as an
Arabic number or as a word (or words) for the number.  If the number is
between zero and twelve (including zero and twelve) then words will be used;
if the number is outside that range, it will be typeset using the package
numprint Words for English representation of numbers are generated within the
package, while those for German are generated using the package
@code{zahl2string}.")
    (license license:lppl1.3+)))

(define-public texlive-foilhtml
  (package
    (name "texlive-foilhtml")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/foilhtml/"
                                     "source/latex/foilhtml/"
                                     "tex/latex/foilhtml/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zrz5jgqm0wwii8bbi8z4pmvs4qk23lw3yklzhrbw1q5wkzdc0ng"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/foilhtml")
    (synopsis "Interface between FoilTeX and LaTeX2HTML")
    (description
     "This package provides integration between FoilTeX and LaTeX2HTML,
adding sectioning commands and elements of logical formatting to FoilTeX and
providing support for FoilTeX commands in LaTeX2HTML.")
    (license license:lppl)))

(define-public texlive-foliono
  (package
    (name "texlive-foliono")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/foliono/" "tex/latex/foliono/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ldp7cp3s75yyzn5wkdp5rw8q5aii6rnpflw13xj0h5hvv0a6h0y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/foliono")
    (synopsis "Use folio numbers to replace page numbers")
    (description
     "This package adds functionality to create several styles of folio numbers.
Folio numbering preceded the modern page numbering convention and was in
common use until the 18th century.  In folio numbering the numbers are placed
only on odd (right-side) pages and the numbers typically comprise of two
parts: quire and folio numbers.  The intended use for this package is to help
creating old-style books.")
    (license license:lppl1.3c)))

(define-public texlive-fontsetup
  (package
    (name "texlive-fontsetup")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fontsetup/"
                                     "tex/latex/fontsetup/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b0xydxscgzz1d9mjv3lv0kyfkdf7jrxazsl9dfdyssb3mnjgsag"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fontsetup")
    (synopsis
     "Front-end to @code{fontspec}, for selected fonts with math support")
    (description
     "This package facilitates the use of @code{fontspec} for users who do not wish
to bother with details, with a special focus on quality fonts supporting
mathematics.")
    (license license:gpl3)))

(define-public texlive-footmisx
  (package
    (name "texlive-footmisx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/footmisx/"
                                     "source/latex/footmisx/"
                                     "tex/latex/footmisx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17gkxi48nr52dcvm2x7zbf81h57aryy64f77y8gj1l4gvkh7ylbm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/footmisx")
    (synopsis "Range of footnote options")
    (description
     "This a fork of @code{footmisc} package allowing to use @code{hyperref}.
The package provides means of changing the layout of the footnotes themselves,
a way to number footnotes per page, to make footnotes disappear in a moving
argument and to deal with multiple references to footnotes from the same
place.  The package also has a range of techniques for labelling footnotes
with symbols rather than numbers.  Some of the functions of the package are
overlap with the functionality of other packages.

Don't be seduced by @code{fnpara}, whose implementation is improved by the
present package.")
    (license license:lppl1.3+)))

(define-public texlive-footnotebackref
  (package
    (name "texlive-footnotebackref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/footnotebackref/"
                                     "tex/latex/footnotebackref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ns4kdqkpirv1n8kc52n9qymbk6z0pczihxz3n26fl4acnz3nsmy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/footnotebackref")
    (synopsis "Back-references from footnotes")
    (description
     "The package provides the means of creating hyperlinks, from a footnote at the
bottom of the page, back to the occurrence of the footnote in the main text.")
    (license license:lppl1.3+)))

(define-public texlive-footnoterange
  (package
    (name "texlive-footnoterange")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/footnoterange/"
                                     "source/latex/footnoterange/"
                                     "tex/latex/footnoterange/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sc3m2hy4hgc3mxsaby9say1hsad4flchs7wv2xxv4wzss3g2kgh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/footnoterange")
    (synopsis "References to ranges of footnotes")
    (description
     "The package provides the environments @code{footnoterange} and
@code{footnoterange*}.  Multiple footnotes inside these environments are not
referenced as (e.g.) @samp{1 2 3} but as @samp{1-3}, i.e., the range (from
first to last referred footnote at that place) is given.  If the
@code{hyperref} package is loaded with enabled @code{hyperfootnotes} option,
then the references are hyperlinked.  (References to footnotes in
@code{footnoterange*} environments are never hyperlinked.)")
    (license license:lppl1.3c)))

(define-public texlive-footnpag
  (package
    (name "texlive-footnpag")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/footnpag/"
                                     "source/latex/footnpag/"
                                     "tex/latex/footnpag/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qf12zr9qs54wpih691290l9jnf3cjdfpym6g8p0w06al8x797zs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/footnpag")
    (synopsis "Per-page numbering of footnotes")
    (description
     "This package allows footnotes on individual pages to be numbered from @samp{1},
rather than being numbered sequentially through the document.")
    (license license:gpl3+)))

(define-public texlive-forarray
  (package
    (name "texlive-forarray")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/forarray/"
                                     "source/latex/forarray/"
                                     "tex/latex/forarray/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xbl5lzyd264avy3dkqz7yq8imk6pziaalhi7smh9d4jra6412a3"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          ;; FIXME: I couldn't find how to build this package without error.
          (delete 'build))))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-breakurl
                  texlive-caption
                  texlive-examplep
                  texlive-hypdoc
                  texlive-ragged2e
                  texlive-subfig
                  texlive-varwidth
                  texlive-vntex
                  texlive-xkeyval))))
    (home-page "https://ctan.org/pkg/forarray")
    (synopsis "Using array structures in LaTeX")
    (description
     "The package provides functionality for processing lists and array structures
in LaTeX.  Arrays can contain characters as well as TeX and LaTeX commands,
nesting of arrays is possible, and arrays are processed within the same brace
level as their surrounding environment.  Array levels can be delimited by
characters or control sequences defined by the user.  Practical uses of this
package include data management, construction of lists and tables, and
calculations based on the contents of lists and arrays.")
    (license license:lppl)))

(define-public texlive-foreign
  (package
    (name "texlive-foreign")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/foreign/" "source/latex/foreign/"
                                     "tex/latex/foreign/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06mbm7j754w44acpvx2miaa3py5gvmjxjq9wh9nq3xv8b7v7a7n3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/foreign")
    (synopsis "Systematic treatment of foreign words in documents")
    (description
     "The package supports authors use of consistent typesetting of foreign words
in documents.")
    (license license:lppl1.3+)))

(define-public texlive-formlett
  (package
    (name "texlive-formlett")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/formlett/"
                                     "tex/generic/formlett/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nbg8g7hyxanyx2jkv7nz2iwz4x25wh9y8licz4zg8vcz99izn1k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/formlett")
    (synopsis "Letters to multiple recipients")
    (description
     "This package provides a package for multiple letters from the same basic
source; the package offers parametrisation of the letters actually sent.")
    (license license:gpl3+)))

(define-public texlive-forms16be
  (package
    (name "texlive-forms16be")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/forms16be/"
                                     "source/latex/forms16be/"
                                     "tex/latex/forms16be/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07lj38mwkj1g0gba8sk435474g417lp815byci691xskr84fy33x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/forms16be")
    (synopsis "Initialize form properties using big-endian encoding")
    (description
     "This package provides support for UTF-16BE Unicode character encoding (called
a big-endian character string) for the text string type (PDF Reference,
version 1.7, beginning on page 158).  Text strings are used in ``text
annotations, bookmark names, article threads, document information, and so
forth'' (to partially quote page 158).  The particular application is to set
property values of form fields, at least those properties that take the text
strings as its value.  The package contains support for Basic Latin plus the
ability to enter any Unicode character using the notation
@code{\\u@var{XXXX}}, where @var{XXXX} are four hex digits.")
    (license license:lppl1.2+)))

(define-public texlive-formular
  (package
    (name "texlive-formular")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/formular/"
                                     "source/latex/formular/"
                                     "tex/latex/formular/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vjqb9r9c9vwxwnn87zwpd2m94ygaqgvi8pzp37hc9kqxbpx1wkx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/formular")
    (synopsis "Create forms containing field for manual entry")
    (description
     "When typesetting forms there often arises the need for defining fields which
consist of one or more lines where the customer can write something down
manually.  This package offers some commands for defining such fields in
a distinctive way.")
    (license license:lppl)))

(define-public texlive-fragments
  (package
    (name "texlive-fragments")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fragments/"
                                     "tex/latex/fragments/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0p2s3nmq25ypvnbfmgr70cw0b3y7s2i40xig9ddjcd1f8q1i1nyq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fragments")
    (synopsis "Fragments of LaTeX code")
    (description
     "This package provides a collection of fragments of LaTeX code, suitable for
inclusion in packages, or (possibly) in users documents.  Included are:
@code{checklab}, for modifying the label checking code at
@code{\\end@{document@}}; @code{overrightarrow}, defining a doubled over-arrow
macro; @code{removefr}, for removing reset relations between counters; and
@code{subscript}, defining a @code{\\textsubscript} command.")
    ;; It contains a collection of packages, with different licenses.
    (license (list license:public-domain license:lppl))))

(define-public texlive-frame
  (package
    (name "texlive-frame")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/frame/" "tex/generic/frame/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02n15mi5amvrm6pnr3hkrw6rww2an437b6nff8j4gh6x7vhapygn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/frame")
    (synopsis "Framed boxes for Plain TeX")
    (description
     "This package provides a jiffy file (taken from @code{fancybox}) for placing
a frame around a box of text.  The macros also provide for typesetting an
empty box of given dimensions.")
    (license license:lppl)))

(define-public texlive-frege
  (package
    (name "texlive-frege")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/frege/" "tex/latex/frege/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "090qsdimmgkmq9xba1kjaxy941y1bkbxlirkx5sn117kfl3v98mq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/frege")
    (synopsis "Typeset fregean @emph{Begriffsschrift}")
    (description
     "The package defines a number of new commands for typesetting fregean
@emph{Begriffsschrift} in LaTeX.  It is loosely based on the package
@code{begriff}, and offers a number of improvements including better relative
lengths of the content stroke with respect to other strokes, content strokes
that point at the middle of lines rather than the bottom, a greater width for
the assertion stroke as compared to the content stroke, a more intuitive
structure for the conditional, greater care taken to allow for the line width
in the spacing of formulas.")
    (license license:gpl3+)))

(define-public texlive-froufrou
  (package
    (name "texlive-froufrou")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/froufrou/"
                                     "source/latex/froufrou/"
                                     "tex/latex/froufrou/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1d1ifplkdxb7s8mr7zisbzkr9r5hvn7hk0q5dpzpyx8zwhzyvkss"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/froufrou")
    (synopsis "Fancy section separators")
    (description
     "This package provides fancy separators, which are visual cues that indicate
a change of subject or context without actually starting a new chapter or
section.")
    (license license:lppl1.3c)))

(define-public texlive-ftcap
  (package
    (name "texlive-ftcap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ftcap/" "tex/latex/ftcap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0z5ydpf7gxpmfmkaxim5jg32drpaqqb0f58jsbdpiap666lhsb34"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ftcap")
    (synopsis
     "Allows @code{\\caption} at the beginning of a @code{table} environment")
    (description
     "For several reasons a @code{\\caption} may be desirable at the top of
a @code{table} environment.  This package changes the @code{table} environment
such that @code{\\abovecaptionskip} and @code{\\belowcaptionskip} are swapped.
The package should also work with a non-standard table environment.")
    (license license:gpl3+)))

(define-public texlive-ftnxtra
  (package
    (name "texlive-ftnxtra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ftnxtra/" "source/latex/ftnxtra/"
                                     "tex/latex/ftnxtra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fyf6gvyn91i3r8jsfcs6wka0ygkdvcll2lbpaigm355mzvm9xnl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ftnxtra")
    (synopsis "Extend the applicability of the @code{\\footnote} command")
    (description
     "The package treats footnotes in @code{\\caption}, the tabular environment,
and @code{\\chapter} and other @code{\\section}-like commands.")
    (license license:lppl)))

(define-public texlive-fullblck
  (package
    (name "texlive-fullblck")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fullblck/"
                                     "source/latex/fullblck/"
                                     "tex/latex/fullblck/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1prr2arwxx6bdzbl9pyhcw25d5jillq1jy6mnyag23rzp2izywrl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fullblck")
    (synopsis "Left-blocking for @code{letter} class")
    (description
     "This package can be used with the @code{letter} document class to set the
letter in a fullblock style (everything at the left margin).")
    (license license:lppl)))

(define-public texlive-fullminipage
  (package
    (name "texlive-fullminipage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fullminipage/"
                                     "source/latex/fullminipage/"
                                     "tex/latex/fullminipage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "040vavcp48fvif39ypnl5hxvalmbywkqy6vvxxwd1pnmmcl17ccf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fullminipage")
    (synopsis "Minipage spanning a complete page")
    (description
     "This package provides the environment @code{fullminipage}, which generates
a minipage spanning a new, complete page with page style empty.  The
environment provides options to set margins around the minipage and configure
the background.")
    (license license:gpl3)))

(define-public texlive-fullwidth
  (package
    (name "texlive-fullwidth")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fullwidth/"
                                     "tex/latex/fullwidth/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04wy2sxsbkyg62bhg5av9zg6q07snabwrxv776x3m1mlwi4fw7nh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fullwidth")
    (synopsis "Adjust margins of text block")
    (description
     "The package provides the environment @code{fullwidth}, which sets the left
and right margins in a simple way.  There is no constraint about page breaks;
if you are using the two-side mode, you can set the inner and outer margins to
avoid the effects of the different margins.")
    (license license:lppl)))

(define-public texlive-functional
  (package
    (name "texlive-functional")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/functional/"
                                     "tex/latex/functional/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11l58cw1pjx19kvqnh6vmglza913jc2vgbx6zk0zzs5j82kb8p38"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/functional")
    (synopsis "Intuitive functional programming interface for LaTeX2")
    (description
     "This package provides an intuitive functional programming interface for
LaTeX2, which is an alternative choice to @code{expl3} or LuaTeX, if you want
to do programming in LaTeX.  Although there are functions in LaTeX3
programming layer (@code{expl3}), the evaluation of them is from outside to
inside.  With this package, the evaluation of functions is from inside to
outside, which is the same as other programming languages such as Lua.  In
this way, it is rather easy to debug code too.")
    (license license:lppl1.3c)))

(define-public texlive-fundus-calligra
  (package
    (name "texlive-fundus-calligra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fundus-calligra/"
                                     "source/latex/fundus-calligra/"
                                     "tex/latex/fundus-calligra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1575ag7z1ydcpi8bpda5lhn4gil5vdcb442vn50acpdml9zdf1a7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fundus-calligra")
    (synopsis "Support for the Calligra font in LaTeX documents")
    (description
     "The package offers support for the Calligra handwriting font, in LaTeX
documents.  The package is part of the @code{fundus} bundle.")
    (license license:lppl1.3c+)))

(define-public texlive-fundus-cyr
  (package
    (name "texlive-fundus-cyr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/latex/fundus-cyr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02zz37h71nqq0f4sf00fiw80pq1q3yadnhqm2j3niz13gms9ydl2"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fundus-cyr")
    (synopsis "Support for Washington University Cyrillic fonts")
    (description
     "The package supports the use of the Washington Cyrillic fonts with LaTeX
(Note that standard LaTeX has support, too, as encoding OT2).  The package is
distributed as part of the @code{fundus} bundle.")
    (license license:lppl1.3+)))

(define-public texlive-fundus-sueterlin
  (package
    (name "texlive-fundus-sueterlin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fundus-sueterlin/"
                                     "source/latex/fundus-sueterlin/"
                                     "tex/latex/fundus-sueterlin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yk6djd3yiwsk20z86b3w9wkfbh7xb3i5r5az6br8aivqqp72fvp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fundus-sueterlin")
    (synopsis "Support for Sueterlin fonts")
    (description
     "The package supports use, in LaTeX, of the Metafont emulation of the
Sueterlin handwriting fonts.  The package is distributed as part of the
@code{fundus} bundle..")
    (license license:lppl1.3+)))

(define-public texlive-fwlw
  (package
    (name "texlive-fwlw")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/fwlw/" "tex/latex/fwlw/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10phasf69lcd9rs6yn997ng1z1g460wzgi3rda45rdjvc0mw336v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/fwlw")
    (synopsis "Get first and last words of a page")
    (description
     "The package extracts the first and last words of a page, together with the
first word of the next page, just before the page is formed into the object to
print.  The package defines a couple of page styles that use the words that
have been extracted.")
    ;; "This software package may be freely used, transmitted, reproduced, or
    ;; modified provided that this notice is left intact."
    (license (license:fsf-free "file://doc/latex/fwlw/README"))))

(define-public texlive-gatherenum
  (package
    (name "texlive-gatherenum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gatherenum/"
                                     "source/latex/gatherenum/"
                                     "tex/latex/gatherenum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1y379ikgz3phvz88h50w1l6ab4sgx3hcs0wz9q6f9g6zv5hbh7fn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gatherenum")
    (synopsis "Crossover of @code{align*} and @code{enumerate}")
    (description
     "This package (ab)uses the inline enumeration capabilities of @code{enumitem}
to add a displayed enumeration mode, triggered by adding @code{gathered} to
the key-value option list of the @code{enumerate} environment.  The end result
is similar to a regular @code{enumerate} environment wrapped in
a @code{multicols} environment, with the following advantages:

@itemize

@item it can pack items depending on their actual width rather than a fixed,
constant number per line;

@item it fills items in a line-major order (instead of column-major order).

@end itemize")
    (license license:gpl3+)))

(define-public texlive-gauss
  (package
    (name "texlive-gauss")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gauss/" "tex/latex/gauss/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y36dywlf2i13im8msqgwdg41p5pf8c5k7cch4z3cvl5kzgsfpm6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gauss")
    (synopsis "Package for Gaussian operations")
    (description
     "The @code{gauss} package provides configurable tools for producing row and
column operations on matrices (a.k.a.@: Gaussian operations).")
    (license license:lppl)))

(define-public texlive-gcard
  (package
    (name "texlive-gcard")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gcard/" "tex/latex/gcard/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ps2iiwzcgka7h75mvpw1g0c63qw6x440bl31dlgnzcwczhk64h3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gcard")
    (synopsis "Arrange text on a sheet to fold into a greeting card")
    (description
     "The package provides a simple means of producing greeting cards.
It arranges four panels onto a single sheet so that when the sheet is folded
twice the four panels are arranged as front cover, inside left and right
pages, and back cover.  The four panels are set in minipages for formatting by
the user.")
    (license license:lppl)))

(define-public texlive-gender
  (package
    (name "texlive-gender")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gender/" "source/latex/gender/"
                                     "tex/latex/gender/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16srrl535ynv2zn6kg6w4rkywznrznjn5zwyhpclv4dhd48p6z27"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gender")
    (synopsis "Gender neutrality for languages with grammatical gender")
    (description
     "Many languages --- like German or French --- use masculine and feminine
grammatical genders.  There are many ideas how to promote gender neutrality in
those languages.  The @code{gender} package uses alternately masculine and
feminine forms.  It is also possible to use just one form out of a template.")
    (license license:lppl1.3+)))

(define-public texlive-genmpage
  (package
    (name "texlive-genmpage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/genmpage/"
                                     "source/latex/genmpage/"
                                     "tex/latex/genmpage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mk55x85kn7v38l4pa5l8yv8axyfgn01vdxk51iahyzzmlw4fm6f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/genmpage")
    (synopsis "Generalization of LaTeX's minipages")
    (description
     "The GenMPage package generalizes LaTeX's minipages.  @code{Keyval} options
and styles can be used to determine their appearance in an easy and consistent
way.  It includes options for paragraph indentation and vertical alignment
with respect to the visual top and bottom margins.")
    (license license:lppl)))

(define-public texlive-gensymb
  (package
    (name "texlive-gensymb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gensymb/" "source/latex/gensymb/"
                                     "tex/latex/gensymb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1k4pkls5yp538s55mck65xm5l15mn6qjz89f0vd92iiljbd2b5z8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gensymb")
    (synopsis "Generic symbols for both text and math mode")
    (description
     "This package provides generic commands @code{\\degree}, @code{\\celsius},
@code{\\perthousand}, @code{\\micro} and @code{\\ohm}, which work both in text
and maths mode.  Various means are provided to fake the symbols or take them
from particular symbol fonts, if they are not available in the default fonts
used in the document.  This should be perfectly transparent at user level, so
that one can apply the same notation for units of measurement in text and math
mode and with arbitrary typefaces.

Note that the package has been designed to work in conjunction with
@file{units.sty}.")
    (license license:lppl1.3+)))

(define-public texlive-getfiledate
  (package
    (name "texlive-getfiledate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/getfiledate/"
                                     "tex/latex/getfiledate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m1fz3g2xxwballmka3qvc58wkgzbn9srvn3w4ij79pnffk89l6r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/getfiledate")
    (synopsis "Find the date of last modification of a file")
    (description
     "The package fetches from the system the date of last modification or opening
of an existing file, using the function @code{\\pdffilemoddate}; the user may
specify how the date is to be presented.")
    (license license:lppl)))

(define-public texlive-getitems
  (package
    (name "texlive-getitems")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/getitems/"
                                     "source/latex/getitems/"
                                     "tex/latex/getitems/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zwdb7hqfr0jzd2shz80wby2x8yqn74yw6im5qiiwgmmzrnvp48m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/getitems")
    (synopsis "Gathering items from a list-like environment")
    (description
     "This package provides a @code{\\gatheritems} command to parse a list of data
separated by @code{\\item} tokens.  This makes it easier to define custom
environments which structure their data in the same way that @code{itemize} or
@code{enumerate} do.")
    (license license:lppl1.3+)))

(define-public texlive-gindex
  (package
    (name "texlive-gindex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gindex/" "makeindex/gindex/"
                                     "tex/latex/gindex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15rk5wbh0xysri3zqd3l0a0z3hcj5fc7g6k3v3li093hfbrzm81q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gindex")
    (synopsis "Formatting indexes")
    (description
     "This package provides a way to generate the format of index entries from
within LaTeX.")
    (license license:expat)))

(define-public texlive-ginpenc
  (package
    (name "texlive-ginpenc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ginpenc/" "source/latex/ginpenc/"
                                     "tex/latex/ginpenc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15kqbgdngw19pnkl9vh94sbdq261lnbi522gxb5h4djsih9pp14p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ginpenc")
    (synopsis "Modification of @code{inputenc} for German")
    (description
     "If @code{inputenc} is used and German umlauts are input directly, they are
converted to the LICR representation such as @samp{\\\"a}.  This breaks the
sort algorithm of MakeIndex, for instance.  Ginpenc converts umlauts and the
sharp-s to the short forms defined by Babel, e.g., @samp{\"a} instead, if the
text is typeset in German.")
    (license license:lppl)))

(define-public texlive-gitfile-info
  (package
    (name "texlive-gitfile-info")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/gitfile-info/"
                                     "source/support/gitfile-info/"
                                     "tex/latex/gitfile-info/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05bfzaralkx3rvz63c2i29v49fp2ki5smwx5gya1lxzlhmv1krmv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gitfile-info")
    (synopsis "Get Git metadata for a specific file")
    (description
     "If you are using @command{git} to control versions of LaTeX files, you may
want to show yourself or other users or devs the current version of the file,
information about the author and last edited date.  All packages for Git known
make that kind of information available for the whole repository.  But
sometimes you have a lot of files within the same repository in different
versions, from different authors etc.  Perhaps you also split up a big project
in small files and want to show within the document who had edited what.  This
package gives you the opportunity to do so.")
    (license license:lppl1.3+)))

(define-public texlive-gitinfo
  (package
    (name "texlive-gitinfo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gitinfo/" "tex/latex/gitinfo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lchsz3800wzz9f4mxy60n2f5qnn78ia9z1hldhh59j5a18h2p1h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gitinfo")
    (synopsis
     "Access metadata from the Git distributed version control system")
    (description
     "The package makes it possible to incorporate git version control metadata
into documents.  For @code{memoir} users, the package provides the means to
tailor page headers and footers to use the metadata.

Note this version is now deprecated, but is kept on the archive, pro tem, for
continuity for existing users.  All new repositories should use
@code{gitinfo2}.")
    (license license:lppl1.3+)))

(define-public texlive-gitinfo2
  (package
    (name "texlive-gitinfo2")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gitinfo2/" "tex/latex/gitinfo2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bbzxb4p4nh7hyrh1888srbh3w9ncyj09jsq0q5yfscn6gbx8gx3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gitinfo2")
    (synopsis
     "Access metadata from the Git distributed version control system")
    (description
     "The package makes it possible to incorporate git version control metadata
into documents.  For @code{memoir} users, the package provides the means to
tailor page headers and footers to use the metadata.")
    (license license:lppl1.3+)))

(define-public texlive-gitlog
  (package
    (name "texlive-gitlog")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gitlog/" "tex/latex/gitlog/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fbr0jwiv9g9vifc55y17i36vmfgqlr27p17fg41mxcfcna4nxvs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gitlog")
    (synopsis "Typesetting @command{git} changelogs")
    (description
     "This package allows @command{git} change log history to be incorporated into
LaTeX documents; the log data is obtained from the Git distributed version
control system.")
    (license license:lppl1.3+)))

(define-public texlive-gitstatus
  (package
    (name "texlive-gitstatus")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gitstatus/"
                                     "source/latex/gitstatus/"
                                     "tex/latex/gitstatus/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01lcqm7r0a95bpfdvdv25dqxj9j0cnj1vihq54a9iqwd8hq196hb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gitstatus")
    (synopsis
     "Include Git information in the document as watermark or via variables")
    (description
     "If your LaTeX document is version-controlled with Git, you might encounter
situations, where you want to include some information of your Git repository
into your LaTeX document, e.g., to keep track on who gave you feedback on
which version of your document.  This Git information can be included on every
page by a watermark or (for custom needs) via provided variables.")
    (license license:lppl1.3+)))

(define-public texlive-gitver
  (package
    (name "texlive-gitver")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gitver/" "tex/latex/gitver/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z2amfxc59zdzhvqdqrxnjxr0qgymc384bnm6w0m00p2mhj5pbvy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gitver")
    (synopsis
     "Get the current Git hash of a project and typeset it in the document")
    (description
     "This package will get a description of the current Git version of the
document and store it in a command @code{\\gitVer}.  If @code{memoir} or
@code{fancyhdr} are in use, it will also add this to the document footers
unless the option @code{noheader} is passed.  The package also defines
a command @code{\\versionBox} which outputs a box containing the version and
date of compilation.")
    (license license:lppl1.3c)))

(define-public texlive-globalvals
  (package
    (name "texlive-globalvals")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/globalvals/"
                                     "tex/latex/globalvals/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wrkkxphwd7ka31ylr27b06854x221gadw2bijj1r18x2vl0n4xb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/globalvals")
    (synopsis "Declare global variables")
    (description
     "This package allows the user to declare a variable which can then be used
anywhere else in a document, including before it was declared.")
    (license license:lppl1.3c)))

(define-public texlive-gloss
  (package
    (name "texlive-gloss")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/gloss/" "bibtex/bst/gloss/"
                                     "doc/latex/gloss/" "tex/latex/gloss/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yma5l861lrl31v435mhmlbkvsp47bfyy8sg5wrf3s2bad89qix5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gloss")
    (synopsis "Create glossaries using BibTeX")
    (description
     "This package provides a glossary package using BibTeX with @code{\\cite}
replaced by @code{\\gloss}.")
    (license license:lppl)))

(define-public texlive-glossaries-danish
  (package
    (name "texlive-glossaries-danish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/glossaries-danish/"
                                     "source/latex/glossaries-danish/"
                                     "tex/latex/glossaries-danish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0z5b71k881qz0649hd9rr5n0cgm8yvckv7jxmk1kh0y6nd9i4k6l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/glossaries-danish")
    (synopsis "Danish language module for @code{glossaries} package")
    (description
     "This package provides a Danish language module for @code{glossaries}
package.")
    (license license:lppl1.3+)))

(define-public texlive-glossaries-dutch
  (package
    (name "texlive-glossaries-dutch")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/glossaries-dutch/"
                                     "source/latex/glossaries-dutch/"
                                     "tex/latex/glossaries-dutch/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q6szswbbz2lkiknmvv53mxwvl0nrxrmbz5pw8ppgf2d13xs6c9f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/glossaries-dutch")
    (synopsis "Dutch language module for @code{glossaries} package")
    (description
     "This package provides a Dutch language module for @code{glossaries} package.")
    (license license:lppl1.3+)))

(define-public texlive-glossaries-english
  (package
    (name "texlive-glossaries-english")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/glossaries-english/"
                                     "source/latex/glossaries-english/"
                                     "tex/latex/glossaries-english/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kj2h74ib9ngywmy2f7cq0w3qjjqlh29f285jpnd31awrcp8si5i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/glossaries-english")
    (synopsis "English language module for @code{glossaries} package")
    (description
     "This package provides a English language module for @code{glossaries}
package.")
    (license license:lppl1.3+)))

(define-public texlive-glossaries-estonian
  (package
    (name "texlive-glossaries-estonian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/glossaries-estonian/"
                                     "source/latex/glossaries-estonian/"
                                     "tex/latex/glossaries-estonian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dkgzcj9ba0l0lvyg1kq8byw9r1lc6l13m0c4hiqcr73srpj7ms9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/glossaries-estonian")
    (synopsis "Estonian language module for @code{glossaries} package")
    (description
     "This package provides the Estonian language module for the @code{glossaries}
package.")
    (license license:lppl1.3+)))

(define-public texlive-glossaries-extra
  (package
    (name "texlive-glossaries-extra")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/glossaries-extra/"
                                     "doc/latex/glossaries-extra/"
                                     "source/latex/glossaries-extra/"
                                     "tex/latex/glossaries-extra/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wngb88dqjjli6hfak9kinbw4bwqlw2342rfzznsnbypr2crpw44"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/glossaries-extra")
    (synopsis "Extension to the @code{glossaries} package")
    (description
     "This package provides improvements and extra features to the
@code{glossaries} package.")
    (license license:lppl1.3+)))

(define-public texlive-glossaries-finnish
  (package
    (name "texlive-glossaries-finnish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/glossaries-finnish/"
                                     "source/latex/glossaries-finnish/"
                                     "tex/latex/glossaries-finnish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mk4x897s1kw0hiiaxxji53b4fx60f0r3x0a5z3fg9fy2pnm4f91"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/glossaries-finnish")
    (synopsis "Finnish language module for @code{glossaries} package")
    (description
     "This package provides a Finnish language module for @code{glossaries}
package.")
    (license license:lppl1.3+)))

(define-public texlive-glossaries-french
  (package
    (name "texlive-glossaries-french")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/glossaries-french/"
                                     "source/latex/glossaries-french/"
                                     "tex/latex/glossaries-french/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1q20vf43fbjbx3jq4w3d6jvk1z0rigdnl85bc6gwis7hxpj63ji9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/glossaries-french")
    (synopsis "French language module for @code{glossaries} package")
    (description
     "This package provides a French language module for @code{glossaries}
package.")
    (license license:lppl1.3+)))

(define-public texlive-glossaries-german
  (package
    (name "texlive-glossaries-german")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/glossaries-german/"
                                     "source/latex/glossaries-german/"
                                     "tex/latex/glossaries-german/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yg9i4fdmxm67nrs5mpijx1vhvfiqzblhca94qylr5ylp8dwxhfc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/glossaries-german")
    (synopsis "German language module for @code{glossaries} package")
    (description
     "This package provides a German language module for the @code{glossaries}
package.")
    (license license:lppl1.3+)))

(define-public texlive-glossaries-irish
  (package
    (name "texlive-glossaries-irish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/glossaries-irish/"
                                     "source/latex/glossaries-irish/"
                                     "tex/latex/glossaries-irish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ks91d428h48kwqhqcflz4z1qx61fn85hi0sm8z35dwxg308h8jw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/glossaries-irish")
    (synopsis "Irish language module for @code{glossaries} package")
    (description
     "This package provides an Irish language module for @code{glossaries} package.")
    (license license:lppl1.3+)))

(define-public texlive-glossaries-italian
  (package
    (name "texlive-glossaries-italian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/glossaries-italian/"
                                     "source/latex/glossaries-italian/"
                                     "tex/latex/glossaries-italian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0z707spqm7i77f0p2vb576z7m2xbi84fk46sxp41if6hdq1ic30k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/glossaries-italian")
    (synopsis "Italian language module for @code{glossaries} package")
    (description
     "This package provides an Italian language module for @code{glossaries}
package.")
    (license license:lppl1.3+)))

(define-public texlive-glossaries-magyar
  (package
    (name "texlive-glossaries-magyar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/glossaries-magyar/"
                                     "source/latex/glossaries-magyar/"
                                     "tex/latex/glossaries-magyar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lha8h8bl2wqw22jy7nznzh908pg4vwk3s4lsd7cnbpiv46c2g1i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/glossaries-magyar")
    (synopsis "Magyar language module for @code{glossaries} package")
    (description
     "This package provides a Magyar language module for @code{glossaries}
package.")
    (license license:lppl1.3+)))

(define-public texlive-glossaries-nynorsk
  (package
    (name "texlive-glossaries-nynorsk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/glossaries-nynorsk/"
                                     "source/latex/glossaries-nynorsk/"
                                     "tex/latex/glossaries-nynorsk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17491x9pa8phvh6drp5yf6j5dcagx6qiymdhy6gs5j1jhczhpx21"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/glossaries-nynorsk")
    (synopsis "Nynorsk language module for the glossaries package")
    (description
     "Norwegian Nynorsk language module for the glossaries package.")
    (license license:lppl1.3+)))

(define-public texlive-glossaries-polish
  (package
    (name "texlive-glossaries-polish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/glossaries-polish/"
                                     "source/latex/glossaries-polish/"
                                     "tex/latex/glossaries-polish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11m958cr2db908hmlcbkfn0jvnc6c5sgvjzc4aca0cf41ds77xl7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/glossaries-polish")
    (synopsis "Polish language module for @code{glossaries} package")
    (description
     "This package provides a Polish language module for the @code{glossaries}
package.")
    (license license:lppl1.3+)))

(define-public texlive-glossaries-portuges
  (package
    (name "texlive-glossaries-portuges")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/glossaries-portuges/"
                                     "source/latex/glossaries-portuges/"
                                     "tex/latex/glossaries-portuges/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0r6a8g12dv99fgq6ky3w9z238q575i8z5nhciv6f8bwbjrw5q6sn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/glossaries-portuges")
    (synopsis "Portuges language module for @code{glossaries} package")
    (description
     "This package provides a Portuges language module for @code{glossaries}
package.")
    (license license:lppl1.3+)))

(define-public texlive-glossaries-serbian
  (package
    (name "texlive-glossaries-serbian")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/glossaries-serbian/"
                                     "source/latex/glossaries-serbian/"
                                     "tex/latex/glossaries-serbian/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fa85pwxpk5yggic7dwfagprj0daklpznipli07hynxhwcp0nwna"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/glossaries-serbian")
    (synopsis "Serbian language module for @code{glossaries} package")
    (description
     "This package provides a Serbian language module for @code{glossaries}
package.")
    (license license:lppl1.3+)))

(define-public texlive-glossaries-slovene
  (package
    (name "texlive-glossaries-slovene")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/glossaries-slovene/"
                                     "source/latex/glossaries-slovene/"
                                     "tex/latex/glossaries-slovene/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16lp6vgkdz49kjc2axzzpa43iv20xlnm1fg1jafyx8d600ys4szw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/glossaries-slovene")
    (synopsis "Slovene language module for @code{glossaries} package")
    (description
     "This package provides a Slovene language module for @code{glossaries}
package.")
    (license license:lppl1.3+)))

(define-public texlive-glossaries-spanish
  (package
    (name "texlive-glossaries-spanish")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/glossaries-spanish/"
                                     "source/latex/glossaries-spanish/"
                                     "tex/latex/glossaries-spanish/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wdlm1h7si2fsrfi56pf9kv5wxa6yv1w47vafm0qlhkwbz4z5f7l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/glossaries-spanish")
    (synopsis "Spanish language module for @code{glossaries} package")
    (description
     "This package provides a Spanish language module for @code{glossaries}
package.")
    (license license:lppl1.3+)))

(define-public texlive-gmdoc
  (package
    (name "texlive-gmdoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gmdoc/" "makeindex/gmdoc/"
                                     "tex/latex/gmdoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09rjn4jn217l0y84jvp8j66nkw1f0bhd7by6m9v5f5v2m7vv9wz5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gmdoc")
    (synopsis "Documentation of LaTeX packages")
    (description
     "This package provides a LaTeX package and an example class for
documenting (La)TeX packages, document classes, @file{.dtx} etc., providing
hyperlinks.  The package is believed to be compatible with @code{doc} and
permits minimal markup of code.  The package provides automatic detection of
definitions (detecting such things as @code{\\def}, @code{\\newcommand},
@code{\\DeclareOption} etc.).")
    (license license:lppl)))

(define-public texlive-gmdoc-enhance
  (package
    (name "texlive-gmdoc-enhance")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gmdoc-enhance/"
                                     "source/latex/gmdoc-enhance/"
                                     "tex/latex/gmdoc-enhance/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yw7nzadhq6175z69fss9y7ivjjinhffd197lpivdryxyc27kpwm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gmdoc-enhance")
    (synopsis "Some enhancements to the @code{gmdoc} package")
    (description
     "This package provides some enhancements for the @code{gmdoc} package: nicer
formatting for multiple line inline comments, an ability to comment out some
code, and a macro to input other files in ``normal'' LaTeX mode.")
    (license license:lppl)))

(define-public texlive-gmiflink
  (package
    (name "texlive-gmiflink")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gmiflink/" "tex/latex/gmiflink/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c84gnb946z45gn7vswp1fyjxzs1fm15g2w64qi7g257y7ycxi5q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gmiflink")
    (synopsis "Simplify usage of @code{\\hypertarget} and @code{\\hyperlink}")
    (description
     "This package provides three @code{hyperref}-based macros that simplify usage
of @code{\\hypertarget} and @code{\\hyperlink}, calling them with one argument
instead of the same one twice.  Also @code{\\gmiflink} and @code{\\gmifref}
typeset plain text instead of generating an error or printing @samp{??}  if
there is no respective hypertarget or label.")
    (license license:lppl)))

(define-public texlive-gmutils
  (package
    (name "texlive-gmutils")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gmutils/" "tex/latex/gmutils/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qaxxhf75rm9jz8bpw1nwfay8vik6i366pqi2yksnplbsnnb46m5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gmutils")
    (synopsis "Support macros for other packages")
    (description
     "This package provides miscellaneous macros used by others of the author's
packages.  The package includes: @code{\\newgif} and other globals;
@code{\\@@ifnextcat} and @code{\\@@ifXeTeX}; @code{\\(Re)storeMacro(s)} to
override redefinitions; @code{\\afterfi} and friends; commands from
@code{relsize}, etc.; ``almost an environment'' or redefinition of
@code{\\begin} (@code{\\begin*} doesn't check if the @code{argument}
environment is defined).")
    (license license:lppl)))

(define-public texlive-gmverb
  (package
    (name "texlive-gmverb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gmverb/" "tex/latex/gmverb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00paaf5s919bfr3g3znv9baa0lswm5aaxdzmp1fl2kr4rcgk8d3v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gmverb")
    (synopsis
     "Variant of LaTeX @code{\\verb}, @code{verbatim} and @code{shortvrb}")
    (description
     "This package provides a redefinition of @code{\\verb} and @code{verbatim} so
that long lines are breakable before @samp{\\} and after @samp{@{} with
@samp{%} as hyphen.  It allows you to define your own @code{verbatim}-like
environments (subject to a size limit) and allows you to declare any single
character as a shorthand as in the @code{\\MakeShortVerb} command of the
@code{shortvrb} package.")
    (license license:lppl)))

(define-public texlive-grabbox
  (package
    (name "texlive-grabbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/grabbox/" "source/latex/grabbox/"
                                     "tex/latex/grabbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c1p9980nvxs182cyy56q11vcb0czrs2sa4bc0jgqvs4a25lpicj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/grabbox")
    (synopsis "Read an argument into a box and execute the code afterwards")
    (description
     "The package provides the command @code{\\grabbox}, which grabs an argument
into a box and executes the code afterwards.")
    (license license:lppl1.3c)))

(define-public texlive-gradient-text
  (package
    (name "texlive-gradient-text")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gradient-text/"
                                     "tex/latex/gradient-text/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00gnv7gbs583mwviajlfpr0m748s1ysc9h7aig8bwhn8v1rrjxqw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gradient-text")
    (synopsis "Decorate text with linear gradient colors")
    (description
     "This package enables writers to conveniently decorate text with linear
gradient colors.  The RGB values of the first and the last character are
specified as parameters while the rest of the text is colored automatically.")
    (license license:lppl1.3c)))

(define-public texlive-grading-scheme
  (package
    (name "texlive-grading-scheme")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/grading-scheme/"
                                     "source/latex/grading-scheme/"
                                     "tex/latex/grading-scheme/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1drxrhkqwg5pz1macxqs11jx06w0myiynqkamrvfzpww0jfij36i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/grading-scheme")
    (synopsis "Typeset grading schemes in tabular format")
    (description
     "This package aims at an easy-to-use interface to typeset grading schemes in
tabular format, in particular grading-schemes of exercises of mathematical
olympiads where multiple solutions have to be graded and might offer mutual
exclusive ways of receiving points.")
    (license license:lppl1.3c)))

(define-public texlive-graphbox
  (package
    (name "texlive-graphbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/graphbox/"
                                     "source/latex/graphbox/"
                                     "tex/latex/graphbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0s5zgfc6c0sanqsc2ww4fr5iphs9zg6388dr5l0x00bwks1579l6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/graphbox")
    (synopsis "Extend graphicx to improve placement of graphics")
    (description
     "Graphbox is an extension of the standard @code{graphicx} LaTeX2e package to
allow the placement of graphics relative to the ``current position'' using
additional optional arguments of @code{\\includegraphics}.  For example,
changing the vertical alignment is convenient for using graphics as elements
of (mathematical) formulae.  Options for shifting, smashing and hiding the
graphics may be useful in support, for example, of the Beamer framework.")
    (license license:lppl1.3+)))

(define-public texlive-graphicscache
  (package
    (name "texlive-graphicscache")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/graphicscache/"
                                     "source/latex/graphicscache/"
                                     "tex/latex/graphicscache/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wi1ls3x934f6nifa25rcxl2jicihvgfh3sn5mjiwb15pxv2hmpd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/graphicscache")
    (synopsis "Cache @code{\\includegraphics} calls")
    (description
     "This LaTeX package provides caching of @code{\\includegraphics} calls,
therefore recompilations are much faster.  Also, images can be post-processed
with Ghostscript before inclusion, with the following consequences:

@itemize

@item automatic downscaling to specified DPI;

@item automatic JPEG compression with configurable quality;

@item much smaller files.

@end itemize

@code{graphicscache} supports pdfLaTeX and LuaLaTeX; XeLaTeX is not
supported.")
    (license license:bsd-3)))

(define-public texlive-graphicx-psmin
  (package
    (name "texlive-graphicx-psmin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/graphicx-psmin/"
                                     "source/latex/graphicx-psmin/"
                                     "tex/latex/graphicx-psmin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vppjv24cwnizg96pyhj68g2wx8dd4193c6bm2k4visqwpnwh95p"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-etoolbox
                  texlive-footmisc
                  texlive-fourier
                  texlive-hypdoc
                  texlive-listings
                  texlive-pgf
                  texlive-pst-text
                  texlive-pstricks
                  texlive-xcolor
                  texlive-xkeyval))))
    (home-page "https://ctan.org/pkg/graphicx-psmin")
    (synopsis "Reduce size of PostScript files by not repeating images")
    (description
     "The package is an extension of the standard @code{graphics} bundle and
provides a way to include repeated PostScript graphics (PS, EPS) only once in
a PostScript document.  This leads to smaller PostScript documents when
having, for instance, a logo on every page.  The package only works when
post-processed with Dvips.")
    (license license:lppl)))

(define-public texlive-graphicxbox
  (package
    (name "texlive-graphicxbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/graphicxbox/"
                                     "source/latex/graphicxbox/"
                                     "tex/latex/graphicxbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qamnhnr06qa24g7vlrhzr92p00zz82in4jk64al0dahv18rpnkc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/graphicxbox")
    (synopsis "Insert a graphical image as a background")
    (description
     "The package defines two new commands @code{\\graphicxbox} and
@code{\\fgraphicxbox}, which are companions to @code{\\colorbox} and
@code{\\fcolorbox} of the standard LaTeX @code{color} package.  The
@code{\\graphicxbox} command inserts a graphical image as a background rather
than a background color, while @code{\\fgraphicxbox} does the same thing, but
also draws a colored frame around the box.")
    (license license:lppl)))

(define-public texlive-graphpaper
  (package
    (name "texlive-graphpaper")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/graphpaper/"
                                     "source/latex/graphpaper/"
                                     "tex/latex/graphpaper/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vi9fhgczi9g0i8wvvd8q4kh558nlnww5y6bvihsajs65p44h638"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/graphpaper")
    (synopsis "LaTeX class to generate several types of graph papers")
    (description
     "Graphpaper is a LaTeX document class which allows printing several types of
graph papers: bilinear (millimeter paper), semilogarithmic, bilogarithmic,
polar, log-polar, Smith charts.  It is based on the @code{picture} environment
and its extensions.")
    (license license:lppl1.3c)))

(define-public texlive-grayhints
  (package
    (name "texlive-grayhints")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/grayhints/"
                                     "source/latex/grayhints/"
                                     "tex/latex/grayhints/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vgdqapcy0iahm7yh5cwlzmq9pq6ra763lgc9rc7sw5s25j1wzvx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/grayhints")
    (synopsis "Produce gray hints to a variable text field")
    (description
     "The package provides JavaScript code snippets to create gray hints.
Gray hints, as the author terms them, are text that appears initially in
a text field that gives a short hint as to what the contents of the text field
should be.  For example, a text field might contain the hint @samp{First
Name}, or a date field might read @samp{yyyy/mm/dd}.  As soon as the field
comes into focus, the hint disappears.  It reappears when the field is blurred
and the user did not enter any text into the field.  The package works for
Dvips/Distiller, pdfLaTeX, LuaLaTeX, and XeLaTeX.")
    (license license:lppl1.2+)))

(define-public texlive-grfpaste
  (package
    (name "texlive-grfpaste")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/grfpaste/" "tex/latex/grfpaste/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fkf8vxaznqmdqjwdixxs56cwi4pdrzqb7rcn09kaq6dhj3a79kl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/grfpaste")
    (synopsis "Include fragments of a DVI file")
    (description
     "This package provides a mechanism to include fragments of DVI files with the
@code{graphicx} package, so that you can use @code{\\includegraphics} to
include DVI files.  The package requires the @command{dvipaste} program.")
    (license license:lppl)))

(define-public texlive-grid
  (package
    (name "texlive-grid")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/grid/" "source/latex/grid/"
                                     "tex/latex/grid/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gli4izscbk4mvgsr4v9vvf8pbsd56sqa261944jy1smiyni7nwc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/grid")
    (synopsis "Grid typesetting in LaTeX")
    (description
     "The package helps to enables grid typesetting in double column documents.
Grid typesetting (vertical aligning of lines of text in adjacent columns) is
a difficult task in LaTeX, and the present package is no more than an attempt
to help users to achieve it in a limited way.")
    (license license:lppl)))

(define-public texlive-grid-system
  (package
    (name "texlive-grid-system")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/grid-system/"
                                     "tex/latex/grid-system/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07sald7i8i5vl1ibw3an3kxxk4rhjnnrgi6c571x9xjwz5qvqbnw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/grid-system")
    (synopsis "Page organisation, modelled on CSS facilities")
    (description
     "The package provides the means for LaTeX to implement a grid system as known
from CSS grid systems.  The facility is useful for creating box layouts as
used in brochures.")
    (license license:asl2.0)))

(define-public texlive-gridpapers
  (package
    (name "texlive-gridpapers")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gridpapers/"
                                     "source/latex/gridpapers/"
                                     "tex/latex/gridpapers/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0csc8dzgvc36p1c5gcfg0k6s5812vq4vpzjm3ybaph9y8cy0vd64"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gridpapers")
    (synopsis "Graph paper backgrounds and color schemes")
    (description
     "This package provides many preset yet customizable graph paper backgrounds.
Some of the preset patterns include standard quadrille or graph pattern, dot
grid, hexagons, isometric or triangular grid, squares with 45deg ``light
cone'' lines, ruled, and more.  Pattern sizes can be controlled via package
options.  There are several preset color palletes, and colors can be
overridden.")
    (license license:lppl1.3+)))

(define-public texlive-gridset
  (package
    (name "texlive-gridset")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gridset/" "source/latex/gridset/"
                                     "tex/latex/gridset/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0r1hkkgr0f4r2j1h68ljnlza1zag4jm3jzkb5zk6ga393xcn056c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gridset")
    (synopsis "Grid, a.k.a.@: in-register, setting")
    (description
     "Grid setting --- also known as strict in-register setting --- is something,
that should be done for a lot of documents but is not easy using LaTeX.  The
package helps to get the information needed for grid setting.  It does not
implement auto grid setting, but there is a command @code{\\vskipnextgrid},
that moves to the next grid position.  This may be enough under some
circumstances, but in other circumstances it may fail.  Thus gridset is only
one more step for grid setting, not a complete solution.")
    (license license:lppl1.3c)))

(define-public texlive-gridslides
  (package
    (name "texlive-gridslides")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gridslides/"
                                     "tex/latex/gridslides/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bnv9sgl7gxa8j92b04x30v3wkwgfg7nz9f8jkr1qk7rk215igmn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gridslides")
    (synopsis "Free form slides with blocks placed on a grid")
    (description
     "This package allows creating free form slides with blocks placed on a grid.
The blocks can be filled with text, equations, figures etc.  The resulting
slides are similar to the ones produced with LaTeX beamer, but more flexible.
Sequential unconvering of elements is supported.  A compiler script is
provided which compiles each slide separately, this way avoiding long compile
times.")
    (license (list license:lppl1.3+ license:gpl2))))

(define-public texlive-gs1
  (package
    (name "texlive-gs1")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/gs1/" "source/latex/gs1/"
                                     "tex/latex/gs1/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0r8lqj5gd349b1blgqq6c5v9mm7s9h6jb131fij1mmm7vrnr1vrc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/gs1")
    (synopsis "Typeset EAN barcodes using TeX rules, only")
    (description
     "The (LaTeX3) package typesets EAN-8 and EAN-13 barcodes, using the facilities
of the @code{rule-D} package.")
    (license license:lppl1.3c)))

(define-public texlive-xcomment
  (package
    (name "texlive-xcomment")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/xcomment/"
                                     "tex/generic/xcomment/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fkk619drqvadm7ixdbn2hrfnjddqylwpnqv383g0b4jjnl5x7p4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xcomment")
    (synopsis "Allows selected environments to be included/excluded")
    (description
     "The package defines an environment that only typesets specified environments
within its scope.  So, for example, if you want nothing but the @code{figure}
and @code{table} environments in your document, you can enclose the whole
document with an @code{xcomment} environment that excludes everything but
those.  This is a lot easier than excluding the chunks of text between the
environments you want, or creating an entire document containing only those
environments.")
    (license license:lppl)))

(define-public texlive-ha-prosper
  (package
    (name "texlive-ha-prosper")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ha-prosper/"
                                     "source/latex/ha-prosper/"
                                     "tex/latex/ha-prosper/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xszyc03vf7h160gxqfd8yfs4aya7s17av4ylf9nc6abbvwipapk"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-eepic
                  texlive-etoolbox
                  texlive-hypdoc
                  texlive-pgf
                  texlive-pst-3d
                  texlive-pst-node
                  texlive-pstricks
                  texlive-xcolor
                  texlive-xcomment
                  texlive-xkeyval))))
    (home-page "https://ctan.org/pkg/ha-prosper")
    (synopsis "Patches and improvements for Prosper")
    (description
     "HA-prosper is a patch for Prosper that adds new functionality to Prosper
based presentations.  Among the new features you will find automatic
generation of a table of contents on each slide, support for notes and
portrait slides.  The available styles demonstrate how to expand the
functionality of Prosper even further.")
    (license license:lppl)))

(define-public texlive-hackthefootline
  (package
    (name "texlive-hackthefootline")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hackthefootline/"
                                     "tex/latex/hackthefootline/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0896maf9g2hmahfgp06aw3ibfy4az4bkvdypdp55padzy6qng9rn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hackthefootline")
    (synopsis
     "Footline selection and configuration for LaTeX Beamer's standard themes")
    (description
     "This package is taking over, defining and redefining different footlines.
Configuration is provided via using key-value syntax.")
    (license license:lppl1.3c)))

(define-public texlive-handin
  (package
    (name "texlive-handin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/handin/" "tex/latex/handin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xxh7419yv2rfzpl9z28dxpb1jvfxdyap1zc3i32y1fl1c7n2naq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/handin")
    (synopsis
     "Light weight template for creating school submissions using LaTeX")
    (description
     "This package is for students creating school submissions using LaTeX.  It is
especially suitable for math, physics, statistics and the like.  It can easily
be used for creating exercises, too.")
    (license license:lppl1.3c)))

(define-public texlive-handout
  (package
    (name "texlive-handout")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/handout/" "tex/latex/handout/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08jmgzfrb17b6kv4d6na7i0a9amapgf5bhs29b8ajh46rdijckym"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/handout")
    (synopsis "Create handout for auditors of a talk")
    (description
     "In some fields of scholarship, a beamer does not offer good support when
giving a talk in a proceeding.  For example, in classical philology, the main
sources are text, and it will be better to distribute a handout to the
audience with extracts of the texts about which we will talk.  The package
supports preparation of such handouts when writing the talk.")
    (license license:lppl1.3+)))

(define-public texlive-handoutwithnotes
  (package
    (name "texlive-handoutwithnotes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/handoutwithnotes/"
                                     "source/latex/handoutwithnotes/"
                                     "tex/latex/handoutwithnotes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qb1av9f95wlnpmc33j497mvpzqy3w62mrvqnj4qnyhfdsas3ik2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/handoutwithnotes")
    (synopsis "Create handouts with notes from your LaTeX Beamer presentation")
    (description
     "This package provides @code{pgfpages} layouts to place notes next to the
scaled slides.")
    (license license:lppl1.3c)))

(define-public texlive-hang
  (package
    (name "texlive-hang")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hang/" "tex/latex/hang/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19b7sff10b1w2acnrp3kgg6wpspw29qqphrdxj805s88wmf3vv57"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hang")
    (synopsis "Environments for hanging paragraphs and list items")
    (description
     "This package provides environments for hanging paragraphs and list items.  In
addition, it defines environments for labeled paragraphs and list items.")
    (license license:lppl1.3+)))

(define-public texlive-harnon-cv
  (package
    (name "texlive-harnon-cv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/harnon-cv/"
                                     "tex/latex/harnon-cv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "142f1rzj4nfplpag7rcphyd7wlvmav01n516z458gdiby9vxm390"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/harnon-cv")
    (synopsis "CV document class with a vertical timeline for experience")
    (description
     "The class offers another modern, neat, design, and provides a simple means of
adding an experience timeline'.")
    (license license:public-domain)))

(define-public texlive-harpoon
  (package
    (name "texlive-harpoon")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/harpoon/" "tex/latex/harpoon/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "163457fhnpc11r2r3lvf4zfcqdvjrahwgjfxl3xa7zhhdx9ai4v7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/harpoon")
    (synopsis "Extra harpoons, using the @code{graphics} package")
    (description
     "This package provides over- and under-harpoon symbol commands; the harpoons
may point in either direction, with the hook pointing up or down.  The covered
object is provided as an argument to the commands, so that they have the look
of accent commands.")
    (license license:public-domain)))

(define-public texlive-hc
  (package
    (name "texlive-hc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/hc/" "doc/latex/hc/"
                                     "source/latex/hc/" "tex/latex/hc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14f794rn7qzrb4g5l4k3chp7r66dg7nyn25byis8hjca0rbd0gcs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hc")
    (synopsis "Replacement for the LaTeX classes")
    (description
     "This package provides a set of replacements for the default LaTeX classes,
based upon the Koma-Script bundle and the @code{seminar} class.  It includes
@code{hcart}, @code{hcreport}, @code{hcletter}, and @code{hcslides}.")
    (license license:gpl2+)))

(define-public texlive-he-she
  (package
    (name "texlive-he-she")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/he-she/" "tex/latex/he-she/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13vkrg4a4czq2l1ngn1y4sc6pa1dljzr4qzh8kgsbdnf48s38nrm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/he-she")
    (synopsis "Alternating pronouns to aid gender-neutral writing")
    (description
     "The package implements a version of semi-automatic pronoun switching for
writing gender-neutral (and possibly annoying) prose.  It has upper- and
lowercase versions of switching pronouns for all case forms, plus anaphoric
versions that reflect the current gender choice.")
    (license license:lppl1.3+)))

(define-public texlive-hep-acronym
  (package
    (name "texlive-hep-acronym")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hep-acronym/"
                                     "source/latex/hep-acronym/"
                                     "tex/latex/hep-acronym/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hf1ldbbqn6a096fc2wdfl6jn1bihw0nb278309px3lzrhkzcri7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hep-acronym")
    (synopsis "@code{acronym} extension for glossaries")
    (description
     "The hep-acronym package provides an @code{\\acronym} macro based on the
@code{glossaries} package.")
    (license license:lppl1.3c)))

(define-public texlive-hep-float
  (package
    (name "texlive-hep-float")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hep-float/"
                                     "source/latex/hep-float/"
                                     "tex/latex/hep-float/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16b6cwjinm4abk8vak9q87axx92l2hcqrk4k95wjdybx6si9mg52"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hep-float")
    (synopsis "Convenience package for float placement")
    (description
     "The @code{hep-float} package redefines some LaTeX float placement defaults
and defines convenience wrappers for floats.")
    (license license:lppl1.3c)))

(define-public texlive-hep-math
  (package
    (name "texlive-hep-math")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hep-math/"
                                     "source/latex/hep-math/"
                                     "tex/latex/hep-math/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08idp6pc1gqsrbwqlmgxc5k4sljasbrnj5jz48b5hh0xka567ifs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hep-math")
    (synopsis "Extended math macros")
    (description
     "The @code{hep-math} package provides some additional features beyond the
@code{mathtools} and @code{amsmath} packages.")
    (license license:lppl1.3c)))

(define-public texlive-hep-text
  (package
    (name "texlive-hep-text")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hep-text/"
                                     "source/latex/hep-text/"
                                     "tex/latex/hep-text/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qwwgh6bdvglnk5kxz4jsknx5gwdmqpnmlwxz6nk9ks6pvb72yxh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hep-text")
    (synopsis "List and text extensions")
    (description
     "The @code{hep-text} package extends LaTeX lists using the @code{enumitem}
package and provides some text macros.")
    (license license:lppl1.3c)))

(define-public texlive-hep-title
  (package
    (name "texlive-hep-title")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hep-title/"
                                     "source/latex/hep-title/"
                                     "tex/latex/hep-title/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0s634x8f233qnc1ib8kl2n0srnlj96vgfkbsx0i08nwaa9xzl6sw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hep-title")
    (synopsis "Extensions for the title page")
    (description
     "The hep-title package extends the title macros of the standard classes with
macros for a preprint, affiliation, editors, and endorsers.")
    (license license:lppl1.3c)))

(define-public texlive-hereapplies
  (package
    (name "texlive-hereapplies")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hereapplies/"
                                     "tex/latex/hereapplies/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gw9lqvkqpplzvr5m93y4qngyf51hcpaq8b7a154nsym39kdn8c3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hereapplies")
    (synopsis "Reference groups of pages that share something in common")
    (description
     "Here Applies is a LaTeX package that allows collecting groups of labels and
reference them altogether.  It can be used for creating informal glossaries
that cross-link concepts to their applications, or simply mentioning multiple
pages that share something in common.")
    (license license:gpl3+)))

(define-public texlive-hhtensor
  (package
    (name "texlive-hhtensor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hhtensor/"
                                     "source/latex/hhtensor/"
                                     "tex/latex/hhtensor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ghqfyhq5467jc506j0wa0nlxxrlm28mx1wp963rgqkynzlflv4j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hhtensor")
    (synopsis "Print vectors, matrices, and tensors")
    (description
     "This package provides commands for vectors, matrices, and tensors with
different styles --- arrows (as the LaTeX default), underlined, and bold.")
    (license license:lppl)))

(define-public texlive-hideanswer
  (package
    (name "texlive-hideanswer")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hideanswer/"
                                     "tex/latex/hideanswer/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1difjhxs4nssis3gjgq809h26zppk0cda40mnm8ry9fc0ij362if"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hideanswer")
    (synopsis
     "Generate documents with and without answers by toggling a switch")
    (description
     "This package can generate documents with and without answers from a single
file by toggling a switch.  However, it can only be used to create documents
to be printed on paper.")
    (license license:expat)))

(define-public texlive-highlightlatex
  (package
    (name "texlive-highlightlatex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/highlightlatex/"
                                     "tex/latex/highlightlatex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "078gfncpx7nxwz2xxhdb1a294bwmf3rh9rcqp664c5aj2q7ynvz0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/highlightlatex")
    (synopsis "Syntax highlighting for LaTeX")
    (description
     "This package provides extensive colored syntax highlighting for LaTeX.
For this purpose it builds on the generic @code{listings} package.")
    (license license:expat)))

(define-public texlive-histogr
  (package
    (name "texlive-histogr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/histogr/" "source/latex/histogr/"
                                     "tex/latex/histogr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1flg3r64zlwxhkxr4np7p5nzsfshyy4bzxspqpkzz08lvj8q7imz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/histogr")
    (synopsis "Draw histograms with the LaTeX @code{picture} environment")
    (description
     "This is a collection of macros to draw histogram bars inside a LaTeX
@code{picture} environment.")
    (license license:lppl1.3+)))

(define-public texlive-hitec
  (package
    (name "texlive-hitec")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hitec/" "tex/latex/hitec/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16c5jk7950nl1b6qa67as8iscm9nk8nlcq6v4c7ib8zm9qf68z29"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hitec")
    (synopsis "Class for documentation")
    (description
     "This package provides an article-based class designed for use for
documentation in high-technology companies.")
    (license license:lppl)))

(define-public texlive-hitreport
  (package
    (name "texlive-hitreport")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hitreport/"
                                     "source/latex/hitreport/"
                                     "tex/latex/hitreport/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sn4xa1y4i71qxw42w6q2l9z3039k2n57b05sfawmy656yjcvqpz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hitreport")
    (synopsis "Harbin Institute of Technology Report LaTeX template")
    (description
     "This package provides an assignment and experiment report template free of
configuration designed for undergraduates on the three campuses of Harbin
Institute of Technology.")
    (license license:lppl1.3c)))

(define-public texlive-hletter
  (package
    (name "texlive-hletter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hletter/" "tex/latex/hletter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dlin6p96w01bwc8jdbajjj1rhrsq27fnjmap1ry4sa7y62gaqxm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hletter")
    (synopsis "Flexible letter typesetting with flexible page headings")
    (description
     "The package permits the user to specify easily, with the aid of self defined
key-words, letters (with a logo and private) and headings.  The heading may
include a footer and the letter provides commands to include a scanned
signature and two signees.")
    (license license:lppl1.2+)))

(define-public texlive-hobsub
  (package
    (name "texlive-hobsub")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hobsub/" "tex/latex/hobsub/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cc5m4kqlx3m0qyjgxrbhgib2qza7a25vrp9rb8b8mpc5n5ycpn8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hobsub")
    (synopsis "Construct package bundles")
    (description
     "Heiko Oberdiek's @code{hobsub} package (and @code{hobsub-hyperref} and
@code{hobsub-generic} packages) defined a mechanism for concatenating multiple
files into a single file for faster loading.  The disadvantage is that it
introduces hard dependencies between the source files that are included and
complicates distribution and updates.  It was principally used with
@code{hyperref} but is not currently used in any standard packages in TeX
Live.  The packages are still distributed as simple stubs that reference the
included packages via @code{\\RequirePackage} rather than copying their
source.")
    (license license:lppl1.3c)))

(define-public texlive-hpsdiss
  (package
    (name "texlive-hpsdiss")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hpsdiss/" "source/latex/hpsdiss/"
                                     "tex/latex/hpsdiss/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15md2rk5bimgy7fjsiq9jvgg18i4ajnrljpzyvy0cc7rfla1myks"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hpsdiss")
    (synopsis "Dissertation class")
    (description
     "The class was developed to typeset a dissertation at ETH Zurich.  The
requirements were to use A5 paper and 10pt type.")
    (license license:gpl3+)))

(define-public texlive-href-ul
  (package
    (name "texlive-href-ul")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/href-ul/" "source/latex/href-ul/"
                                     "tex/latex/href-ul/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01sav2158ipgkkfadmc3j3sbfly4hliizvpj3flb5m644zhcx1y3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-hyperref texlive-ulem))
    (home-page "https://ctan.org/pkg/href-ul")
    (synopsis "Underscored LaTeX hyperlinks")
    (description
     "This LaTeX package makes hyperlinks underscored, just like on the web.")
    (license license:expat)))

(define-public texlive-hrefhide
  (package
    (name "texlive-hrefhide")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hrefhide/"
                                     "source/latex/hrefhide/"
                                     "tex/latex/hrefhide/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1smbklq7cyjzvd2kryv97kwvyh2alpd6gn2j6pbj6v9bcsyc3lmx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hrefhide")
    (synopsis "Suppress hyper links when printing")
    (description
     "This package provides the command @code{\\hrefdisplayonly} (additionally to
@code{\\href} provided by the @code{hyperref} package).  While
the (hyperlinked) text appears like an ordinary @code{\\href} in the compiled
PDF file, the same text will be hidden when printing the text.  Hiding is
actually achieved by making the text the same colour as the background, thus
preserving the layout of the rest of the text.

Further, the commands @code{\\hycon} and @code{\\hycoff} can be used to
simulate switching option @code{ocgcolorlinks} of the @code{hyperref} package
on and off.  This package is possibly obsolete.")
    (license license:lppl1.3+)))

(define-public texlive-huawei
  (package
    (name "texlive-huawei")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/huawei/" "source/latex/huawei/"
                                     "tex/latex/huawei/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05g75hs6j0fw95a12mjvzfdam7xs7n00d8cbm6rz7s2ln3nhf52r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-anyfontsize
           texlive-biblatex
           texlive-caption
           texlive-catchfile
           texlive-changepage
           texlive-currfile
           texlive-datetime
           texlive-enumitem
           texlive-environ
           texlive-fancyhdr
           texlive-ffcode
           texlive-filehook
           texlive-fmtcount
           texlive-fontsize
           texlive-footmisc
           texlive-geometry
           texlive-hyperref
           texlive-lastpage
           texlive-libertine
           texlive-listings
           texlive-listingsutf8
           texlive-makecell
           texlive-microtype
           texlive-pagecolor
           texlive-paralist
           texlive-pdfcol
           texlive-pgf
           texlive-pgfopts
           texlive-ragged2e
           texlive-setspace
           texlive-svg
           texlive-tcolorbox
           texlive-textpos
           texlive-tikzfill
           texlive-titling
           texlive-transparent
           texlive-trimspaces
           texlive-wrapfig
           texlive-xcolor))
    (home-page "https://ctan.org/pkg/huawei")
    (synopsis "Template for Huawei documents")
    (description
     "This unofficial package provides a class for creating documents for people
working with Huawei Technologies Co., Ltd.")
    (license license:expat)))

(define-public texlive-hvextern
  (package
    (name "texlive-hvextern")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hvextern/" "tex/latex/hvextern/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cw8gpfxljc53p4nxb13rzdqhxc7qss16968qcnqdxjc76ikxqmc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hvextern")
    (synopsis "Write and execute external code, and insert the output")
    (description
     "This package allows writing MetaPost, TeX, ConTeXt, LaTeX, LuaTeX,
LuaLaTeX, XeTeX, XeLaTeX, Lua, Perl, or Python source code into an external
file, run that file via shell escape to create PDF, PNG, or text output, and
include that output automatically into the main LaTeX document.")
    (license license:lppl1.3c)))

(define-public texlive-hvindex
  (package
    (name "texlive-hvindex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hvindex/" "tex/latex/hvindex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vy5x6ws4kq68g6k9bprxnhk41w63v035ippsc3wq2mfp6s29hif"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hvindex")
    (synopsis "Support for indexing")
    (description
     "The package simplifies the indexing of words using the @code{\\index} command
of @code{makeidx}.  With the package, to index a word in a text, you only have
to type it once; the package makes sure it is both typeset and indexed.")
    (license license:lppl)))

(define-public texlive-hvlogos
  (package
    (name "texlive-hvlogos")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hvlogos/" "tex/latex/hvlogos/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15qsh73dpxw8ifkp3fxq0fqn1p23w7n1icxxa3505a8mf6ga1aba"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hvlogos")
    (synopsis "Print TeX-related names as logo")
    (description
     "This package is more or less an extension to Heiko Oberdiek's package
@code{hologo}.  It prints TeX-related names as logos.")
    (license license:lppl)))

(define-public texlive-hvpygmentex
  (package
    (name "texlive-hvpygmentex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hvpygmentex/"
                                     "tex/latex/hvpygmentex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0i63wq2bshswxg0ccxn18bqcs1v79wziazihs2bg6jcs4ns12y40"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hvpygmentex")
    (synopsis "Syntax-highlighting of program code")
    (description
     "The package is based on @code{pygmentex} but provides an automatic run from
within the document itself, with the option @code{--shell-escape}.  It does
not need the additional action by the user to run the external program
pygmentize to create the code snippets.")
    (license license:lppl1.3c)))

(define-public texlive-hvqrurl
  (package
    (name "texlive-hvqrurl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hvqrurl/" "tex/latex/hvqrurl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "037ylh723l8zvi1lz6idfr1sjx270wwfm2qiswy7iwsmzail2xb7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hvqrurl")
    (synopsis "Insert a QR code in the margin")
    (description
     "This package allows drawing a URL as a QR code into the margin of a one- or
two-sided document.")
    (license license:lppl1.3+)))

(define-public texlive-hwemoji
  (package
    (name "texlive-hwemoji")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hwemoji/" "tex/latex/hwemoji/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k0w0y2qm8a4pflsyv5fmw9yrm19zgic041w6si7aaz6k6mvjcvh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hwemoji")
    (synopsis "Unicode emoji support for pdfLaTeX with sequences")
    (description
     "This package provides direct support for Unicode emoji in pdfLaTeX, with full
access to emoji sequences including but not limited to flag sequences,
diversity modifier sequences, and tag sequences.")
    (license (list license:lppl1.3c license:cc-by4.0))))

(define-public texlive-hypdestopt
  (package
    (name "texlive-hypdestopt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hypdestopt/"
                                     "tex/latex/hypdestopt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pzzgjdwxz7hxhkwc663dbqp0kc831353yrzsm8av1qcnl3mmrk9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hypdestopt")
    (synopsis "@code{hyperref} destination optimizer")
    (description
     "This package supports @code{hyperref}'s pdfTeX driver.  It removes
unnecessary destinations and shortens the destination names or uses numbered
destinations to get smaller PDF files.")
    (license license:lppl1.3+)))

(define-public texlive-hypdvips
  (package
    (name "texlive-hypdvips")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hypdvips/" "tex/latex/hypdvips/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03zpciwfzcp7mrr7mq60i0fwx10spgvyc5hjz490k0p2ha95l8i6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hypdvips")
    (synopsis "@code{hyperref} extensions for use with Dvips")
    (description
     "The @code{hypdvips} package fixes some problems when using @code{hyperref}
with Dvips.  It also adds support for breaking links, file attachments,
embedded documents and different types of GoTo-links.  The cooperation of
@code{hyperref} with @code{cleveref} is improved, which in addition allows an
enhanced back-referencing system.")
    (license license:lppl1.3+)))

(define-public texlive-hyper
  (package
    (name "texlive-hyper")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hyper/" "source/latex/hyper/"
                                     "tex/latex/hyper/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z01dlbsjdppvfjgggnla1l7v9a0l3zy2j8fa56g757jcidi1s1k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hyper")
    (synopsis "Hypertext cross referencing")
    (description
     "This package redefines LaTeX cross-referencing commands to insert
@code{\\special} commands for HyperTeX DVI viewers, such as recent versions of
@command{xdvi}.  The package is now largely superseded by @code{hyperref}.")
    (license license:lppl)))

(define-public texlive-hyperbar
  (package
    (name "texlive-hyperbar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hyperbar/"
                                     "source/latex/hyperbar/"
                                     "tex/latex/hyperbar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1v059dqmjfp0bv4b3w7bd99z7b5cip4zrr2qll4fw9fq4w36gxzy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hyperbar")
    (synopsis "Add interactive barcode fields to PDF forms")
    (description
     "The package extends the hyperref functionality for creating interactive forms
to allow adding Barcode form fields supported by some modern PDF readers.
Currently, only pdfTeX is supported.")
    (license license:lppl1.3c)))

(define-public texlive-hypernat
  (package
    (name "texlive-hypernat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/hypernat/" "tex/latex/hypernat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16kdllcc7ab9hy5d3gnacxha4kkn20x7v1j7j30flg2vrgfphvmf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/hypernat")
    (synopsis "Allow @code{hyperref} and @code{natbib} to work together")
    (description
     "This package allows @code{hyperref} package and the @code{natbib} package
with options @code{numbers} and @code{sort&compress} to work together.  This
means that multiple sequential citations, e.g., @samp{[3,2,1]}, will be
compressed to @samp{[1-3]}, where the @samp{1} and the @samp{3} are
(color-)linked to the bibliography.")
    (license license:gpl3+)))

(define-public texlive-identkey
  (package
    (name "texlive-identkey")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/identkey/" "tex/latex/identkey/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h9am5zwjmpy8wrszldiwfwqx2z310s7mv3mnk4ra2hhllkpdvgy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/identkey")
    (synopsis "Typesetting bracketed dichotomous identification keys")
    (description
     "The package is for typesetting bracketed dichotomous identification keys.")
    (license license:gpl3)))

(define-public texlive-idxcmds
  (package
    (name "texlive-idxcmds")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/idxcmds/" "tex/latex/idxcmds/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i4jb86dlawqc4nxwrz5h3wc5h1mp0zav2f349f83hhf5gaf6y5x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/idxcmds")
    (synopsis "Semantic commands for adding formatted index entries")
    (description
     "The package provides commands for adding formatted index entries.")
    (license license:lppl1.3+)))

(define-public texlive-idxlayout
  (package
    (name "texlive-idxlayout")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/idxlayout/"
                                     "source/latex/idxlayout/"
                                     "tex/latex/idxlayout/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1d3ir3rqyr62db82mad09z2xpyyczflrgkjgnkgj45ahd0mhdplr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/idxlayout")
    (synopsis
     "Configurable index layout, responsive to KOMA-Script and @code{memoir}")
    (description
     "The @code{idxlayout} package offers a key-value interface to configure index
layout parameters, e.g. allowing for three-column indexes or for parent items
and their affiliated subitems being typeset as a single paragraph.  The
package is responsive to the index-related options and commands of the
KOMA-Script and @code{memoir} classes.")
    (license license:lppl)))

(define-public texlive-ifallfalse
  (package
    (name "texlive-ifallfalse")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ifallfalse/"
                                     "source/latex/ifallfalse/"
                                     "tex/latex/ifallfalse/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0alv6y4pphbsz04hqj51gsh99xnn38srx6hz9y96gvkq0v66bx1d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ifallfalse")
    (synopsis "Compare a string against a set of other strings")
    (description
     "This package allows you to check whether a string is contained within another
set of strings, and perform an action if it is not.  This is done by using the
@code{allfalse} environment and passing in a string and an action to be
performed if the string is not contained in the set.  Then, passing in
a string to the @code{\\orcheck} macro inside the respective @code{allfalse}
environment adds that to the set of strings.  This package does not work with
the LuaTeX engine.")
    (license license:lppl1.3+)))

(define-public texlive-iffont
  (package
    (name "texlive-iffont")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/iffont/" "source/latex/iffont/"
                                     "tex/latex/iffont/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1l18ggmcp87r22d99vnnpfb5iaahplylm0gm70hschr71nkl7bgz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/iffont")
    (synopsis "Conditionally load fonts with @code{fontspec}")
    (description
     "This package provides a macro to select the first font XeLaTeX or LuaTeX can
find in a comma separated list and, additionally, a number of macro tests.")
    (license license:lppl1.3+)))

(define-public texlive-ifmslide
  (package
    (name "texlive-ifmslide")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ifmslide/" "tex/latex/ifmslide/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qwf9bx7im71nr04y4im47lh29m8s7w772y077m70fbr5mbila9n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ifmslide")
    (synopsis "Presentation slides for screen and printouts")
    (description
     "This package is used to produce printed slides with LaTeX and online
presentations with pdfLaTeX.")
    (license license:lppl1.2+)))

(define-public texlive-ifnextok
  (package
    (name "texlive-ifnextok")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ifnextok/"
                                     "source/latex/ifnextok/"
                                     "tex/latex/ifnextok/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hlf4vn8ki9p425s9wki2b86jx9kxcmbk12h3cljmy32f6bxs7bh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ifnextok")
    (synopsis "Utility macro: peek ahead without ignoring spaces")
    (description
     "The package deals with the behaviour of the LaTeX internal command
@code{\\@@ifnextchar}, which skips blank spaces.  This has the potential to
surprise users, since it can produce really unwanted effects.  A common
example occurs with brackets starting a line following @code{\\\\}: the
command looks for an optional argument, whereas the user wants the brackets to
be printed.  The package offers commands and options for modifying this
behaviour, maybe limited to certain parts of the document source.")
    (license license:lppl1.3+)))

(define-public texlive-ifthenx
  (package
    (name "texlive-ifthenx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ifthenx/" "tex/latex/ifthenx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10ii2p56c088m786grsidq2l9cvk52jp10nmah3xamlix7nx10lm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ifthenx")
    (synopsis "Extra tests for \\ifthenelse")
    (description
     "The package extends the @code{ifthen} package, providing extra predicates for
the package's @code{\\ifthenelse} command.  The package is complementary to
@code{xifthen}, in that they provide different facilities; the two may be
loaded in the same document, as long as @code{xifthen} is loaded first.")
    (license license:lppl)))

(define-public texlive-iitem
  (package
    (name "texlive-iitem")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/iitem/" "source/latex/iitem/"
                                     "tex/latex/iitem/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wizydpgy1xghwy18l0ywwi5r3mkiw8m37dafa8pg1k5rvffz4zq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/iitem")
    (synopsis "Multiple level of lists in one list-like environment")
    (description
     "The package defines multiple level lists within one list-like environment,
with the help of the @code{\\iitem}, @code{\\iiitem}, ... macros.")
    (license license:lppl)))

(define-public texlive-image-gallery
  (package
    (name "texlive-image-gallery")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/image-gallery/"
                                     "tex/latex/image-gallery/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19n9ll9gbqv56f14vd9sqn85wl726z8rhs7ba2631qlpskj9qb1v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/image-gallery")
    (synopsis
     "Create an overview of pictures from a digital camera or other sources")
    (description
     "The class may be used to create an overview of pictures from a digital camera
or from other sources.  It is possible to adjust the size of the pictures and
all the margins.")
    (license license:lppl)))

(define-public texlive-indextools
  (package
    (name "texlive-indextools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/indextools/"
                                     "source/latex/indextools/"
                                     "tex/latex/indextools/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1l6pkpgyvlgk0wri54m52rr5j313qfrsifmx8x5jhjihy68hrm2j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/indextools")
    (synopsis "Producing multiple indices")
    (description
     "This package enables the user to produce and typeset one or more indices
simultaneously.  The package is known to work in LaTeX documents processed
with pdfLaTeX, XeLaTeX and LuaLaTeX. If @command{makeindex} is used for
processing the index entries, no particular setup is needed.  Using
@command{xindy} or other programs, it is necessary to enable shell escape.
Shell escape is also needed if @command{splitindex} is used.  This is a fork
of @code{imakeidx}, with new features and fixed bugs.")
    (license license:lppl1.3+)))

(define-public texlive-inline-images
  (package
    (name "texlive-inline-images")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/inline-images/"
                                     "tex/latex/inline-images/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00bmn7fi72wyk202lii51r0gflqsrnxjlddpd0hq7j1j06rkpyvg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/inline-images")
    (synopsis "Inline images in base64 encoding")
    (description
     "The package provides a command @code{\\inlineimg} to dynamically create
a file containing the inline image in base64 format, which is decoded and
included in the source file.")
    (license license:lgpl3)))

(define-public texlive-inlinelabel
  (package
    (name "texlive-inlinelabel")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/inlinelabel/"
                                     "tex/latex/inlinelabel/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rsngfllng3qajm2rpdjpyf88iizd1nshbwriawh3d6g8b0yi82r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/inlinelabel")
    (synopsis "Assign equation numbers to inline equations")
    (description
     "This package can assign equation numbers to inline equations.  When Japanese
is supported, you can switch to circled equation numbers.")
    (license license:expat)))

(define-public texlive-inputtrc
  (package
    (name "texlive-inputtrc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/inputtrc/"
                                     "source/latex/inputtrc/"
                                     "tex/latex/inputtrc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nmflwlf1ydrrb1n6gy8b6zfh18c02z0iyfv91m6c674spaiplsr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/inputtrc")
    (synopsis "Trace which file loads which")
    (description
     "The package produces screen/log messages of the form @samp{<current>
INPUTTING <next>} reporting LaTeX input commands (@samp{<current>} and
@samp{<next}> being file names).  The message is indented to reflect the level
of input nesting.  Tracing may be turned on and off, and the unit of
indentation may be adjusted.")
    (license license:lppl1.3+)))

(define-public texlive-interactiveworkbook
  (package
    (name "texlive-interactiveworkbook")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list
                                "doc/latex/interactiveworkbook/documentation/"
                                "doc/latex/interactiveworkbook/epsfiles/"
                                "doc/latex/interactiveworkbook/samplefiles/"
                                "tex/latex/interactiveworkbook/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yvavrbnmq8azzl6yijxah0sqcp1p9xm58n1r006zlpixkhq7d6g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/interactiveworkbook")
    (synopsis "LaTeX-based interactive PDF on the Web")
    (description
     "The package @code{interactiveworkbook} gives the user the ability to write
LaTeX documents which, ultimately, create interactive question-and-answer
Portable Document Format (PDF) tutorials meant to be used by internet students
and that, in particular, freely use mathematical notation.")
    (license license:lppl)))

(define-public texlive-interfaces
  (package
    (name "texlive-interfaces")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/interfaces/"
                                     "source/latex/interfaces/"
                                     "tex/latex/interfaces/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fq0fld4j0z3pi9sczv8iisigbvv64j3bnfg478dx2sqnn6maybp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/interfaces")
    (synopsis "Set parameters for other packages, conveniently")
    (description
     "The package provides a small number of convenient macros that access features
in other frequently-used packages, or provide interfaces to other useful
facilities such as the pdfTeX @code{\\pdfelapsedtime} primitive.")
    (license license:lppl1.3+)))

(define-public texlive-intopdf
  (package
    (name "texlive-intopdf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/intopdf/" "source/latex/intopdf/"
                                     "tex/latex/intopdf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04mys6v63mahinv08cjd71yvs1d93ly7hqw5n4m0pkljjihdjyf7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/intopdf")
    (synopsis "Embed non-PDF files into PDF with hyperlink")
    (description
     "The package allows embeding non-PDF files (e.g., BibTeX} into PDF with an
hyperlink.")
    (license license:lppl1.3c)))

(define-public texlive-inversepath
  (package
    (name "texlive-inversepath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/inversepath/"
                                     "source/latex/inversepath/"
                                     "tex/latex/inversepath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mbvx1lj1h0p2li4qjc5s238iiwnp9cg0vsdlxxwdlng8ahc62p0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/inversepath")
    (synopsis "Calculate inverse file paths")
    (description
     "The package calculates inverse relative paths.  Such things may be useful,
for example, when writing an auxiliary file to a different directory.")
    (license license:lppl1.3+)))

(define-public texlive-invoice
  (package
    (name "texlive-invoice")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/invoice/" "tex/latex/invoice/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12c7kqnra2mv98xjqb0rba8xqnhvvqfd2712y8j2y47zf0r7a26k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/invoice")
    (synopsis "Generate invoices")
    (description
     "The package may be used for generating invoices.  The package can deal with
invisible expense items and deductions; output may be presented in any of 10
different languages.")
    (license license:lppl1.3c)))

(define-public texlive-invoice-class
  (package
    (name "texlive-invoice-class")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/invoice-class/"
                                     "tex/latex/invoice-class/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0078i0vv2qxfxgn45rxxzll7f7b0h33jcigm9zkx6hcmq62sv0rz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/invoice-class")
    (synopsis "Produces a standard US invoice from a CSV file")
    (description
     "This class produces a standard US commercial invoice using data from a CSV file.
Invoices can span multiple pages.  The class is configurable for different
shipping addresses.")
    (license license:lppl1.3+)))

(define-public texlive-invoice2
  (package
    (name "texlive-invoice2")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/invoice2/"
                                     "source/latex/invoice2/"
                                     "tex/latex/invoice2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "133v3jk4lhbp17i1435jf4n3gnb7r892qiylzpd65pxdwivi3k0n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-booktabs
                             texlive-l3kernel
                             texlive-l3packages
                             texlive-siunitx
                             texlive-tools
                             texlive-translations
                             texlive-xcolor))
    (home-page "https://ctan.org/pkg/invoice2")
    (synopsis "Intelligent invoices with LaTeX3")
    (description
     "This package typesets invoices with automatic VAT and calculation of totals.
It supports internationalization, invoices are typeset with @code{booktabs}
for readability.  It does not support separate projects per invoice.  It can
be used as a replacement for @code{invoice} in most cases.")
    (license license:gpl3+)))

(define-public texlive-iso
  (package
    (name "texlive-iso")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/iso/" "makeindex/iso/"
                                     "source/latex/iso/" "tex/latex/iso/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rzxf4nykw6ar9dhn4vanwdryx7hapfjmqqjnlpg0ly05fckqd4i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/iso")
    (synopsis "Generic ISO standards typesetting macros")
    (description
     "This package provide generic class and package files for typesetting ISO
International Standard documents.  Several standard documents have been
printed by ISO from camera-ready copy prepared using LaTeX and these files.")
    (license license:lppl)))

(define-public texlive-iso10303
  (package
    (name "texlive-iso10303")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/iso10303/"
                                     "source/latex/iso10303/"
                                     "tex/latex/iso10303/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04yackrrjba2ddgl8ps3ka6mmh09cw5b9rz69vczvgfdc9cr6krx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/iso10303")
    (synopsis "Typesetting the STEP standards")
    (description
     "This package provides class and package files building on @code{iso} for
typesetting the ISO 10303 (STEP) standards.  Standard documents prepared using
these packages have been published by ISO.")
    (license license:lppl)))

(define-public texlive-isodoc
  (package
    (name "texlive-isodoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/isodoc/" "source/latex/isodoc/"
                                     "tex/latex/isodoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04p3rjxd636k270cy4mqzfmmhp54s69rdr2rjynvvf84p3l2573q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "luatex"))
    (home-page "https://ctan.org/pkg/isodoc")
    (synopsis "Latex class for typesetting letters and invoices")
    (description
     "The @code{isodoc} class can be used for the preparation of letters and
invoices.  Documents are set up with options, thus making the class easily
adaptable to user's wishes and extensible for other document types.  The class
is based on the NTG @code{brief} class, which implements the NEN1026
standard.")
    (license license:lppl1.3c)))

(define-public texlive-isonums
  (package
    (name "texlive-isonums")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/isonums/" "tex/latex/isonums/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lm47qxvhdw3mc7549bw32k978cl7gik0inkmin8x0w9mdg22lm5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/isonums")
    (synopsis "Display numbers in maths mode according to ISO 31-0")
    (description
     "The package makes a quick hack to ziffer to display numbers in maths mode
according to ISO 31-0, regardless of input format (European $1.235,7$ or
Anglo-American $1,235.7$).")
    (license license:lppl)))

(define-public texlive-isopt
  (package
    (name "texlive-isopt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/isopt/" "tex/latex/isopt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1i4zhjqknx74ki7hq55j2qn02kw17fnagb49p59bk3ifs03z4w9s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/isopt")
    (synopsis "Writing a TeX length with a space between number and unit")
    (description
     "Writing a TeX length with @code{\\the} writes the value and the unit without
a space.  Package @code{isopt} provides a macro @code{\\ISO} which inserts
a user defined space between number and unit.")
    (license license:lppl)))

(define-public texlive-isorot
  (package
    (name "texlive-isorot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/isorot/" "source/latex/isorot/"
                                     "tex/latex/isorot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mpph7pvcw6l65zkq641gc0c0j0vq593mqsqhbb6zq3cmvc00dkr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/isorot")
    (synopsis "Rotation of document elements")
    (description
     "The package is for rotation of document elements.  It is a combination of the
@code{lscape} package and an extension of the @code{rotating} package.  The
package is designed for use with the @code{iso} class but may be used with any
normal class.")
    (license license:lppl)))

(define-public texlive-isotope
  (package
    (name "texlive-isotope")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/isotope/" "source/latex/isotope/"
                                     "tex/latex/isotope/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16828laxqjbq5303c649j9nb36ci3rjdki8zds6pw2y9sdiy2kki"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/isotope")
    (synopsis "Typeset isotopes")
    (description
     "The package provides a command @code{\\isotope} for setting the atomic weight
and atomic number indications of isotopes.")
    (license license:lppl)))

(define-public texlive-issuulinks
  (package
    (name "texlive-issuulinks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/issuulinks/"
                                     "source/latex/issuulinks/"
                                     "tex/latex/issuulinks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lawg1l5q0c6vblwmj9nyszqk9q3ivmk05bpczwycc28xsmr6rd6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/issuulinks")
    (synopsis "Produce external links instead of internal ones")
    (description
     "The PDF visualizer @url{http://issuu.com/ISSUU} is a popular service which
shows PDF documents ``a page a time''.  Due to the way it is implemented,
internal links in these documents are not allowed.  Instead, they must be
converted to external ones in the form
@url{http://issuu.com/action/page?page=PAGENUMBER}. The package patches
@code{hyperref} to produce external links in the required form instead of
internal links created by @code{\\ref}, @code{\\cite} and other commands.

Since the package redefines the internals of @code{hyperref}, it must be
loaded after @code{hyperref}.")
    (license license:lppl1.3+)))

(define-public texlive-jlabels
  (package
    (name "texlive-jlabels")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jlabels/" "tex/latex/jlabels/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p12sr2i44mmn4cr3vsmrbaixx17c53qx4jh4k3mscwj7rkf3af1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jlabels")
    (synopsis "Make letter-sized pages of labels")
    (description
     "The package makes letter-sized pages of labels.  It provides controls for the
numbers of rows and columns.")
    (license license:lppl)))

(define-public texlive-jmsdelim
  (package
    (name "texlive-jmsdelim")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jmsdelim/"
                                     "source/latex/jmsdelim/"
                                     "tex/latex/jmsdelim/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xi2gijzl747ixhl7nwam0ldzvq834j70cmqbz8sik75gwmisdj9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jmsdelim")
    (synopsis "Package for compositional delimiter sizing")
    (description
     "Correctly sizing delimiters is very difficult, particularly in
well-architected documents: a correctly engineered mathematical document will
include macros for all operations, and these macros necessarily will include
delimiters (such as parentheses).  However, the correct size for the delimiter
cannot be chosen ahead of time, because it will depend on the arguments; two
options are available: Provide optional arguments to each notation macro for
choosing delimiter sizes.  This is nearly intractable to do in practice.
Ignore delimiter sizes.  With @code{jmsdelim} we offer an alternative: the
correct delimiter sizes can be set at the leaf nodes of a mathematical
expression, and magically bubble upward through the delimiters.")
    (license license:lppl1.3c)))

(define-public texlive-jobname-suffix
  (package
    (name "texlive-jobname-suffix")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jobname-suffix/"
                                     "tex/latex/jobname-suffix/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qyb61pzfwdqna53akjpwwbaab1w827rjv83hrq8ss1cd754v2ka"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jobname-suffix")
    (synopsis "Compile differently based on the filename")
    (description
     "This package allows compiling a document differently depending on the
portion of the document's file name (internally, the @code{\\jobname}) that
comes after the first @samp{-} character.  This allows one to have one source
file and multiple links to this source file that each compile differently.")
    (license license:lppl1.3+)))

(define-public texlive-jslectureplanner
  (package
    (name "texlive-jslectureplanner")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jslectureplanner/"
                                     "tex/latex/jslectureplanner/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "060dzg66zh3zfynjh514p9szw03k9xld16y4nzh2wjh8ib41m519"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jslectureplanner")
    (synopsis "Creation and management of university course material")
    (description
     "The @code{jslectureplanner} package facilitates the generation and management
of university course material.  It provides an interface to set up and access
centralized course data that can be reused in all course documents.
Furthermore, the package is able to calculate the session dates of a whole
semester and generate course programs, if the course is held weekly and the
date of the first lecture is specified.  Moreover, the package can be used to
generate a sectioned course bibliography via BibLaTeX.  The bundle also
includes a package @file{jsmembertable.sty} that helps in generating course
member and presence lists.")
    (license license:lppl1.3+)))

(define-public texlive-jumplines
  (package
    (name "texlive-jumplines")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jumplines/"
                                     "tex/latex/jumplines/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vih9bayflngvsx0q0pfqzp04vbp5mjjgc7m8yhs4drr27nh75j2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jumplines")
    (synopsis "Articles with teasers and continuation later on")
    (description
     "Jumplines is a package for typesetting (newspaper) articles that show a teaser
(some few lines of text/content) and are continued at a later place, with
optional hyperlinking and a list of articles.  It requires LuaLaTeX for colour
support in split boxes.")
    (license license:lppl1.3+)))

(define-public texlive-jvlisting
  (package
    (name "texlive-jvlisting")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/jvlisting/"
                                     "source/latex/jvlisting/"
                                     "tex/latex/jvlisting/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0isbn35x3228bhkp77q3agy380w7akryam3p5i3rvi7bmk1s5958"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/jvlisting")
    (synopsis "Replacement for LaTeX's @code{verbatim} package")
    (description
     "This package provides a LaTeX environment @code{listing}, an alternative to
the built-in @code{verbatim} environment.  The @code{listing} environment is
tailored for including listings of computer program source code into
documents.  The main advantages over the original @code{verbatim} environment
are: environments automatically fixes leading whitespace so that the
environment and program listing can be indented with the rest of the document
source, and; @code{listing} environments may easily be customised and
extended.")
    (license license:lppl)))

(define-public texlive-kalendarium
  (package
    (name "texlive-kalendarium")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/kalendarium/"
                                     "source/latex/kalendarium/"
                                     "tex/latex/kalendarium/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08cj503m0v69a3fz5n2i6y8ga3xkp79nxp3cnc5g2bk4fqq1mv7l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/kalendarium")
    (synopsis "Print dates according to the classical Latin calendar")
    (description
     "@code{kalendarium} is a LaTeX3 package that provides several macros with
which to print dates in classical Latin given days on the Julian or Gregorian
calendars, using the same syntax used by ancient Roman authors.  The format of
these dates may be customised either in the package options or on
a per-command basis; these options also allow for the generation of date
strings according to different eras of the Classical period.")
    (license license:lppl1.3c)))

(define-public texlive-kerntest
  (package
    (name "texlive-kerntest")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/kerntest/"
                                     "source/latex/kerntest/"
                                     "tex/latex/kerntest/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08g814zv8cq6q1174wdx4z2p5lpyyp1s5mpzk4dmzsz7rzr4gdhm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/kerntest")
    (synopsis "Print tables and generate control files to adjust kernings")
    (description
     "This class makes it easy to generate tables that show many different kerning
pairs of an arbitrary font, usable by LaTeX.  It shows the kerning values that
are used in the font by default.  In addition, this class enables the user to
alter the kernings and to observe the results.  Kerning pairs can be defined
for groups of similar glyphs at the same time.  An @file{.mtx} file is
generated automatically.  The @file{.mtx} file may then be loaded by
@code{fontinst} to introduce the user-made kernings into the virtual font for
later use in LaTeX.")
    (license license:lppl)))

(define-public texlive-keycommand
  (package
    (name "texlive-keycommand")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/keycommand/"
                                     "source/latex/keycommand/"
                                     "tex/latex/keycommand/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0if07qinrxr798xin04rhf6g6chq0lj1p684zi40rrlkwgrc5br5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/keycommand")
    (synopsis "Simple creation of commands with key-value arguments")
    (description
     "The package (which requires e-TeX) provides a natural way to define commands
with optional keys.  The package provides @code{\\newkeycommand},
@code{\\renewkeycommand}, @code{\\providekeycommand},
@code{\\newkeyenvironment} and @code{\\renewkeyenvironment}, together with
@code{\\keycmd} for a more advanced interface.")
    (license license:lppl)))

(define-public texlive-keyfloat
  (package
    (name "texlive-keyfloat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/keyfloat/"
                                     "source/latex/keyfloat/"
                                     "tex/latex/keyfloat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0122nsxrdvqz3nxbv2wiz80im4in6q964q4havk00m94zy8iybvl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/keyfloat")
    (synopsis "Provides a key/value interface for generating floats")
    (description
     "The @code{keyfloat} package provides a key/value user interface for
quickly creating figures with a single image each, figures with arbitrary
contents, tables, subfloats, rows of floats, floats located @emph{here},
floats in the margin, and floats with text wrapped around them.  Key/value
combinations may specify a caption and label, a width proportional to
@code{\\linewidth}, a fixed width and/or height, rotation, scaling, a tight or
loose frame, an @code{\\arraystretch}, a continued float, additional
supplemental text, and an artist/author's name with automatic index entry.
When used with the @code{tocdata} package, the name also appears in the list
of figures.  Floats may be placed into a @code{row} environment, and are
typeset to fit within the given number of columns, continuing to the next row
if necessary.  Nested sub-rows may be used to generate layouts such as two
small figures placed vertically next to one larger figure.  Subfloats are
supported by two environments.")
    (license license:lppl1.3+)))

(define-public texlive-keyindex
  (package
    (name "texlive-keyindex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/keyindex/"
                                     "source/latex/keyindex/"
                                     "tex/latex/keyindex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zw2sj3qq0v0kp68mmb72x44mpwfj0hnzxwqdv92m5528k1ylyr9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/keyindex")
    (synopsis "Index entries by key lookup")
    (description
     "The package provides functionality for producing an index without directly
entering index entries into the text using the @code{\\index} command, but
instead by looking up short keys and printing a predefined string in the main
text and adding a corresponding index entry.  The standard use case is the
production of an index of names.")
    (license license:lppl1.3c)))

(define-public texlive-keyparse
  (package
    (name "texlive-keyparse")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/keyparse/"
                                     "source/latex/keyparse/"
                                     "tex/latex/keyparse/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11g2knzck2g1j8mcqy3821p8a7xz1a0krz2s3ak7jn060aim72hi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/keyparse")
    (synopsis "Key based parser")
    (description
     "This LaTeX package provides an interface to define and evaluate key-based
replacement rules.  It can be used to parse the argument specification of
a document command.")
    (license license:lppl1.3c)))

(define-public texlive-keyreader
  (package
    (name "texlive-keyreader")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/keyreader/"
                                     "tex/latex/keyreader/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zw0qkg4lbqk260fmdsdz0j3044dph7f1ypx81yflwj2hvinsr3z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/keyreader")
    (synopsis "Robust interface to @code{xkeyval}")
    (description
     "The package provides a robust interface to controlling keys in @code{xkeyval},
removing some of that package's restrictions.  The package also addresses some
of the issues now covered by @code{ltxkeys} package, which was assumed to be
a replacement for @code{keyreader}.  Since @code{keyreader} has remained
a favourite with users, it has been reinstated.")
    (license license:lppl1.3+)))

(define-public texlive-keystroke
  (package
    (name "texlive-keystroke")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/keystroke/"
                                     "tex/latex/keystroke/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vgzbh02aadnwmhfvysijxxy4bkf3wv6hxmghb8kz8g7sam4f5p1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/keystroke")
    (synopsis "Graphical representation of keys on keyboard")
    (description
     "This package provides a LaTeX package which provides macros for the
graphical representation of the keys on a computer keyboard.")
    (license license:gpl3+)))

(define-public texlive-keyval2e
  (package
    (name "texlive-keyval2e")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/keyval2e/" "tex/latex/keyval2e/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h8clf8xy8lw3zairdr8x5v4yv904ffibcva54ckbnvzls48ka6m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/keyval2e")
    (synopsis "Lightweight and robust key-value parser")
    (description
     "The package provides lightweight and robust facilities for creating and
managing keys.  Its machinery isn't as extensive as that of, e.g., the
@code{ltxkeys} package, but it is equally robust; ease of use and speed of
processing are the design aims of the package.")
    (license license:lppl1.3+)))

(define-public texlive-keyvaltable
  (package
    (name "texlive-keyvaltable")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/keyvaltable/"
                                     "source/latex/keyvaltable/"
                                     "tex/latex/keyvaltable/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c1wgdh83b673ay0ak18iyqpwdmfyhpfqlpbk30fjrkxf78bmw83"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/keyvaltable")
    (synopsis "Re-usable table layouts separating content and presentation")
    (description
     "The main goal of this package is to offer means for typesetting tables easily
and yet still looking rather nicely in a way that separates content from
presentation and with re-usable layout for tables of the same type.  For this
purpose, the package provides the environment @code{KeyValTable}, which allows
one to typeset tables that have a previously defined column layout and whose
rows can be produced in a key-value fashion.")
    (license license:lppl1.2+)))

(define-public texlive-kix
  (package
    (name "texlive-kix")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/kix/" "tex/latex/kix/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sbvvjmrz61il4xy6vv7n0zsbv42s5g65grn4bn14sc60sfa968h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/kix")
    (synopsis "Typeset KIX codes")
    (description
     "This package implements KIX codes as used by the Dutch PTT for bulk mail
addressing. (Royal Mail 4 State Code.)")
    (license license:lppl1.0+)))

(define-public texlive-knowledge
  (package
    (name "texlive-knowledge")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/knowledge/"
                                     "source/latex/knowledge/"
                                     "tex/latex/knowledge/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "033kk7xr5js3p3khv33xvqb59y2aa1nq0mr7jf922q8i9bja9brl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/knowledge")
    (synopsis "Displaying, hyperlinking, and indexing notions in a document")
    (description
     "The package offers a systematic way to handle notions/concepts/terms
throughout a document.  It helps building an index.  In combination with
@code{hyperref} it makes it easy to have every reference of a concept linked
to its introduction.  It also offers simple notations.")
    (license license:lppl1.2+)))

(define-public texlive-koma-moderncvclassic
  (package
    (name "texlive-koma-moderncvclassic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/koma-moderncvclassic/"
                                     "tex/latex/koma-moderncvclassic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "169z8jvbsg8c9czf9p5lkcffm3nic6vvp7l4s1my0rqbvyyqs795"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/koma-moderncvclassic")
    (synopsis
     "Combine @code{moderncv} classic style and @code{koma-script} classes")
    (description
     "This package provides an imitation of the @code{moderncv} class with the
classic style, to be used in conjunction with the @code{koma-script} classes.
Thus it is possible to configure pagelayout, headings etc., the way it is done
in @code{koma-scripts} classes.  Moreover, it is possible to use BibLaTeX,
while the original @code{moderncv} class is incompatible with it.")
    (license license:lppl1.3+)))

(define-public texlive-koma-script-sfs
  (package
    (name "texlive-koma-script-sfs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/koma-script-sfs/"
                                     "tex/latex/koma-script-sfs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1awzff92bmc0gh5sycs5646cn15kzk7v2l79zjm27f2mpahd65l8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/koma-script-sfs")
    (synopsis "@code{koma-script} letter class option for Finnish")
    (description
     "This package provides a @code{koma-script} parameter set for letters on A4
paper, complying with Finnish standards SFS 2486, 2487 and 2488; suitable for
window envelopes with window on the left size in the sizes C5, C65, E5 and E65
(although, because the address window is smaller, for sizes E5 and E65 the
address may not fit within the window, but ordinary 3-line address should
fit).")
    (license license:lppl)))

(define-public texlive-komacv
  (package
    (name "texlive-komacv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/komacv/" "source/latex/komacv/"
                                     "tex/latex/komacv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17830drzdsk3nhd1n9fcmc4dbcm2lwia3jp2asi3g73yvzkjx7sz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/komacv")
    (synopsis "Typesetting a beautiful CV with various style options")
    (description
     "The class simplifies the creation of beautiful CV. The user may choose
between different styles, and may adjust settings to tune the output.")
    (license license:lppl1.3+)))

(define-public texlive-komacv-rg
  (package
    (name "texlive-komacv-rg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/komacv-rg/"
                                     "source/latex/komacv-rg/"
                                     "tex/latex/komacv-rg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13r94krp1mylj09pi800mxdv0q3f0r7zd31rw8wblfkqrzhh7gw2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/komacv-rg")
    (synopsis
     "Aid in creating CVs and related documents with the @code{komacv} class")
    (description
     "The @code{komacv-rg} bundle provides packages that aid in creating CVs based
on the @code{komacv} class and creating related documents, such as cover
letters and cover sheets for job applications.

Concretely, the bundle consists of three packages: @code{komacv-addons},
@code{komacv-lco}, and @code{komacv-multilang}.  @code{komacv-addons} is
a small collection of add-ons and fixes for the @code{komacv} class;
@code{komacv-lco} enables the use of @code{letter} class options from
@code{scrlttr2} also in @code{komacv}-based and other
non-@code{scrlttr2}-based documents; @code{komacv-multilang} enables the
provisioning of CVs in multiple languages and the selection of a language via
Babel or Polyglossia.")
    (license license:lppl1.2+)))

(define-public texlive-ktv-texdata
  (package
    (name "texlive-ktv-texdata")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ktv-texdata/"
                                     "source/latex/ktv-texdata/"
                                     "tex/latex/ktv-texdata/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1flmshqyjjh5m6s51rym9rn92pgqlkjvsxlvifgxj5blc4p8gmhi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ktv-texdata")
    (synopsis "Extract subsets of documents")
    (description
     "The package defines an exercise environment which numbers every exercise, and
a command @code{\\get} to extract a collection whose argument is
a comma-separated set of exercise index numbers.  While the package was
designed for teachers constructing tables of exercises, it plainly has more
general application.")
    (license license:gpl3+)))

(define-public texlive-labbook
  (package
    (name "texlive-labbook")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/labbook/" "source/latex/labbook/"
                                     "tex/latex/labbook/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zc1mlfyjxwrq60ch6inwkryygcg5fmj90bc6w6wfzrvb0gm2yw8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/labbook")
    (synopsis "Typeset laboratory journals")
    (description
     "This class is designed to typeset laboratory journals that contain
chronologically ordered records about experiments.  From the sectioning
commands, an experiment index is generated.  The class is based on the
KOMA-Script class @file{scrbook.cls}.  There can be several index entries for
one experiment.")
    (license license:lppl)))

(define-public texlive-labels
  (package
    (name "texlive-labels")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/labels/" "source/latex/labels/"
                                     "tex/latex/labels/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ldvd3d5c1g2hm4h02px1gzvv3kkkx834nwp3m3skh80nbhd3hcz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/labels")
    (synopsis "Print sheets of sticky labels")
    (description
     "This package provides a LaTeX package to print a regular grid of ragged-right
labels on a page, suitable for sheets of labels which can be fed through
a printer.  Macros are provided to allow easy input of names and addresses in
a form free of TeX markup.  Equally useful is a feature for making multiple
copies of a single label, e.g., return address stickers to go with the labels.
Rows, columns, borders can all be specified to match the label sheet being
used.")
    (license license:lppl1.2+)))

(define-public texlive-labels4easylist
  (package
    (name "texlive-labels4easylist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/labels4easylist/"
                                     "tex/latex/labels4easylist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1igsf1lqvmfp1yjynwcr3w6lpwsckq3gcx44j6jh65425sfn7mxy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/labels4easylist")
    (synopsis "Add reference labels to @code{easylist} items")
    (description
     "This package provides the @code{\\itemLabel} macro for adding configurable
reference labels to @code{easylist} items.")
    (license license:expat)))

(define-public texlive-labelschanged
  (package
    (name "texlive-labelschanged")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/labelschanged/"
                                     "source/latex/labelschanged/"
                                     "tex/latex/labelschanged/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "116xpva8icdnxbaq5j8k080yl38cl5lwx5rs45kmnxz6246akg3y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/labelschanged")
    (synopsis
     "Identify labels which cause endless ``may have changed'' warnings")
    (description
     "Several conditions can cause LaTeX labels to keep changing, no matter how
many times a document is recompiled.  This package helps diagnose the cause of
repeated ``Label(s) may have changed'' warnings.  The names and before/after
definitions of changing labels are printed at the end of each compile.
Multiply-defined labels are printed as well.")
    (license license:public-domain)))

(define-public texlive-lambdax
  (package
    (name "texlive-lambdax")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lambdax/" "source/latex/lambdax/"
                                     "tex/latex/lambdax/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lmqayjzzpamvwnff65iqaqjp6x5v926p5nw4yvrd7j0nnwmz0wg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lambdax")
    (synopsis "Use Lambda expression within LaTeX")
    (description
     "This package provides Lambda expressions.  It is an interface to specify the
parameters and replacement code of a document-command, and then to evaluate it
with compatible arguments.  Optionally, it can be used recursively.")
    (license license:lppl1.3c)))

(define-public texlive-lastpackage
  (package
    (name "texlive-lastpackage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lastpackage/"
                                     "source/latex/lastpackage/"
                                     "tex/latex/lastpackage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wa0cdrig4zivblalxx9q935yyd9z36jy26f8chj8skva25dhbz8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lastpackage")
    (synopsis "Indicates the last loaded package")
    (description
     "This package may be used to define the last point where some code shall be
executed.")
    (license license:lppl1.3+)))

(define-public texlive-latex-uni8
  (package
    (name "texlive-latex-uni8")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latex-uni8/"
                                     "tex/latex/latex-uni8/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c5x8v40gvw9q35xjmpndmklkc37ry4idld0657h0xrw0b5ljnh6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latex-uni8")
    (synopsis
     "Universal @code{inputenc}, @code{fontenc}, and @code{babel} for pdfLaTeX and
LuaLaTeX")
    (description
     "This package provides a LaTeX style file which makes it easy to use input
encoding (UTF-8 by default, can be changed), @file{fontspec.sty} (optional),
font encoding (T1 if @file{fontspec.sty} is not used), @code{babel} (English
language by default), hyphenation, underline (with @file{soul.sty}), default
text and math fonts (Computer Modern or Times), and paper sizes correctly with
both pdfLaTeX and LuaLaTeX.")
    (license license:lppl)))

(define-public texlive-latexcolors
  (package
    (name "texlive-latexcolors")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latexcolors/"
                                     "source/latex/latexcolors/"
                                     "tex/latex/latexcolors/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1y3wvf8jvcb9i1dvkgnm2gd8pvxg538mxpchhw930gaf4rwi5xyp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latexcolors")
    (synopsis "Use color definitions from @url{latexcolor.com}")
    (description
     "Built on top of the @code{xcolor} package, the @code{latexcolors} package
defines the set of colors shown on @url{latexcolor.com} for use in documents
typeset with LaTeX and friends.")
    (license license:lppl1.3+)))

(define-public texlive-latexdemo
  (package
    (name "texlive-latexdemo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latexdemo/"
                                     "source/latex/latexdemo/"
                                     "tex/latex/latexdemo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bans4djr58ym72ippjbrxd8hjabpq735hb4b0cq285k24wa8h98"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latexdemo")
    (synopsis "Demonstrate LaTeX code with its resulting output")
    (description
     "The package provides configurable tools to print out LaTeX code and the
resulting output in the same document.  It also supports printing the result
inside a conditional sequence; thus one may suppress printing if the code
would not compile.")
    (license license:lppl1.3+)))

(define-public texlive-latexgit
  (package
    (name "texlive-latexgit")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/latexgit/"
                                     "source/latex/latexgit/"
                                     "tex/latex/latexgit/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c2407abynq00hllpiyg5m6dbbmy8rz9s4jgr227l6ynfnjd8mir"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/latexgit")
    (synopsis "LaTeX git wrapper")
    (description
     "This package provides several macros to fetch git information and typeset it.
The macros defined by LaTeXgit can be helpful to documentation authors and
others to whom clear document versioning is important.")
    (license license:gpl3)))

(define-public texlive-layouts
  (package
    (name "texlive-layouts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/layouts/" "source/latex/layouts/"
                                     "tex/latex/layouts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bmkqld4rc0pw8ha54b1z4ycy5rj5alr9n1yv7qj5b0a4jadynf3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/layouts")
    (synopsis "Display various elements of a document's layout")
    (description
     "This package displays information about a document, including: text
positioning on a page; disposition of floats; layout of paragraphs, lists,
footnotes, table of contents, and sectional headings; font boxes.  Facilities
are provided for a document designer to experiment with the layout
parameters.")
    (license license:lppl1.3+)))

(define-public texlive-lazylist
  (package
    (name "texlive-lazylist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lazylist/" "tex/latex/lazylist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pyz8p3m25ccna6w8bahg29nqivryzygq62mzl1ybls90h9pls1p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lazylist")
    (synopsis "Lists in TeX's mouth")
    (description
     "The package was developed to provide flexible lists, whose ordering can be
altered on the fly.  The implementation involves a pile of lambda-calculus and
list-handling macros of an incredibly obtuse nature.  The TUGboat paper serves
as a manual for the macros.  Having said all of which, confidence is enhanced
by the knowledge that the TeX code was formally verified.")
    (license license:lppl1.2+)))

(define-public texlive-lccaps
  (package
    (name "texlive-lccaps")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lccaps/" "source/latex/lccaps/"
                                     "tex/latex/lccaps/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a56p7c7ldyhhrin1dm9lq1pjjblx32kyjs5005pkl35h8fl2gd2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/lccaps")
    (synopsis "Lowercased (spaced) small capitals")
    (description
     "This little package serves the purpose of providing a uniform method to use
lowercased small capitals and spaced lowercased small capitals.  It comes with
four new user macros:

@itemize

@item @code{\\textlcc}, the main feature: lowercased small capitals;

@item @code{\\spacedcaps}, a prefix to small capitals text commands to
slightly increase their spacing;

@item @code{\\textslcc} and @code{\\textssc}, which are shortcuts for
@code{\\spacedcaps\\textlcc} and @code{\\spacedcaps\\textsc} (respectively).

@end itemize")
    (license license:lppl1.3c)))

(define-public texlive-lcd
  (package
    (name "texlive-lcd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lcd/" "source/latex/lcd/"
                                     "tex/latex/lcd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1iglq9rcdx2m9b7k2k2m10mc1k0xylxyqk4gwz3q1avp9vxdqpd8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          ;; Do not stop build to ask about building part of the
          ;; documentation.
          (add-after 'unpack 'non-interactive-build
            (lambda _
              (substitute* "source/latex/lcd/lcd.ins"
                (("\\\\generateexampletrue") "\\generateexamplefalse")))))))
    (home-page "https://ctan.org/pkg/lcd")
    (synopsis "Alphanumerical LCD-style displays")
    (description
     "This is a LaTeX package that will display text as on an
(early) LCD display (the output is very visibly pixellated).  It assumes 8-bit
input in its internal verbatim-style environment.")
    (license license:lppl)))

(define-public texlive-lcg
  (package
    (name "texlive-lcg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lcg/" "source/latex/lcg/"
                                     "tex/latex/lcg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gj2bpw7fpa47dbs7myx6ch5lk2yc59qp3f6wv1b69gi0kg873cv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lcg")
    (synopsis "Generate random integers")
    (description
     "The @code{lcg} package generates random numbers (integers) via a linear
congruential generator (Schrage's method).  The random numbers are written to
a counter.  The @code{keyval} package is used for the user to provide values
for the range and a seed, and for the name of the counter to be used.")
    (license license:lppl)))

(define-public texlive-leading
  (package
    (name "texlive-leading")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/leading/" "source/latex/leading/"
                                     "tex/latex/leading/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fhdld6bagjyg0fs6c4gy0yp1p6wcrldqrs4hkrhylgrs2ilana9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/leading")
    (synopsis "Define leading with a length")
    (description
     "The package defines a command @code{\\leading}, whose argument specifies the
nominal distance between consecutive baselines of typeset text.  The command
replaces the rather more difficult LaTeX command @code{\\linespread}, where
the leading is specified by reference to the font size.")
    (license license:lppl)))

(define-public texlive-leaflet
  (package
    (name "texlive-leaflet")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/leaflet/" "source/latex/leaflet/"
                                     "tex/latex/leaflet/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vgcywhq8llskfsxxhld9jgzdjlmz0gijs9xcv3sqcz6cw6sis68"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/leaflet")
    (synopsis "Create small handouts (flyers)")
    (description
     "This package provides a document class to create small hand-outs (flyers)
that fit on a single sheet of paper which is then folded twice.  Pages are
rearranged by LaTeX so that they print correctly on a single sheet --- no
external script is necessary.")
    (license license:lppl1.3+)))

(define-public texlive-colorist
  (package
    (name "texlive-colorist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/colorist/" "tex/latex/colorist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vdwvn3v93n7x2nfp65rnsprahvhf0frgj2j1viz7g68njnl4j1f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-projlib))
    (home-page "https://ctan.org/pkg/colorist")
    (synopsis "Write your articles or books in a colorful way")
    (description
     "This package offers you a LaTeX style file and two classes to typeset
articles or books in a colorful way.  These classes currently have native
support for English, French, German, Italian, Portuguese (European and
Brazilian), and Spanish typesetting.  They compile with any major TeX engine.")
    (license license:lppl1.3c)))

(define-public texlive-lebhart
  (package
    (name "texlive-lebhart")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lebhart/" "tex/latex/lebhart/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r1d8jxdwgagc6ljmwi45q58np3lhjbz1njh27j3n31sx4y43w69"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-colorist))
    (home-page "https://ctan.org/pkg/lebhart")
    (synopsis "Write your articles in a colorful way")
    (description
     "This package provides a LaTeX class for typesetting articles with a colorful
design.  Currently, it has native support for Chinese (simplified and
traditional), English, French, German, Italian, Japanese, Portuguese (European
and Brazilian), Russian and Spanish typesetting.  It compiles with either
XeLaTeX or LuaLaTeX.")
    (license license:lppl1.3c)))

(define-public texlive-lectures
  (package
    (name "texlive-lectures")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lectures/" "tex/latex/lectures/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05x3dc40n83v7faw789iw5nzwn43zx6vjl58iqwdsqchkmd8alrv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lectures")
    (synopsis
     "Document class for quickly drafting nice looking lecture notes")
    (description
     "This LaTeX document class provides a number of gimmicks to draft nice looking
lecture notes, such as a number of theorem environments, automatic spacing and
alignment of figures and much more.")
    (license license:expat)))

(define-public texlive-lectureslides
  (package
    (name "texlive-lectureslides")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lectureslides/"
                                     "tex/latex/lectureslides/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "189sm3vxgi1qf6xf07f98p16bah8siwz0q97dpsjrpzx7m32bbiw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lectureslides")
    (synopsis "Combine single PDF files into one file")
    (description
     "This package makes it easy to combine and index individual PDF files into one
large PDF file.")
    (license license:cc-by4.0)))

(define-public texlive-leftidx
  (package
    (name "texlive-leftidx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/leftidx/" "source/latex/leftidx/"
                                     "tex/latex/leftidx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "031vrri30b0ccg44ia9i06mraamv3mr9184vmyqipcmsd2glpyla"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/leftidx")
    (synopsis "Left and right subscripts and superscripts in math mode")
    (description
     "Using this package, left and right subscripts and superscripts are
automatically raised for better fitting to the symbol they belong to.")
    (license license:lppl)))

(define-public texlive-leftindex
  (package
    (name "texlive-leftindex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/leftindex/"
                                     "tex/latex/leftindex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "034a5jgb220g7xc45ls62x725195ac3k1y7ix0fs8sqh8a2xmxl0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/leftindex")
    (synopsis "Left indices with better spacing")
    (description
     "This package provides commands for typesetting left indices.  Unlike other
similar packages, @code{leftindex} also indents the left superscript,
providing much better spacing in general.")
    (license license:lppl1.3c)))

(define-public texlive-leipzig
  (package
    (name "texlive-leipzig")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/leipzig/" "makeindex/leipzig/"
                                     "source/latex/leipzig/" "tex/latex/leipzig/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1iwra0yvalprgxqk4vdbh4wr17pla94x5lnjnwg3jh8nlb1887a6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/leipzig")
    (synopsis "Typeset and index linguistic gloss abbreviations")
    (description
     "The @code{leipzig} package provides a set of macros for standard glossing
abbreviations, with options to create new ones.  They are mnemonic.  These
abbreviations can be used alone or on top of the @code{glossaries} package for
easy indexing and glossary printing.")
    (license license:lppl1.3+)))

(define-public texlive-lengthconvert
  (package
    (name "texlive-lengthconvert")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lengthconvert/"
                                     "source/latex/lengthconvert/"
                                     "tex/latex/lengthconvert/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19j6ls0jh0s8is0sizc9r3m6x715zblk3rb3cp4nwicf526vnfg3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lengthconvert")
    (synopsis "Express lengths in arbitrary units")
    (description
     "The package provides a command to convert a length to any of a large
selection of units.")
    (license license:lppl1.3+)))

(define-public texlive-lettre
  (package
    (name "texlive-lettre")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lettre/" "tex/latex/lettre/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ahcsx9ds5vw3cf9jxs277jcckhbslpcs9ahhj40ycygfrlkw4p8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lettre")
    (synopsis "Letters and faxes in French")
    (description
     "This class is for writing letters and faxes in French.")
    (license license:lppl1.3+)))

(define-public texlive-lettrine
  (package
    (name "texlive-lettrine")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lettrine/"
                                     "source/latex/lettrine/"
                                     "tex/latex/lettrine/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gg1a4z89jqcsznizksn2hcpphg37dcqdbh9fvf6a887qa8apaab"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lettrine")
    (synopsis "Typeset dropped capitals")
    (description
     "The @code{lettrine} package supports various dropped capitals styles,
typically those described in the French typographic books.  In particular, it
has facilities for the paragraph text's left edge to follow the outline of
capitals that have a regular shape (such as @samp{A} and @samp{V}).")
    (license license:lppl1.3+)))

(define-public texlive-lewis
  (package
    (name "texlive-lewis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lewis/" "tex/latex/lewis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13w585adasl0ss9mfvpnx8f55iy18748zv66x038nw2i25yrs0ly"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lewis")
    (synopsis "Draw Lewis structures")
    (description
     "The package provides rudimentary support for drawing Lewis Structures.
Support is limited to elements that support the octet rule.")
    (license license:public-domain)))

(define-public texlive-lhelp
  (package
    (name "texlive-lhelp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lhelp/" "source/latex/lhelp/"
                                     "tex/latex/lhelp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yr9mv7vihizrra37dy1d0xvrkhbkyg5fvzbhgd1lh25wgpsmi92"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lhelp")
    (synopsis "Miscellaneous helper packages")
    (description
     "This package defines macros which are useful for many documents.  It is
a large collection of simple little helpers which do not really warrant
a separate package on their own.  Included are, among other things,
definitions of common units with preceding thinspaces, framed boxes where
both width and height can be specified, starting new odd or even pages, draft
markers, notes, conditional includes, including EPS files, and versions of
enumerate and itemize which allow the horizontal and vertical spacing to be
changed.")
    (license license:gpl3+)))

(define-public texlive-libgreek
  (package
    (name "texlive-libgreek")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/libgreek/"
                                     "source/latex/libgreek/"
                                     "tex/latex/libgreek/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ma56mn0b2wh0kja3p275w94vhss3anv7djnil2gx3k7878kjpgy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/libgreek")
    (synopsis
     "Greek letters in math mode from Libertinus or Linux Libertine/Biolinum")
    (description
     "This package allows LaTeX users (especially if using traditional
@code{LaTeX/pdfLaTeX)} to set the Greek letters in math mode using the glyphs
from the Libertinus Serif or Sans font via the font support files provided by
Bob Tennent's libertinus-type1 package.  All Greek letters are defined both in
\\...up and \\...it variants.  The style (ISO, TeX, or French i.e., upright)
can be modified midway in the document.  A legacy mode uses font support from
the (obsolete) @code{libertine-legacy} package which maps to the Linux
Libertine or Biolinum fonts.  This package is for users who only want to
customize Greek letters in math mode.")
    (license license:lppl1.3c)))

(define-public texlive-limap
  (package
    (name "texlive-limap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/limap/" "source/latex/limap/"
                                     "tex/latex/limap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1v81wckm2g0c67shgwxvci6lfsfjhilwrigy22hcpmszfk1czasm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/limap")
    (synopsis
     "Typeset maps and blocks according to the Information Mapping(r) method")
    (description
     "The Information Mapping method provides a methodology for structuring and
presenting information.  It claims to be useful for readers who are more
concerned about finding the right information than reading the document as
a whole.  Thus short, highly structured, and context free pieces of
information are used.  A LaTeX style and a LaTeX class are provided.  The
style contains definitions to typeset maps and blocks according to the
Information Mapping method.  The class provides all definitions to typeset
a whole document.")
    (license license:lppl1.3c)))

(define-public texlive-linegoal
  (package
    (name "texlive-linegoal")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/linegoal/"
                                     "source/latex/linegoal/"
                                     "tex/latex/linegoal/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1aipk7y42gkibpaqicbw8myfyj94qs736m2sk3l390xidz81fmw8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/linegoal")
    (synopsis "@emph{dimen} that returns the space left on the line")
    (description
     "The @code{linegoal} package provides a macro @code{\\linegoal} to be used
with @code{\\setlength}: @samp{\\setlength<some dimen>\\linegoal} will set
@samp{<some dimen>} to the horizontal length of the remainder of the line.")
    (license license:lppl1.3+)))

(define-public texlive-linop
  (package
    (name "texlive-linop")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/linop/" "tex/latex/linop/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0w8g6xfmk2y04xzn6la96ykvv2y0lz9lib6gcnz7p8cbh24fjxa5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/linop")
    (synopsis
     "Typeset linear operators as they appear in quantum theory or linear algebra")
    (description
     "This small package aims to provide two simple commands and many options to
easily write linear operators as they appear in many-body physics, quantum
theory, and linear algebra, in any of the ways commonly in use.")
    (license license:lppl1.3+)))

(define-public texlive-lisp-on-tex
  (package
    (name "texlive-lisp-on-tex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lisp-on-tex/"
                                     "tex/latex/lisp-on-tex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07d4bw1hs3vl8yrix13cski3gzdv6sd3s32amdnca7sjjbfp9b0l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lisp-on-tex")
    (synopsis "Execute LISP code in a LaTeX document")
    (description
     "The package provides a LISP interpreter written using TeX macros; it is
provided as a LaTeX package.  The interpreter static scoping, dynamic typing,
and eager evaluation.")
    (license license:bsd-2)))

(define-public texlive-listing
  (package
    (name "texlive-listing")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/listing/" "tex/latex/listing/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0f74bff3dk9v316hznjqnlfljkbbdshqj3s8b4arvf2jipg96npd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/listing")
    (synopsis "Produce formatted program listings")
    (description
     "The @code{listing} environment is provided and is similar to figure and
table, although it is not a floating environment.  Includes support for
@code{\\caption}, @code{\\label}, @code{\\ref}, and introduces
@code{\\listoflistings}, @code{\\listingname}, @code{\\listlistingname}.  It
produces a @file{.lol} file.  It does not change
@code{\\@@makecaption} (unless the option @code{bigcaptions} is used), so
packages that change the layout of @code{\\caption} still work.")
    (license license:lppl)))

(define-public texlive-listlbls
  (package
    (name "texlive-listlbls")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/listlbls/"
                                     "source/latex/listlbls/"
                                     "tex/latex/listlbls/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hdcaf817fyz37n3ib8b425rfkiriyhn6lliprjsvq8jdv8hmdxa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/listlbls")
    (synopsis "Creates a list of all labels used throughout a document")
    (description
     "The package aims to help a LaTeX author to keep track of all defined
labels by typesetting a complete list of labels wherever the author requests it.
(Of course, the user may need to have additional LaTeX runs to get the
references right.)")
    (license license:lppl1.3+)))

(define-public texlive-listliketab
  (package
    (name "texlive-listliketab")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/listliketab/"
                                     "source/latex/listliketab/"
                                     "tex/latex/listliketab/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gmd78nnjgq8ka4x9a7zmbq9f9345lcpms9pk9dhiz9a5kwpi7ii"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/listliketab")
    (synopsis "Typeset lists as tables")
    (description
     "The @code{listliketab} package helps the user make list-like tabulars, i.e.,
a tabular that is indistinguishable from an @code{itemize} or @code{enumerate}
environment.  The advantage of using a tabular is that the user can add
additional columns to each entry in the list.")
    (license license:lppl)))

(define-public texlive-listofsymbols
  (package
    (name "texlive-listofsymbols")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/listofsymbols/"
                                     "source/latex/listofsymbols/"
                                     "tex/latex/listofsymbols/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1srbs3hfymyzxf9jz9zsvjladzkc27k7r4lb50aqypry9x2m0p04"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/listofsymbols")
    (synopsis "Create and manipulate lists of symbols")
    (description
     "Listofsymbols provides commands to automatically create a list of
symbols (also called notation or nomenclature), and to handle symbols
logically, i.e., define a macro that is expanded to the desired output and use
the macro in the text rather than hard-coding the output into the text.  This
helps to ensure consistency throughout the text, especially if there is
a chance that symbols will be changed at some stage.  The package is more or
less a combination of what the packages @code{nomencl} and @code{formula} do.
The concept of creating the list of symbols, though, is different from the way
@file{nomencl.sty} does it.")
    (license license:lppl)))

(define-public texlive-lkproof
  (package
    (name "texlive-lkproof")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lkproof/" "tex/latex/lkproof/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hlf5wgvkbi12p52dy1jh7fq9d6sw8vma1hcv9s6b9fzk03h21v4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lkproof")
    (synopsis "LK Proof figure macros")
    (description
     "The package defines a pair of commands @code{\\infer} and @code{\\deduce},
that are used in constructing LK proof diagrams.")
    (license license:gpl3+)))

(define-public texlive-lmake
  (package
    (name "texlive-lmake")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lmake/" "source/latex/lmake/"
                                     "tex/latex/lmake/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d3bn1rbnmv1ai7ciiym6z10yrpca3c7f5phsf49hbrpp3x4whpj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lmake")
    (synopsis "Process lists to do repetitive actions")
    (description
     "The package provides commands to simplify processing of sequential list-like
structures, such as making a series of similar commands from a list of names.")
    (license license:lppl1.2+)))

(define-public texlive-locality
  (package
    (name "texlive-locality")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/locality/"
                                     "source/latex/locality/"
                                     "tex/latex/locality/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q26jb8x9ik3wfv224yxdfj651pxq49qvbz45f0x0iw6vxqllx1n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/locality")
    (synopsis "Various macros for keeping things local")
    (description
     "This package provides a toolbox of macros designed to allow the LaTeX
programmer to work around some of the restrictions of the TeX grouping
mechanisms.  The present release offers a preliminary view of the package; not
all of its facilities are working optimally")
    (license license:lppl1.3+)))

(define-public texlive-logbox
  (package
    (name "texlive-logbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/logbox/" "source/latex/logbox/"
                                     "tex/latex/logbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qpywgp8nl2s43cmq8xxdm8jlcbglmvif0fp28zi4psapdr0kybi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/logbox")
    (synopsis "e-TeX @code{showbox} facilities for exploration purposes")
    (description
     "The command @code{\\logbox} does @code{\\showbox} without stopping the
compilation.  The package's main command is @code{\\viewbox*}: the box is
typeset (copied) with its dimensions, and its contents are logged in the
@file{.log} file.")
    (license license:lppl1.3+)))

(define-public texlive-logical-markup-utils
  (package
    (name "texlive-logical-markup-utils")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/logical-markup-utils/"
                                     "tex/latex/logical-markup-utils/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rklvva3gxifb5j1i0bswh0hra2rkmavk5v88pcxqp6jmzps9zpd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/logical-markup-utils")
    (synopsis "Packages for language-dependent inline quotes and dashes")
    (description
     "The bundle contains two packages: @code{quoted}, for inserting quotation
marks; and @code{onedash}, for inserting dashes.  Each package takes
a language name as an option; accepted language options are @code{american},
@code{british}, @code{german} and @code{polish}.")
    (license license:gpl3)))

(define-public texlive-logpap
  (package
    (name "texlive-logpap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/logpap/" "source/latex/logpap/"
                                     "tex/latex/logpap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jg7jp40h80bmdjwhm9pz2ipz3r4r5rz1ksnac5ssybxp6psnhkq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          ;; Do not stop build to ask about building part of the
          ;; documentation.
          (add-after 'unpack 'non-interactive-build
            (lambda _
              (substitute* "source/latex/logpap/logpap.ins"
                (("\\\\generateexampletrue") "\\generateexamplefalse")))))))
    (home-page "https://ctan.org/pkg/logpap")
    (synopsis "Generate logarithmic graph paper with LaTeX")
    (description
     "The logpap package provides four macros for drawing logarithmic-logarithmic,
logarithmic-linear, linear-logarithmic and (because it was easy to implement)
linear-linear graph paper with LaTeX.")
    (license license:lppl)))

(define-public texlive-longfbox
  (package
    (name "texlive-longfbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/longfbox/" "tex/latex/longfbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yqjn1xmn10g5rhd1prbndzxyccy3z8piab5aribzgl5kw466zyn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/longfbox")
    (synopsis
     "Draw framed boxes with standard CSS attributes able to span over
multiple pages")
    (description
     "The @code{longfbox} package provides framed boxes that can be customized
using standard CSS attributes.  It was written to support precise rendering of
Madoko documents in LaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-longfigure
  (package
    (name "texlive-longfigure")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/longfigure/"
                                     "source/latex/longfigure/"
                                     "tex/latex/longfigure/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01km3597c6anzy6psq9i502bn3cz5hdybgm4aypi6a59w4y2fp6p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/longfigure")
    (synopsis "Provides a @code{figure}-like environment that break over pages")
    (description
     "The @code{longfigure} package uses and relabels components of the well-known
@code{longtable} package to provide a @code{table}-like environment that can
display a stream of figures as a single figure that can break across pages.")
    (license license:lppl1.3+)))

(define-public texlive-longnamefilelist
  (package
    (name "texlive-longnamefilelist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/longnamefilelist/"
                                     "source/latex/longnamefilelist/"
                                     "tex/latex/longnamefilelist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05bjbn4l45ydyj2npaxki3k5kd4d2pwlbp672xg0mbh6aj1bnanr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/longnamefilelist")
    (synopsis "Tidy @code{\\listfiles} with long file names")
    (description
     "The package equips LaTeX's @code{\\listfiles} command with an optional
argument for the number of characters in the longest base filename.  This way
you get a neatly aligned file list even when it contains files whose base
names have more than 8 characters.  The package can be combined with the
@code{myfilist} package as explained in the documentation.")
    (license license:lppl1.3+)))

(define-public texlive-loops
  (package
    (name "texlive-loops")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/loops/" "tex/latex/loops/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09r744s5v87a18h51idy59slhjqqal85wh8xl9axjkwky9ar6dk7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/loops")
    (synopsis "General looping macros for use with LaTeX")
    (description
     "The package provides efficient looping macros for processing both CSV
(separated-values) and NSV/TSV (non-separated values) lists.  CSV lists which
have associated parsers may be processed with the tools of the package.")
    (license license:lppl1.3+)))

(define-public texlive-lsc
  (package
    (name "texlive-lsc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/lsc/" "doc/latex/lsc/"
                                     "tex/latex/lsc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jxxcngaqxcgm1q4z2zq88xlsa9h3ij61icqpjk0gp7w5r0qcbpm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lsc")
    (synopsis "Typesetting @acronym{LSC, Live Sequence Charts}")
    (description
     "This package is similar to the @code{msc} package in that it provides macros
for typesetting a variant of sequence diagrams, in this case the Live Sequence
Charts of Damm and Harel.  The package supports the full LSC language of the
original LSC paper, the Klose-extensions for formal verification and some of
the Harel-extensions for the Play-In/Play-Out approach.")
    (license license:lppl)))

(define-public texlive-lstaddons
  (package
    (name "texlive-lstaddons")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lstaddons/"
                                     "source/latex/lstaddons/"
                                     "tex/latex/lstaddons/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0frav8hr2xwpdpkb0qlz3sdiy3vhpln36rk58grvzqdiissa1azg"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ydoc")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ydoc))
    (home-page "https://ctan.org/pkg/lstaddons")
    (synopsis "Add-on packages for @code{listings}")
    (description
     "The bundle contains a small collection of add-on packages for the
@code{listings} package.  Current packages are: @code{lstlinebgrd}: colour the
background of some or all lines of a listing; and @code{lstautogobble}: set
the standard @code{gobble} option to the indent of the first line of the
code.")
    (license license:lppl1.3+)))

(define-public texlive-lstfiracode
  (package
    (name "texlive-lstfiracode")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lstfiracode/"
                                     "tex/latex/lstfiracode/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l2v3ir0yj3kgavijny03d10zgm273rnnn3317cnrpjjlb1gwxv1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lstfiracode")
    (synopsis "Use Fira Code font for listings")
    (description
     "The @code{lstfiracode} package defines @code{FiraCodeStyle} for the use with
the @code{listings} package.  This style contains almost all ligatures in Fira
Code family of fonts.")
    (license license:lppl1.3c)))

(define-public texlive-lt3graph
  (package
    (name "texlive-lt3graph")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lt3graph/" "tex/latex/lt3graph/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0n68mxgidr5kb5qz8mgdc3i6qk6bmirbvs6wij6b04a3b9d0fkh0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lt3graph")
    (synopsis "Provide a graph datastructure for experimental LaTeX3")
    (description
     "The package defines a graph data structure, for use in documents that are
using the experimental LaTeX 3 syntax.")
    (license license:lppl1.3+)))

(define-public texlive-lt3rawobjects
  (package
    (name "texlive-lt3rawobjects")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/lt3rawobjects/"
                                     "source/latex/lt3rawobjects/"
                                     "tex/latex/lt3rawobjects/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "027sx3v7sg8rjkkpxcsv1p7q2wgyyazrhhpnlj2pf55sdky8zjxh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lt3rawobjects")
    (synopsis "Objects and proxies in LaTeX3")
    (description
     "This package introduces a new mechanism to create objects like the well known
C structures.  The functions exported by this package are quite low level, and
many important mechanisms like member protection and name resolution aren't
already defined and should be introduced by intermediate packages.")
    (license license:gpl3+)))

(define-public texlive-ltabptch
  (package
    (name "texlive-ltabptch")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ltabptch/" "tex/latex/ltabptch/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jk16qkgvpi1jjw82gcn34p4wqry8sl5ybjv5vfhc820871fwfbl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ltabptch")
    (synopsis "Bug fix for longtable")
    (description
     "This package provides a patch for LaTeX bugs tools/3180 and tools/3480.
The patch applies to version 4.11 of @code{longtable}.")
    (license license:lppl)))

(define-public texlive-ltxguidex
  (package
    (name "texlive-ltxguidex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ltxguidex/"
                                     "tex/latex/ltxguidex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wi2v8fvp12vqrhfmbj16mgi9lph0jdf9gks6z3p0kwp0l9jn5cy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ltxguidex")
    (synopsis "Extended @code{ltxguide} class")
    (description
     "The @code{ltxguidex} document class extends @code{ltxguide} with a set of
environments and commands that make writing beautiful LaTeX documentation
easier and more natural.")
    (license license:lppl1.3c)))

(define-public texlive-ltxkeys
  (package
    (name "texlive-ltxkeys")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ltxkeys/" "tex/latex/ltxkeys/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "169hm5v3rr7nl06f3qlpf7x4cpchs69r37q0xdzvpjm184s0r03n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ltxkeys")
    (synopsis "Robust key parser for LaTeX")
    (description
     "The package provides facilities for creating and managing keys in the sense
of the @code{keyval} and @code{xkeyval} packages, but it is intended to be
more robust and faster.  Its robustness comes from its ability to preserve
braces in key values throughout parsing.  The need to preserve braces in key
values arises often in parsing keys (for example, in the @code{xwatermark}
package).  The package also provides functions for defining and managing
keys.")
    (license license:lppl)))

(define-public texlive-ltxnew
  (package
    (name "texlive-ltxnew")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ltxnew/" "source/latex/ltxnew/"
                                     "tex/latex/ltxnew/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c60x0qmjxxi3l8zbc12xv4hyj3apr9m3knjl0vsj8dyl9iyan0s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ltxnew")
    (synopsis "Simple means of creating commands")
    (description
     "The package @code{ltxnew} provides @code{\\new}, @code{\\renew} and
@code{\\provide} prefixes for checking definitions.  It is designed to work
with e-TeX distributions of LaTeX and relies on the LaTeX internal macro
@code{\\@@ifdefinable}.  Local allocation of counters, dimensions, skips,
muskips, boxes, tokens and marks are provided by the etex package.
@code{\\new} and @code{\\renew} as well as @code{\\provide} may be used for
all kind of control sequences.")
    (license license:lppl1.3+)))

(define-public texlive-ltxtools
  (package
    (name "texlive-ltxtools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ltxtools/" "tex/latex/ltxtools/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rvwdnx33k805xb72vdi6r3gw6kmw1apjiqrf0ggvi9dl2r4pfbj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ltxtools")
    (synopsis "Collection of LaTeX API macros")
    (description
     "This is a bundle of macros that the author uses in the coding of others of
his macro files.")
    (license license:lppl1.3+)))

(define-public texlive-lua-check-hyphen
  (package
    (name "texlive-lua-check-hyphen")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/lua-check-hyphen/doc/"
                                     "tex/lualatex/lua-check-hyphen/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pxqz93izg5xpzp4p923mi97jr7y2ng9mxa8fqyxdbzvl92q48ni"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lua-check-hyphen")
    (synopsis "Mark hyphenations in a document, for checking")
    (description
     "The package looks at all hyphenation breaks in the document, comparing them
against a white-list prepared by the author.  If a hyphenation break is found,
for which there is no entry in the white-list, the package flags the line
where the break starts.  The author may then either add the hyphenation to the
white-list, or adjust the document to avoid the break.")
    (license license:expat)))

(define-public texlive-lua-physical
  (package
    (name "texlive-lua-physical")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/lua-physical/"
                                     "scripts/lua-physical/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bkzlzbpa26iw78qpp00svrzndcw78kcw1zv39hwbsyk9lz2a39s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/lua-physical")
    (synopsis
     "Functions and objects for the computation of physical quantities")
    (description
     "This is a pure Lua library, which provides functions and objects for the
computation of physical quantities.  The package provides units of the SI and
the imperial system.  In order to display the numbers with measurement
uncertainties, the package is able to perform Gaussian error propagation.")
    (license license:expat)))

(define-public texlive-luatodonotes
  (package
    (name "texlive-luatodonotes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/luatodonotes/"
                                     "source/lualatex/luatodonotes/"
                                     "tex/lualatex/luatodonotes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0skkr16d6kpn811nwqifsypc14p9m0q0jza8lmmk609bq8r7qvf1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/luatodonotes")
    (synopsis "Add editing annotations in a LuaLaTeX document")
    (description
     "The package allows the user to insert comments into a document that
suggest (for example) further editing that may be needed.  The comments are
shown in the margins alongside the text; different styles for the comments may
be used; the styles are selected using package options.  The package is based
on the package @code{todonotes}, and depends heavily on Lua, so it can only be
used with LuaLaTeX.")
    (license license:lppl1.2+)))

(define-public texlive-macrolist
  (package
    (name "texlive-macrolist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/macrolist/"
                                     "source/latex/macrolist/"
                                     "tex/latex/macrolist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lirq03dnz9pf454njqc9fmq9ra0pkkyx28lx3qjz1wph9g7cayv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/macrolist")
    (synopsis "List operations for LaTeX2e")
    (description
     "This package provides a list data structure and common list functions such as
@code{\\macrolistadd}, @code{\\macrolistremove}, @code{\\macrolistforeach}, as
well as @code{\\macrolistremovelast} and @code{\\macrolistjoin}.  Unlike most
programming languages, the lists in this package are 1-indexed, meaning the
first element is numbered 1, the second element numbered 2, and so on.")
    (license license:lppl1.3+)))

(define-public texlive-macroswap
  (package
    (name "texlive-macroswap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/macroswap/"
                                     "source/latex/macroswap/"
                                     "tex/latex/macroswap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06qj68pi24rblmx16wm76p5cy791p9whmglwi384k3vikb91qjrl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/macroswap")
    (synopsis "Swap the definitions of two LaTeX macros")
    (description
     "The package provides simple utility methods to swap the meaning (token
expansion) of two macros by name.")
    (license license:lppl1.2+)))

(define-public texlive-magaz
  (package
    (name "texlive-magaz")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/magaz/" "tex/latex/magaz/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "142hclmrvja2pp7iks25mga099k9vp219m32b1b6vds5dzqnxc63"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/magaz")
    (synopsis "Magazine layout")
    (description
     "The current version does special formatting for the first line of text in
a paragraph.  The package is part of a larger body of tools which remain in
preparation.")
    ;; "This software may be freely used, transmitted, reproduced, or
    ;; modified provided that the copyright notice and this permission
    ;; is retained."
    (license (license:fsf-free "file://tex/latex/magaz/magaz.sty"))))

(define-public texlive-magicnum
  (package
    (name "texlive-magicnum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/magicnum/" "scripts/magicnum/"
                                     "source/latex/magicnum/"
                                     "tex/generic/magicnum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "004zwr1qgk1cmhrxj0qb6i4p3dilh1mzbaaif03zr4wj6bb25dq3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/magicnum")
    (synopsis "Access TeX systems' ``magic numbers''")
    (description
     "This package allows access to the various parameter values in TeX
(catcode values), e-TeX (group, if and node types, and interaction mode), and
LuaTeX (@code{pdfliteral} mode) by a hierarchical name system.")
    (license license:lppl1.3c)))

(define-public texlive-magicwatermark
  (package
    (name "texlive-magicwatermark")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/magicwatermark/"
                                     "source/latex/magicwatermark/"
                                     "tex/latex/magicwatermark/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1abi3xvy123alpgv0z7h7gyfj2ynz462vfsxpx0q5pnbv8648y3h"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ctex")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ctex))
    (home-page "https://ctan.org/pkg/magicwatermark")
    (synopsis "Flexible way to set watermarks")
    (description
     "This package can flexibly set and clear watermarks.  All watermark content is
placed inside a TikZ node in the center of the page.")
    (license license:lppl1.3c)))

(define-public texlive-mailing
  (package
    (name "texlive-mailing")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mailing/" "source/latex/mailing/"
                                     "tex/latex/mailing/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16x4s7cql6ckcfplmxx2wc52625wyg0nr0vkdyp7r2kh3j1xci1w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mailing")
    (synopsis "Macros for mail merging")
    (description
     "This package is for use when sending a large number of letters, all with the
same body text.  The package's @code{\\addressfile} command is used to specify
who the letter is to be sent to; the body of the @code{\\mailingtext} command
specifies the text of the letters, possibly using macros defined in the
@code{\\addressfile}.")
    (license license:lppl)))

(define-public texlive-mailmerge
  (package
    (name "texlive-mailmerge")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mailmerge/"
                                     "source/latex/mailmerge/"
                                     "tex/latex/mailmerge/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b2kixzf42ylyicibdzfqw0d8fwsqllfpa90xs9xxvaiz13pfiyj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mailmerge")
    (synopsis "Repeating text field substitution")
    (description
     "The package @code{mailmerge} provides an interface to produce text from
a template, where fields are replaced by actual data, as in a database.  The
package may be used to produce several letters from a template, certificates
or other such documents.  It allows access to the entry number, number of
entries and so on.")
    (license license:lppl1.2+)))

(define-public texlive-makebarcode
  (package
    (name "texlive-makebarcode")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/makebarcode/"
                                     "tex/latex/makebarcode/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02vqhf33bnmag5q08q4r2n41j04c73i40zz54wknrhhs2w6ksp20"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/makebarcode")
    (synopsis "Print various kinds 2/5 and Code 39 bar codes")
    (description
     "The package contains macros for printing various 2/5 bar codes and Code 39
bar codes.  The macros do not use fonts but create the bar codes directly
using vertical rules.  It is therefore possible to vary width to height ratio,
ratio of thin and thick bars.  The package is therefore convenient for
printing ITF bar codes as well as bar codes for identification labels for HP
storage media.")
    (license license:lppl)))

(define-public texlive-makebase
  (package
    (name "texlive-makebase")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/makebase/"
                                     "source/latex/makebase/"
                                     "tex/latex/makebase/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rqgfxfardp4z000zxfmnh231vi4wffyzsd3wfvyz9j7jd543pip"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/makebase")
    (synopsis "Typeset counters in a different base")
    (description
     "This package typesets a LaTeX counter such as page in an arbitrary base
(default 16).  It does not change font or typeface.")
    (license license:lppl1.3+)))

(define-public texlive-makebox
  (package
    (name "texlive-makebox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/makebox/" "source/latex/makebox/"
                                     "tex/latex/makebox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0n7gxbqlx88bigcrw2z8jqwaakhisdzxx2lzn0ddjnpvslhm4hl9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/makebox")
    (synopsis "Defines a @code{\\makebox*} command")
    (description
     "This package defines a @code{\\makebox*} command that does the same as
a @code{\\makebox} command, except that the width is given by a sample text
instead of an explicit length measure.")
    (license license:lppl)))

(define-public texlive-makecirc
  (package
    (name "texlive-makecirc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/metapost/makecirc/"
                                     "metapost/makecirc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17l4gd9ipbgfcpiy980dlp7zzbrsy9qfcci1ajig2l23gqa50j52"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/makecirc")
    (synopsis "MetaPost library for drawing electrical circuit diagrams")
    (description
     "MakeCirc is a MetaPost library that contains diverse symbols for use in
circuit diagrams.  MakeCirc offers a high quality tool, with a simple syntax.
MakeCirc is completely integrated with LaTeX documents and with other MetaPost
drawing/graphic.  Its output is a PostScript file.")
    (license license:lppl)))

(define-public texlive-makecookbook
  (package
    (name "texlive-makecookbook")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/makecookbook/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1abzwzsm2jh11qj2qr31bznfc344ynjrdagqayrcgifg4725fa0f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/makecookbook")
    (synopsis "Make a cookbook")
    (description
     "The @code{makecookbook} bundle contains the files needed to create a nice
quality family cookbook in a form ready to submit to most print-on-demand
companies.  Modifiable choices have been made regarding standard book features
such as trim size, margins, headers/footers, chapter heading formatting, front
matter (copyright page, table of contents, etc.) and back matter (index).
Commands and environments have been created to format the food stories and
recipes.  The user will need to: supply their own food stories and recipes(!),
and install the needed fonts.  We assume a LuaTeX compile.

Please note that no new document class or package is included here.  Rather,
we provide a modifiable preamble and a small number of other files that,
together, fully support creation of all of the internal pages of
a cookbook (i.e., everything except the cover art).")
    (license license:lppl1.3c)))

(define-public texlive-makedtx
  (package
    (name "texlive-makedtx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/support/makedtx/" "scripts/makedtx/"
                                     "source/support/makedtx/"
                                     "tex/latex/makedtx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g20p9n834b8a55rp3l4ybwxvz2w1pp27fmak2wn8zz62nmxl4lf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "makedtx.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/makedtx")
    (synopsis "Perl script to help generate @file{.dtx} and @file{.ins} files")
    (description
     "The @code{makedtx} bundle is provided to help LaTeX2e developers to write the
code and documentation in separate files, and then combine them into a single
@file{.dtx} file for distribution.  It automatically generates the character
table, and also writes the associated installation (@file{.ins}) script.")
    (license license:lppl)))

(define-public texlive-makeglos
  (package
    (name "texlive-makeglos")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/makeglos/" "tex/latex/makeglos/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10d74vw46y5ckkr2s5rpkv6cf4z1cxp8idqx4gjm6zxfr3arp2ss"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/makeglos")
    (synopsis "Include a glossary into a document")
    (description
     "The package provides the means to include a glossary into a document.  The
glossary is prepared by an external program, such as @command{xindy} or
@command{makeindex}, in the same way that an index is made.")
    (license license:gpl3+)))

(define-public texlive-makelabels
  (package
    (name "texlive-makelabels")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/makelabels/"
                                     "source/latex/makelabels/"
                                     "tex/latex/makelabels/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0aplzmyvdkyqkzwhyjcjp11dnmf2v1xm4b4qbyrvmhjbldrmzsps"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/makelabels")
    (synopsis
     "Add a @code{\\makelabels} feature to KOMA-Script letter classes and package")
    (description
     "The standard letter class @code{letter} has a label feature.  You can
activate it using @code{\\makelabels}.  While in Germany window envelopes are
common, printing labels is not common, and @code{scrlttr2} has never supported
label printing.  Using @file{makelabels.lco} does implement
a @code{\\makelabels} feature similar to the standard letter classes.
Currently there are (almost) no configuration features for
@file{makelabels.lco}.  But you may use the @code{envlab} package after
loading @file{makelabels.lco} to get various configuration features.")
    (license license:lppl1.3c)))

(define-public texlive-makerobust
  (package
    (name "texlive-makerobust")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/makerobust/"
                                     "tex/latex/makerobust/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a5360vda131jh1qvwarbqc9riwksxjrzamqkcf3a2zg1ps13w59"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/makerobust")
    (synopsis "Making a macro robust (legacy package)")
    (description
     "Heiko Oberdiek's @code{makerobust} package defined a command with name
@code{\\MakeRobustCommand} that could be used to make fragile commands robust.
The LaTeX format has, since 2015, included a command @code{\\MakeRobust} with
the same syntax and behaviour.  Also by 2019, almost all commands in LaTeX
that may be used in a moving argument are already robust.  This package is now
just a simple one-liner defining the name @code{\\MakeRobustCommand} as an
alias for @code{\\MakeRobust}.  This package should not be used in any new
documents.")
    (license license:lppl1.3c)))

(define-public texlive-mandi
  (package
    (name "texlive-mandi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mandi/" "source/latex/mandi/"
                                     "tex/latex/mandi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jzg9i4kw58b00w35f0q7ymb2pyvmhy7hkp2bbaxgbpicxxb9aqy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mandi")
    (synopsis "Macros for introductory physics and astronomy")
    (description
     "The package contains commands for students and teachers of introductory physics.
Commands for physical quantities intelligently handle SI units so the user
need not do so.  There are other features that should make LaTeX easy for
introductory physics students.")
    (license license:lppl1.3+)))

(define-public texlive-manuscript
  (package
    (name "texlive-manuscript")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/manuscript/"
                                     "source/latex/manuscript/"
                                     "tex/latex/manuscript/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1idb43b4c74mdyzypvq5izfv2jf91b33d8qhva12bd7njz3wnpg9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/manuscript")
    (synopsis "Emulate look of a document typed on a typewriter")
    (description
     "This package is designed for those who have to submit dissertations, etc., to
institutions that still maintain the typewriter is the summit of
non-professional printing.")
    (license license:lppl)))

(define-public texlive-manyind
  (package
    (name "texlive-manyind")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/manyind/" "tex/latex/manyind/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0szsdqxl962c5bsqhg9qvqx8ls5rfpxq7yp8cwlpn11rmp77jbca"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/manyind")
    (synopsis "Provides support for many indexes")
    (description
     "This package provides support for many indexes, leaving all the bookkeeping
to LaTeX and MakeIndex.  No extra programs or files are needed.  One runs
@command{latex} and @command{makeindex} as if there is just one index.  In the
main file one puts commands like @samp{\\setindex@{main@}} to steer the flow.
Some features of MakeIndex may no longer work.")
    (license license:lppl1.2+)))

(define-public texlive-marginfit
  (package
    (name "texlive-marginfit")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/marginfit/"
                                     "source/latex/marginfit/"
                                     "tex/latex/marginfit/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hw87d6f6r23f9ri9j7r51v6vbq4naycldqjach2snv19s6a2855"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/marginfit")
    (synopsis "Improved margin notes")
    (description
     "This package fixes various bugs with the margin paragraph implementation
of LaTeX.  Those bugs include margin notes that are attached to the wrong side
as well as those that stick out of the bottom of the page.  This package
provides a drop-in replacement solution.")
    (license license:lppl1.3+)))

(define-public texlive-mathexam
  (package
    (name "texlive-mathexam")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mathexam/"
                                     "source/latex/mathexam/"
                                     "tex/latex/mathexam/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jw06n6cghs3s2s0yz3w0y5zx39hx7f74qs797lfki57bic34mla"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mathexam")
    (synopsis "Package for typesetting exams")
    (description
     "The package can help you typeset exams (mostly in mathematics and related
disciplines where students are required to show their calculations followed by
one or more short answers).  It provides commands for inclusion of space for
calculations, as well as commands for automatic creation of answer spaces.  In
addition, the package will automatically create page headers and footers, and
will let you include instructions and space for students to put their name.")
    (license license:lppl)))

(define-public texlive-mathfam256
  (package
    (name "texlive-mathfam256")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mathfam256/"
                                     "tex/latex/mathfam256/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "170hjgam55xgfrmznqmqycr5iwk76s1gknfdjjg8jxqd0z8z55i9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mathfam256")
    (synopsis "Extend math family up to 256 for pLaTeX/upLaTeX/Lamed")
    (description
     "This package increases the upper limit of math symbols up to 256, using
@code{\\omath}...  primitives.  These primitives were originally introduced in
Omega and are currently available in the following formats: pLaTeX (runs on
e-pTeX), upLaTeX (runs on e-upTeX), and Lamed (runs on Aleph, successor of
Omega).")
    (license license:bsd-3)))

(define-public texlive-mathfont
  (package
    (name "texlive-mathfont")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mathfont/"
                                     "source/latex/mathfont/"
                                     "tex/latex/mathfont/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xyd3lw95qr117g1m0wl37l6ilfnl304lg7vcx840j1gd2sakkcm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mathfont")
    (synopsis "Use TrueType and OpenType fonts in math mode")
    (description
     "The @code{mathfont} package adapts unicode text fonts for math mode.  The
package allows the user to specify a default unicode font for different
classes of math symbols, and it provides tools to change the font locally for
math alphabet characters.  When typesetting with LuaTeX, @code{mathfont} adds
resizable delimiters, big operators, and a @code{MathConstants} table to text
fonts.")
    (license license:lppl1.3c)))

(define-public texlive-maybemath
  (package
    (name "texlive-maybemath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/maybemath/"
                                     "tex/latex/maybemath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07xg0kljl4pj5hx6490yxsl3i4hi1mcmy0g69jpv80zizbgx3004"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/maybemath")
    (synopsis "Make math bold or italic according to context")
    (description
     "The @code{\\maybebm} and @code{\\maybeit} macros can be used in maths
expressions to make the arguments typeset as bold or italic respectively if
the surrounding context is appropriate.  They are useful for writing user
macros for use in general contexts.  @code{\\maybebm} is especially
appropriate when section titles contain math expressions, since the title will
appear bold but the header and table of contents usually replicate the title
in normal width.  @code{\\maybeit} performs a similar role to @code{\\mathrm}
but the maths expression will be italicised if the surrounding text is.
@code{\\maybeitsubscript} is provided to shift subscripts to the left if the
expression is italicised.")
    (license license:lppl)))

(define-public texlive-mcaption
  (package
    (name "texlive-mcaption")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mcaption/"
                                     "source/latex/mcaption/"
                                     "tex/latex/mcaption/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ibg7k05mcwjkb6ln4w6nlbp9f4iybqhs7wrc1smf6f7dh14d0np"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mcaption")
    (synopsis "Put captions in the margin")
    (description
     "The @code{mcaption} package provides an @code{mcaption} environment which
puts figure or table captions in the margin.  The package works with the
standard classes and with the KOMA-Script document classes @code{scrartcl},
@code{scrreprt} and @code{scrbook}.")
    (license license:lppl)))

(define-public texlive-mceinleger
  (package
    (name "texlive-mceinleger")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mceinleger/"
                                     "tex/latex/mceinleger/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fkg8hz11nl7xfg1d4w4yxc2wf2ffry0jcv48phcxsjm50hw7wv2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mceinleger")
    (synopsis "Creating covers for music cassettes")
    (description
     "This package provides a package for creating MC-covers on your own.  It
allows the creation of simple covers as well as covers with an additional page
for more information about the cassette (e.g., table of contents).")
    (license license:gpl3+)))

(define-public texlive-mcexam
  (package
    (name "texlive-mcexam")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mcexam/" "tex/latex/mcexam/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1j16v67rq9vlyaxjc49lbl7xawas0m2l4vkfnkl47va4091dcq29"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mcexam")
    (synopsis "Create randomized multiple choice questions")
    (description
     "This LaTeX package automatically randomly permutes the order of questions as
well as the answer options in different versions of a multiple choice
exam/test.  Next to the exam versions themselves, the package also allows
printing a concept version of the exam, a key table with the correct answers
or points, and a document with solutions and explanations per exam version.
The package also allows writing an R code which processes the results of the
exam and calculates the grades.")
    (license license:lppl1.3c)))

(define-public texlive-mcite
  (package
    (name "texlive-mcite")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mcite/" "source/latex/mcite/"
                                     "tex/latex/mcite/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hr8hc5d7ha249a817rgc64jx3nh8k1assbvknd14gbbp3x8wqx7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mcite")
    (synopsis "Multiple items in a single citation")
    (description
     "The mcite package allows the user to collapse multiple citations into one, as
is customary in physics journals.  The package requires a customised BibTeX
style for its work; the documentation explains how to do that customisation.")
    (license license:gpl3+)))

(define-public texlive-mciteplus
  (package
    (name "texlive-mciteplus")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/mciteplus/"
                                     "doc/latex/mciteplus/"
                                     "tex/latex/mciteplus/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1j6dhj5rcxlx7824060yq5fixhbccz6qjns52d8v2vrs11rgw2q5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mciteplus")
    (synopsis "Enhanced multiple citations")
    (description
     "The @code{mciteplus} LaTeX package is an enhanced reimplementation of
@code{mcite} package which provides support for the grouping of multiple
citations together as is often done in physics journals.  An extensive set of
features provide for other applications such as reference sublisting.")
    (license license:lppl)))

(define-public texlive-media4svg
  (package
    (name "texlive-media4svg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/media4svg/"
                                     "tex/latex/media4svg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01a9p1c4mqvs07qn5gign7d389q856mkh9rszw26d5czxc2rb6kh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/media4svg")
    (synopsis "Multimedia inclusion for the @code{dvisvgm} backend")
    (description
     "This package implements an interface for embedding video and audio files in
@acronym{SVG, Scalable Vector Graphics} output.  SVG with embedded media is
very portable, as it is supported by all modern Web browsers across a variety
of operating systems and platforms, including portable devices.  All DVI
producing TeX engines can be used.  The @command{dvisvgm} utility converts the
intermediate DVI to SVG.  By default, media files are embedded into the SVG
output to make self-sufficient SVG files.")
    (license license:lppl)))

(define-public texlive-medstarbeamer
  (package
    (name "texlive-medstarbeamer")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/medstarbeamer/"
                                     "tex/latex/medstarbeamer/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08psazzrskzf1wspzjxfl9wlsafm0v5cjmfyn8wwmmwngzz87bwj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/medstarbeamer")
    (synopsis "Beamer document class for MedStar Health Research Institute")
    (description
     "This is a Beamer template for MedStar Health presentations.  It includes
sample presentations using both @file{.tex} files and @file{.rnw} files.  The
document class is obviously compatible with both.")
    (license license:lppl1.3+)))

(define-public texlive-meetingmins
  (package
    (name "texlive-meetingmins")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/meetingmins/"
                                     "source/latex/meetingmins/"
                                     "tex/latex/meetingmins/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x5w8iwxhf6cyl5iimrsddfi38ijgydhcg5sh5vb3spzf7dfjl64"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:phases
           ;; Build process writes files to a sub-directory.  Create it first
           ;; to prevent an error.
           #~(modify-phases %standard-phases
               (add-before 'build 'fix-build
                 (lambda _ (mkdir-p "build/samples/"))))))
    (home-page "https://ctan.org/pkg/meetingmins")
    (synopsis "Format written minutes of meetings")
    (description
     "The class allows formatting of meeting minutes using @code{\\section}
commands (which provide hierarchical structure).  An agenda can also
be produced for distribution prior to the meeting, with user-selected
portions suppressed from printing.")
    (license license:lppl1.3+)))

(define-public texlive-memexsupp
  (package
    (name "texlive-memexsupp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/memexsupp/"
                                     "tex/latex/memexsupp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ckgin457bskn3iih0fzyy2jnh7w4xyyx7nspcpk2bc6ncslmbpj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/memexsupp")
    (synopsis "Experimental @code{memoir} support")
    (description
     "This package provides a package of code proposed as supporting material for
@code{memoir}.  The package is intended as a test bed for such code, which may
in the fullness of time be adopted into the main @code{memoir} release.")
    (license license:lppl)))

(define-public texlive-memory
  (package
    (name "texlive-memory")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/memory/" "source/latex/memory/"
                                     "tex/latex/memory/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04rkyi3kb90hcbhy124yw2akzsy5ws36bh2pva0zxncq62l60lj4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/memory")
    (synopsis "Containers for data in LaTeX")
    (description
     "The package allows the user to declare single object or array containers.")
    (license license:lppl1.3+)))

(define-public texlive-mensa-tex
  (package
    (name "texlive-mensa-tex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mensa-tex/"
                                     "tex/latex/mensa-tex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09g0dafp3xfsndvff9mrapsy35zg9jax04jwwslyd7rvh2cl37fg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mensa-tex")
    (synopsis "Typeset simple school cafeteria menus")
    (description
     "This package provides a flexible LaTeX2e class for typesetting school
cafeteria menus consisting of two lunches (with dessert), and dinner.  It
supports two different layouts.  The first layout is optimized for printing
the menu on A4 paper.  The second layout is optimized for smartphone screens
and uses one (A6 sized) page per day.  Supported localizations are
English (GB/US) and German.")
    (license license:lppl1.3c)))

(define-public texlive-menu
  (package
    (name "texlive-menu")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/menu/" "source/latex/menu/"
                                     "tex/latex/menu/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qlwrkqnj59s9c5qqp65xagv834wh6ak4aafc7hk97m29jyndygr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/menu")
    (synopsis "Typesetting menus")
    (description
     "The package defines command @code{\\menu} which assists typesetting of a path
through a program's menu.")
    (license license:lppl)))

(define-public texlive-menucard
  (package
    (name "texlive-menucard")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/menucard/"
                                     "source/latex/menucard/"
                                     "tex/latex/menucard/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01n1n4yamx6z1bs2drqqr7sjbarans1llqlkyaisxcrbv9hn47sa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/menucard")
    (synopsis "Typesetting menu cards with LaTeX")
    (description
     "This LaTeX package can be used for typesetting simple restaurant menus.")
    (license license:lppl1.3+)))

(define-public texlive-menukeys
  (package
    (name "texlive-menukeys")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/menukeys/"
                                     "source/latex/menukeys/"
                                     "tex/latex/menukeys/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cscn6mafm08459amgacy2awa5disqjlr0nbg0zwb0wfkgk5iqln"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/menukeys")
    (synopsis "Format menu sequences, paths and keystrokes from lists")
    (description
     "This package is designed to format menu sequences, paths and keyboard
shortcuts automatically.  There are several predefined styles and one can
define one's own styles in a flexible way.")
    (license license:lppl1.3c)))

(define-public texlive-metalogox
  (package
    (name "texlive-metalogox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/metalogox/"
                                     "source/latex/metalogox/"
                                     "tex/latex/metalogox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xqc6r6ii2dwz8sc3xrg40xqcpb01zp0337n2ixmmpnnp2khiw90"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/metalogox")
    (synopsis "Adjust TeX logos, with font detection")
    (description
     "This package extends the @code{metalogo} package to automatically adjust the
appearance of the logos TeX, LaTeX, LaTeX2e, XeLaTeX, and LuaLaTeX, depending
on the font detected or the option given to @code{metalogox}.")
    (license license:lppl1.3+)))

(define-public texlive-metanorma
  (package
    (name "texlive-metanorma")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/metanorma/"
                                     "tex/latex/metanorma/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b0f2sz7229q3nkv8ch1b72ima32jjh3ji5i4j3fwrsa0ck8gjw6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/metanorma")
    (synopsis "Write Metanorma standardization documents using LaTeX")
    (description
     "This work includes a LaTeX document class, a LaTeXML script and
a @code{latexmlpost} stylesheet which allow you to write a LaTeX document and
transcode it into Metanorma's ADOC format.")
    (license license:expat)))

(define-public texlive-metastr
  (package
    (name "texlive-metastr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/metastr/" "source/latex/metastr/"
                                     "tex/latex/metastr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ljsprddbdfqp9iy6dahlf8nym7x66l2yjx4x3yhdqx0ir8562jl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/metastr")
    (synopsis "Store and compose strings")
    (description
     "This is a package to store and compose strings in a structured way.
This can serve various purposes, for example: manage and write document
metadata; use templates for formatting document data; assist in assembling and
displaying document license information; facilitate basic internationalisation
and localisation.")
    (license license:lppl1.3+)))

(define-public texlive-method
  (package
    (name "texlive-method")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/method/" "source/latex/method/"
                                     "tex/latex/method/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0x8lqdj245jpkqywjwql34l0qvhvbx38qk02kcf03icdy1szfdlr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/method")
    (synopsis "Typeset method and variable declarations")
    (description
     "The package supports typesetting of programming language method and variable
declarations.  It supports declarations in German, French and English.")
    (license license:lppl)))

(define-public texlive-metre
  (package
    (name "texlive-metre")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/metre/" "source/latex/metre/"
                                     "tex/latex/metre/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "033q7ikg7fcvfqjy8p3xhnmgr0gxvs2qgw7nmpzs1wcd8xvp2qmh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/metre")
    (synopsis "Support for the work of classicists")
    (description
     "The package provides classicists with some of the tools that are needed for
typesetting scholarly publications dealing with Greek and Latin texts, with
special emphasis on Greek verse.  As the package's name suggests, its core is
a comprehensive set of commands for generating metrical schemes and for
placing prosodical marks on text set in the Latin or the Greek alphabet.  The
rest of the package provides a miscellany of commands for symbols (most of
them not directly related to metre) that are often used in critical editions
of classical texts.")
    (license license:lppl)))

(define-public texlive-mftinc
  (package
    (name "texlive-mftinc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mftinc/" "source/latex/mftinc/"
                                     "tex/latex/mftinc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kixm45whs2160yg8kw0anyvhrklwr342zdqhxkdpvqb5qp957mr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mftinc")
    (synopsis "Pretty-print Metafont source")
    (description
     "The @code{mft} program pretty-prints Metafont source code into a TeX file.
The @code{mftinc} package facilitates incorporating such files into a LaTeX2e
document.  In addition, @code{mftinc} provides routines for improved comment
formatting and for typesetting font tables.")
    (license license:lppl)))

(define-public texlive-mi-solns
  (package
    (name "texlive-mi-solns")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mi-solns/"
                                     "source/latex/mi-solns/"
                                     "tex/latex/mi-solns/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1s8p7cibai4mc0pw9cqz87v3frq556wjh3kvvrxqs216s6wg9n53"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mi-solns")
    (synopsis "Extract solutions from exercises and quizzes")
    (description
     "This package is designed to mark a solution environment of an exercise or
quiz and insert it into the same or a different document.  Solutions are ones
created by either the @code{exerquiz} or @code{eqexam} package.")
    (license license:lppl1.2+)))

(define-public texlive-midpage
  (package
    (name "texlive-midpage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/midpage/" "tex/latex/midpage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ky1p8y4vc30p6395yw820qw6i3rs0fhjrylf0szfbd969qk50yv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/midpage")
    (synopsis "Environment for vertical centering")
    (description
     "The environment will center text, if immediately preceded and followed by
@code{\\clearpage}.")
    (license license:lppl)))

(define-public texlive-mindflow
  (package
    (name "texlive-mindflow")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mindflow/"
                                     "source/latex/mindflow/"
                                     "tex/latex/mindflow/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1js0w4xgw7485c78cdakckg7jkl9q86m17xw2iqzq21ip97pr03q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mindflow")
    (synopsis "Write your ideas in a clear way")
    (description
     "This package provides an environment that has its own line numbers or markers
and can be well distinguished from the main text, for writing your ideas or
annotations.")
    (license license:lppl1.3c)))

(define-public texlive-minibox
  (package
    (name "texlive-minibox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/minibox/" "source/latex/minibox/"
                                     "tex/latex/minibox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0z53r59771rdkbqxyjxn37r2ra67kw0ir0fnggmza90h3vidq5yg"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-filecontents")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs (list texlive-filecontents))
    (home-page "https://ctan.org/pkg/minibox")
    (synopsis "Simple type of box for LaTeX")
    (description
     "This small package provides a convenient input syntax for boxes that don't
break their text over lines automatically, but do allow manual line breaks.
The boxes shrink to the natural width of the longest line they contain.")
    (license license:lppl)))

(define-public texlive-minidocument
  (package
    (name "texlive-minidocument")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/minidocument/"
                                     "source/latex/minidocument/"
                                     "tex/latex/minidocument/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04nz6c7prm2icbkcjzxxd53wqaqxbc52damnny13b1jlcj7c9kn9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/minidocument")
    (synopsis "Creates miniature documents inside other LaTeX documents")
    (description
     "This package can be used to create miniature documents inside other LaTeX
documents.  Inside the minidocument all features of the outer vertical mode like
page breaking, floats, marginpars, etc., are available.")
    (license license:lppl1.3+)))

(define-public texlive-minifp
  (package
    (name "texlive-minifp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/minifp/"
                                     "source/generic/minifp/"
                                     "tex/generic/minifp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kan8c7v4y7b56wxxap64x13a22dl04xq4w5aaq9lyd1v55d4cyh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/minifp")
    (synopsis "Fixed-point real computations to 8 decimals")
    (description
     "The package provides basic arithmetic operations to 8 decimal places for
plain TeX or LaTeX.  Results are exact when they fit within the digit limits.
Along with the basic package is an optional extension that adds computation of
sin, cos, log, sqrt, exp, powers and angles.  These are also exact when
theoretically possible and are otherwise accurate to at least 7 decimal
places.  In addition, the package provides a stack-based programming
environment.")
    (license license:lppl1.3+)))

(define-public texlive-minipage-marginpar
  (package
    (name "texlive-minipage-marginpar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/minipage-marginpar/"
                                     "source/latex/minipage-marginpar/"
                                     "tex/latex/minipage-marginpar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0k6ygpbb8ym45z7r4zk6wbywaamxk5kclk01i7pryg9wk1j6kwwi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/minipage-marginpar")
    (synopsis "Minipages with marginal notes")
    (description
     "This package allows @code{\\marginpar}-commands inside of minipages and other
boxes.  The package defines an environment @code{minipagewithmarginpars} (to
be used like minipage) --- and the internal commands may be used by other
packages to define similar environments or commands.")
    (license license:lppl)))

(define-public texlive-minorrevision
  (package
    (name "texlive-minorrevision")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/minorrevision/"
                                     "tex/latex/minorrevision/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ijamqhl709877z3rcfbvcsgjsw611ag7swx1brk2rgzz4llyjqj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/minorrevision")
    (synopsis "Quote and refer to a manuscript for minor revisions")
    (description
     "The package supports those who publish articles in peer-reviewed journals.
In the final stages of the review process, the authors typically have to
provide an additional document (such as a letter to the editors), in which
they provide a list of modifications that they made to the manuscript.  The
package automatically provides line numbers and quotations from the
manuscript, for this letter.")
    (license license:lppl1.2+)))

(define-public texlive-minutes
  (package
    (name "texlive-minutes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/minutes/" "source/latex/minutes/"
                                     "tex/latex/minutes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ln6lxw8sf9wyqii7v8w7cjw7byhkasyvmwivkwszwqjn054431b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/minutes")
    (synopsis "Typeset the minutes of meetings")
    (description
     "This package supports the creation of a collection of minutes.  Its features
include:

@itemize

@item support of tasks (who, schedule, what, time of finishing; possibility of
creating a list of open tasks; inclusion of open tasks from other minutes);

@item support for attachments;

@item support of schedule dates (in planning: support for the @code{calendar}
package);

@item different versions, such as secret parts;

@item macros for votes and decisions (list of decisions).

@end itemize

Support for minutes in German, Dutch and English is provided.")
    (license license:lppl)))

(define-public texlive-mla-paper
  (package
    (name "texlive-mla-paper")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mla-paper/"
                                     "tex/latex/mla-paper/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0i8phimwfdg29njkvnk8p7rcybqsfxv5d90sfpbba990h4knz95y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mla-paper")
    (synopsis "Proper MLA formatting")
    (description
     "The package formats articles using the @acronym{MLA, Modern Language
Association} style.  The aim is that students and other academics in the
humanities should be able to typeset their materials, properly, with minimal
effort on their part.")
    (license license:lppl)))

(define-public texlive-mleftright
  (package
    (name "texlive-mleftright")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mleftright/"
                                     "source/latex/mleftright/"
                                     "tex/generic/mleftright/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17rx9kndll8iwbkh07swjv5dn78wm74hd2qiga3gc7xbq9zmiczs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mleftright")
    (synopsis "Variants of delimiters that act as maths open/close")
    (description
     "The package defines variants @code{\\mleft} and @code{\\mright} of
@code{\\left} and @code{\\right}, that make the delimiters act as
@code{\\mathopen} and @code{\\mathclose}.  These commands address spacing
difficulties in sub-formulas.")
    (license license:lppl1.3+)))

(define-public texlive-mlist
  (package
    (name "texlive-mlist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mlist/" "source/latex/mlist/"
                                     "tex/latex/mlist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r5pi557f75k4z3f4dfs52hid98g2ly5nqgg8jpya0qrxcfgj1mp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mlist")
    (synopsis "Logical markup for lists")
    (description
     "The package defines commands that create macros for typesetting vectors,
matrices and functions, in a logical way.  For example, logical indexing can
then be used to refer to elements or arguments without hard-coding the symbols
in the document.")
    (license license:lppl)))

(define-public texlive-mmap
  (package
    (name "texlive-mmap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mmap/" "tex/latex/mmap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gzkpsgfiqkazjrcnr5bvrjs9fa220sxdq761mspvsw80aglagy5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mmap")
    (synopsis "Include CMap resources in PDF files from pdfTeX")
    (description
     "The package is an extension of @code{cmap} with improved flexibility and coverage,
including the ability to re-encode Knuth's basic mathematics fonts.")
    (license license:lppl)))

(define-public texlive-mnotes
  (package
    (name "texlive-mnotes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mnotes/" "source/latex/mnotes/"
                                     "tex/latex/mnotes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01bd57f9k0g1dp866jj66m6mrcp6483imqxp4nx05s5m6pivs2ff"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mnotes")
    (synopsis "Margin annotation for collaborative writing")
    (description
     "The package provides a flexible mechanism for annotating, and commenting upon,
collaboratively-written documents.")
    (license license:lppl1.3+)))

(define-public texlive-moderncv
  (package
    (name "texlive-moderncv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/moderncv/" "tex/latex/moderncv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0g4syan63zycw07ixy7qk1qmwb8gfwb3mpj7lg65514k80jh8nbi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-etoolbox
           texlive-fancyhdr
           texlive-graphics
           texlive-hyperref
           texlive-iftex
           texlive-l3packages
           texlive-microtype
           texlive-tools
           texlive-url
           texlive-xcolor))
    (home-page "https://ctan.org/pkg/moderncv")
    (synopsis "Modern curriculum vitae class")
    (description
     "The class provides facilities for typesetting modern curriculums vitae, both
in a classic and in a casual style.  It is fairly customizable, allowing you
to define your own style by changing the colours, the fonts, etc.")
    (license license:lppl1.3c)))

(define-public texlive-modernposter
  (package
    (name "texlive-modernposter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/modernposter/"
                                     "tex/latex/modernposter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ihkzzq141k2pw3qdyz808vsj59wx4zs7qs0qq0qwawcdv1q7bl9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/modernposter")
    (synopsis "Modern LaTeX poster theme")
    (description
     "This class extends the a0poster class in that it adds support to easily
create posters without the need for taking care of the layout at all.  It
allows using @code{\\maketitle} to generate a fancy header containing the
title information and also provides macros to position various different types
of text boxes in a two-column layout.  The color scheme is inspired by the
@code{metropolis} Beamer theme.")
    (license license:cc-by-sa4.0)))

(define-public texlive-moderntimeline
  (package
    (name "texlive-moderntimeline")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/moderntimeline/"
                                     "source/latex/moderntimeline/"
                                     "tex/latex/moderntimeline/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bn0kcgrr76slg93fp8zqlcwawk8a38galknyr6dv79lilmldx8h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/moderntimeline")
    (synopsis "Timelines for use with @code{moderncv}")
    (description
     "The package provides commands to configure and to draw time line diagrams;
such diagrams are designed to fit into Curriculum Vitae documents written
using the @code{moderncv} class.")
    (license license:lppl1.3+)))

(define-public texlive-modref
  (package
    (name "texlive-modref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/modref/" "source/latex/modref/"
                                     "tex/latex/modref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1az7lkvazjn5yqkmxi6h60yk18nm16arl5glv0bcslwhagn63lfk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/modref")
    (synopsis "Customisation of cross-references in LaTeX")
    (description
     "The package contains macros which allow authors to easily customise how
cross-references appear in their document, both in general (across all
cross-references) and for particular types of references (identified by
a prefix in the reference label), in a very generic manner.")
    (license license:lppl)))

(define-public texlive-modroman
  (package
    (name "texlive-modroman")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/modroman/"
                                     "source/latex/modroman/"
                                     "tex/latex/modroman/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sjj98a2qwwknlznrvjzpblp3kxs5l3kzw2rg09l73xn2kj91jwh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/modroman")
    (synopsis "Write numbers in lower case roman numerals")
    (description
     "This package provides only two macros: @code{\\modromannumeral} which writes
the number given as argument in lower case roman numeral with a @samp{j}
instead of a @samp{i} as the final letter of numbers greater than 1, and
@code{\\modroman}, which writes the value of a counter in the same way.

You use the first in the same way as the TeX primitive @code{\\romannumeral}
and the second as LaTeX command @code{\\roman}.  The default option is
@code{vpourv} with which @samp{5} is translated as @samp{v} and option
@samp{upourv} with which the same @samp{5} is given as @samp{u}.")
    (license license:lppl)))

(define-public texlive-modular
  (package
    (name "texlive-modular")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/modular/" "tex/latex/modular/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "050z4181br4npg413xbb7wngssyj5mvfc3nc7wwagijd0c6n7l1k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/modular")
    (synopsis "Relative section headings for modular documents")
    (description
     "LaTeX sections have absolute depth, e.g., @code{\\section},
@code{\\subsection}, etc.  When composing modular documents, we want relative
depths.  The @code{coseoul} package provides relative headings, but does not
get things right when composing a document modularly from multiple parts.
This package provides the missing piece.")
    (license license:lppl1.3+)))

(define-public texlive-monofill
  (package
    (name "texlive-monofill")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/monofill/"
                                     "source/latex/monofill/"
                                     "tex/latex/monofill/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1v6inr7q7bx7x2asyky7qx6ccrvyminr1sbb97xkxy2z064j11n7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/monofill")
    (synopsis "Alignment of plain text")
    (description
     "The package provides horizontal alignment, as in the LaTeX command
@code{\\listfiles}.  Uses may include in-text tables, or even code listings.")
    (license license:lppl1.3+)))

(define-public texlive-moodle
  (package
    (name "texlive-moodle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/moodle/" "source/latex/moodle/"
                                     "tex/latex/moodle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zi30nl5zqhz3291i2fvkra2bx5ysi9lsmkybcl9kzw63nzrnvwf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/moodle")
    (synopsis "Generating Moodle quizzes via LaTeX")
    (description
     "This package provides a package for writing Moodle quizzes in LaTeX.  In
addition to typesetting the quizzes for proofreading, the package compiles an
XML file to be uploaded to a Moodle server.")
    (license license:lppl1.3+)))

(define-public texlive-moreenum
  (package
    (name "texlive-moreenum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/moreenum/" "tex/latex/moreenum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0v0wvnshsva5z2ll9y204rxfqp334v1dxwz015y5v4kzf0wgi826"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/moreenum")
    (synopsis "More enumeration options")
    (description
     "The package provides the following new @code{enumerate} styles: @code{\\greek},
@code{\\Greek}, @code{\\enumHex}, @code{\\enumhex}, @code{\\enumbinary},
@code{\\enumoctal},, @code{\\levelnth}, @code{\\raisenth}, @code{\\Nthwords},
@code{\\NTHWORDS}, @code{\\nwords}, @code{\\Nwords}, and @code{\\NWORDS}.
Each of these works with @code{enumitem}'s starred variant feature.  So
@samp{\\begin@{enumerate@}[label=\\enumhex*]} will output a hex enumerated
list.")
    (license license:lppl1.3+)))

(define-public texlive-morehype
  (package
    (name "texlive-morehype")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/morehype/"
                                     "source/latex/morehype/"
                                     "tex/latex/morehype/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h7pp2j43b3ks78js3dcs9213piazscc44ylwjsd1vsm0yg7xscd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/morehype")
    (synopsis "Hypertext tools for use with LaTeX")
    (description
     "The bundle provides three packages:

@itemize

@item @code{texlinks}: shorthand macros for TeX-related external hyperlinks
with @code{hyperref}, the @code{blog} package in the present bundle, etc;

@item @code{hypertoc}: adjust the presentation of coloured frames in
@code{hyperref} tables of contents (@code{article} class only);

@item @code{blog}: fast generation of simple HTML by expanding LaTeX macros,
using the @code{fifinddo} package.

@end itemize")
    (license license:lppl1.3+)))

(define-public texlive-moresize
  (package
    (name "texlive-moresize")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/moresize/"
                                     "source/latex/moresize/"
                                     "tex/latex/moresize/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wa1pp7k5s8xcxjw37543jdjclnx5hzcx4gnivhsb34s9nhwcjzn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/moresize")
    (synopsis "Allows font sizes up to 35.83pt")
    (description
     "This package provides a package for using font sizes up to 35.88pt, for
example with the EC fonts.  New commands @code{\\HUGE} and @code{\\ssmall} for
selecting font sizes are provided together with some options working around
current LaTeX2e shortcomings in using big font sizes.  The package also
provides options for improving the typesetting of paragraphs (or headlines)
with embedded math expressions at font sizes above 17.28pt.")
    (license license:lppl)))

(define-public texlive-movie15
  (package
    (name "texlive-movie15")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/movie15/" "tex/latex/movie15/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1q1l099s84cnp7byh889mi322vjs8nivw7zljgffngjpzinccgbm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/movie15")
    (synopsis "Multimedia inclusion package")
    (description
     "The package provides an interface to embed movies, sounds and 3D objects into
PDF documents for use with LaTeX as well as pdfLaTeX.  The package defines
a command @code{\\includemovie} with PDF-1.5 compatibility.  Option
@code{autoplay} causes the media clip to be started right after the page has
loaded.  This is useful for side by side movie clips to be played back
synchronously.  The package is now superseded by @code{media9}.")
    (license license:lppl)))

(define-public texlive-mpostinl
  (package
    (name "texlive-mpostinl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mpostinl/"
                                     "source/latex/mpostinl/"
                                     "tex/latex/mpostinl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02micxsgrhry1ii5ih070rd014c3vxvz8mrzzd5qh2pf32zzfwa4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mpostinl")
    (synopsis "Embed MetaPost figures within LaTeX documents")
    (description
     "This LaTeX2e package enables the embedding of MetaPost figures within LaTeX
documents.  The package automatically collects the embedded definitions and
figures in a @file{.mp} file, adds an appropriate LaTeX document structure,
and compiles it to @file{.mps} files.  It also allows for various
configuration options to manage the generation of files and compilation.")
    (license license:lppl1.3+)))

(define-public texlive-msc
  (package
    (name "texlive-msc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/msc/" "tex/latex/msc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hsxvqk0nhx8zwmlzws8xl47syg993k044sbj0w22kvk3kqf0cqc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/msc")
    (synopsis "Draw MSC diagrams")
    (description
     "The package should be useful to all people that prepare their texts with
LaTeX and want to draw @acronym{MSC, Message Sequence Charts} in their texts.
The package is not an MSC editor; it simply takes a textual description of an
MSC and draws the corresponding MSC. The current version of the MSC macro
package supports the full MSC2000 language.")
    (license license:lppl1.3+)))

(define-public texlive-msg
  (package
    (name "texlive-msg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/msg/" "source/latex/msg/"
                                     "tex/latex/msg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1l6imkzdnygfsqzx75qj9j5rk2qvjgqhclvj54mai9rs6dfrcvk9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/msg")
    (synopsis "Package for LaTeX localisation")
    (description
     "The package is designed to localise any document class or package.  This
should be very useful for end-users who could obtain messages in their own
preferred language.")
    (license license:lppl)))

(define-public texlive-mslapa
  (package
    (name "texlive-mslapa")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/mslapa/" "doc/latex/mslapa/"
                                     "tex/latex/mslapa/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c3bw05gaqdwzvs40z1481gn6dr4rf71h520pplrcp1mgbxabzhv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mslapa")
    (synopsis "Michael Landy's APA citation style")
    (description
     "This package provides LaTeX and BibTeX style files for a respectably close
approximation to @acronym{APA, American Psychological Association} citation
and reference style.")
    (license license:public-domain)))

(define-public texlive-mtgreek
  (package
    (name "texlive-mtgreek")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mtgreek/" "source/latex/mtgreek/"
                                     "tex/latex/mtgreek/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c4npkwx6apdg22ivkvc16scdlr06499idax351s1jq6sdw0yzpb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mtgreek")
    (synopsis "Use italic and upright greek letters with mathtime")
    (description
     "This package is an add-on to the MathTime a style to provide TeX support for
the use of the MathTime fonts.  The MathTime package has uppercase Greek
letters hardwired to be upright and only upright; this package provides
a switch to choose between the two kinds of Greek uppercase letters.")
    (license license:lppl)))

(define-public texlive-multenum
  (package
    (name "texlive-multenum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/multenum/" "tex/latex/multenum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18nvnxs5gpaxz82kbfxc7yj8vc7vh0ki1yc0y91xchfnc88hcdhs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/multenum")
    (synopsis "Multi-column enumerated lists")
    (description
     "This package defines an environment @code{multienumerate}, that produces an
enumerated array in which columns are vertically aligned on the counter.")
    (license license:lppl1.0+)))

(define-public texlive-multiaudience
  (package
    (name "texlive-multiaudience")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/multiaudience/"
                                     "source/latex/multiaudience/"
                                     "tex/latex/multiaudience/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1j0lh7pwaqccg68x1j938c69b05x7qbj1i70ka4ywh3pi6ilqw9i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/multiaudience")
    (synopsis "Several versions of output from the same source")
    (description
     "This package allows generating several versions of the same document for
different audiences.")
    (license license:lppl1.3+)))

(define-public texlive-multibbl
  (package
    (name "texlive-multibbl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/multibbl/"
                                     "source/latex/multibbl/"
                                     "tex/latex/multibbl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06abaw5disihnjg1x5zd7y413rrqmwq10pqjw2hkn9frak2xmhaw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/multibbl")
    (synopsis "Multiple bibliographies")
    (description
     "The package @code{multibbl} redefines the standard bibliographic commands so
that one can generate multiple reference sections.  Each section has it own
auxiliary file (for use with BibTeX) and title.")
    (license license:lppl)))

(define-public texlive-multicap
  (package
    (name "texlive-multicap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/multicap/"
                                     "source/latex/multicap/"
                                     "tex/latex/multicap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hczlj5hhk3qigbq09k8b8s4sgn526lm72a99r14frblpc3177qr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    ;; "multicap.dtx" only generates documentation, not
    ;; "multicap.sty".
    (arguments (list #:build-targets #~'()))
    (home-page "https://ctan.org/pkg/multicap")
    (synopsis "Format captions inside @code{multicols}")
    (description
     "This is a package for formatting captions of column figures and column
tabular material, which cannot be standard floats in a @code{multicols}
environment.  The package also provides a convenient way to customise your
captions, whether they be in @code{multicols} or not.")
    (license license:lppl)))

(define-public texlive-multicolrule
  (package
    (name "texlive-multicolrule")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/multicolrule/"
                                     "source/latex/multicolrule/"
                                     "tex/latex/multicolrule/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l58120c9pfizsqxjhwn7jsd9mhp7b5hmwjliyjw91xb0z1agz9x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/multicolrule")
    (synopsis "Decorative rules between columns")
    (description
     "This package lets you customize the appearance of the vertical rule that
appears between columns of multicolumn text.  It is primarily intended to work
with the @code{multicol} package, hence its name, but also supports the
@code{twocolumn} option and @code{\\twocolumn} macro provided by the standard
classes (and related classes such as the KOMA-Script equivalents).")
    (license license:lppl1.3c)))

(define-public texlive-multidef
  (package
    (name "texlive-multidef")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/multidef/"
                                     "source/latex/multidef/"
                                     "tex/latex/multidef/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cicj54nkl6b4f10j3zr5n1hjakrb8nq7lah4cf4l6qy68d11ias"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/multidef")
    (synopsis "Quickly define several similar macros")
    (description
     "@code{multidef} provides a simple way of defining several macros having
similar definitions.")
    (license license:lppl1.3+)))

(define-public texlive-multienv
  (package
    (name "texlive-multienv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/multienv/"
                                     "source/latex/multienv/"
                                     "tex/latex/multienv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m3p6ql3mqipay9caif3n92687jwnrnhbvwdwa5y5ibrqqpnxi59"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ydoc")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ydoc))
    (home-page "https://ctan.org/pkg/multienv")
    (synopsis "Multiple environments using a @samp{key=value} syntax")
    (description
     "The package provides a @code{multienv} environment which permits easy
addition of multiple environments using a @samp{key=value} syntax.
Macros to define environments using this syntax are also provided.")
    (license license:lppl1.3+)))

(define-public texlive-multiexpand
  (package
    (name "texlive-multiexpand")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/multiexpand/"
                                     "source/generic/multiexpand/"
                                     "tex/generic/multiexpand/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gvdmz8sahwb1idnivn21wvl1zkaywqianl813hrxji4gvm2ifg1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/multiexpand")
    (synopsis "Variations on the primitive command @code{\\expandafter}")
    (description
     "The package provides two user commands; one that performs multiple expansions,
and one that does multiple @code{\\expandafter} operations, in a single macro
call.")
    (license license:lppl1.3c)))

(define-public texlive-multifootnote
  (package
    (name "texlive-multifootnote")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/multifootnote/"
                                     "tex/latex/multifootnote/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d4xn8ks3wdl59qyx2hlnljkxa7d5k22xlqqlrizmmlyb743inbl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/multifootnote")
    (synopsis "Multiple numbers for the same footnote")
    (description
     "This package provides several commands for generating footnotes with multiple
numbers (resp., marks).")
    (license license:lppl1.3c)))

(define-public texlive-multilang
  (package
    (name "texlive-multilang")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/multilang/"
                                     "source/latex/multilang/"
                                     "tex/latex/multilang/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ssh6c0hsdbghy56pxv8wnjlpan5f9wn5748ahwnjr8vnkrq3ixp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/multilang")
    (synopsis
     "LaTeX package for maintaining multiple translations of a document")
    (description
     "Maintaining a LaTeX document with translations for multiple languages can be
cumbersome and error-prone.  This package provides a set of macros for
defining macros and environments as wrappers around existing macros and
environments.  These wrappers allow one to clearly specify multiple
translations for the arguments to the wrapped macros and environments while
only the translation of the document's language is actually shown.  Choosing
a translation then is as simple as choosing the document's language via Babel
or Polyglossia.")
    (license license:lppl1.2+)))

(define-public texlive-multiple-choice
  (package
    (name "texlive-multiple-choice")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/multiple-choice/"
                                     "tex/latex/multiple-choice/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g99ggspnab763jil1xdapnpi6bzwdpa4f9qdxm9iy5vvwhdzc1i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/multiple-choice")
    (synopsis "LaTeX package for multiple-choice questions")
    (description
     "This package adjusts the choices of the multiple-choice question
automatically.")
    (license license:lppl1.3c)))

(define-public texlive-mversion
  (package
    (name "texlive-mversion")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mversion/"
                                     "source/latex/mversion/"
                                     "tex/latex/mversion/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04s7lhqs3hznjai9by61p4i2kycxypc8rs02zay14cl1glhwh21a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mversion")
    (synopsis "Keeping track of document versions")
    (description
     "The package enables the user to keep track of different versions of a LaTeX
document.  The command @code{\\version} prints the version and build numbers;
each time you compile your document, the build number is increased by one.  By
placing @code{\\version} in the header or footer, each page can be marked with
the unique build number describing the progress of your document.")
    (license license:lppl1.2+)))

(define-public texlive-mwe
  (package
    (name "texlive-mwe")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mwe/" "source/latex/mwe/"
                                     "tex/latex/mwe/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19ak9zq3mcz2bla9vwvlbvj8h6k64n0wpsvjbbdql51jrqa1r4dj"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ydoc")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ydoc))
    (home-page "https://ctan.org/pkg/mwe")
    (synopsis "Packages and image files for MWEs")
    (description
     "The bundle provides several files useful when creating a @acronym{MWE,
Minimal Working Example}.  The package itself loads a small set of packages
often used when creating MWEs.  In addition, a range of images are provided,
so that they may be used in any (La)TeX document.  This allows different users
to share MWEs which include image commands, without the need to share image
files or to use replacement code.")
    (license license:lppl1.3+)))

(define-public texlive-mycv
  (package
    (name "texlive-mycv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mycv/" "scripts/mycv/"
                                     "source/latex/mycv/" "tex/latex/mycv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qz2n8iqp87xnfa0w6a0hq6k2b6kzf9cbl722h5yc0msrp635nfs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mycv")
    (synopsis "List-driven CV class, allowing TikZ decorations")
    (description
     "The class provides a set of functionality for writing @acronym{CV, Curriculum
Vitae} with different layouts.  The idea is that a user can write some custom
configuration directives, by means of which is possible both to produce
different CV layouts and quickly switch among them.  In order to process such
directives, the class uses a set of lists, provided by the package
@code{etextools}.  Basic support for using TikZ decorations is also provided.")
    (license license:lppl1.3+)))

(define-public texlive-mylatex
  (package
    (name "texlive-mylatex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mylatex/" "tex/latex/mylatex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18a2mswspg6m02mx1nkbsrqh82cky6yyywbrjv423z09w95s3nks"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mylatex")
    (synopsis "Make a format containing a document's preamble")
    (description
     "The file @file{mylatex.ltx} permits you to create a format that pre-loads
a set of package files (and/or other macros) that you regularly use.")
    (license license:lppl)))

(define-public texlive-mylatexformat
  (package
    (name "texlive-mylatexformat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/mylatexformat/"
                                     "source/latex/mylatexformat/"
                                     "tex/latex/mylatexformat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kas0rgpim2dw3ym3wxslvmi8y08wmxp0ypl2zx3r4agb2fcy1jn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/mylatexformat")
    (synopsis "Build a format based on the preamble of a LaTeX file")
    (description
     "The use of formats helps to speed up compilations: packages which have been
dumped in the format are loaded at very high speed.  This is useful when
a document loads many packages.")
    (license license:lppl1.3+)))

(define-public texlive-nag
  (package
    (name "texlive-nag")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nag/" "source/latex/nag/"
                                     "tex/latex/nag/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r7b31wbd3cxixm9dqw4pkn9r9ghsdzqz2rb4mbp5va6yrmiz1sw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nag")
    (synopsis "Detecting and warning about obsolete LaTeX commands")
    (description
     "There are commands, classes and packages which are outdated and superseded.
The @code{nag} package provides routines to warn the user about the use of
such obsolete things.")
    (license license:lppl)))

(define-public texlive-nameauth
  (package
    (name "texlive-nameauth")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nameauth/"
                                     "source/latex/nameauth/"
                                     "tex/latex/nameauth/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vfs6k3vqy2zpsmk4d39138kxmhqs6dsrzj2z56rxw4f7kx76k0m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nameauth")
    (synopsis
     "Name authority mechanism for consistency in body text and index")
    (description
     "Publications, that reference many names, require editors and proofreaders to
track those names in the text and index.  The package offers name authority
macros that allow authors and compilers to normalize occurrences of names,
variant name forms, and pen names in the text and index.  This may help
minimize writing and production time and cost.")
    (license license:lppl1.3+)))

(define-public texlive-namespc
  (package
    (name "texlive-namespc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/namespc/" "source/latex/namespc/"
                                     "tex/latex/namespc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1k4j0rjfl0cy0in272k3dyiqzq5nc31zhygqckfvaw328mkkagz9"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-etoolbox texlive-hypdoc texlive-ntgclass))))
    (home-page "https://ctan.org/pkg/namespc")
    (synopsis "Rudimentary C++-like namespaces in LaTeX")
    (description
     "The @code{namespc} package adds rudimentary C++-like namespace functionality
to LaTeX.  It may be used to declare local LaTeX commands, which can be made
accessible in a later contexts without defining them globally.")
    (license license:lppl)))

(define-public texlive-ncclatex
  (package
    (name "texlive-ncclatex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ncclatex/" "tex/latex/ncclatex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10jv9da81472x33bhjqhxan4f4hzbl5pbf1p3xj0fnidd8440nk2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ncclatex")
    (synopsis "Extended general-purpose class")
    (description
     "The @code{ncc} class provides a framework for a common class to replace the
standard @code{article}, @code{book} and @code{report} classes, and providing
a @code{preprint} class.  The class's extensions are provided in a number of
small packages, some of which may also be used with the standard classes.")
    (license license:lppl)))

(define-public texlive-nestquot
  (package
    (name "texlive-nestquot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/latex/nestquot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l2glc6aykd492rspxphgscx0ykc8cakvqkm8z99jq7xxi80l1x8"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nestquot")
    (synopsis "Alternate quotes between double and single with nesting")
    (description
     "This package provides two new commands: @code{\\nlq} and @code{\\nrq} for
nesting left and right quotes that properly change between double and single
quotes according to their nesting level.")
    (license license:bsd-3)))

(define-public texlive-newcommand
  (package
    (name "texlive-newcommand")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/newcommand/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vlxm26393psl4kjfh533q03sb4klnfq84nld9ggs8l5x08dks58"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/newcommand")
    (synopsis "Generate new LaTeX command definitions")
    (description
     "Generating any other than the simple @code{\\newcommand}-style commands, in
LaTeX, is tedious.  This script allows the specification of commands in
a natural style; the script then generates macros to define the command.")
    (license license:lppl)))

(define-public texlive-newenviron
  (package
    (name "texlive-newenviron")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/newenviron/"
                                     "tex/latex/newenviron/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "193qxw4mck3sngjf1p63c65sbysji15j3hbvq0mbmg6xrjw2im7j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/newenviron")
    (synopsis "Processing an environment's body")
    (description
     "The package offers tools for collecting and executing an environment's body.")
    (license license:lppl1.3+)))

(define-public texlive-newfile
  (package
    (name "texlive-newfile")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/newfile/" "source/latex/newfile/"
                                     "tex/latex/newfile/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sqn7yylhzi6q2bvnbcvh79ljk7afqn99hjnqk3l6ys48vq2cgkc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/newfile")
    (synopsis "User level management of LaTeX input and output")
    (description
     "This package defines commands to manage the limited pool of input and output
handles provided by TeX.  The streams so provided are mapped to various of the
LaTeX input and output mechanisms.  Some facilities of the @code{verbatim}
package are also mapped.")
    (license license:lppl)))

(define-public texlive-newlfm
  (package
    (name "texlive-newlfm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/newlfm/" "source/latex/newlfm/"
                                     "tex/latex/newlfm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1psscqagy9p1gv208dwv0xd053afpaa6s3rxasv69ni6inm3wlln"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/newlfm")
    (synopsis "Write letters, facsimiles, and memos")
    (description
     "This package integrates the @code{letter} class with @code{fancyhdr} and
@code{geometry} to automatically make letterhead stationery.  It is useful for
writing letters, fax, and memos.  You can set up an address book using wrapper
macros.  You put all the information for a person into a wrapper and then put
the wrapper in a document.  The class handles letterheads automatically.  You
place the object for the letterhead (picture, information, etc.) in a box and
all sizing is set automatically.")
    (license license:gpl3+)))

(define-public texlive-newspaper
  (package
    (name "texlive-newspaper")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/newspaper/"
                                     "source/latex/newspaper/"
                                     "tex/latex/newspaper/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1naa0w3bvnj709msfq9kk6yb7b5qf1sahisjr7z8bfs1q17ml8xc"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments
     (list
      #:tex-format "pdflatex"
      #:phases
      #~(modify-phases %standard-phases
          ;; Build process requires images from "doc/"; we need to
          ;; point to them.
          (add-before 'build 'fix-build
            (lambda _
              (substitute* "source/latex/newspaper/newspaper.dtx"
                (("\\{Figure(1|2)\\}" _ n)
                 (string-append "{"
                                (getcwd) "/doc/latex/newspaper/Figure" n ".pdf"
                                "}"))))))))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-etoolbox texlive-hypdoc texlive-pdflscape))))
    (home-page "https://ctan.org/pkg/newspaper")
    (synopsis "Typeset newsletters to resemble newspapers")
    (description
     "The @code{newspaper} package redefines the page style and
@code{\\maketitle} command to produce a typeset page similar to that
of a newspaper.  It also provides several commands that (when used
with other packages) simplify the writing of articles in
a newspaper-style column format.")
    (license license:lppl)))

(define-public texlive-newvbtm
  (package
    (name "texlive-newvbtm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/newvbtm/" "source/latex/newvbtm/"
                                     "tex/latex/newvbtm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cvm24v80f40yi2mx6w33kaznlng3gj8b385f5imzd8qrgwkf3f2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/newvbtm")
    (synopsis "Define your own verbatim-like environment")
    (description
     "Defines general purpose macro named @code{\\newverbatim} to define your own
verbatim-like environment.  It also has a supplementary style file
@file{varvbtm.sty} to provide set of macros for variants of verbatim, such as
@samp{Tab} emulation.")
    (license license:lppl)))

(define-public texlive-nextpage
  (package
    (name "texlive-nextpage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/latex/nextpage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p9dvw7fqspkg6hk6rdmsb5k5m9mkj0kz5a47wg5dgfqgrqpixf8"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nextpage")
    (synopsis "Generalisations of the page advance commands")
    (description
     "This package provides @code{\\clearpage} and @code{\\newpage} variants that
guarantee to end up on even/odd numbered pages; these four commands all have
an optional argument whose content will be placed on any empty page
generated.")
    (license license:lppl)))

(define-public texlive-nfssext-cfr
  (package
    (name "texlive-nfssext-cfr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nfssext-cfr/"
                                     "tex/latex/nfssext-cfr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jbxqkcn84ldap7j6ln64763wy73z3acp52a3zjgadx9m3rfp27r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nfssext-cfr")
    (synopsis "Extensions to the LaTeX NFSS")
    (description
     "The package is a development of @file{nfssext.sty}, distributed with the
examples for the font installation guide.")
    (license license:lppl1.3+)))

(define-public texlive-nicefilelist
  (package
    (name "texlive-nicefilelist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nicefilelist/"
                                     "source/latex/nicefilelist/"
                                     "tex/latex/nicefilelist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wylqgqrwdsyqx16whksgpvm3f1d83cssz5qk7nk3k7vn3da81mn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nicefilelist")
    (synopsis "Provide @code{\\listfiles} alignment")
    (description
     "The package extends @code{longnamefilelist}, keeping separate columns for
date, version and caption.  Alignment is not disturbed by short file name
extensions, such as @file{.fd}.")
    (license license:lppl1.3c)))

(define-public texlive-niceframe
  (package
    (name "texlive-niceframe")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/niceframe/"
                                     "fonts/source/public/niceframe/"
                                     "fonts/tfm/public/niceframe/"
                                     "source/latex/niceframe/"
                                     "tex/latex/niceframe/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0an86fr2crlxxz84d325jhpccal0ilbkhscqzl6dhk91cysdzrij"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:phases
           ;; FIXME: This phase fails with "! Strange path
           ;; (turning number is zero)" error.
           #~(modify-phases %standard-phases
               (delete 'generate-font-metrics))))
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/niceframe")
    (synopsis "Support for fancy frames")
    (description
     "The package defines means of drawing frames around boxes, using dingbat fonts.
Some (Metafont) font sources are included; the fonts are available separately
in Type 1 format.")
    (license license:lppl)))

(define-public texlive-nicetext
  (package
    (name "texlive-nicetext")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nicetext/"
                                     "source/latex/nicetext/"
                                     "tex/latex/nicetext/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1si1slffnw957h6bmyvgnhivbcdz32wcj7s1r5myq7rjhq1dg9ar"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nicetext")
    (synopsis
     "Minimal markup for simple text (Wikipedia style) and documentation")
    (description
     "The bundle offers minimal markup syntax for various simple kinds of text.
The user will typically involve little more than is printed, and will still
get LaTeX quality.The bundle provides four packages:

@itemize

@item @code{wiki} addresses general texts, marked up in the simple style used
on Wikipedia;

@item @code{niceverb} is yet another means of documenting LaTeX packages: it
offers syntax-aware typesetting of meta-variables (macro arguments) and for
referring to commands (and their syntax) in footnotes, section titles etc.;

@item @code{fifinddo} aims to parse plain text or (La)TeX files using TeX, and
to write the results to an external file;

@item @code{makedoc} provides the means to produce typeset documentation
direct from package files.

@end itemize")
    (license license:lppl1.3+)))

(define-public texlive-nidanfloat
  (package
    (name "texlive-nidanfloat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nidanfloat/"
                                     "source/latex/nidanfloat/"
                                     "tex/latex/nidanfloat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18c58k4f2vq6ys7dq8b4xcl0yxvwn4maazb51fyf4mnl8cd2sl6f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nidanfloat")
    (synopsis
     "Bottom placement option for double float in two column mode (nidan-kumi)")
    (description
     "This package enables a bottom placement option for double floats in two
column mode (@emph{nidan-kumi}).")
    (license license:bsd-3)))

(define-public texlive-ninecolors
  (package
    (name "texlive-ninecolors")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ninecolors/"
                                     "tex/latex/ninecolors/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00y4csamr0nrrjmf9xjcym95a4rkg2a8dncdwgjc39il3ql0za9c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ninecolors")
    (synopsis "Select colors with proper WCAG color contrast")
    (description
     "This package carefully selects and defines 9 colors for 13 hues each.  All
colors with the same suffix number have equal luminance level.  Also the color
black is of level 0, and the color white is of level 10.  By simply choosing two
colors in the above list, which differ in level by at least 5, as foreground and
background colors, you will get proper WCAG Color Contrast.")
    (license license:lppl1.3+)))

(define-public texlive-nlctdoc
  (package
    (name "texlive-nlctdoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nlctdoc/" "tex/latex/nlctdoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "17anqqcdjlrl9c3scbjz5d5dzy2q9y5r0l0v6y490p3sdflizgak"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nlctdoc")
    (synopsis "Package documentation class")
    (description
     "The class provides support for the documentation of the author's packages,
using KOMA-Script.  This class is provided as is solely for the benefit of
anyone who wants to compile the documentation of those packages.")
    (license license:lppl)))

(define-public texlive-noconflict
  (package
    (name "texlive-noconflict")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/noconflict/"
                                     "tex/latex/noconflict/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bsn56qy21j8iqrk0cz522ad7x9sn67gfrk5xzjf6y9yhyach44p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/noconflict")
    (synopsis "Resolve macro name conflict between packages")
    (description
     "The package provides several commands to prefix (and hence obscure) a macro's
(or a sequence of macros') name, and to restore the original macro(s) at places
in a document where they are needed.")
    (license license:lppl1.3+)))

(define-public texlive-noindentafter
  (package
    (name "texlive-noindentafter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/noindentafter/"
                                     "source/latex/noindentafter/"
                                     "tex/latex/noindentafter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16kg9x8s1kk9spa91vdnkgc4v69919w4n378kyyxy33pd64cyzzx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/noindentafter")
    (synopsis "Prevent paragraph indentation after environments or macros")
    (description
     "The package, as the name suggests, supplies tools to automatically suppress
indentations in following paragraphs, specifically those following a particular
macro or environment.")
    (license license:lppl1.3c)))

(define-public texlive-noitcrul
  (package
    (name "texlive-noitcrul")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/noitcrul/"
                                     "source/latex/noitcrul/"
                                     "tex/latex/noitcrul/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c06ziixcmfmfqq23gi71vingk3f6c19ggbsj1zm5l78nyk2s48v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/noitcrul")
    (synopsis "Improved underlines in mathematics")
    (description
     "The package provides a (maths mode) @code{\\underline} variant which doesn't
impose italics correction at the end.")
    (license license:lppl)))

(define-public texlive-nolbreaks
  (package
    (name "texlive-nolbreaks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nolbreaks/"
                                     "tex/latex/nolbreaks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00hpb5zzr3v342a7vgx3cgwhzsiywqp4w8qrj3w042h0ix17q7ja"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nolbreaks")
    (synopsis "No line breaks in text")
    (description
     "Using this package, @samp{\\nolbreaks@{some text@}} to prevent line breaks in
@samp{some text}.  This has the advantage over @code{\\mbox} that glue (rubber
space) remains flexible.  Most common cases are handled
here (@code{\\linebreak} is disabled, for example) but spaces hidden in macros
or @samp{@{} and @samp{@}} can still create break-points.")
    (license license:public-domain)))

(define-public texlive-nomentbl
  (package
    (name "texlive-nomentbl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nomentbl/" "makeindex/nomentbl/"
                                     "source/latex/nomentbl/"
                                     "tex/latex/nomentbl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1q44gay0a701sn99ripip2h4p4g95p10958vkxxc3cs5hhlqv9s5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nomentbl")
    (synopsis "Nomenclature typeset in a longtable")
    (description
     "@code{nomentbl} typeset nomenclatures in a longtable instead of the
@code{makeindex} style of @code{nomencl}.  A nomenclature entry may have three
arguments: the symbol, description and physical unit.")
    (license license:lppl)))

(define-public texlive-nonfloat
  (package
    (name "texlive-nonfloat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nonfloat/"
                                     "source/latex/nonfloat/"
                                     "tex/latex/nonfloat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "085mas0as5p1bk4d2ffk01xc6fm1n52iidcdlzrw9d2s5cf8kc8y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nonfloat")
    (synopsis "Non-floating table and figure captions")
    (description
     "This package adjusts the @code{figure} and @code{table} environments to
ensure that centered objects as one line captions are centered as well.  Also
the vertical spaces for table captions above the table are changed.")
    (license license:public-domain)))

(define-public texlive-nonumonpart
  (package
    (name "texlive-nonumonpart")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nonumonpart/"
                                     "source/latex/nonumonpart/"
                                     "tex/latex/nonumonpart/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dn7y32yzzv6wy5z6v96q0cbhrdgadqj6hdcla2k7cfrnvh3lc1k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nonumonpart")
    (synopsis "Prevent page numbers on part pages")
    (description
     "The package removes page numbers on @code{\\part} pages.  The package accepts
no options and defines no user commands; the user needs only to load it, and
the requirement is met.")
    (license license:lppl1.2+)))

(define-public texlive-nopageno
  (package
    (name "texlive-nopageno")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nopageno/" "tex/latex/nopageno/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1az5hq793q20h73vay67pyxk6bhmi1xxbp7gw5nbyy7jcyq39389"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nopageno")
    (synopsis "No page numbers in LaTeX documents")
    (description
     "LaTeX's standard styles use two page styles, one on normal pages and one on
opening pages with @code{\\maketitle} or @code{\\chapter}, etc.  Unfortunately
there is only easy access to changing one of these two so if you want
something other than plain on the opening pages you must use
@code{\\thispagestyle} on each such page.  The @code{fancyhdr} package does
provide a more flexible interface, but if you just want an empty page style on
all pages then this package will do the job.")
    (license license:lppl)))

(define-public texlive-normalcolor
  (package
    (name "texlive-normalcolor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/normalcolor/"
                                     "source/latex/normalcolor/"
                                     "tex/latex/normalcolor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p8718q0jc451m812wfgkj8i7dip49hhyba73s36c7vbnmk3wmfg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/normalcolor")
    (synopsis "Changing @code{\\normalcolor}")
    (description
     "This package provides a command @code{\\setnormalcolor} with the same syntax
as the command @code{\\color}.  However, @code{\\setnormalcolor} will not
change the current colour but the normal or default color.")
    (license license:lppl1.3+)))

(define-public texlive-notes
  (package
    (name "texlive-notes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/notes/" "source/latex/notes/"
                                     "tex/latex/notes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sbkksm3zgp2fd8lzay7mszhzs6n201qzy4a652j972yzy5bs1j7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/notes")
    (synopsis "Mark sections of a document")
    (description
     "The package provides environments to highlight significant portions of text
within a document, by putting the text in a box and adding an icon in the
margin.")
    (license license:lppl)))

(define-public texlive-notespages
  (package
    (name "texlive-notespages")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/notespages/"
                                     "source/latex/notespages/"
                                     "tex/latex/notespages/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14q6rjkbnhnj7fbw3vsnnxp08qm3w9vax6s22g20qclh3q1x2ll6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          ;; Do not stop build to ask about building part of the
          ;; documentation.
          (add-after 'unpack 'non-interactive-build
            (lambda _
              (substitute* "source/latex/notespages/notespages.ins"
                (("\\\\generateexampletrue") "\\generateexamplefalse")))))))
    (home-page "https://ctan.org/pkg/notespages")
    (synopsis "Filling documents with notes pages and notes areas")
    (description
     "This package package provides one macro to insert a single notes page and
another to fill the document with multiple notes pages, until the total number
of pages (so far) is a multiple of a given number.  A third command can be
used to fill half empty pages with a notes area.")
    (license license:lppl1.3+)))

(define-public texlive-notestex
  (package
    (name "texlive-notestex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/notestex/" "tex/latex/notestex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qdgqmiq94k758h68gphir4y50pmggmd3h2jlxjw411l15fgnyvx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/notestex")
    (synopsis "All-in-one LaTeX notes package for students")
    (description
     "This is a modification of the original Jhep journal format in order to suit
the needs of students in university.  The goal of this package was to make
notetaking easier for students and offer easy support for marginnotes along
with a reliable and legible formatting structure.")
    (license license:lppl1.3+)))

(define-public texlive-notoccite
  (package
    (name "texlive-notoccite")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/notoccite/"
                                     "tex/latex/notoccite/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1l5gj5f495vmxiixnfjmkfp2wlq0gg39y6lhd3f68lf3wq3nqd99"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/notoccite")
    (synopsis "Prevent trouble from citations in table of contents, etc")
    (description
     "If you have @code{\\cite} commands in @code{\\section}-like commands, or in
@code{\\caption}, the citation will also appear in the table of contents, or
list of whatever.  If you are also using an @code{unsrt}-like bibliography
style, these citations will come at the very start of the bibliography, which
is confusing.  This package suppresses the effect.")
    (license license:public-domain)))

(define-public texlive-nowidow
  (package
    (name "texlive-nowidow")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nowidow/" "source/latex/nowidow/"
                                     "tex/latex/nowidow/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06vfrixlxv49y53hjsk8spr5k0sd533lnql684jp4yfjq9qqyyaw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nowidow")
    (synopsis "Avoid widows")
    (description "This package provides a useful macro to manage widow lines.")
    (license license:lppl1.3+)))

(define-public texlive-nox
  (package
    (name "texlive-nox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/nox/" "tex/latex/nox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bp6p9485myn5w9nn9l8mjyqm6f7j678xpc04g9q1wfc5yi7zm4p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/nox")
    (synopsis "Adaptable tables")
    (description
     "The package allows data, text (including (La)TeX commands or environments) to
be formatted into a array which may be split.")
    (license license:lppl)))

(define-public texlive-numberedblock
  (package
    (name "texlive-numberedblock")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/numberedblock/"
                                     "tex/latex/numberedblock/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "006vgcs8x00knp0a7rmnjh3fbjhwc212iy6ixi97s0awkkhmb1j6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/numberedblock")
    (synopsis "Print a block of code, with unique index number")
    (description
     "The package has been created for the convenience of the report writer; it
provides the means to number, and label, code-block snippets in your document.
In this way, you can (unambiguously) refer to each snippet elsewhere in your
document.")
    (license license:lppl1.3+)))

(define-public texlive-numname
  (package
    (name "texlive-numname")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/numname/" "tex/latex/numname/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "164v2rlz3gvfmdpi0qprgkbkz14z8nndr282g85bkggdl4fl9968"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/numname")
    (synopsis "Convert a number to its English expression")
    (description
     "The package can generate cardinal (one, two, ...) and ordinal (first, second,
...) numbers.  The code derives from the memoir class, and is extracted for
the convenience of non-users of that class.")
    (license license:lppl)))

(define-public texlive-numspell
  (package
    (name "texlive-numspell")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/numspell/" "tex/latex/numspell/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cb1xzpkassg9zdk2p22dm6f9x4hg7ij7siw1bivhqwfgkd1l617"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/numspell")
    (synopsis "Spelling cardinal and ordinal numbers")
    (description
     "This package supports the spelling of cardinal and ordinal numbers.
Supported languages are English, French, German, Hungarian, Italian, and
Latin.")
    (license license:lppl1.3+)))

(define-public texlive-ocg-p
  (package
    (name "texlive-ocg-p")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ocg-p/" "tex/latex/ocg-p/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fm3a0ipzqmk2wjc866b42imfkqc5a3zrfr6cs030m0j0g9dccjy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ocg-p")
    (synopsis "PDF OCG support in LaTeX")
    (description
     "The package provides OCG (Optional Content Groups) support within a PDF
document, replacing the @code{file.sty} distributed with Asymptote.  Nested
OCGs are supported.  The package may be used with pdfLaTeX and XeLaTeX.")
    (license license:lppl)))

(define-public texlive-ocgx
  (package
    (name "texlive-ocgx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ocgx/" "source/latex/ocgx/"
                                     "tex/latex/ocgx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19m54qp1s3gxiys4lh5dha3x2vci85i3sk0sszsbbvwf0ivsryhc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ocgx")
    (synopsis "Use OCGs within a PDF document without JavaScript")
    (description
     "The package extends the @code{ocg} package, which allows you to create
OCGs (Optional Content Groups) in PDF documents.  Every OCG includes TeX
material into a layer of the PDF file.  Each of these layers can be displayed
or not.  Links can enable or disable the display of OCGs.  The @code{ocgx}
package does not use Javascript embedded in the PDF document to enable (to
show) or disable (to hide) OCGs.")
    (license (list license:lppl license:lppl))))

(define-public texlive-ocr-latex
  (package
    (name "texlive-ocr-latex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ocr-latex/"
                                     "tex/latex/ocr-latex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sykr0xvy0fk75prq7614k302vzdpfx8qz0yvj2yx7kzk2pr5h6k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ocr-latex")
    (synopsis "LaTeX support for @code{ocr} fonts")
    (description
     "The package supports use of both @code{ocr-a} and @code{ocr-b} fonts in LaTeX
documents.")
    (license license:gpl3+)))

(define-public texlive-oldstyle
  (package
    (name "texlive-oldstyle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/oldstyle/"
                                     "source/latex/oldstyle/"
                                     "tex/latex/oldstyle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lrjr8w54m2ab9a8l1vigjdlsbg21lh0nl9kyyhpn6xgpi16ph1p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/oldstyle")
    (synopsis "Old style numbers in OT1 encoding")
    (description
     "This package provides font information needed to load the @code{cmmi} and
@code{cmmib} fonts for use to produce old-style numbers.")
    (license license:lppl)))

(define-public texlive-onlyamsmath
  (package
    (name "texlive-onlyamsmath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/onlyamsmath/"
                                     "source/latex/onlyamsmath/"
                                     "tex/latex/onlyamsmath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sl2zrd2vp9lpvjxaqa9mfff8n9m6wk39mb855k6xr2pkhdiyw7m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/onlyamsmath")
    (synopsis
     "Inhibit use of non-@code{amsmath} mathematics markup when using amsmath")
    (description
     "This package inhibits the usage of plain TeX and (on demand) of standard
LaTeX mathematics environments.  This is useful for class writers who want to
encourage their users to use the environments provided by the @code{amsmath}
package.")
    (license license:lppl)))

(define-public texlive-opcit
  (package
    (name "texlive-opcit")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/opcit/" "doc/latex/opcit/"
                                     "source/latex/opcit/" "tex/latex/opcit/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x6jjhg5z33kxkrs1fc5snvvzaiz95dgpdbzfmw81v565l84ppyc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/opcit")
    (synopsis "Footnote-style bibliographical references")
    (description
     "This package addresses the problem of expressing citations in a style that is
natural for humanities studies, yet does not interfere with the flow of
text (as author-year styles do).  The package differs from @code{footbib} in
that it uses real footnotes, potentially in the same series as any of the
document's other footnotes.  @code{opcit} also, as its name implies, avoids
repetition of full citations, achieving this, to a large extent,
automatically.")
    (license license:lppl)))

(define-public texlive-opencolor
  (package
    (name "texlive-opencolor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/opencolor/"
                                     "tex/latex/opencolor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q632lyhjbvvan92jd0w76zy78lbqr6vp17v0bbwcs68jpff65m0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/opencolor")
    (synopsis "Definitions from the Open Color library")
    (description
     "This package provides hexadecimal color definitions of the 130 colors
included in the Open Color library.")
    (license license:expat)))

(define-public texlive-optidef
  (package
    (name "texlive-optidef")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/optidef/" "tex/latex/optidef/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1k51i2r67rn2c3i4qar6smhqrrf978cyvcsiak2a6kq446yspy4x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/optidef")
    (synopsis "Environments for writing optimization problems")
    (description
     "This small library provides a standard set of environments for writing
optimization problems.  It automatically aligns the problems in three points
with an optional fourth:

@itemize

@item beginning of the words @samp{minimize/argmin} and @samp{subject to},

@item the objective function and the longest left hand side of the
constraints.

@item the @samp{$=}, @samp{|}, @samp{>}, @samp{|}, @samp{<$} signs of the
constraints.

@item optionally, the user can add manually a double align character @samp{&&}
to align some common constraints feature; a clear example could be the
constraints names, e.g., @samp{boundary constraint} alignment with
@samp{dynamic constraint}.

@end itemize

Furthermore, it provides an easy interface to define optimization problem for
three different reference situations:

@enumerate

@item where no equation is referenced/numbered;

@item where the problem is referenced with a single number;

@item where each equation has an individual reference.

@end enumerate

Finally, it also allows a definition of any optimization problem without
a limitless number of constraints.")
    (license license:lppl1.3+)))

(define-public texlive-optional
  (package
    (name "texlive-optional")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/optional/" "tex/latex/optional/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06dxidxin8jaygr1glzwlhcpxcq71kcd0g86k0r61sgiwscnr8bg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/optional")
    (synopsis "Facilitate optional printing of parts of a document")
    (description
     "@code{optional} provides simple, flexible, optional compilation of LaTeX
documents.  Option switches may be given via package options, by the
@code{\\UseOption} command, or interactively via the @code{\\AskOption}
command (help text may be provided, by defining the @code{\\ExplainOptions}
command).  The package is not robust, in the way that comment package is,
against ill-behaved text.  In particular, verbatim text may not be directly
included in optional sections (whether they're included or not).")
    (license license:lppl)))

(define-public texlive-options
  (package
    (name "texlive-options")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/options/" "tex/latex/options/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06qbmf3z0wxjgr2zrmymk271nxssvwlig6x2i283fvl2m73sw683"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/options")
    (synopsis
     "Provides convenient key-value options for LaTeX package writers")
    (description
     "The options package provides easy to use key-value options for LaTeX package
writers.  It has a similar interface as pgfkeys with path options but comes
with more built-in data types and more convenient support for families and
searching.")
    (license license:lppl1.3+)))

(define-public texlive-orcidlink
  (package
    (name "texlive-orcidlink")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/orcidlink/"
                                     "source/latex/orcidlink/"
                                     "tex/latex/orcidlink/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0r0n8g8gi8p21d5k57j6gl1vgkzcrn8qh2l0v0r8i1a9k0yllimi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/orcidlink")
    (synopsis "Insert hyperlinked ORCiD logo")
    (description
     "This package provides a command to insert the ORCiD logo, which is
hyperlinked to the URL of the researcher whose iD was specified.")
    (license license:lppl1.3c)))

(define-public texlive-orientation
  (package
    (name "texlive-orientation")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/orientation/"
                                     "tex/latex/orientation/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qb9a3wmccih89q609r45bjbl0gq95didgz9766wyzzx3sq2zbxx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/orientation")
    (synopsis "Set page orientation with Dvips/Ghostscript")
    (description
     "This package provides commands for manual (per-page and per-document)
orientation of pages in a PDF created with
dvips/Ghostscript (@command{ps2pdf}).")
    (license license:cc0)))

(define-public texlive-outline
  (package
    (name "texlive-outline")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/outline/" "tex/latex/outline/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nnv02xf0w821spaxhvv2qb54d23a5dv33js4hdil60lnn6893fw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/outline")
    (synopsis "List environment for making outlines")
    (description
     "The package defines an @code{outline} environment, which provides facilities
similar to @code{enumerate}, but up to 6 levels deep.")
    (license license:lppl)))

(define-public texlive-outliner
  (package
    (name "texlive-outliner")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/outliner/" "tex/latex/outliner/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qgvg1807vqfbcdkg74jmqjlbjc63vvfi9dhds79jzygjwm1carq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/outliner")
    (synopsis "Change section levels easily")
    (description
     "This package allows you to write @code{\\Level 2 @{Some heading@}} instead of
the usual @code{\\section} stuff; the definitions of the levels can then
easily be changed.  There is a mechanism for shifting all levels.  This makes
it easy to bundle existing articles into a compilation.")
    (license license:gpl3+)))

(define-public texlive-outlines
  (package
    (name "texlive-outlines")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/outlines/" "tex/latex/outlines/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jdsjyxsx9shl6vlm05a3lnq55a6lnfm6w4kh6ykzmn6jms9kkjd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/outlines")
    (synopsis "Produce outline lists")
    (description
     "This package defines an @code{outline} environment, which allows
outline-style indented lists with freely mixed levels up to four levels deep.
It replaces the nested @code{begin}/@code{end} pairs by different item tags
@samp{\\1} to @samp{\\4} for each nesting level.  This is very convenient in
cases where nested lists are used a lot, such as for to-do lists or
presentation slides.")
    (license license:lppl)))

(define-public texlive-outlining
  (package
    (name "texlive-outlining")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/outlining/"
                                     "source/latex/outlining/"
                                     "tex/latex/outlining/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0s4lhxiv4dzakjbd2x2z5x8bhphw5pn4d5fzrw18y42fql544b2p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/outlining")
    (synopsis "Create outlines for scientific documents")
    (description
     "Every scientifc document requires outlining before it is written.  This
package adds simple macros for your LaTeX document.")
    (license license:lppl1.3+)))

(define-public texlive-overlays
  (package
    (name "texlive-overlays")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/overlays/" "tex/latex/overlays/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15lhbpja1rjjqn15c1b0pcqzv8lhacka63m1d80jnzfj16jkmvdc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/overlays")
    (synopsis "Incremental slides")
    (description
     "This package allows writing presentations with incremental slides.  It does
not presuppose any specific document class.  Rather, it is a lightweight
alternative to full-fledged presentation classes like @code{beamer}.")
    (license license:lppl1.3c)))

(define-public texlive-padcount
  (package
    (name "texlive-padcount")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/padcount/"
                                     "source/latex/padcount/"
                                     "tex/latex/padcount/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13dk66ax3wr7vx0nkr36dnw411qc5q3d7wdm40kgm8r6a9xg0f7w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/padcount")
    (synopsis "Pad numbers with arbitrary characters")
    (description
     "This package provides some simple macros which will pad numbers (or, indeed,
any expanded token) with your choice of character (defaulting to @samp{0}) to
your choice of number of places (defaults to @samp{2}).  This works not only
on Arabic numerals, but on any expanded list of tokens passed to it.  This
makes it suitable for, among other things, counters of all kinds.")
    (license license:lppl1.3c)))

(define-public texlive-pagecont
  (package
    (name "texlive-pagecont")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pagecont/"
                                     "source/latex/pagecont/"
                                     "tex/latex/pagecont/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n2axjznak2mlajk5m9jgdxzn7n3jmaiv0hsx2mk165630h4vaax"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pagecont")
    (synopsis "Page numbering that continues between documents")
    (description
     "The package provides the facility that several documents can be typeset
independently with page numbers in sequence, as if they were a single
document.")
    (license license:lppl)))

(define-public texlive-pagegrid
  (package
    (name "texlive-pagegrid")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pagegrid/"
                                     "source/latex/pagegrid/"
                                     "tex/latex/pagegrid/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vyy27d9209r5v0n6scd8zbk7qgjx13df12qwydkrhg246khx0is"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pagegrid")
    (synopsis "Print page grid in background")
    (description
     "This package puts a grid on the paper.  It was written for developers of
a class or package who have to put elements on definite locations on
a page (e.g., @code{letter} class).  The grid allows a faster optical check,
whether the positions are correct.  If the previewer already offers features
for measuring, the package might be unnecessary.  Otherwise it saves the
developer from printing the page and measuring by hand.")
    (license license:lppl1.3+)))

(define-public texlive-pagelayout
  (package
    (name "texlive-pagelayout")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pagelayout/"
                                     "doc/man/man1/pagelayoutapi.1"
                                     "doc/man/man1/pagelayoutapi.man1.pdf"
                                     "doc/man/man1/textestvis.1"
                                     "doc/man/man1/textestvis.man1.pdf"
                                     "scripts/pagelayout/"
                                     "tex/latex/pagelayout/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rwwvr0xxwqzwrb586s6802z0h28k9vqd1fsrbphnlj03hxb6v6i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts #~(list "pagelayoutapi" "textestvis")))
    (home-page "https://ctan.org/pkg/pagelayout")
    (synopsis "Layout graphic rich documents")
    (description
     "The @code{pagelayout} class enables you to layout pages declaratively
using simple macros for pages, covers, grids, templates, text, and graphics to
create graphic rich, perfectly typeset, and print ready PDFs.  The integration
of Inkscape allows your to create box shadows.  The integration of ImageMagick
allows you to configure compression and sharpening for bitmap graphics to
export web, print or preview versions of your document.  Parallelized image
optimization, caching, and a draft mode enable fast PDF creation and
a responsive workflow, even for large documents with lots of photos and
graphics.")
    (license license:lppl1.3c)))

(define-public texlive-pagerange
  (package
    (name "texlive-pagerange")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pagerange/"
                                     "tex/latex/pagerange/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07ddakr8p8gjzyxs3b6kl000ij13y9i4pdbxay0ghddx36z7z620"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pagerange")
    (synopsis "Flexible and configurable page range typesetting")
    (description
     "The package defines a command @code{\\pagerange} that typesets ranges of page
numbers, expanding them (e.g., adding first or last page numbers) and
standardising them.")
    (license license:lppl)))

(define-public texlive-pageslts
  (package
    (name "texlive-pageslts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pageslts/"
                                     "source/latex/pageslts/"
                                     "tex/latex/pageslts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cxkmdiipcclyvrg54rv0lzqr3bllflr6f4pvaar0avw8grgrljc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pageslts")
    (synopsis "Variants of last page labels")
    (description
     "The package was designed as an extension of the @code{lastpage} package.
When more than one page numbering scheme is in operation (as in a @code{book}
class document with frontmatter), the labels above do not give the total
number of pages, so the package also provides labels @code{pagesLTS.<numbering
scheme>}, where the numbering scheme is @code{arabic}, @code{roman}, etc.")
    (license license:lppl1.3+)))

(define-public texlive-palette
  (package
    (name "texlive-palette")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/palette/" "source/latex/palette/"
                                     "tex/latex/palette/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sb4jfrp2g1nf0a9ihzcfwsfc2b7mdx3knfdzzw3m6hfkhgplv4f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/palette")
    (synopsis "Create palettes for colors and symbols that can be swapped in")
    (description
     "The package @code{palette} contains two files: @file{colorpalette.sty} and
@file{symbolpalette}.  One deals with colors and the other deals with symbols;
the implementation is quite similar.  With this package you can create themes.
Each of these themes have a set of colors, and you can create palettes based
on this theme with specific color values for each of the theme's color slots.
The active palette for each theme can be swapped in to make experimenting with
colors easier or give users choices as to which theme they pick.")
    (license license:lppl1.3+)))

(define-public texlive-pangram
  (package
    (name "texlive-pangram")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pangram/" "source/latex/pangram/"
                                     "tex/latex/pangram/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14vlhvrc2j1vz9jhj3npm0nn1qbs9b2b4dv5qm3mnvi5a34wq586"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pangram")
    (synopsis "LaTeX package for testing fonts")
    (description
     "This package provides a simple way for font designers and users to test their
fonts in different sizes without much input.")
    (license license:lppl1.3c)))

(define-public texlive-paper
  (package
    (name "texlive-paper")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/paper/" "source/latex/paper/"
                                     "tex/latex/paper/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1clhnncan253k88gxhqg2wjqp95w483skydk0f6imfz89jbpyixs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:tex-format "latex"
           ;; FIXME: I couldn't find how to re-generate package from
           ;; source.
           #:phases #~(modify-phases %standard-phases (delete 'build))))
    (home-page "https://ctan.org/pkg/paper")
    (synopsis
     "Versions of @code{article} class, tuned for scholarly publications")
    (description
     "This package provides a pair of classes derived from @code{article},
tuned for producing papers for journals.  The classes introduce new layout
options and font commands for sections and parts, and define a new keywords
environment, subtitle and institution commands for the title section and new
commands for revisions.")
    (license license:gpl3+)))

(define-public texlive-papercdcase
  (package
    (name "texlive-papercdcase")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/papercdcase/"
                                     "source/latex/papercdcase/"
                                     "tex/latex/papercdcase/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c4nyy0brcarc2pa8wi6x2z0jv281qzr74s3majlirpkk4c87421"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/papercdcase")
    (synopsis "Origami-style folding paper CD case")
    (description
     "This package implements a LaTeX style file to produce origami-style
folding paper CD cases.")
    (license license:lppl)))

(define-public texlive-papermas
  (package
    (name "texlive-papermas")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/papermas/"
                                     "source/latex/papermas/"
                                     "tex/latex/papermas/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18q43s0aw84avzjcx0w0z9rilrpcaq8wvsh6x3zhx55fjygm94xj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/papermas")
    (synopsis "Compute the mass of a printed version of a document")
    (description
     "The package computes the number of sheets of paper used by, and hence the
mass of a document.  This is useful (for example) when calculating postal
charges.")
    (license license:lppl1.3+)))

(define-public texlive-papertex
  (package
    (name "texlive-papertex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/papertex/"
                                     "source/latex/papertex/"
                                     "tex/latex/papertex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d6dps2pj03mc2g7yzwi998x0rqml2afnnh6kh2mqrl1b64l3zvd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/papertex")
    (synopsis "Class for newspapers, etc")
    (description
     "This class allows LaTeX users to create a paperTeX newspaper.  The final
document has a front page and as many inner pages as desired.  News items
appear one after another and the user can choose the number of columns, style
and so on.  The class allows users to create newsletters too.")
    (license license:lppl)))

(define-public texlive-paracol
  (package
    (name "texlive-paracol")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/paracol/" "source/latex/paracol/"
                                     "tex/latex/paracol/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qrwdbz75i32gmaqg8cmzycqgjmw9m651fqq4h582lzaqkgqwyq1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/paracol")
    (synopsis "Multiple columns with texts in parallel")
    (description
     "The package provides yet another multi-column typesetting mechanism by which
you produce multi-column (e.g., bilingual) document switching and sychronizing
each corresponding part in parallel.")
    (license license:lppl)))

(define-public texlive-parades
  (package
    (name "texlive-parades")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/parades/" "tex/latex/parades/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1s7vdypyrkvg4c17qgwy8x9d6jkjkr29cjgzg9lx2iq1zaw178zb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/parades")
    (synopsis "Tabulators and space between paragraphs in galley approach")
    (description
     "The LaTeX package @code{paravesp} controls the spaces above and below
paragraphs.  The Python script @file{parades.py} generates paragraph styles
with support of space above, space below and tabulators.  The system imposes
the galley approach on the document.")
    (license license:lppl1.3+)))

(define-public texlive-paresse
  (package
    (name "texlive-paresse")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/paresse/" "source/latex/paresse/"
                                     "tex/latex/paresse/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03rk67lc2rg5v3d3rs9kn2gvmavsjls1xywi4q78jjnak4dr2kb6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/paresse")
    (synopsis "Define simple macros for Greek letters")
    (description
     "The package defines macros using SS to type Greek letters so that the user
may type @samp{SSa} to get the effect of @code{$\\alpha$}.  However, it takes
care only of letters which have a macro name like @code{\\alpha} or
@code{\\Omega}.")
    (license license:lppl1.3c)))

(define-public texlive-parnotes
  (package
    (name "texlive-parnotes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/parnotes/" "tex/latex/parnotes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "129wgpd2bwff2g8w6ihjpz2l6n4hyl6bs12g502xd1y89a7g1f0x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/parnotes")
    (synopsis "Notes after every paragraph (or elsewhere)")
    (description
     "The package provides the @code{\\parnote} command.  The notes are set as
running paragraphs; placement is at the end of each paragraph, or manually,
using the @code{\\parnotes} command.")
    (license license:lppl1.3+)))

(define-public texlive-parsa
  (package
    (name "texlive-parsa")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/xelatex/parsa/" "tex/xelatex/parsa/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0g22q6frngl8mw1lhjzyfizw8394n0f8mnafxijyw0am40ipsvi4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/parsa")
    (synopsis
     "XeLaTeX package for theses and dissertations at Iranian universities")
    (description
     "This package provides a package for preparing dissertations and theses for
Iranian universities as fast and as efficiently as possible.")
    (license license:lppl1.3c)))

(define-public texlive-parselines
  (package
    (name "texlive-parselines")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/parselines/"
                                     "source/latex/parselines/"
                                     "tex/latex/parselines/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11gmlsw6m86wqdzfah2qgr43mxnr7cwk73fxwv8nd47pxcfb9cvj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/parselines")
    (synopsis "Apply a macro to each line of an environment")
    (description
     "The package defines an environment @code{parse lines} which processes each
line of an environment with a macro.  An example of shading the lines of an
environment is given.")
    (license license:lppl1.3+)))

(define-public texlive-pas-cours
  (package
    (name "texlive-pas-cours")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pas-cours/"
                                     "tex/latex/pas-cours/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02rqs5r345n64313h64mmszm7s8c0q8pwxaz9rjijzgs499jyzmn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pas-cours")
    (synopsis "Macros useful in preparing teaching material")
    (description
     "This package provides several groups of macros cover different branches of
mathematics.  Those are useful in preparing teaching material.")
    (license license:lppl)))

(define-public texlive-pas-cv
  (package
    (name "texlive-pas-cv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pas-cv/" "tex/latex/pas-cv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bd3i240fj90fawvcjk78r53nmdmjdcmcv85as7v13r6b1h2f6fs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pas-cv")
    (synopsis "Flexible typesetting of Curricula Vitae")
    (description
     "The package provides the framework for typesetting a Curriculum
Vitae (composed in French), together with a number of themes that may be used
with the package.  Conversion for use with other languages (than French)
should be possible.")
    (license license:lppl)))

(define-public texlive-pas-tableur
  (package
    (name "texlive-pas-tableur")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pas-tableur/"
                                     "tex/latex/pas-tableur/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wrlmvcxq9wv9ka2sywgrbmcvyx3qjlyp1miinbxlgzzr7a5y534"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pas-tableur")
    (synopsis "Create a spreadsheet layout")
    (description
     "The package provides commands for creating a grid of rectangles, and commands
for populating locations in the grid.  PGF/TikZ is used for placement and
population of the cells.")
    (license license:lppl)))

(define-public texlive-patch
  (package
    (name "texlive-patch")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "source/generic/patch/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02xfy1fs30nha0l03lqwl8xrpd81855kb5nb660ks83aj187dghy"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/patch")
    (synopsis "Patch loaded packages, etc.")
    (description
     "The package defines macros that allow patching of existing commands,
specifying those parts of the existing macro to be replaced, along with the
replacements.  Thus it provides more sophisticated manipulation than a package
like @code{patchcmd}, which only permits modification by adding commands at
the beginning or end of an existing definition.")
    (license license:lppl)))

(define-public texlive-patchcmd
  (package
    (name "texlive-patchcmd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/patchcmd/"
                                     "source/latex/patchcmd/"
                                     "tex/latex/patchcmd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14w3r2xqwq9nwhpdfmlib48xjg2wn4ns58qa4rqsslw1bbsyrl3q"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/patchcmd")
    (synopsis "Change the definition of an existing command")
    (description
     "The package provides a command @code{\\patchcommand} that can be used to add
material at the beginning and the end of the replacement text of an existing
macro.  It works for macros with any number of normal arguments, including
those that were defined with @code{\\DeclareRobustCommand}.")
    (license license:lppl)))

(define-public texlive-pauldoc
  (package
    (name "texlive-pauldoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pauldoc/" "source/latex/pauldoc/"
                                     "tex/latex/pauldoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kml8vqxxypddipf4vinhj1kxb0qxb7c8yhanx7nll08z668cdwp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pauldoc")
    (synopsis "German LaTeX package documentation")
    (description
     "The package provides helpers for German language package documentation.")
    (license license:lppl)))

(define-public texlive-pawpict
  (package
    (name "texlive-pawpict")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pawpict/" "source/latex/pawpict/"
                                     "tex/latex/pawpict/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15b9xr4ilvkwgcw19narv52ixn4w9c6q2cl2dqs3myglvaw21w4p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pawpict")
    (synopsis "Using graphics from PAW")
    (description
     "This package provides support for the easy inclusion of graphics made by
@acronym{PAW, Physics Analysis Workstation}.")
    (license license:gpl3+)))

(define-public texlive-pax
  (package
    (name "texlive-pax")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pax/" "scripts/pax/"
                                     "source/latex/pax/" "tex/latex/pax/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fnpf4rfv552ss5jw2a1k0irb503magvzlcbp2mwwpi5k3wdvkx2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts #~(list "pdfannotextractor.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/pax")
    (synopsis "Extract and reinsert PDF annotations with pdfTeX")
    (description
     "If PDF files are included using pdfTeX, PDF annotations are stripped.
The Pax project offers a solution without altering pdfTeX.  A Java program
(@file{pax.jar}) parses the PDF file that will later be included.  The program
then writes the data of the annotations into a file that can be read by TeX.
The LaTeX package @code{pax} extends the @code{graphics} package to support
the scheme: if a PDF file is included, the package looks for the file with the
annotation data, reads them and puts the annotations in the right place.")
    (license (list license:lppl license:gpl3+))))

(define-public texlive-pbalance
  (package
    (name "texlive-pbalance")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pbalance/"
                                     "source/latex/pbalance/"
                                     "tex/latex/pbalance/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r3xqdmcx3k5labiwm3swy7lp530b02yyiw3skfjc8ysy01p8rfv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pbalance")
    (synopsis "Balance last page in two-column mode")
    (description
     "This package balances the columns on the last page of a two-column document.
If the page is simple (no footnotes, floats, or marginpars), it uses the
balance package; otherwise, it uses @code{\\enlargethispage} to make the left
column shorter, balancing the columns.")
    (license license:lppl1.3c)))

(define-public texlive-pbsheet
  (package
    (name "texlive-pbsheet")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pbsheet/" "source/latex/pbsheet/"
                                     "tex/latex/pbsheet/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "126gps82j47xhw01p8w8qpcdlfffzqxan6xjizz9gdj1bhgyqk49"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pbsheet")
    (synopsis "Problem sheet class")
    (description
     "This class is designed to simplify the typesetting of problem sheets with
mathematics and computer science content.  It is currently customised towards
teaching in French (and the examples are in French).")
    (license license:lppl)))

(define-public texlive-pdf14
  (package
    (name "texlive-pdf14")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdf14/" "source/latex/pdf14/"
                                     "tex/latex/pdf14/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sha8vbj0d75a3hsx8x34r79yfm3r5x9fn0qi4zbf070x3way6ff"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdf14")
    (synopsis "Restore PDF 1.4 to a TeX live 2010 format")
    (description
     "Starting with TeX Live 2010, the various formats, that directly generate PDF,
default to generating PDF 1.5.  This is generally a good thing, but it can
lead to compatibility issues with some older PDF viewers.  This package
changes the version of PDF generated with formats (based on pdfTeX or LuaTeX
in PDF mode), back to 1.4 for documents that need to achieve maximal
compatibility with old viewers.")
    (license license:lppl1.3+)))

(define-public texlive-pdfcolmk
  (package
    (name "texlive-pdfcolmk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdfcolmk/" "tex/latex/pdfcolmk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0maapa92xjv2d9l4ra0zjn4girzyk5lnaq7asigj050a9v611wqs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfcolmk")
    (synopsis "Improved colour support under pdfTeX (legacy stub)")
    (description
     "The package used to provide macros that emulated the colour stack
functionality of Dvips.  The colour stack deals with colour manipulations when
asynchronous events (like page-breaking) occur.  For current releases of
pdfTeX, this package is not needed, since real colour stacks are available.
It has therefore become empty stub that does nothing at all, just in case
there are still documents that reference it.")
    (license license:lppl1.3c)))

(define-public texlive-pdfcomment
  (package
    (name "texlive-pdfcomment")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdfcomment/"
                                     "tex/latex/pdfcomment/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vv2lgnfnxyx7slbyg0xa4rh4j7192s4gis30zsz7rnydzq016fi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfcomment")
    (synopsis "User-friendly interface to PDF annotations")
    (description
     "For a long time pdfLaTeX has offered the command @code{\\pdfannot} for
inserting arbitrary PDF annotations.  The package offers a convenient and
user-friendly means of using @code{\\pdfannot} to provide comments in PDF
files.  It also supports LaTeX, Dvips, @command{ps2pdf}, LaTeX,
@command{dvipdfmx}, XeLaTeX and LuaLaTeX.  Unfortunately, support of PDF
annotations by PDF viewers may vary.")
    (license license:lppl1.3+)))

(define-public texlive-pdfcprot
  (package
    (name "texlive-pdfcprot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdfcprot/"
                                     "source/latex/pdfcprot/"
                                     "tex/latex/pdfcprot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12ijgxy2ki3ygi3kfzi2z6shys9wb32gra8qdmksnp5zn3rv5spf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfcprot")
    (synopsis "Activating and setting of character protruding using pdfLaTeX")
    (description
     "This package provides an easy interface to adjust the character protrusion
for different fonts and choosing the right adjustment automatically depending
on the font.  The package is largely superseded by @code{microtype}.")
    (license license:lppl)))

(define-public texlive-pdfmarginpar
  (package
    (name "texlive-pdfmarginpar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdfmarginpar/"
                                     "tex/latex/pdfmarginpar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l294kgyvjmrvnvfp3hdjb7nfcl6d02n5nmjlnzrghcj2692hy8v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfmarginpar")
    (synopsis "Generate marginpar-equivalent PDF annotations")
    (description
     "The package provides the @code{\\pdfmarginpar} command which is similar in
spirit to @code{\\marginpar}.  However, it creates PDF annotations which may
be viewed with Adobe Reader in place of marginal texts.  Small icons indicate
the in-text position where the message originates, popups provide the messages
themselves.  Thus bugfixes and other such communications are clearly visible
together when viewing the document, while the document itself is not
obscured.")
    (license license:gpl3+)))

(define-public texlive-pdfoverlay
  (package
    (name "texlive-pdfoverlay")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdfoverlay/"
                                     "source/latex/pdfoverlay/"
                                     "tex/latex/pdfoverlay/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jv6kh19vm2kflvajcridcjn14i00xmgc0wamnhxiz4ias4v72yq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfoverlay")
    (synopsis "LaTeX style for overlaying text on a PDF")
    (description
     "It is often desirable to take an existing PDF and easily add annotations or
text overlaying the PDF.  This might arise if you wish to add comments to
a PDF, fill in a PDF form, or add text to a PDF where space has been left for
notes.  This package provides a simple interface to do this without having to
resort to inserting one page at a time.  Some or all of the pages of the PDF
can be included and not all pages of the PDF need have overlayed text.  It is
also possible to include text between pages of the PDF.  Another advantage of
this package is that the overlayed text can be set as normal flowing from one
page to another or with manual page breaks if you wish.  It is also possible
to use any standard method to position text at arbitrary places on a given
page.")
    (license license:lppl1.3c)))

(define-public texlive-pdfpagediff
  (package
    (name "texlive-pdfpagediff")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdfpagediff/"
                                     "tex/latex/pdfpagediff/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02mz7qc68772ixdmnrdi7a9mrfimzfaxxjc31c01jrrx7ph4g33y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfpagediff")
    (synopsis "Find difference between two PDF")
    (description "This package finds the differences between two PDF files.")
    (license license:lppl1.0+)))

(define-public texlive-pdfpc
  (package
    (name "texlive-pdfpc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdfpc/" "tex/latex/pdfpc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hb8ppm74w1p59mmivmygiwz3nd0fazh7f32drm05zg43h5y0xmp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfpc")
    (synopsis "Define data for the @command{pdfpc} presentation viewer")
    (description
     "This package allows defining additional meta data within the PDF file which
can be interpreted by the PDF presenter console (@command{pdfpc}) program.")
    (license license:gpl3+)))

(define-public texlive-pdfpc-movie
  (package
    (name "texlive-pdfpc-movie")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdfpc-movie/"
                                     "source/latex/pdfpc-movie/"
                                     "tex/latex/pdfpc-movie/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bcr2vn4mljh4y5z75ar8lxfk4m1g5gc168dd12v55jasbghx1sm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfpc-movie")
    (synopsis "Pdfpc viewer-compatible hyperlinks to movies")
    (description
     "This LaTeX2e package provides a command @code{\\pdfpcmovie} for
embedding (hyperlinking) movies in a way compatible with the PDF Presenter
Console (@command{pdfpc}).")
    (license license:lppl1.3c)))

(define-public texlive-pdfprivacy
  (package
    (name "texlive-pdfprivacy")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdfprivacy/"
                                     "source/latex/pdfprivacy/"
                                     "tex/latex/pdfprivacy/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xs4gsgbdp5q8p32d9idq10bscnxn8whbdha1n3l6ki1dmn89g0g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfprivacy")
    (synopsis "LaTeX package to remove or suppress pdf meta-data")
    (description
     "Creating PDFs with pdfLaTeX populates several PDF meta-data fields such as
date/time of creation/modification, information about the LaTeX
installation (e.g., pdfTeX version), and the relative paths of included PDFs.
The @code{pdfprivacy} package provides support for emptying several of these
PDF meta-data fields as well as suppressing some pdfTeX meta-data entries in
the resulting PDF.")
    (license license:lppl1.3c)))

(define-public texlive-pdfreview
  (package
    (name "texlive-pdfreview")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdfreview/"
                                     "tex/latex/pdfreview/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19ybq5yqzp39z9l04sf3inp41rm9w5k6h02ig7qhc34gi9ps97bi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfreview")
    (synopsis "Annotate PDF files with margin notes")
    (description
     "This package lets you add comments in the page margins of PDF files, e.g.,
when reviewing manuscripts or grading reports.  The PDF file to be annotated
is included, one page at a time, as graphics, in a manner similar to the
@code{pdfpages} package.  Notes are placed in the margin next to the included
graphics using a grid of help lines.  Alternatively, only numbers are placed
in the page margins, and the notes are collected into a numbered list at the
end of the document.

Note that this package is not intended for adding notes directly to the LaTeX
source of the document that is being reviewed; instead, the document
undergoing review is already in PDF format and remains unchanged.  Also note
that this package does not produce the usual PDF sticky notes that must be
opened by clicking on them; instead, the notes are simply shown as text.")
    (license license:lppl)))

(define-public texlive-pdfscreen
  (package
    (name "texlive-pdfscreen")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdfscreen/"
                                     "tex/latex/pdfscreen/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0g6jydzd4zs4qpz3v53fiagca24vzn3slqd3fsw5kghx3zysq145"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfscreen")
    (synopsis "Support screen-based document design")
    (description
     "This package is an extension of the @code{hyperref} package that provides
a screen-based document design.  This package helps to generate PDF documents
that are readable on screen and will fit the screen's aspect ratio.  Also it
can be used with various options to produce regular print versions of the same
document without any extra effort.")
    (license license:lppl)))

(define-public texlive-pdfslide
  (package
    (name "texlive-pdfslide")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdfslide/" "tex/latex/pdfslide/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00h5f6acmxq4mwr91k1zcmvjv1n7rv8kk9lqy11pngqp76gf5w5n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfslide")
    (synopsis "Presentation slides using pdfTeX")
    (description
     "This is a package for use with pdfTeX, to make nice presentation slides.
Its aims are: to devise a method for easier technical presentation; to help
the mix of mathematical formulae with text and graphics which other present
day document processing tools fail to accomplish; to exploit the platform
independence of TeX so that presentation documents become portable; and to
offer the freedom and possibilities of using various backgrounds and other
embellishments that a user can imagine to have in as presentation.

The package can make use of the facilities of the PPower4 post-processor.")
    (license license:lppl)))

(define-public texlive-pdfsync
  (package
    (name "texlive-pdfsync")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdfsync/" "tex/latex/pdfsync/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0csxvx2wns2hng28s320i1wv7c73yx98jzwiich1hsqp93sss6a1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfsync")
    (synopsis "Provide links between source and PDF")
    (description
     "The package runs with pdfTeX or XeTeX, and creates an auxiliary file with
geometrical information to permit references back and forth between source and
PDF, assuming a conforming editor and PDF viewer.")
    (license license:lppl)))

(define-public texlive-pdfwin
  (package
    (name "texlive-pdfwin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pdfwin/" "tex/latex/pdfwin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hf6f3fhp5k87g1cvjr3frcl3dq9v12948lshn03q7fxl1zm36cc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pdfwin")
    (synopsis "Customizable windows for screen viewing of TeX documents")
    (description
     "This package provides customizable windows for screen viewing of TeX
documents.")
    (license license:lppl1.2+)))

(define-public texlive-pecha
  (package
    (name "texlive-pecha")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pecha/" "tex/latex/pecha/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a7j556dnc59a4r88g037ssr8ggsfvycyfcsdk2rbs8x16ljdvjh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pecha")
    (synopsis "Print Tibetan text in the classic pecha layout style")
    (description
     "The @code{pecha} class provides an environment for writing Tibetan on LaTeX2e
in the traditional Tibetan Pecha layout used for spiritual or philosophical
texts, using the cTib4TeX package.  It provides features like headers in
different languages, page numbering in Tibetan and more.")
    (license license:gpl3+)))

(define-public texlive-perltex
  (package
    (name "texlive-perltex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/perltex/"
                                     "doc/man/man1/perltex.1"
                                     "doc/man/man1/perltex.man1.pdf"
                                     "scripts/perltex/"
                                     "source/latex/perltex/"
                                     "tex/latex/perltex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1djgcpij1g63ln74n60xkm8fd43948yq6nks4854627w23yi8k19"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "perltex.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/perltex")
    (synopsis "Define LaTeX macros in terms of Perl code")
    (description
     "PerlTeX is a combination Perl script (@file{perltex.pl}) and LaTeX2e
package (@file{perltex.sty}) that, together, give the user the ability to
define LaTeX macros in terms of Perl code.  Once defined, a Perl macro becomes
indistinguishable from any other LaTeX macro.  PerlTeX thereby combines
LaTeX's typesetting power with Perl's programmability.  PerlTeX will make use
of persistent named pipes, and thereby run more efficiently.  Also provided is
a switch to generate a PerlTeX-free, document-specific, @file{noperltex.sty}
that is useful when distributing a document to places where PerlTeX is not
available.")
    (license license:lppl)))

(define-public texlive-permute
  (package
    (name "texlive-permute")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/permute/" "source/latex/permute/"
                                     "tex/latex/permute/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lrkk57w9sslj8cvjala4frpp71v28ixdkvizrmwpjcn9n0p46pv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/permute")
    (synopsis "Support for symmetric groups")
    (description
     "This package provides a package for symmetric groups, allowing you to input,
output, and calculate with them.")
    (license license:lppl)))

(define-public texlive-petiteannonce
  (package
    (name "texlive-petiteannonce")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/petiteannonce/"
                                     "tex/latex/petiteannonce/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d3ljwsbyv8idym40q1d40md74mlvgpx41ya99y89p2xfm69xffy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/petiteannonce")
    (synopsis "Class for small advertisements")
    (description
     "The class enables you to create the sort of adverts that you pin on
a noticeboard, with tear-off strips at the bottom where you can place contact
details.")
    (license license:lppl)))

(define-public texlive-pgfmath-xfp
  (package
    (name "texlive-pgfmath-xfp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pgfmath-xfp/"
                                     "source/latex/pgfmath-xfp/"
                                     "tex/latex/pgfmath-xfp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ss8wfqj5bmngzpcp0nfw6zm331bnjqa9x0ddfl1hf6i6j6c27b2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pgfmath-xfp")
    (synopsis "Define pgfmath functions using @code{xfp}")
    (description
     "This package allows defining @code{pgfmath} functions that use the
@code{xfp} FPU for their calculations.  The input arguments are parsed with
@code{pgfmath}, and the results are forwarded to the FPU for the function
evaluation.  The result of that calculation is then parsed by @code{pgfmath}
again.  This way the functions should be usable in every @code{pgfmath}
context, though there is some overhead to this approach.")
    (license license:lppl1.3c)))

(define-public texlive-phfcc
  (package
    (name "texlive-phfcc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/phfcc/" "source/latex/phfcc/"
                                     "tex/latex/phfcc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04i0srq2ps4l8vbacci3ipdw4mc4hccwzp03lxj4b4a874yxdhg6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/phfcc")
    (synopsis "Convenient inline commenting in collaborative documents")
    (description
     "This package allows one to easily define helper macros to insert comments in
a LaTeX document.  A convenient syntax enables you to mark text
additions (e.g., @samp{\\phf@{I'm adding this text@}}), an in-line
comment (e.g., @samp{We're the best \\phf[I'm not sure about this.]}), and
text removals (e.g., @samp{\\phf*@{remove me@}}).  New colors are assigned
automatically to each commenter by default, and the appearance of all comments
is highly customizable.")
    (license license:lppl1.3+)))

(define-public texlive-phfextendedabstract
  (package
    (name "texlive-phfextendedabstract")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/phfextendedabstract/"
                                     "source/latex/phfextendedabstract/"
                                     "tex/latex/phfextendedabstract/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a9jrsmlafi2q67bqzzwmdxiivqnrzscz9nb99is08rkwnfwmj97"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/phfextendedabstract")
    (synopsis "Typeset extended abstracts for conferences")
    (description
     "Several conferences in various fields require the submission of extended
abstracts.  An extended abstract is a summary of a scientific result,
presented at a high level, and consisting of at most a small handful of pages.
The @code{phfextendedabstract} LaTeX class provides a simple style for such
abstracts.  There are only two sectioning levels, sections and paragraphs, and
the style is optimized to save space as well as to guide the reader's eye
through the overall structure of the document.  An option will try to compress
all vertical space to save some space, in case you need to satisfy page
constraints.  The style builds upon the powerful RevTeX class, so you can use
all of RevTeX's features such as author affiliations, etc.")
    (license license:lppl1.3+)))

(define-public texlive-phffullpagefigure
  (package
    (name "texlive-phffullpagefigure")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/phffullpagefigure/"
                                     "source/latex/phffullpagefigure/"
                                     "tex/latex/phffullpagefigure/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15s58c6b0yp948dwyw68cr6r1cj9wlwh334b49a6yi1fnfgrr71l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/phffullpagefigure")
    (synopsis "Figures which fill up a whole page")
    (description
     "This package defines a @code{figure} environment which provides the figure
content on its own page, with the corresponding caption reading for example
@samp{Figure 3 (on next page): <caption>}.")
    (license license:lppl1.3+)))

(define-public texlive-phfnote
  (package
    (name "texlive-phfnote")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/phfnote/" "doc/latex/phfnote/"
                                     "source/latex/phfnote/" "tex/latex/phfnote/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fx5lpd4wfnjj441xm6d539kfvq88b2gkw8i8k28c2gksjs4hdgx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/phfnote")
    (synopsis "Basic formatting for short documents")
    (description
     "This package provides basic formatting for short documents such as notes on
a specific topic, short documentation, or quick memos.  It aims to cover all
basic needs for such purposes: include a standard set of relevant packages,
a nice title which doesn't take up too much space, better page margin sizes,
and some basic styling to make the note look nicer.  At the same time, it is
highly flexible and customizable.")
    (license license:lppl1.3+)))

(define-public texlive-phfparen
  (package
    (name "texlive-phfparen")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/phfparen/"
                                     "source/latex/phfparen/"
                                     "tex/latex/phfparen/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b11l81xcqna11w7hhzy4adybrgpr1a64jl7376w970v7d41nd4d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/phfparen")
    (synopsis "Parenthetic math expressions made simpler and less redundant")
    (description
     "This package provides a more condensed and flexible syntax for
parenthesis-delimited expressions in math mode which also allows for an easier
switching of brace sizes.  For example, the syntax @samp{\\big( a + b )} can
be used to replace @samp{\\bigl( a + b \\bigr)}.")
    (license license:lppl1.3+)))

(define-public texlive-phfqit
  (package
    (name "texlive-phfqit")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/phfqit/" "source/latex/phfqit/"
                                     "tex/latex/phfqit/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n9waig83pq0s6wgnbaxh3p1b1pj85j77pqsbvjsnmffffaiaqg8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/phfqit")
    (synopsis "Macros for typesetting quantum information theory")
    (description
     "This package provides macros to typeset some general mathematical operators
(identity operator, trace, diagonal, rank, ...), a powerful implementation of
the bra-ket notation (kets, bras, brakets, matrix elements etc.  which can be
sized as required), delimited expressions such as averages and norms, and some
basic Lie algebra/group names.  Macros for entropy measures for quantum
information theory (smooth min- and max-entropy, smooth relative entropies,
etc.) are also provided.")
    (license license:lppl1.3+)))

(define-public texlive-phfquotetext
  (package
    (name "texlive-phfquotetext")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/phfquotetext/"
                                     "source/latex/phfquotetext/"
                                     "tex/latex/phfquotetext/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zhbxcdsg1250yn9m31w1zbqz1pcp2znif3r3fc1az4pfgcd8hyy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/phfquotetext")
    (synopsis "Quote verbatim text without white space formatting")
    (description
     "This package provides an environment for displaying block text with special
characters, such as verbatim quotes from a referee report which may contain
pseudo-(La)TeX code.  This behaves like a @code{verbatim} environment, except
that it displays its content as normal paragraph content, ignoring any white
space preformatting.")
    (license license:lppl1.3+)))

(define-public texlive-phfsvnwatermark
  (package
    (name "texlive-phfsvnwatermark")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/phfsvnwatermark/"
                                     "source/latex/phfsvnwatermark/"
                                     "tex/latex/phfsvnwatermark/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q8ylfraz8c20x665aacgjzz1sx7ykp7wg0ygxv2q3z2cniqgr3z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/phfsvnwatermark")
    (synopsis "Watermarks with version control information from SVN")
    (description
     "This package allows you to add version control information as a gray
watermark on each page of your document.  The SVN info is read from keyword
tags such as @code{$Id$}, via the @code{svn} or @code{svn-multi} packages.")
    (license license:lppl1.3+)))

(define-public texlive-phfthm
  (package
    (name "texlive-phfthm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/phfthm/" "source/latex/phfthm/"
                                     "tex/latex/phfthm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m6xavj8wiyx9z6agy8z6sm7kskjrmhfvi9idd0qwyvjgsnfb3v8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/phfthm")
    (synopsis "Goodies for theorems and proofs")
    (description
     "This package provides enhanced theorem and proof environments based on the
amsthm original versions.  It allows for hooks to be placed, adds some default
goodies and is highly customizable.  In particular, it can connect theorems to
proofs, automatically producing text such as @samp{See proof on page X}.")
    (license license:lppl1.3+)))

(define-public texlive-philex
  (package
    (name "texlive-philex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/philex/" "tex/latex/philex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05qlcfradxs3pcz8a9an6aihbxwm0dbsa8b6sf55yi7j85ymp991"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/philex")
    (synopsis "Cross references for named and numbered environments")
    (description
     "Philex provides means for creating and cross-referencing named or numbered
environments.  Possible uses would be equations, example sentences (as in
linguistics or philosophy) or named principles.  Cross references may refer
either to the number, or to a short name of the target environment, or to the
contents of the environment.  Philex builds on the facilities of the
@code{linguex} package.")
    (license license:lppl)))

(define-public texlive-phonenumbers
  (package
    (name "texlive-phonenumbers")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/phonenumbers/"
                                     "tex/latex/phonenumbers/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18886ag4j8n6p9p00qsv7jjbfk75z59lfmrmawgsjpf2a435jg3d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/phonenumbers")
    (synopsis "Typesetting telephone numbers with LaTeX")
    (description
     "The @code{phonenumbers} package makes it possible to typeset telephone
numbers according to different national conventions.  German, Austrian,
French, British and North American phone numbers are supported.  Phone numbers
from other countries are supported rudimentarily.  The user can select from
various formatting options, including the additional output of the country
calling code.  The package is able to check if a phone number is valid
according to the national rules.  It also allows linking phone numbers using
the @code{hyperref} package.")
    (license license:lppl1.3+)))

(define-public texlive-photo
  (package
    (name "texlive-photo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/photo/" "source/latex/photo/"
                                     "tex/latex/photo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cyyvqd1l4m7sy0c88j3fyalxg4nkgq62wnw28js7q3qsd6bd40j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/photo")
    (synopsis "Float environment for photographs")
    (description
     "This package introduces a new float type called @code{photo} which works
similar to the float types @code{table} and @code{figure}.  Various options
exist for placing photos, captions, and a photographer line.  In
@code{twocolumn} documents, a possibility exists to generate double-column
floats automatically if the photo does not fit into one column.  Photos do not
have to be placed as floats, they can also be placed as boxes, with captions
and photographer line still being available.")
    (license license:lppl)))

(define-public texlive-photobook
  (package
    (name "texlive-photobook")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/photobook/"
                                     "tex/latex/photobook/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qhpvyac484ykhjjx9v5glw5d5bpd845gbq3f2w3yxazgnbf33qc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-adjustbox
                             texlive-atbegshi
                             texlive-changepage
                             texlive-colorspace
                             texlive-environ
                             texlive-eso-pic
                             texlive-etoolbox
                             texlive-fancyhdr
                             texlive-fancyvrb
                             texlive-flowfram
                             texlive-geometry
                             texlive-graphics
                             texlive-hyperref
                             texlive-iftex
                             texlive-kvoptions
                             texlive-listofitems
                             texlive-mdframed
                             texlive-numprint
                             texlive-pagecolor
                             texlive-pdfcomment
                             texlive-pdfpages
                             texlive-pgf
                             texlive-textpos
                             texlive-xargs
                             texlive-xcolor
                             texlive-xint
                             texlive-xkeyval))
    (home-page "https://ctan.org/pkg/photobook")
    (synopsis "Document class for typesetting photo books")
    (description
     "The @code{photobook} LaTeX document class extends the book class defining
a set of parameters, meta-macros, macros and environments with reasonable
defaults to help typeset, build and print books mainly based on visual/image
content.")
    (license license:bsd-3)))

(define-public texlive-picture
  (package
    (name "texlive-picture")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/picture/" "source/latex/picture/"
                                     "tex/latex/picture/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "157icaf3sx263y7vf25klcxs1ycnv5rxcag0wc8q19hbxj2qxg6v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/picture")
    (synopsis "Dimensions for picture macros")
    (description
     "There are macro and environment arguments that expect numbers that will
internally be multiplied by @code{\\unitlength}.  This package extends the
syntax of these arguments, so that dimensions with calculation support may be
used for these arguments.")
    (license license:lppl1.3+)))

(define-public texlive-piff
  (package
    (name "texlive-piff")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/piff/" "tex/latex/piff/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1y61wv1msddh4d1cybdq4dxcaibbc2rx9yhv1c0kjavzyvdmjyxx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/piff")
    (synopsis "Macro tools by Mike Piff")
    (description
     "This collection of tools consists of: a small package for dealing with
duplicate-numbered output pages; @code{newproof}, for defining mathematical
proof structures; @code{onepagem} for omitting the page number in one-page
documents and @code{time}, which prints a 12-hour format time.")
    (license license:public-domain)))

(define-public texlive-pkgloader
  (package
    (name "texlive-pkgloader")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pkgloader/"
                                     "tex/latex/pkgloader/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lmim1ssnhws8lvh6rs36q6b50al3j638nd6rqilv2pvy9z30ich"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pkgloader")
    (synopsis "Manage the options and loading order of other packages")
    (description
     "The package seeks to address the frustration caused by package conflicts.  It
manages the options and loading order of other packages.")
    (license license:lppl1.3+)))

(define-public texlive-plantslabels
  (package
    (name "texlive-plantslabels")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/plantslabels/"
                                     "tex/latex/plantslabels/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1isrp48vzawl7fw1w2166nlhz78h7vjcjnsri389i5kv54k2pihz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/plantslabels")
    (synopsis "Write labels for plants")
    (description
     "The package defines a command @code{\\plant}, which has three mandatory and
seven optional argument.")
    (license license:lppl)))

(define-public texlive-plates
  (package
    (name "texlive-plates")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/plates/" "tex/latex/plates/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08dpfyy22d1fh7jxyhlhv98bb5lmd6jkfbix5fqjdbrxyhz8snsk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/plates")
    (synopsis "Arrange for plates sections of documents")
    (description
     "The @code{plates} package provides a simple facility for inserting colour
figures in a document when they should be gathered and printed together as in
a book's section of colour plates.  The package provides a @code{plate}
environment that takes the place of the @code{figure} environment for such
colour images.")
    (license license:lppl)))

(define-public texlive-plweb
  (package
    (name "texlive-plweb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/plweb/" "source/latex/plweb/"
                                     "tex/latex/plweb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gnr1ykjmj014w4di19c02ir3y6x6fqzdz6g7km3bki1kjq0gj6p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pl")
    (synopsis "Literate programming for Prolog with LaTeX")
    (description
     "Instead of having to transform the common source into program or documentation,
the central idea was to develop a method to have one common source which can
be interpreted by a Prolog system as well as by LaTeX.")
    (license (license:fsf-free "file://doc/latex/plweb/README"))))

(define-public texlive-pmboxdraw
  (package
    (name "texlive-pmboxdraw")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pmboxdraw/"
                                     "source/latex/pmboxdraw/"
                                     "tex/latex/pmboxdraw/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19zgl38h0cxm7w7md3zjji3j2in9ibalhc4ljazdla50rgmcr81p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pmboxdraw")
    (synopsis "Poor man's box drawing characters")
    (description
     "This package declares box drawing characters of old code pages,
e.g. @samp{cp437}.  It uses rules instead of using a font.")
    (license license:lppl1.3c)))

(define-public texlive-polynom
  (package
    (name "texlive-polynom")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/polynom/" "source/latex/polynom/"
                                     "tex/latex/polynom/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zywkgngpf7n8hgfdwj0cp2i3b2wn0jqrf799vrgfscwg7dhbgm3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/polynom")
    (synopsis "Macros for manipulating polynomials")
    (description
     "The @code{polynom} package implements macros for manipulating polynomials,
for example it can typeset long polynomial divisions.  The main test case and
application is the polynomial ring in one variable with rational
coefficients.")
    (license license:lppl1.3+)))

(define-public texlive-polynomial
  (package
    (name "texlive-polynomial")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/polynomial/"
                                     "source/latex/polynomial/"
                                     "tex/latex/polynomial/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jxiv64368n7my0qc52gdbh510ys106lq9vfx0y9i9w88alm7js6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/polynomial")
    (synopsis "Typeset (univariate) polynomials")
    (description
     "The package offers an easy way to write (univariate) polynomials and rational
functions.  It defines two commands, one for polynomials
@code{\\polynomial@{coeffs@}} and one for rational functions
@code{\\polynomialfrac@{Numerator@}@{Denominator@}}.  Both commands take lists
of coefficients as arguments, and offer limited optional behaviour.")
    (license license:lppl)))

(define-public texlive-polytable
  (package
    (name "texlive-polytable")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/polytable/"
                                     "source/latex/polytable/"
                                     "tex/latex/polytable/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16hr99p6mx14px3jrwhgw5pqpp80prkb9l2647gmfk59df9zjl6m"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/polytable")
    (synopsis "Tabular-like environments with named columns")
    (description
     "This package implements a variant of tabular-like environments where columns
can be given a name and entries can flexibly be placed between arbitrary
columns.  Complex alignment-based layouts, for example for program code, are
possible.")
    (license license:lppl)))

(define-public texlive-postcards
  (package
    (name "texlive-postcards")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/postcards/"
                                     "tex/latex/postcards/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "110q0lha3wkvh17c67qgdib81pg0qbfbqwbjr00p0zhfyb7ri4xx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/postcards")
    (synopsis "Facilitates mass-mailing of postcards (junkmail)")
    (description
     "This package provides a modification of the standard LaTeX letter class which
prints multiple, pre-stamped, 5.5 by 3.5 postcards (a US standard size) via
the @code{envlab} and @code{mailing} packages.  An address database is
employed to address the front side of each postcard and a message is printed
on the back side of all.")
    (license license:lppl)))

(define-public texlive-poster-mac
  (package
    (name "texlive-poster-mac")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/poster-mac/"
                                     "tex/generic/poster-mac/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1h63zijhan1rvghklsia9siyzg67f7mq2pfl5n068qdss5i91k77"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/poster-mac")
    (synopsis "Make posters and banners with TeX")
    (description
     "The package offers macros for making posters and banners with TeX.  It is
compatible with most TeX macro formats, including Plain TeX, LaTeX, AmSTeX,
and AmS-LaTeX.  The package creates a poster as huge box, which is then
distributed over as many printer pages as necessary.  The only special
requirement is that your printer not be bothered by text that lies off the
page.  This is true of most printers, including laser printers and PostScript
printers.")
    (license license:lppl)))

(define-public texlive-postnotes
  (package
    (name "texlive-postnotes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/postnotes/"
                                     "source/latex/postnotes/"
                                     "tex/latex/postnotes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xiv6hjid167kdrzlldnsdzpxclp2maazdla6zvpp56p5bxh4sjl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/postnotes")
    (synopsis "Endnotes for LaTeX")
    (description
     "This is an endnotes package for LaTeX.  Its user interface provides means to
print multiple sections of notes along the document, and to subdivide them
either automatically --- by chapter, by section --- or at manually specified
places, thus being able to easily handle both numbered and unnumbered
headings.  The package also provides infrastructure for setting up contextual
running headers for printed notes.  The default is a simple but useful one, in
the form @samp{Notes to pages N-M}, but more elaborate ones can be built.
When @code{hyperref} is loaded, postnotes provides hyperlinked notes,
including back links.")
    (license license:lppl1.3c)))

(define-public texlive-powerdot
  (package
    (name "texlive-powerdot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/powerdot/"
                                     "source/latex/powerdot/"
                                     "tex/latex/powerdot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b5fmrzaif2d7rwbwlpd9xdykpw1r5p5cpjqiw3gs1f3241p43f4"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/powerdot")
    (arguments
     (list
      #:tex-format "latex"
      #:phases #~(modify-phases %standard-phases
                   ;; Building documentation, automatic when
                   ;; generating runfiles, fails.  Skip building it.
                   (add-after 'unpack 'skip-documentation
                     (lambda _
                       (substitute* "source/latex/powerdot/powerdot.dtx"
                         (("\\\\DocInput\\{powerdot\\.dtx\\}") "")))))))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-enumitem
                  texlive-etoolbox
                  texlive-fourier
                  texlive-hypdoc
                  texlive-listings
                  texlive-pgf
                  texlive-placeins
                  texlive-pst-node
                  texlive-pst-text
                  texlive-pstricks
                  texlive-xcolor
                  texlive-xkeyval))))
    (synopsis "Presentation class")
    (description
     "Powerdot is a presentation class for LaTeX that allows for the quick and easy
development of professional presentations.  It comes with many tools that
enhance presentations and aid the presenter.  Examples are automatic overlays,
personal notes and a handout mode.  To view a presentation, DVI, PS or PDF
output can be used.  A powerful template system is available to easily develop
new styles.")
    (license license:lppl1.3+)))

(define-public texlive-ppr-prv
  (package
    (name "texlive-ppr-prv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ppr-prv/" "source/latex/ppr-prv/"
                                     "tex/latex/ppr-prv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13fyjhym5idskszlrxajr7aglrn7y44xm5adh9l32xjvf3lnsmgh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ppr-prv")
    (synopsis "Prosper preview")
    (description
     "This class is used with LaTeX presentations using the @code{prosper} class.
The aim of this class is to produce a printable version of the slides written
with Prosper, with two slides per page.")
    (license license:lppl)))

(define-public texlive-crumbs
  (package
    (name "texlive-crumbs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/crumbs/" "source/latex/crumbs/"
                                     "tex/latex/crumbs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12hyir8ia6ns2r3wf27vr58ymkgcvpsj2m3vzal815znimhk8ik2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-catchfile texlive-etoolbox
                             texlive-xkeyval))
    (home-page "https://ctan.org/pkg/crumbs")
    (synopsis "Add a navigation path to the page header")
    (description
     "This package adds a navigation path, or breadcrumb trail, to the header of
a presentation, just like some websites do in order to simplify navigation.")
    (license license:expat)))

(define-public texlive-pagecolor
  (package
    (name "texlive-pagecolor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pagecolor/"
                                     "source/latex/pagecolor/"
                                     "tex/latex/pagecolor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rdxq2r5s7jkglirp3ycxzv7852sm47hz0irkrf8c6kcjkzpabj6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pagecolor")
    (synopsis "Interrogate page color")
    (description
     "This package provides the command @code{\\thepagecolor}, which gives the current page
(background) color, i.e., the argument used with the most recent call of
@code{\\pagecolor@{...@}}.  The command @code{\\thepagecolornone} gives the
same color as @code{\\thepagecolor}, except when the page background color is
@code{none} (e.g., as a result of using the @code{\\nopagecolor} command).  In
that case @code{\\thepagecolor} is @code{white} and @code{\\thepagecolornone}
is @code{none}.  When @code{\\nopagecolor} is unknown or broken
(@code{crop} package), this package provides a replacement.  Similar to @code{\\newgeometry}
and @code{\\restoregeometry} of the @code{geometry} package @code{\\newpagecolor@{...@}} and
@code{\\restorepagecolor} are provided.  For use with the @code{crop} package
@code{\\backgroundpagecolor@{...@}} as well as @code{\\newbackgroundpagecolor@{...@}} and
@code{\\restorebackgroundpagecolor} are provided.")
    (license license:lppl1.3c)))

(define-public texlive-ppt-slides
  (package
    (name "texlive-ppt-slides")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ppt-slides/"
                                     "source/latex/ppt-slides/"
                                     "tex/latex/ppt-slides/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cp0kkw4jb6fm87r8wmnnkn23y9wv4ap8d88j2gx35c7q28g0wsy"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-crumbs
           texlive-enumitem
           texlive-hyperref
           texlive-pagecolor
           texlive-pgf
           texlive-pgfopts
           texlive-qrcode
           texlive-seqsplit
           texlive-tikzpagenodes
           texlive-tools
           texlive-varwidth
           texlive-xcolor))
    (home-page "https://ctan.org/pkg/ppt-slides")
    (synopsis "Slide decks a la PowerPoint (PPT)")
    (description
     "This LaTeX package helps you create slide decks looking like those created
with PowerPoint, but more precise, uniform, and visually strict.")
    (license license:expat)))

(define-public texlive-practicalreports
  (package
    (name "texlive-practicalreports")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/practicalreports/"
                                     "tex/latex/practicalreports/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zm7rx8d5vgg2b2dlra44qk77kgivb4pq7glkaligcd1fw8sdzyp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/practicalreports")
    (synopsis "Some macros for writing practical reports")
    (description
     "This package provides a handful of macros for writing up science practical
reports.")
    (license license:lppl1.3c)))

(define-public texlive-prelim2e
  (package
    (name "texlive-prelim2e")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/prelim2e/"
                                     "source/latex/prelim2e/"
                                     "tex/latex/prelim2e/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0p86dh95rdddrakwdr6rf6adnfpg5pppqkgqvhzp8q028xz0xdbi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/prelim2e")
    (synopsis "Allows the marking of preliminary versions of a document")
    (description
     "This package puts text below the normal page content (the default text marks
the document as draft and puts a timestamp on it).  It Can be used together
with e.g., the @code{vrsion}, @code{rcs} and @code{rcsinfo} packages.")
    (license license:lppl1.3c)))

(define-public texlive-pressrelease
  (package
    (name "texlive-pressrelease")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pressrelease/"
                                     "source/latex/pressrelease/"
                                     "tex/latex/pressrelease/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gp9m7smh21r3shvlqivnh560sgpfvibh47qlz39pwn6285nix51"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pressrelease")
    (synopsis "Class for typesetting press releases")
    (description
     "This package provides a configurable class for writing press releases.")
    (license license:lppl1.3+)))

(define-public texlive-prettyref
  (package
    (name "texlive-prettyref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/prettyref/"
                                     "source/latex/prettyref/"
                                     "tex/latex/prettyref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kp50ipij9n32w5ri7qir5qqnxkm08d3rrq3ngc0k1lpnibc8xwn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/prettyref")
    (synopsis "Make label references self-identify")
    (description
     "@code{prettyref} provides a command @code{\\newrefformat}, which specifies
the way in which a reference is typeset, according to a label identification.
The identification is set in the @code{\\label} command, by using prefixed
label names; so instead of @code{\\label@{mysection@}}, one uses
@code{\\label@{sec:mysection@}}, and @code{prettyref} interprets the
@samp{sec:} part.")
    (license license:public-domain)))

(define-public texlive-prettytok
  (package
    (name "texlive-prettytok")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/prettytok/"
                                     "tex/latex/prettytok/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0di3g0r61grk720flwrwn1bzixcigx45ry2mwi0qrd9i2kxz8a8y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-filecontentsdef texlive-l3kernel
                             texlive-precattl))
    (home-page "https://ctan.org/pkg/prettytok")
    (synopsis "Pretty-print token lists")
    (description
     "This package pretty-prints token lists to HTML file for debugging purposes.
Open the file in any browser to view the result.  It can be used to replace
@code{\\tl_analysis_show:n}.")
    (license license:lppl1.3c)))

(define-public texlive-printlen
  (package
    (name "texlive-printlen")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/printlen/" "tex/latex/printlen/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pha10m0zgsp4zs100kjlf1zgdj2dsb1i1a6ng3wamhbq8l0508l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/printlen")
    (synopsis "Print lengths using specified units")
    (description
     "@code{\\printlength@{length@}} prints the value of a LaTeX length in the
units specified by @code{\\uselengthunit@{unit@}}, where @samp{unit} may be
any TeX length unit: @samp{pt}, @samp{pc}, @samp{in}, @samp{mm}, @samp{cm},
@samp{bp}, @samp{dd} or @samp{cc}).  When the unit is @samp{pt}, the printed
length value will include any stretch or shrink; otherwise these are not
printed.  The unit argument may also be @samp{PT}, in which case length values
will be printed in point units but without any stretch or shrink values.")
    (license license:lppl)))

(define-public texlive-probsoln
  (package
    (name "texlive-probsoln")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/probsoln/"
                                     "source/latex/probsoln/"
                                     "tex/latex/probsoln/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1805q6qq2rgq2l2akdkh8a7zn9b9l051fc9nbdkwv0j8dvynvlkv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/probsoln")
    (synopsis "Generate problem sheets and their solution sheets")
    (description
     "The package is designed for lecturers who have to generate new problem sheets
for their students on a regular basis by randomly selecting a specified number
of problems defined in another file.  The package allows you easily to
generate a new problem sheet that is different from the previous year, thus
alleviating the temptation of students to seek out the previous year's
students and checking out their answers.  The solutions to the problems can be
defined along with the problem, making it easy to generate the solution sheet
from the same source code; problems may be reused within a document, so that
solutions may appear in a different section of the same document as the
problems they cover.")
    (license license:lppl)))

(define-public texlive-program
  (package
    (name "texlive-program")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/program/" "tex/latex/program/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1icg7zv74g1q0rvg5vsmri1m17n87wmazgvy9brp3dmincsvg1jd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/program")
    (synopsis "Typesetting programs and algorithms")
    (description
     "The main offering is a @code{program} environment; a @code{programbox}
environment is available for fragments that must not break with the pages.")
    (license license:gpl3)))

(define-public texlive-progress
  (package
    (name "texlive-progress")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/progress/" "tex/latex/progress/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14sfbs9d3b28xqqaxzv7wcyjk60gqy30zwpl91mz0g55xxng7y6r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/progress")
    (synopsis "Creates an overview of a document's state")
    (description
     "Progress is a package which, when compiling TeX and LaTeX documents,
generates a HTML file showing an overview of a document's state (of how
finished it is).  The report is sent to file @code{\\ProgressReportName},
which is by default the @code{\\jobname} with the date appended (but is
user-modifiable).")
    (license license:lppl)))

(define-public texlive-progressbar
  (package
    (name "texlive-progressbar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/progressbar/"
                                     "tex/latex/progressbar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0s2hspv490bbvazjzkcpvaa3l4ypgwn3pymiiqibas9kvgs5yycj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/progressbar")
    (synopsis
     "Visualize shares of total amounts in the form of a (progress-)bar")
    (description
     "This package allows you to easily visualize shares of total amounts in the
form of a bar.  So basically you can convert any number between 0 and 1 to
a progressbar using the command @code{\\progressbar@{<number>@}}.  Also a lot
of customizations are possible, allowing you to create an unique progress bar
on your own.  The package uses TikZ to produce its graphics.")
    (license license:lppl)))

(define-public texlive-proofread
  (package
    (name "texlive-proofread")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/proofread/"
                                     "source/latex/proofread/"
                                     "tex/latex/proofread/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13sp7xd1a5k25l5wvjzk51p01zk6wcnj5fjd7fpca4indqz3x2kx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/proofread")
    (synopsis "Commands for inserting annotations")
    (description
     "This package defines a few LaTeX commands that may be useful when you
proofread a LaTeX document.  They allow you to easily highlight text and add
comments in the margin.  Vim escape sequences are provided for inserting or
removing these LaTeX commands in the source.  Options are provided for
displaying the document with extra line spacing, and for displaying it in
either corrected or uncorrected state, both without margin notes.")
    (license license:lppl1.3c)))

(define-public texlive-properties
  (package
    (name "texlive-properties")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/properties/"
                                     "tex/latex/properties/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0za99c6894nmss3jz7ivbx7gia2c6pzqsxnr0rmzayd4ig4q543y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/properties")
    (synopsis "Load properties from a file")
    (description
     "The package loads properties (key, value) from a properties file, e.g.,
@code{\\jobname.properties}.")
    (license license:lppl)))

(define-public texlive-prosper
  (package
    (name "texlive-prosper")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/prosper/" "tex/latex/prosper/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wbfgvh0lgfz7l9ihd6p25w88zpbgn2v1pjfsr19xyrf5h1dkg0s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/prosper")
    (synopsis "LaTeX class for high quality slides")
    (description
     "Prosper is a LaTeX class for writing transparencies.  It is written as an
extension of the @code{seminar} class.  Prosper offers a friendly environment
for creating slides for both presentations with an overhead projector and
a video projector.  Slides prepared for a presentation with a computer and
a video projector may integrate animation effects, incremental display, and so
on.  Various visual styles are supported and others are being contributed.")
    (license license:lppl1.2+)))

(define-public texlive-protex
  (package
    (name "texlive-protex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/protex/" "tex/latex/protex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1cbsz5r8dj528mrpsbdp3flz3dma6kifbd2xqy1vkw6vhc3nbvcg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/protex")
    (synopsis "Literate programming package")
    (description
     "ProTeX is a simple but powerful literate programming tool, which is designed
to generate useful hypertext output (either PDF, or HTML using TeX4ht).")
    (license license:lppl)))

(define-public texlive-protocol
  (package
    (name "texlive-protocol")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/protocol/"
                                     "source/latex/protocol/"
                                     "tex/latex/protocol/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "000gqwbqfbir9kx8j9n0hs40pdwsk7mf82j3p4m3byhc38j56cds"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/protocol")
    (synopsis "Class for minutes of meetings")
    (description
     "The present version of the class supports German meeting minutes including
vote results and action items.")
    (license license:lppl1.3+)))

(define-public texlive-psfragx
  (package
    (name "texlive-psfragx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/psfragx/" "source/latex/psfragx/"
                                     "tex/latex/psfragx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1d6rsdjdjjr4m3b18hakzhzrscxw2kf07kh5p9pnb26771ikvndz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:tex-format "latex"
           #:build-targets #~(list "psfragx.dtx")))
    (home-page "https://ctan.org/pkg/psfragx")
    (synopsis "@code{psfrag} extension")
    (description
     "PSfragX offers a mechanism to embed @code{\\psfrag} commands, as provided by
the @code{psfrag} package, into the EPS file itself.  Each time a graphic is
included, the EPS file is scanned.  If some tagged lines are found, they are
used to define the psfrag replacements that should be performed automatically.
In addition, a similar mechanism holds for overpic objects.  These are picture
objects superimposed on the included graphic.  For example, if Babel is used,
it is possible to define different replacements corresponding to different
languages.  The replacements to take into account will be selected on the
basis of the current language of the document.

A Matlab script (LaPrint) is provided, to export an EPS file with
@code{psfragx} annotations ready embedded.")
    (license license:lppl)))

(define-public texlive-pstring
  (package
    (name "texlive-pstring")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pstring/" "tex/latex/pstring/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "07z072r8l55gplyr538nc76c0pfmz8mslx84gdy7nmmp9410sqv1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pstring")
    (synopsis "Typeset sequences with justification pointers")
    (description
     "This package lets you typeset justified sequences, also called pointing
strings.  It's used for instance, in research papers about game semantics to
represent sequence of game moves with their associated justification
pointers.")
    (license license:public-domain)))

(define-public texlive-pxgreeks
  (package
    (name "texlive-pxgreeks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pxgreeks/"
                                     "source/latex/pxgreeks/"
                                     "tex/latex/pxgreeks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1s4bckmniy5paszg6hjqkf7vkj66mc5fpplwlz7xq432k0773xx3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/pxgreeks")
    (synopsis "Shape selection for PX fonts Greek letters")
    (description
     "The package allows LaTeX maths users of the PX fonts to select the shapes
(italic or upright) for the Greek lowercase and uppercase letters.  Once the
shapes for lowercase and uppercase have been selected via a package option,
the @code{\\other} prefix (e.g., @code{\\otheralpha}) allows using the
alternate glyph (as in the fourier package).  The @code{pxgreeks} package does
not constrain the text font that may be used in the document.")
    (license license:lppl1.3+)))

(define-public texlive-pygmentex
  (package
    (name "texlive-pygmentex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pygmentex/" "scripts/pygmentex/"
                                     "tex/latex/pygmentex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "012ljn25ihnw3i9fava7z9zg1372m7map6sgkjsikwlk18v8b30j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts #~(list "pygmentex.py")))
    (inputs (list python))
    (home-page "https://ctan.org/pkg/pygmentex")
    (synopsis "Use Pygments to format code listings in documents")
    (description
     "PygmenTeX is a Python-based LaTeX package that can be used for typesetting
code listings in a LaTeX document using Pygments.  Pygments is a generic
syntax highlighter for general use in all kinds of software such as forum
systems, wikis or other applications that need to prettify source code.")
    (license license:lppl1.3+)))

(define-public texlive-python
  (package
    (name "texlive-python")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/python/" "tex/latex/python/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b6r510m4a9iy6nk8r5id6265kvxljir8y6v06gp7r841cj5sy9z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/python")
    (synopsis "Embed Python code in LaTeX")
    (description
     "The package enables you to embed Python code in LaTeX, and insert the
script's output in the document.")
    (license license:gpl3+)))

(define-public texlive-pythonimmediate
  (package
    (name "texlive-pythonimmediate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/pythonimmediate/"
                                     "tex/latex/pythonimmediate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jxdxjxibds2bcwfq5zql0v80r9qlkzl8vm82avra5c9d2vc4a3l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-currfile texlive-l3packages
                             texlive-precattl texlive-saveenv))
    (home-page "https://ctan.org/pkg/pythonimmediate")
    (synopsis "Library to run Python code")
    (description
     "This is a library to run Python code.  Just like PerlTeX or PyLuaTeX,
this only requires a single run, and variables are persistent throughout the
run.  Unlike PerlTeX or PyLuaTeX, there is no restriction on compiler or
script required to run the code.

There are also debugging functionalities: TeX errors result in Python
traceback, and Python errors result in TeX traceback.  Errors in code executed
with the @code{pycode} environment give the correct traceback point to the
Python line of code in the TeX file.  For advanced users, this package allows
the user to manipulate the TeX state directly from within Python, so you don't
need to write a single line of TeX code.

In addition to this LaTeX package you need the Python
@code{pythonimmediate-tex} package.")
    (license license:lppl1.3c)))

(define-public texlive-qcm
  (package
    (name "texlive-qcm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/qcm/" "source/latex/qcm/"
                                     "tex/latex/qcm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ck1q695z1j5vjb528k10cq000kswrw524caia3amw8ibxxvqzdi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/qcm")
    (synopsis "LaTeX2e class for making multiple choice questionnaires")
    (description
     "QCM is a package for making multiple choices questionnaires under LaTeX2e
(@emph{QCM} is the French acronym for this style of test).  A special
environment allows you to define questions and possible answers.  You can
specify which answers are correct and which are not.  QCM not only formats the
questions for you, but also generates a form (a grid that your students will
have to fill in), and a mask (the same grid, only with correct answers
properly checked in).  You can then print the mask on a slide and correct the
questionnaires more easily by superimposing the mask on top of students forms.
QCM can also typeset exam corrections automatically, and comes with support
for AUC-TeX.")
    (license license:lppl)))

(define-public texlive-qstest
  (package
    (name "texlive-qstest")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/qstest/" "source/latex/qstest/"
                                     "tex/latex/qstest/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b1w1h4g2b3hbgza87aqm9hb36g46xwcr2f42qb30drc8p5svybv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/qstest")
    (synopsis "Bundle for unit tests and pattern matching")
    (description
     "This is @code{qstest} bundle, which contains the packages @code{makematch}
for matching patterns to targets (with a generalization in the form of pattern
lists and keyword lists), and @code{qstest} for performing unit tests,
allowing the user to run a number of logged tests ensuring the consistency of
values, properties and call sequences during execution of test code.  Both
packages make extensive use of in their package documentation, providing
illustrated examples that are automatically verified to work as expected.")
    (license license:lppl)))

(define-public texlive-qsymbols
  (package
    (name "texlive-qsymbols")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/qsymbols/"
                                     "source/latex/qsymbols/"
                                     "tex/latex/qsymbols/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02hb4d193dqsm2190alr4mh49rdx7wyy51281amz8pnfnkhlqifc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/qsymbols")
    (synopsis "Maths symbol abbreviations")
    (description
     "This package provides macros for defining systematic mnemonic abbreviations,
starting with @samp{`} for math symbols and @samp{\\\"} for arrows, using
standard symbols as well as those from the @code{amsfonts} bundle and the
@code{stmaryrd} package.")
    (license license:gpl3+)))

(define-public texlive-quicktype
  (package
    (name "texlive-quicktype")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/quicktype/"
                                     "tex/latex/quicktype/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1aza4qdzqylv8h2gdzq83m8hs4n8lf3f6l4x2gf3q9mg2v0gms2x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/quicktype")
    (synopsis "LaTeX package for quick typesetting")
    (description
     "This package is intended for the quick typesetting of basic LaTeX documents
using shortcuts to existing commands and specific commands for quick
formatting and creation of tables and title pages with a graphic image.")
    (license license:lppl1.3+)))

(define-public texlive-quiz2socrative
  (package
    (name "texlive-quiz2socrative")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/quiz2socrative/"
                                     "tex/latex/quiz2socrative/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02w9hqb2ri1xp3b5mi2sd41q2grq4vw4cvi7zmff02rrwaxd16wa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/quiz2socrative")
    (synopsis "Prepare questions for socrative quizzes")
    (description
     "This is a LaTeX package for preparing multiple choice, true/false,
and short answer questions.  Its main purpose is to offer a tool to
easily insert rather complicated mathematical material in
@url{https://socrative.com, socrative quizzes}.")
    (license license:lppl1.3c)))

(define-public texlive-quotchap
  (package
    (name "texlive-quotchap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/quotchap/"
                                     "source/latex/quotchap/"
                                     "tex/latex/quotchap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1v3hn7znccza193jlny1f61q6nx1hawp3hmr3277iq31idv59m99"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/quotchap")
    (synopsis "Decorative chapter headings")
    (description
     "This is a package for creating decorative chapter headings with quotations.
Uses graphical and coloured output and by default needs the Adobe standard
font set (as supported by @code{psnfss}).")
    (license license:gpl2)))

(define-public texlive-quoting
  (package
    (name "texlive-quoting")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/quoting/" "source/latex/quoting/"
                                     "tex/latex/quoting/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "035jilwq326893l3iza8dasznjfxvxg0w3r5zkygrjc5zycqmfp4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/quoting")
    (synopsis "Consolidated environment for displayed text")
    (description
     "As an alternative to the LaTeX standard environments @code{quotation} and
@code{quote}, the package provides a consolidated environment for displayed
text.  First-line indentation may be activated by adding a blank line before
the quoting environment.  A key-value interface (using kvoptions) allows the
user to configure font properties and spacing and to control orphans within
and after the environment.")
    (license license:lppl1.3+)))

(define-public texlive-quotmark
  (package
    (name "texlive-quotmark")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/quotmark/"
                                     "source/latex/quotmark/"
                                     "tex/latex/quotmark/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hijpw5d29b6zdgrqrpmg8p5vh9kf3f6kx6r6qr1yc2l7ydscyma"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/quotmark")
    (synopsis "Consistent quote marks")
    (description
     "The package provides a means of ensuring consistent quote marks throughout
your document.  The style can be changed either via package option or command,
and the package detects language selections (from the @code{babel} or
@code{ngerman} packages), and uses the punctuation marks appropriate for the
current language.

The author now considers the package obsolete, and recommends use of
@code{csquotes} in its place.")
    (license license:lppl)))

(define-public texlive-ran-toks
  (package
    (name "texlive-ran-toks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ran_toks/"
                                     "source/latex/ran_toks/"
                                     "tex/latex/ran_toks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18js88apqcvsr4z4fwjf6219d28fxnhcv3srhhksbi5h4ky8y88m"))))
    (outputs '("out" "doc"))
    (properties '((upstream-name . "ran_toks")))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ran_toks")
    (synopsis "Randomise token strings")
    (description
     "The package provides means of randomising lists of tokens, or lists of chunks
of tokens.  Two mechanisms for defining chunks are provided: the
@code{\\ranToks} command accepts an argument containing tokens to be
randomised; and the @code{\\bRTVToks/\\eRTVToks} commands delimit a collection
of tokens for randomising; each group inside a @code{rtVw} constitutes one of
these (typically larger) token sets.")
    (license license:lppl1.0+)))

(define-public texlive-randtext
  (package
    (name "texlive-randtext")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/randtext/" "tex/latex/randtext/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19zammzlnd4c0sa34pcm4gn5ascxsxcd9k2lrzpxdzck6cydycg8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/randtext")
    (synopsis "Randomise the order of characters in strings")
    (description
     "The package provides a single macro @code{\\randomize@{@var{TEXT}@}} that
typesets the characters of @var{TEXT} in random order, such that the resulting
output appears correct, but most automated attempts to read the file will
misunderstand it.  This function allows one to include an email address in
a TeX document and publish it online without fear of email address harvesters
or spammers easily picking up the address.")
    (license license:lppl)))

(define-public texlive-rccol
  (package
    (name "texlive-rccol")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rccol/" "source/latex/rccol/"
                                     "tex/latex/rccol/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qd37lacjixjkz89lw6q3nszdqxbdsn89rw262rqldx4wn65l4qa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rccol")
    (synopsis "Decimal-centered optionally rounded numbers in tabular")
    (description
     "The @code{rccol} package provides decimal-centered numbers: corresponding
digits and decimal separators aligned.  Furthermore, rounding to the desired
precision is possible.")
    (license license:lppl1.2+)))

(define-public texlive-rcs-multi
  (package
    (name "texlive-rcs-multi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rcs-multi/"
                                     "source/latex/rcs-multi/"
                                     "tex/latex/rcs-multi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13wa428acrycfrqva5agdq7mhnxr2cya5jzlprrs5k4bn01g40lj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rcs-multi")
    (synopsis "Typeset RCS version control in multiple-file documents")
    (description
     "The package enables the user to typeset version control information provided
by RCS keywords (e.g., @samp{$ID: ... $}) in LaTeX documents that contain
multiple TeX files.")
    (license license:lppl)))

(define-public texlive-rcsinfo
  (package
    (name "texlive-rcsinfo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rcsinfo/" "source/latex/rcsinfo/"
                                     "tex/latex/rcsinfo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q0d961vqj7kmzmf07zssq6wwwj7zjdhl3a9yi53slhfjar4y8zz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rcsinfo")
    (synopsis "Support for the revision control system")
    (description
     "This package provides a package to extract @acronym{RCS, Revision Control
System} information and use it in a LaTeX document.  For users of LaTeX2HTML,
@file{rcsinfo.perl} is included.")
    (license license:lppl)))

(define-public texlive-readablecv
  (package
    (name "texlive-readablecv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/readablecv/"
                                     "tex/latex/readablecv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l8py60k2s8iws7na8qfl3djhahl49jsjcjcggmc6175z1pkiwxz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/readablecv")
    (synopsis "Readable and good looking CV and letter class")
    (description
     "This class provides an attractive and highly readable CV which will hopefully
lead to your CV being read rather than discarded.")
    (license license:lppl1.3+)))

(define-public texlive-realboxes
  (package
    (name "texlive-realboxes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/realboxes/"
                                     "source/latex/realboxes/"
                                     "tex/latex/realboxes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bvd1apjdw8x1rhp8g09p7mhy7v1hqbx27vhc18lfg3izz79gkr3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/realboxes")
    (synopsis
     "Variants of common box-commands reading their content as real box")
    (description
     "The package uses @code{collectbox} to define variants of common box related
macros which read the content as real box and not as macro argument.  This
enables the use of verbatim or other special material as part of this content.
The provided macros have the same names as the original versions but start
with an upper-case letter instead.  The long-form macros, like
@code{\\Makebox}, can also be used as environments, but not the short-form
macros, like @code{\\Mbox}.  However, normally the long form uses the short
form anyway when no optional arguments are used.")
    (license license:lppl1.3+)))

(define-public texlive-recipe
  (package
    (name "texlive-recipe")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/recipe/" "tex/latex/recipe/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rw29wqyasp939w3shkh0ch1q97g51r1jd3g0gskasif9i4p4al8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/recipe")
    (synopsis "LaTeX class to typeset recipes")
    (description
     "The layout design is relatively straightforward; the class uses the Bookman and the
BrushScript-Italic fonts.")
    (license license:public-domain)))

(define-public texlive-recipebook
  (package
    (name "texlive-recipebook")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/recipebook/"
                                     "tex/latex/recipebook/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "058hrxnj3zhp4yjcq1xbbyg1rp7jxycpp6nac2gn9v1admcdami0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/recipebook")
    (synopsis "Typeset 5.5\" x 8\" recipes for browsing or printing")
    (description
     "This is a LaTeX2e class for typesetting recipes.  It is designed for
typesetting one or two recipes per page, with dimensions of 5.5 x 8.5.  The
hyperlinked table of contents and page numbers make browsing recipes
convenient, and the pages can be joined together or printed two per sheet to
normal letterpaper easily.  The size was chosen to work in half-page 3-ring
binder cover sheets.")
    (license license:lppl1.3+)))

(define-public texlive-recipecard
  (package
    (name "texlive-recipecard")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/recipecard/"
                                     "source/latex/recipecard/"
                                     "tex/latex/recipecard/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0794jd9d28rjvwk6bx93al2dcavjrb341yjmivhmq74d504wahpf"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs (list (texlive-updmap.cfg
                          (list texlive-etoolbox texlive-hypdoc))))
    (home-page "https://ctan.org/pkg/recipecard")
    (synopsis "Typeset recipes in note-card-sized boxes")
    (description
     "The @code{recipecard} class typesets recipes into note card sized boxes that
can then be cut out and pasted on to note cards.  The recipe then looks
elegant and fits in the box of recipes.")
    (license license:lppl)))

(define-public texlive-rectopma
  (package
    (name "texlive-rectopma")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rectopma/" "tex/latex/rectopma/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "158rk112xb538zav89w6yp4s0nasp8z4s7gwq22q3nchm4q7j8br"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rectopma")
    (synopsis "Recycle top matter")
    (description
     "This package saves the arguments of @code{\\author} and
@code{\\title} for reference (after @code{\\maketitle}) in
a document.")
    (license license:lppl)))

(define-public texlive-refcheck
  (package
    (name "texlive-refcheck")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/refcheck/" "tex/latex/refcheck/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zrwz6450p8gapw2sm7716k0h2si0l3c419xph0i0j9mj381kr8y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/refcheck")
    (synopsis "Check references (in figures, table, equations, etc)")
    (description
     "The package checks references in a document, looking for numbered but
unlabelled equations, for labels which are not used in the text, for unused
bibliography references.  It can also display label names in text near
corresponding numbers of equations and/or bibliography references.")
    (license license:gpl3+)))

(define-public texlive-refenums
  (package
    (name "texlive-refenums")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/refenums/" "tex/latex/refenums/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08k7n3vwb12hyjdyj2509gll724v08r6cx1196piqcclbxb6vrll"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/refenums")
    (synopsis "Define named items and provide back-references with that name")
    (description
     "The package provides commands to define enumerable items with a number and
a long name, which can be referenced later with the name or just the short
form.  For instance, @samp{Milestone M1: Specification created} can be defined
and later on be referenced with @samp{M1} or @samp{M1 (\"Specification
created\")}.  The text in the references is derived from the definition and
also rendered as hyperlink to the definition.")
    (license license:lppl1.3+)))

(define-public texlive-reflectgraphics
  (package
    (name "texlive-reflectgraphics")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/reflectgraphics/"
                                     "source/latex/reflectgraphics/"
                                     "tex/latex/reflectgraphics/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hwri11ywffm1a4rwgbb11yhhsa5p5ccz7x8rpclpr86rqg54mv1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/reflectgraphics")
    (synopsis "Techniques for reflecting graphics")
    (description
     "The package provides a macro for reflecting images, in a number of different
ways, in pursuit of more striking graphics in a document.")
    (license license:lppl1.3+)))

(define-public texlive-refman
  (package
    (name "texlive-refman")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/refman/" "source/latex/refman/"
                                     "tex/latex/refman/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11yrv849xq2qa6x1zihm1mk19gs7zfa7blw0psbcv945vxpz6vm8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/refman")
    (synopsis "Format technical reference manuals")
    (description
     "This package provides document classes (@code{report} and @code{article}
style) for writing technical reference manuals.  It offers a wide left margin
for notes to the reader, like some of the manuals distributed by Adobe.")
    (license license:lppl)))

(define-public texlive-regcount
  (package
    (name "texlive-regcount")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/regcount/"
                                     "source/latex/regcount/"
                                     "tex/latex/regcount/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1iyc21qs4y5cf1xbqz6h7hpv5w2aplb5xlczzkva23n562gg3gf7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/regcount")
    (synopsis "Display the allocation status of the TeX registers")
    (description
     "The package adds a macro @code{\\rgcounts} which displays the allocation
status of the TeX registers.  The display is written into the @file{.log} file
as it is a bit verbose.  An automatic call to @code{\\rgcounts} is done at
@code{\\begin@{document@}} and @code{\\end@{document@}}.")
    (license license:lppl)))

(define-public texlive-register
  (package
    (name "texlive-register")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/register/"
                                     "source/latex/register/"
                                     "tex/latex/register/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0zcffpp53dg59d7l24vsl6qjb6qfhmfbvwcbr658jhdmhawkzirr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/register")
    (synopsis "Typeset programmable elements in digital hardware (registers)")
    (description
     "This package is designed for typesetting the programmable elements in digital
hardware, i.e., registers.  Such registers typically have many fields and can
be quite wide; they are thus a challenge to typeset in a consistent manner.
Register is similar in some aspects to the @code{bytefield} and
@code{bitpattern} packages.  Anyone doing hardware documentation using LaTeX
should examine those packages.  An example Perl module and script are
provided, to convert the register specifications into structures suitable for,
say, a pre-silicon test environment.")
    (license license:lppl1.3+)))

(define-public texlive-regstats
  (package
    (name "texlive-regstats")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/regstats/"
                                     "source/latex/regstats/"
                                     "tex/latex/regstats/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1l4if1agj643m7ks50x2d5bzzfbr5mwpdnl2clgn8m4ni1r0l1qg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/regstats")
    (synopsis "Information about register use")
    (description
     "The package will report number of used registers (@code{counter},
@code{dimen}, @code{skip}, @code{muskip}, @code{box}, @code{token},
@code{input}, @code{output}, @code{math families}, @code{languages},
@code{insertions}), and will compare the number to the maximum available
number of such registers.")
    (license license:lppl1.3+)))

(define-public texlive-relenc
  (package
    (name "texlive-relenc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/relenc/"
                                     "fonts/tfm/public/relenc/"
                                     "fonts/vf/public/relenc/"
                                     "source/latex/relenc/" "tex/latex/relenc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n712fg70rsxw3y7yxi3ijwb5cdn78ylkfs0j5kxi8k73lzxjjkb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/relenc")
    (synopsis "Relaxed font encoding")
    (description
     "This LaTeX package provides a relaxed font encoding to make available to
a font designer more slots for insertion of ligatures and accented
characters.")
    (license license:lppl1.0+)))

(define-public texlive-repeatindex
  (package
    (name "texlive-repeatindex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/repeatindex/"
                                     "makeindex/repeatindex/"
                                     "tex/latex/repeatindex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10i5z21vz123xq7mn8248584n2h4gziznb28cmjbfmljvc7gfcfr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/repeatindex")
    (synopsis "Repeat items in an index after a page or column break")
    (description
     "This package repeats item of an index if a page or column break occurs within a
list of subitems.  This helps to find out to which main item a subitem belongs.")
    (license license:lppl)))

(define-public texlive-repltext
  (package
    (name "texlive-repltext")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/repltext/"
                                     "source/latex/repltext/"
                                     "tex/latex/repltext/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kgkybp0fajswdl0cv8w29nglc2a0g2fxsm4k8z6idn2dkcc2z0c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/repltext")
    (synopsis "Control how text gets copied from a PDF file")
    (description
     "The @code{repltext} package exposes to LaTeX a relatively obscure PDF
feature: replacement text.  When replacement text is specified for a piece of
text, it is the replacement text, not the typeset text that is copied and
pasted.")
    (license license:lppl1.3c)))

(define-public texlive-rescansync
  (package
    (name "texlive-rescansync")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rescansync/"
                                     "tex/latex/rescansync/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "084wqg5h7jxqccz2ml7r0y2r3a9mp7zd7add9g1ly7p3fykygi0h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rescansync")
    (synopsis "Re-scan tokens with synctex information")
    (description
     "This package allows users to execute saved code to typeset text while
preserving SyncTeX information.")
    (license license:lppl1.3c)))

(define-public texlive-resmes
  (package
    (name "texlive-resmes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/resmes/" "source/latex/resmes/"
                                     "tex/latex/resmes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rj78zbk6dcadacck9n6jp23424aciwk88b5xgqmxgb3km5rnp89"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/resmes")
    (synopsis "Measure restriction symbol in LaTeX")
    (description
     "This package provides a simple macro @code{\\resmes} that prints the measure
restriction symbol.")
    (license license:expat)))

(define-public texlive-returntogrid
  (package
    (name "texlive-returntogrid")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/returntogrid/"
                                     "tex/latex/returntogrid/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sm1ncfplpa1bfmxi6ak3hnpalkw211h6mrhl89qls00gd3hf5hg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/returntogrid")
    (synopsis "Semi-automatic grid typesetting")
    (description
     "@code{returntogrid} offers a few commands to get something like an simple,
semi-automatic grid typesetting.  It does more or less what the existing
@code{gridset} package does.  The main differences to gridset are that
@code{returntogrid} works also with LuaLaTeX and that it has also a command to
do some horizontal movements to get to @samp{Tab} positions.")
    (license license:lppl1.3c)))

(define-public texlive-rgltxdoc
  (package
    (name "texlive-rgltxdoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rgltxdoc/"
                                     "source/latex/rgltxdoc/"
                                     "tex/latex/rgltxdoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wbgxl24d67hcwy01vsajg2am6ia6dagxgl32ql4854gcim0ypbj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rgltxdoc")
    (synopsis "Common code for documentation of the author's packages")
    (description
     "This package combines several other packages and defines additional macros
and environments for documenting LaTeX code.  The package mainly serves the
purpose of combining the preferences used in the author's own package
documentations.")
    (license license:lppl1.2+)))

(define-public texlive-rjlparshap
  (package
    (name "texlive-rjlparshap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rjlparshap/"
                                     "source/latex/rjlparshap/"
                                     "tex/latex/rjlparshap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1csigz0i8a1zlrzlv0wl5dc5rqbpjkfhadaib5y92qb54n4aqi36"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rjlparshap")
    (synopsis "Support for use of @code{\\parshape} in LaTeX")
    (description
     "The package provides macros and environments that relieve the programmer of
some of the difficulties of using @code{\\parshape} in LaTeX macros.  It does
not actually calculate shapes in the way that the @code{shapepar} package
does.")
    (license license:lppl1.2+)))

(define-public texlive-rlepsf
  (package
    (name "texlive-rlepsf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/rlepsf/" "tex/generic/rlepsf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q3apjplxx9z1ff5cpg5ysjbybdfz8fj0av9h3kvrgvy0b4pqdg5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rlepsf")
    (synopsis "Rewrite labels in EPS graphics")
    (description
     "This package provides a macro package for use with @file{epsf.tex} which
allows PostScript labels in an Encapsulated PostScript file to be replaced by
TeX labels.  The package provides commands @code{\\relabel} (simply replace
a PostScript string), @code{\\adjustrelabel} (replace a PostScript string,
with position adjustment), and @code{\\extralabel} (add a label at given
coordinates).  You can, if you so choose, use the facilities of the
@code{labelfig} package in place of using @code{\\extralabel}.")
    (license license:lppl)))

(define-public texlive-rmpage
  (package
    (name "texlive-rmpage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rmpage/" "tex/latex/rmpage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wv0nv514a8017vgbfbsykzn92lzpp7ma5hckn6fwhpvh9y8h9r7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rmpage")
    (synopsis "Change page layout parameters in LaTeX")
    (description
     "The package lets you change page layout parameters in small steps over
a range of values using options.  It can set @code{\\textwidth} appropriately
for the main fount, and ensure that the text fits inside the printable area of
a printer.  An rmpage-formatted document can be typeset identically without
@code{rmpage} after a single cut and paste operation.  Local configuration can
set defaults: for all documents; and by class, by printer, and by paper size.
The @code{geometry} package is better if you want to set page layout
parameters to particular measurements.")
    (license license:gpl3+)))

(define-public texlive-robustcommand
  (package
    (name "texlive-robustcommand")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/robustcommand/"
                                     "source/latex/robustcommand/"
                                     "tex/latex/robustcommand/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h8j23ww9mrwsnn61f21inxr5m8xsgb60qswk6p8nw89z2zgrl7x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/robustcommand")
    (synopsis "Declare robust command, with @code{\\newcommand} checks")
    (description
     "The package merely provides a variation of @code{\\DeclareRobustCommand},
which checks for the existence of a command before declaring it robust.")
    (license license:lppl)))

(define-public texlive-robustindex
  (package
    (name "texlive-robustindex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/robustindex/"
                                     "tex/latex/robustindex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vm0fsshl9g4kkw9sfdva6xrmxmqhk1sndrg4nbh6ch8mk5s4b2a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/robustindex")
    (synopsis "Create index with pagerefs")
    (description
     "Third parties often change the page numbers without rerunning
@command{makeindex}.  One would like to make the page numbers in the index
entries more robust.  This bundle provides @file{robustindex.sty} and
@file{robustglossary.sty}, which use the @code{\\pageref} mechanism to
maintain correct page numbers.")
    (license license:lppl1.2+)))

(define-public texlive-romanbar
  (package
    (name "texlive-romanbar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/romanbar/"
                                     "source/latex/romanbar/"
                                     "tex/latex/romanbar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fq5jlpfj7cz6b4ic6y19sk35z51h6qqkqh0n8kg5snpclag1662"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/romanbar")
    (synopsis "Write roman number with bars")
    (description
     "Bars, in the present context, are lines above and below text that abut with
the text.  Barred roman numerals are sometimes found in publications.  The
package provides a function that prints barred roman numerals (converting
Arabic numerals if necessary).  The package also provides a predicate
@code{\\ifnumeric}.")
    (license license:lppl1.3+)))

(define-public texlive-romanbarpagenumber
  (package
    (name "texlive-romanbarpagenumber")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/romanbarpagenumber/"
                                     "source/latex/romanbarpagenumber/"
                                     "tex/latex/romanbarpagenumber/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "179n10ij40zfbnfqh44598c7amz45829i7lh155afl5hx40g72xm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/romanbarpagenumber")
    (synopsis "Typesetting roman page numbers")
    (description
     "The package romanbar allows typesetting roman numbers with bars.  This package
allows you to use those roman numbers as page number.")
    (license license:lppl1.3+)))

(define-public texlive-romanneg
  (package
    (name "texlive-romanneg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/romanneg/" "tex/latex/romanneg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1j6anqlmvg36znah2cx10lpa5fnlqa1g2lfv3g2351hy2i94g9f8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/romanneg")
    (synopsis "Roman page numbers negative")
    (description
     "This package causes the page numbers in the DVI file (as defined by
@code{\\count0}) to be negative when roman page numbering is in effect.")
    (license license:public-domain)))

(define-public texlive-romannum
  (package
    (name "texlive-romannum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/romannum/"
                                     "source/latex/romannum/"
                                     "tex/latex/romannum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n9hy1pxb6lgf27zmzzizj7jlygv9jc72gjlawqpp1akzjfzdq5r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/romannum")
    (synopsis "Generate roman numerals instead of Arabic digits")
    (description
     "The @code{romannum} package changes LaTeX generated numbers to be printed
with roman numerals instead of Arabic digits.  Users of the @code{bookhands}
fonts may find this package useful.")
    (license license:lppl)))

(define-public texlive-rotfloat
  (package
    (name "texlive-rotfloat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rotfloat/"
                                     "source/latex/rotfloat/"
                                     "tex/latex/rotfloat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m0xmy3yip4j62rby0fqri2dk4jl75cph1y27r3x129l4kzyblvw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rotfloat")
    (synopsis "Rotate floats")
    (description
     "The @code{float} package provides commands to define new floats of various styles
(plain, boxed, ruled, and userdefined ones); the @code{rotating} package
provides new environments (@code{sidewaysfigure} and @code{sidewaystable})
which are rotated by 90 or 270 degrees.  But what about new rotated floats,
e.g., a rotated ruled one? This package makes this possible; it builds
a bridge between the two packages and extends the commands from the float
package to define rotated versions of the new floats, too.")
    (license license:lppl)))

(define-public texlive-rotpages
  (package
    (name "texlive-rotpages")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rotpages/" "tex/latex/rotpages/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lr7xj6z1l0prl787sfw3l5z4m4gp46n840zc84a51rm05vghjp7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rotpages")
    (synopsis "Typeset sets of pages upside-down and backwards")
    (description
     "The @code{rotpages} package allows you to format documents where small sets
of pages are rotated by 180 degrees and rearranged, so that they can be read
by turning the printed copy upside-down.  It was developed for collecting
exercises and solutions: using the package, you can print the exercise text
normally and the solutions rotated.")
    (license license:lppl)))

(define-public texlive-roundbox
  (package
    (name "texlive-roundbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/roundbox/" "tex/latex/roundbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pyxk774xpl88pqjd1jg17cv06ipvv0injkhvf96ziz6mkranjzw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/roundbox")
    (synopsis "Round boxes in LaTeX")
    (description
     "This package implements a command @code{\\roundbox} that can be used, in LaTeX,
for producing boxes, framed with rounded corners.")
    (license license:lppl1.3+)))

(define-public texlive-rterface
  (package
    (name "texlive-rterface")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rterface/" "tex/latex/rterface/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1k9xfi2sxl9p7h3vm5b4dzp15w2vdr80p2bf8pvlry2wn8lb9vws"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rterface")
    (synopsis "Access to R analysis from within a document")
    (description
     "The package mediates interaction between LaTeX and R; it allows LaTeX to set
R's parameters, and provides code to read R output.")
    (license license:lppl1.2+)))

(define-public texlive-rtkinenc
  (package
    (name "texlive-rtkinenc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rtkinenc/"
                                     "source/latex/rtkinenc/"
                                     "tex/latex/rtkinenc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0921b6c5k168nbs32vlqxg8jznzw51dd02w5g1q6ld4dw8c78zxc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rtkinenc")
    (synopsis "Input encoding with fallback procedures")
    (description
     "The @code{rtkinenc} package is functionally similar to the standard LaTeX
package @code{inputenc}: both set up active characters so that an input
character outside the range of 7-bit visible ASCII is converted into one or
more corresponding LaTeX commands.  The main difference lies in that
@code{rtkinenc} allows the user to specify a fallback procedure to use when
the text command corresponding to some input character isn't available.  Names
of commands in @code{rtkinenc} have been selected so that it can read
@code{inputenc} encoding definition files, and the aim is that @code{rtkinenc}
should be backwards compatible with @code{inputenc}.  @code{rtkinenc} is not
a new version of @code{inputenc} though, nor is it part of standard LaTeX.")
    (license license:lppl)))

(define-public texlive-rulerbox
  (package
    (name "texlive-rulerbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rulerbox/" "tex/latex/rulerbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rrhkr9z22xz0adm77b09spcpc80v2ld3iqzcgaq4hfmsl4vykzv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rulerbox")
    (synopsis "Draw rulers around a box")
    (description
     "This is a LaTeX package for drawing rulers around a box.  This might be
useful when showing the absolute size of something in electronic documents, or
designating the relative scale in printed materials.")
    (license license:lppl1.3c)))

(define-public texlive-rulercompass
  (package
    (name "texlive-rulercompass")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rulercompass/"
                                     "source/latex/rulercompass/"
                                     "tex/latex/rulercompass/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ndbyvpqx5p8z7fnpiz8rihmvd8qni0pwl5d2wa8xslialy777b0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rulercompass")
    (synopsis "TikZ library for straight-edge and compass diagrams")
    (description
     "The package defines some commands and styles to support drawing straight-edge
and compass diagrams with TikZ.")
    (license license:lppl1.3+)))

(define-public texlive-runcode
  (package
    (name "texlive-runcode")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/runcode/" "tex/latex/runcode/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gv7crjrdgj7a735hyrdyq9yf9kn42lrizm54f9v3mss7nzw0nrl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/runcode")
    (synopsis
     "Execute foreign source code and embed the result in the PDF file")
    (description
     "This LaTeX package executes programming source codes (including all command
line tools) from within LaTeX and embeds the output in the resulting
@file{.pdf} file.  Many programming languages can be easily used and any
command-line executable can be invoked when preparing the @file{.pdf} file
from a @file{.tex} file.  It is however recommended to use this package in
server-mode together with the Python @command{talk2stat} package.  Currently,
this server-mode supports Julia, MatLab, Python, and R.")
    (license license:lppl1.3c)))

(define-public texlive-rvwrite
  (package
    (name "texlive-rvwrite")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/rvwrite/" "tex/latex/rvwrite/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m3arw9ccm32y07w6ryvkyhyywgccc58pmyc8w46rlzzjq1bns13"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/rvwrite")
    (synopsis "Increase the number of available output streams in LaTeX")
    (description
     "The package addresses, for LaTeX documents, the severe limitation on the
number of output streams that TeX provides.  The package uses a single TeX
output stream, and writes marked-up output to this stream.  The user may then
post-process the marked-up output file, using LaTeX, and the document's output
appears as separate files, according to the calls made to the package.  The
output to be post-processed uses macros from the widely-available ProTeX
package.")
    (license license:lppl)))

(define-public texlive-sanitize-umlaut
  (package
    (name "texlive-sanitize-umlaut")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sanitize-umlaut/"
                                     "tex/latex/sanitize-umlaut/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "022qrm85cyz8r9q4miy9yd0m8yizi4z8zj7xfx1kvb1nqk6rzkpf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sanitize-umlaut")
    (synopsis "Sanitize umlauts for MakeIndex and pdfLaTeX")
    (description
     "This package sanitizes umlauts to be used directly in index entries for
MakeIndex and friends with pdfLaTeX.  This means that inside @code{\\index} an
umlaut can be used as @samp{\"U} or as @samp{U}.  In both cases, the letter is
written as @samp{\"U} into the raw index file for correct processing with
MakeIndex and pdfLaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-precattl
  (package
    (name "texlive-precattl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/precattl/" "tex/latex/precattl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b003sdv58chmckyqcrij6k2b76639j7r5hiidnwcwf1lk56wfk4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/precattl")
    (synopsis "Prepare special catcodes from token list")
    (description
     "This package allows users to write code that contains tokens with unusual
catcodes.")
    (license license:lppl1.3c)))

(define-public texlive-saveenv
  (package
    (name "texlive-saveenv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/saveenv/" "tex/latex/saveenv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m3pmzmqpksymlqn71d5p98d10yg3nqz7a5pqcylpb4a8w0g63r7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-precattl))
    (home-page "https://ctan.org/pkg/saveenv")
    (synopsis "Save environment content verbatim")
    (description
     "This package provides tools to create your own verbatim environments, and
works for all values of @code{\\endlinechar}.")
    (license license:lppl1.3c)))

(define-public texlive-savefnmark
  (package
    (name "texlive-savefnmark")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/savefnmark/"
                                     "source/latex/savefnmark/"
                                     "tex/latex/savefnmark/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06gcknhf2hm924l8zzbp4bxpcs69kchd3nqgy7n3fjaz8k8gwz0i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/savefnmark")
    (synopsis "Save name of the footnote mark for reuse")
    (description
     "Sometimes the same footnote applies to more than one location in a table.
With this package the mark of a footnote can be saved into a name, and re-used
subsequently without creating another footnote at the bottom.")
    (license license:gpl3+)))

(define-public texlive-savesym
  (package
    (name "texlive-savesym")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/latex/savesym/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18z0xwarbkb6cm7n29wasa04d92g2pirlzsr0icnzfip2f4j7524"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/savesym")
    (synopsis "Redefine symbols where names conflict")
    (description
     "There are a number of symbols (e.g., @code{\\Square}) that are defined by
several packages.  In order to typeset all the variants in a document, we have
to give the glyph a unique name.  To do that, we define
@code{\\savesymbol@{XXX@}}, which renames a symbol from @code{\\XXX} to
@code{\\origXXX}, and @code{\\restoresymbols@{yyy@}@{XXX@}}, which renames
@code{\\origXXX} back to @code{\\XXX} and defines a new command,
@code{\\yyyXXX}, which corresponds to the most recently loaded version of
@code{\\XXX}.")
    (license license:lppl)))

(define-public texlive-savetrees
  (package
    (name "texlive-savetrees")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/savetrees/"
                                     "doc/latex/savetrees/"
                                     "source/latex/savetrees/"
                                     "tex/latex/savetrees/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06vhi0yzdrry5l8xg1j3hm0c22af4hasdaivgrbgqbjxldll2dxa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/savetrees")
    (synopsis "Optimise the use of each page of a LaTeX document")
    (description
     "The goal of the @code{savetrees} package is to pack as much text as possible
onto each page of a LaTeX document.  Admittedly, this makes the document far
less attractive.  Nevertheless, @code{savetrees} is a simple way to save paper
when printing draft copies of a document.  It can also be useful when trying
to meet a tight page-length requirement for a conference or journal
submission.  Most of the package options cover specific modifications to
typesetting rules, but there are also options subtle, moderate and extreme
options for the broad brush approach.")
    (license license:lppl1.3+)))

(define-public texlive-scale
  (package
    (name "texlive-scale")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/scale/" "source/latex/scale/"
                                     "tex/latex/scale/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "150dm7w2nlqfrhi71xnnmi92mrhdn7lbpnnsz22r0z71wk95qb26"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/scale")
    (synopsis "Scale document by sqrt(2) or magstep(2)")
    (description
     "This package provides a package to scale a document by sqrt(2) (or by
@code{\\magstep@{2@}}).  This is useful if you are preparing a document on,
for example, A5 paper and want to print on A4 paper to achieve a better
resolution.")
    (license license:gpl3+)))

(define-public texlive-scalebar
  (package
    (name "texlive-scalebar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/scalebar/"
                                     "source/latex/scalebar/"
                                     "tex/latex/scalebar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09s698gnw8qh30srff40yd8f2dl7ja0vgh8djh20i5xyzb74c0xg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/scalebar")
    (synopsis "Create scalebars for maps, diagrams or photos")
    (description
     "This is a small package to create scalebars for maps, diagrams or photos.
It was designed for use with cave maps but can be used for anything from
showing a scalebar in kilometres for topographic maps to a scalebar in
micrometres for an electron microscope image.")
    (license license:lppl)))

(define-public texlive-scalerel
  (package
    (name "texlive-scalerel")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/scalerel/" "tex/latex/scalerel/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1l2miwqhgrcv74iy3zwi656bs89hsag1pyfs9ycbcbxs6rcp270h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/scalerel")
    (synopsis "Constrained scaling and stretching of objects")
    (description
     "The package provides four commands for vertically scaling and stretching
objects.  Its primary function is the ability to scale/stretch and shift one
object to conform to the size of a specified second object.  This feature can
be useful in both equations and schematic diagrams.  Additionally, the scaling
and stretching commands offer constraints on maximum width and/or minimum
aspect ratio, which are often used to preserve legibility or for the sake of
general appearance.")
    (license license:lppl1.3+)))

(define-public texlive-scanpages
  (package
    (name "texlive-scanpages")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/scanpages/"
                                     "fonts/map/dvips/scanpages/"
                                     "fonts/tfm/public/scanpages/"
                                     "fonts/type1/public/scanpages/"
                                     "tex/latex/scanpages/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a94fvacp5hqkz5f0wkshhjlnv97b2nqvm49fc93hylkgvi9pqym"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/scanpages")
    (synopsis "Support importing and embellishing scanned documents")
    (description
     "The bundle provides support for the process of creating documents based on
pre-TeX-era material that is available as scanned pages, only.")
    (license license:lppl1.3+)))

(define-public texlive-schedule
  (package
    (name "texlive-schedule")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/schedule/"
                                     "source/latex/schedule/"
                                     "tex/latex/schedule/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08k092d0vy1s45180bgh4476r0h22lg3ngizh8ncy5mkgh5fyznl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/schedule")
    (synopsis "Weekly schedules")
    (description
     "This package automatically formats weekly schedules using LaTeX's
@code{picture} environment.  Its main feature is the accuracy with which
appointments are represented: boxes drawn to represent a particular
appointment are accurate to the minute --- i.e., a 31-minute appointment will
have a box 1/30th longer than a 30-minute appointment.  A number of features
are included to allow the user to customize the output.")
    (license license:lppl1.3c)))

(define-public texlive-schooldocs
  (package
    (name "texlive-schooldocs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/schooldocs/"
                                     "source/latex/schooldocs/"
                                     "tex/latex/schooldocs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0j4i2mx672vgygpvficjqds4r4rrl0czxpgfk6ha200fsyddlx65"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/schooldocs")
    (synopsis "Various layout styles for school documents")
    (description
     "The purpose of this package is to provide several layout styles for school
documents.  It is useful for exercise sheets, exams, course materials.  The
package sets the page geometry (dimensions of text and margins) and the title
typesetting; the various styles define the header, footer and title formatting.
Many features are freely configurable.")
    (license license:lppl1.3+)))

(define-public texlive-scontents
  (package
    (name "texlive-scontents")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/scontents/"
                                     "source/latex/scontents/"
                                     "tex/context/third/scontents/"
                                     "tex/generic/scontents/"
                                     "tex/latex/scontents/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0817f3xjaxli7rjqpr1gl13mx2iba3c0p95y9818kwccj47v71py"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/scontents")
    (synopsis "Stores LaTeX contents in memory or files")
    (description
     "This package stores valid LaTeX code in memory (sequences).  The stored
content (including verbatim) can be used as many times as desired in the
document, additionally can be written to external files if desired.")
    (license license:lppl1.3c)))

(define-public texlive-scrambledenvs
  (package
    (name "texlive-scrambledenvs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/scrambledenvs/"
                                     "source/latex/scrambledenvs/"
                                     "tex/latex/scrambledenvs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0s88vg9zwsbny8i8m5vs9hwd4fpblsvwwxam5z3416i2xc924mnx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/scrambledenvs")
    (synopsis "Create and print scrambled environments")
    (description
     "This package allows you to create and print scrambled environments for purposes
such as randomized hint environments.  You can mark a location with a series of
hints, and then print the hints at the end in a pseudo-random order.  The
general structure follows: there is an outer environment which creates the
label, an inner environment that creates the references, and a print command
that prints out all of the hints.  This generalizes beyond hints; one can create
scrambled solutions as well, etc.")
    (license license:lppl1.3+)))

(define-public texlive-scrlayer-fancyhdr
  (package
    (name "texlive-scrlayer-fancyhdr")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/scrlayer-fancyhdr/"
                                     "source/latex/scrlayer-fancyhdr/"
                                     "tex/latex/scrlayer-fancyhdr/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ikr1l1pa33l6v2d3ad4gz2qp3ggldk1f31j49cgfazs6qwnzy0a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/scrlayer-fancyhdr")
    (synopsis
     "Combining package @code{fancyhdr} with KOMA-Script's @code{scrlayer}")
    (description
     "This LaTeX package uses KOMA-Script's @code{scrlayer} to redefine the page
styles of package @code{fancyhdr}.  This allows the combination of features of
@code{fancyhdr} with features of @code{scrlayer}.")
    (license license:lppl1.3c)))

(define-public texlive-scrlttr2copy
  (package
    (name "texlive-scrlttr2copy")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/scrlttr2copy/"
                                     "tex/latex/scrlttr2copy/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05wgvw2fqaf5fnrxx1viscic4c3hmncmkbji9kljwx8mpl2s2zcs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/scrlttr2copy")
    (synopsis
     "Letter class option file for the automatic creation of copies")
    (description
     "The file @file{copy.lco} provides the new class option @code{copy} to the
KOMA-Script letter class @code{scrlttr2}.  If this option is given, all pages
of a specific letter are duplicated with background text marking as copies.")
    (license license:lppl1.3+)))

(define-public texlive-sdaps
  (package
    (name "texlive-sdaps")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sdaps/" "source/latex/sdaps/"
                                     "tex/latex/sdaps/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nddqv5wgbay8wqdjppanbks6xivb48x0l0fpbkv1sak7h92kmbg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs
     (list texlive-environ
           texlive-lastpage
           texlive-pgf
           texlive-qrcode
           texlive-sectsty
           texlive-translator))
    (home-page "https://ctan.org/pkg/sdaps")
    (synopsis "LaTeX support files for SDAPS")
    (description
     "This bundle contains LaTeX classes and packages to create machine
readable questionnaires.  Metadata is generated for the whole document and it is
possible to process created forms fully automatically using the SDAPS main
program.

Its features include:

@itemize

@item PDF form generation,

@item advanced array like layouting,

@item can flow over multiple pages and repeats the header automatically,

@item optional document wide alignment of @code{array} environments,

@item has complex layout features like rotating the headers to safe space,

@item ability to exchange rows and columns on the fly,

@item different question types: free-form text, single/multiple choice
questions, range questions,

@item Layouting questions in rows or columns,

@item Possibility to pre-fill questionnaires from LaTeX.

@end itemize")
    (license license:lppl1.3c)))

(define-public texlive-sdrt
  (package
    (name "texlive-sdrt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sdrt/" "tex/latex/sdrt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1lv0fv3af0z5r7ca422dymimf6lkc55ylqhaq8hpq8ynz0qh7zl0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sdrt")
    (synopsis
     "Macros for @acronym{SDRT, Segmented Discourse Representation Theory}")
    (description
     "The package provides macros to produce the Box notation of SDRT (and DRT), to
draw trees representing discourse relations, and finally to have an easy access
to various mathematical symbols used in that theory, mostly with automatic
mathematics mode, so they work the same in formulae and in text.")
    (license license:lppl)))

(define-public texlive-secdot
  (package
    (name "texlive-secdot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/secdot/" "tex/latex/secdot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ndmzj21xwjdqz905h0bgz581adsij2w95m1zjpc9avhgsgx7fy0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/secdot")
    (synopsis "Section numbers with trailing dots")
    (description
     "This package makes the numbers of @code{\\section} commands come out with
a trailing dot.  It includes a command whereby the same can be made to happen
with other sectioning commands.")
    (license license:lppl)))

(define-public texlive-secnum
  (package
    (name "texlive-secnum")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/secnum/" "source/latex/secnum/"
                                     "tex/latex/secnum/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nsvq3w3925r45qg6na5i79wg84sy6p4a2gi6nrgkilb1mdvxxqx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/secnum")
    (synopsis "Macro to format section numbering intuitively")
    (description
     "This package provides a macro @code{\\setsecnum} to format section numbering
intuitively.")
    (license license:lppl1.3c)))

(define-public texlive-sectionbox
  (package
    (name "texlive-sectionbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sectionbox/"
                                     "tex/latex/sectionbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lhjf0pmp9i0ka24flfpn88z4k66mxid0vrhvwxfq01bcr695wcf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sectionbox")
    (synopsis "Create fancy boxed ((sub)sub)sections")
    (description
     "@code{sectionbox} is a LaTeX package for putting fancy colored boxes around
sections, subsections, and subsubsections, especially for use in posters, etc.
It was designed with the @code{sciposter} class in mind, and certainly works
with that class and with derived classes.")
    (license license:lppl)))

(define-public texlive-sectionbreak
  (package
    (name "texlive-sectionbreak")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sectionbreak/"
                                     "tex/latex/sectionbreak/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b58qzhxbsmg3yfkmgq8xis3l9yb3jzi85znzczd75yvbcs5b0f3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sectionbreak")
    (synopsis "LaTeX support for section breaks")
    (description
     "This package provides LaTeX support for section breaks, used mainly in
fiction books to signal changes in a story, like changes in time, location,
etc.  It supports the asterism symbol, text content, or custom macros as the
section break mark symbol.")
    (license license:lppl1.3+)))

(define-public texlive-seealso
  (package
    (name "texlive-seealso")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/seealso/" "source/latex/seealso/"
                                     "tex/latex/seealso/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ibgrrmbdmdbkzahkwgi726zaqz06q9da2102lkyy6r11x7dnvbf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/seealso")
    (synopsis "Improve the performance of @code{\\see} macros with MakeIndex")
    (description
     "The package amends the @code{\\see} and @code{\\seealso} macros that are used
in building indexes with MakeIndex, to deal with repetitions, and to ensure
page numbers are present in the actual index entries.")
    (license license:lppl1.3+)))

(define-public texlive-selectp
  (package
    (name "texlive-selectp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/selectp/" "tex/latex/selectp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1j1i4d5ira8kiqxl24pvlzic8fvvl5zlmsm6wy7hk6z37wp4jmc7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/selectp")
    (synopsis "Select pages to be output")
    (description
     "This package defines a command @code{\\outputonly}, whose argument is a list
of pages to be output.  With the command present in the header, only those
pages are output.")
    (license license:public-domain)))

(define-public texlive-semantex
  (package
    (name "texlive-semantex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/semantex/" "tex/latex/semantex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0pjx6ff628bwa027vrcjx1x9vg967mh22vb7sy3pdxdk1mx0idhn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-semtex))
    (home-page "https://ctan.org/pkg/semantex")
    (synopsis "Semantic, keyval-based mathematics")
    (description
     "The SemanTeX package for LaTeX delivers a more semantic,
systematized way of writing mathematics, compared to the classical math syntax
in LaTeX.  The system uses keyval syntax, and the user can define their own
keys and customize the system down to the last detail.  At the same time, care
has been taken to make the syntax as simple, natural, practical, and
lightweight as possible.  Furthermore, the package has a companion package,
called @code{stripsemantex}, which allows you to completely strip your
documents of SemanTeX markup to prepare them e.g., for publication.")
    (license license:lppl1.3c)))

(define-public texlive-semantic
  (package
    (name "texlive-semantic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/semantic/"
                                     "source/latex/semantic/"
                                     "tex/latex/semantic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14v1538y7gsn63833j41z9yan8cpn2c4pls2rwyyk7qmzjj30nh7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/semantic")
    (synopsis "Help for writing programming language semantics")
    (description
     "This package eases the typesetting of notation of semantics and compilers.
It includes T-diagrams, various derivation symbols and inference trees.")
    (license license:lppl)))

(define-public texlive-semantic-markup
  (package
    (name "texlive-semantic-markup")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/semantic-markup/"
                                     "tex/latex/semantic-markup/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c7n0rwz8lm5qs67rln2qky9bjkffkwlrx9xaw6c1z7xsgwbm6n1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/semantic-markup")
    (synopsis
     "Meaningful semantic markup in the spirit of the Text Encoding Initiative")
    (description
     "The package provides simple commands to allow authors (especially scholars in
the humanities) to write with a focus on content rather than presentation.
The commands are inspired by the XML elements of the Text Encoding Initiative.
Commands like @code{\\term} and @code{\\foreign} are aliases for
@code{\\emph}.  @code{\\quoted} and @code{\\soCalled} are aliases for quoting
commands.  These commands could be easily redefined for different formats.
The package also provides a @code{footnote} environment so that long footnotes
can be more cleanly separated from the main text.  Eventually, the package
also includes some macros for musical symbols and other basic notations for
musical analysis.")
    (license license:lppl1.3+)))

(define-public texlive-semesterplanner
  (package
    (name "texlive-semesterplanner")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/semesterplanner/"
                                     "source/lualatex/semesterplanner/"
                                     "tex/lualatex/semesterplanner/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ixi839q2p88gplzlxhx4mqk9nwaw9yi16xh2fvihbmd0gllzw86"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/semesterplanner")
    (synopsis "Create beautiful semester timetables and more")
    (description
     "This package defines several useful environments for a beautiful printable
semester plan.  It includes a timetable (which is using the schedule-Package)
as well as appointments, deadlines, and exams.")
    (license license:lppl1.3+)))

(define-public texlive-semioneside
  (package
    (name "texlive-semioneside")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/semioneside/"
                                     "source/latex/semioneside/"
                                     "tex/latex/semioneside/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "025wvr95j3p8i1pfcvai57zaq1bnw0wkf1j8piljlaap95fc09ii"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/semioneside")
    (synopsis
     "Put only special contents on left-hand pages in two sided layout")
    (description
     "This package supports the preparation of semi one sided documents.  That is,
two sided documents, where all text is output on right-hand pages --- as in
a one-sided documents --- and only special contents are output on left-hand
pages on user request, e.g., floating objects.")
    (license license:lppl)))

(define-public texlive-semproc
  (package
    (name "texlive-semproc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/semproc/" "source/latex/semproc/"
                                     "tex/latex/semproc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ymixf3wggka9n7888wnaylkh2hzlylsdnzlk6chy9llnfy4wr7d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/semproc")
    (synopsis "Seminar proceedings")
    (description
     "The package provides functionality for typesetting seminar proceedings based
on KOMA-Script's @code{scrreprt} class and @code{etoc}.  It offers an
alternative to @code{\\chapter} that typesets the speaker and if necessary the
typist of the notes for the talk in question.

Moreover, the class provides two types of table of contents.  A global table
of contents showing only the talks of the seminar and the respective speakers
and a local table of contents for each talk showing the sections and
subsections of the respective talk.")
    (license license:lppl1.3+)))

(define-public texlive-semtex
  (package
    (name "texlive-semtex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/semtex/" "tex/latex/semtex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1d0sh9rjnwnfgkh5vnnv2sbk4xnklbf8a6dk1dc3y3p3qv36yial"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/semtex")
    (synopsis "Deals with stripped SemanTeX documents")
    (description
     "This package is a small LaTeX package that adds a collection of simple macros
for parentheses and bullets.  It exists for one purpose only, to be loaded by
documents which were originally typeset using the package SemanTeX, but which
have been stripped of SemanTeX markup using the package @code{stripsemantex}
which is part of SemanTeX.  Therefore, unless your document is one of those,
simply don't use this package.  And even if your document is one of those,
there is a good chance you will not have to load it after all.  In most cases,
you will be able to replace the macros it provides by macros from other
packages.")
    (license license:lppl1.3c)))

(define-public texlive-sepfootnotes
  (package
    (name "texlive-sepfootnotes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sepfootnotes/"
                                     "tex/latex/sepfootnotes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1k9hi6vffn10j75gw5pjxjqila2dyvlv6s1b8r4m4s0mad24498f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sepfootnotes")
    (synopsis "Support footnotes and endnotes from separate files")
    (description
     "The package supports footnotes and endnotes from separate files.  This is
achieved with commands @code{\\sepfootnotecontent} and @code{\\sepfootnote};
the former defines the content of a note, while the latter typesets that
note.")
    (license license:lppl1.3+)))

(define-public texlive-sesstime
  (package
    (name "texlive-sesstime")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sesstime/"
                                     "source/latex/sesstime/"
                                     "tex/latex/sesstime/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ajryzcw1pf9yva3qpbx1f7mpl5pnkj4k3ccvh5hxaif86jydcc1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sesstime")
    (synopsis "Session and timing information in lecture notes")
    (description
     "This LaTeX2e package makes it possible to add timing marks to lecture notes
in order to help managing the time available for presenting a given section of
the document.  It also provides tools to record and estimate the progress
throughout the course.")
    (license license:lppl1.3+)))

(define-public texlive-sf298
  (package
    (name "texlive-sf298")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sf298/" "source/latex/sf298/"
                                     "tex/latex/sf298/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mn1lhj2hqwpyb2q06sw15vgz5ykl7gx4n5iy3q1d3dj8nj3rr6v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sf298")
    (synopsis "Standard form 298")
    (description
     "This LaTeX package generates a completed standard form 298 (Rev.@: 8-98) as
prescribed by ANSI Std.@: Z39.18 for report documentation as part of
a document delivered, for instance, on a U.S.  government contract.")
    (license license:lppl1.2+)))

(define-public texlive-sffms
  (package
    (name "texlive-sffms")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sffms/" "source/latex/sffms/"
                                     "tex/latex/sffms/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bijlqr55fbd1jx6739242vbi04zai5mcqmy23dzhpn8bbayzvrj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sffms")
    (synopsis "Typesetting science fiction/fantasy manuscripts")
    (description
     "The class is designed for typesetting science fiction and fantasy manuscripts.
Sffms now includes several options for specific publishers as well as
extensive documentation aimed at new LaTeX users.")
    (license license:lppl)))

(define-public texlive-sfmath
  (package
    (name "texlive-sfmath")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/latex/sfmath/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05m3whw5xkml48yx93j9h46qmspnr5hwsfszb59l4wy4jfj66zk4"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sfmath")
    (synopsis "Sans-serif mathematics")
    (description
     "@code{sfmath} is a simple package for sans serif maths in documents.  After
including the package, all maths of the current document is displayed with
sans serif fonts.")
    (license license:lppl)))

(define-public texlive-shadethm
  (package
    (name "texlive-shadethm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/shadethm/" "tex/latex/shadethm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mzvfvz5f07mva4hjaba9jrhj9jalv7hqck93236qqbxkp1lxpr9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/shadethm")
    (synopsis "Theorem environments that are shaded")
    (description
     "This package extends the @code{\\newtheorem} command with a new command,
@code{\\newshadetheorem}, which can produce theorem statement in a shaded box.
It supports all the options of @code{\\newtheorem}.

However, this package is considered as obsolete by its author.  Users are
generally recommended, therefore, to use @code{mdframed} instead.")
    (license license:lppl)))

(define-public texlive-shadow
  (package
    (name "texlive-shadow")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/shadow/" "tex/latex/shadow/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rqwga17jy4d8zyv2v3sf0vww8cf54jg4qqd0blxq748fk2b4509"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/shadow")
    (synopsis "Shadow boxes")
    (description
     "This package defines a command @code{\\shabox} (analogous to @code{\\fbox}),
and supporting mechanisms.")
    (license license:lppl)))

(define-public texlive-shadowtext
  (package
    (name "texlive-shadowtext")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/shadowtext/"
                                     "tex/latex/shadowtext/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ffldvx7as6jympf2fqkwd2arxphcf6l1cmpf8kvgh1f5hdbzwcr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/shadowtext")
    (synopsis "Produce text with a shadow behind it")
    (description
     "The package introduces a command @code{\\shadowtext}, which adds a drop
shadow to the text that is given as its argument.  The colour and positioning
of the shadow are customisable.")
    (license license:lppl)))

(define-public texlive-shapepar
  (package
    (name "texlive-shapepar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/shapepar/"
                                     "tex/generic/shapepar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bv18gkw4x5hz5bharypnw30zhiasryczvq92bib57gww8lxr3n7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/shapepar")
    (synopsis "Macro to typeset paragraphs in specific shapes")
    (description
     "@code{\\shapepar} is a macro to typeset paragraphs in a specific shape.  The
size is adjusted automatically so that the entire shape is filled with text.
There may not be displayed maths or @code{\\vadjust} material (no
@code{\\vspace}) in the argument of @code{\\shapepar}.  The macros work for
both LaTeX and plain TeX.

@code{\\shapepar} works in terms of user-defined shapes, though the package
does provide some predefined shapes.  The tedium of creating these polygon
definitions may be alleviated by using the @code{shapepatch} extension to
@code{transfig} which will convert @code{xfig} output to @code{\\shapepar}
polygon form.")
    ;; Python scripts (in "doc" output) is released under GPL2+, all
    ;; other files are licensed by the statement: " This software may
    ;; be freely used, transmitted, shared, copied, sold, or modified,
    ;; provided that any modifications are clearly identified and this
    ;; notice is left intact.
    (license
     (list license:gpl2+
           (license:fsf-free "file://doc/generic/shapepar/README.shapepar")))))

(define-public texlive-shdoc
  (package
    (name "texlive-shdoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/shdoc/" "source/latex/shdoc/"
                                     "tex/latex/shdoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gx7jndmz4x2n03af7537bbngbmpg4vh51m35q9ziz6agsvjlxn3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/shdoc")
    (synopsis
     "Float environment to document the shell commands of a terminal session")
    (description
     "The package provides a simple, though fancy float environment to document
terminal sessions --- like command executions or shell operations.  The look
and feel of the package output imitates the look of a shell prompt.")
    (license license:lppl1.3+)))

(define-public texlive-shipunov
  (package
    (name "texlive-shipunov")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/shipunov/" "doc/latex/shipunov/"
                                     "tex/latex/shipunov/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zzjbsshv60k2a3nfgj1rdad3883ys04an5hsq7hm4vs62k6j53b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/shipunov")
    (synopsis "Collection of LaTeX packages and classes")
    (description
     "The bundle collects packages and classes, along with one bibliography style
and examples and scripts for converting TeX files.  Many of the files in the
collection are designed to support field biologists and/or Russian writers,
while others have wider application.  The collection includes:

@itemize

@item @code{add2}, a quick way to fit as many as possible into one page, which
is good for handouts.

@item @code{altverse}, for typesetting verses.

@item @code{autolist}, a means to define various sorts of list.

@item @code{biokey}, providing flexible identification key tables in LaTeX.
It implements straightforward macros to typeset sets of biological
identification keys.  Layout is flexible, and the macros will be useful in
other disciplines.

@item @code{biolist}, to list observed species.  It offers pretty formatting of
species lists of flora and fauna.

@item @code{boldline}, for heavier lines in tables.  The package provides
commands replacing @code{\\hline} and @code{\\cline}, as well as a table
preamble element that generates heavy lines.

@item @code{cassete}, to print labels for audio cassettes.

@item @code{classif2}, for biological classification tables.  The package
defines an environment @code{classif} that simplifies the process of
typesetting classification tables.

@item @code{dline}, for a double line on the left of text.

@item @code{drcaps}, for simple dropped capitals.  The package offers simple
macros for dropped capitals, in a couple of forms.

@item @code{etiketka}, a class for typesetting business-card-sized
information (including business cards).

@item @code{flower}, for typesetting lists of flower formulas.

@item @code{isyntax}, which interactively checks LaTeX file syntax.

@item @code{numerus}, for spelling numbers in Russian words.

@item @code{punct}: within italicized text, punctuation is still straight,
this is typographically more aesthetic.

@item @code{qqru}, providing universal quotation marks, for Russian and
English.

@item @code{rusnat}, a bibliography style file, now deprecated.

@item @code{sltables}, which simplifies tables for LaTeX.  These macros
develop the concepts of the @code{stables}, which are designed to offer table
macros whose use is as simple as one might hope.  Some would claim that
LaTeX's built-in table specifications are as simple as one might hope, but
this package offers many short-cuts and optimization of the mechanisms of
tables.

@item @code{starfn}, for stars as footnote marks.

@item @code{textfrac}, for simple slanted fractions.

@end itemize")
    (license license:lppl1.3+)))

(define-public texlive-shorttoc
  (package
    (name "texlive-shorttoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/shorttoc/"
                                     "source/latex/shorttoc/"
                                     "tex/latex/shorttoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ajzxmpj3d4lnzh3l86k4bii1jjs2483x7lmzgc2rqkp80zaayh0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/shorttoc")
    (synopsis "Table of contents with different depths")
    (description
     "This package creates another table of contents with a different depth, useful
in large documents where a detailed table of contents should be accompanied by
a shorter one, giving only a general overview of the main topics in the
document.")
    (license license:lppl)))

(define-public texlive-show2e
  (package
    (name "texlive-show2e")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/show2e/" "source/latex/show2e/"
                                     "tex/latex/show2e/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1j1cb5qy25qni8wq1kaf6p6c0whzrbymhm00g4jjajaizagm4ki2"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-babel
                  texlive-etoolbox
                  texlive-hypdoc
                  texlive-lm
                  texlive-microtype))))
    (home-page "https://ctan.org/pkg/show2e")
    (synopsis "Variants of @code{\\show} for LaTeX2e")
    (description
     "This small package aims at making debugging (especially in an interactive
way) easier, by providing @code{\\show} variants suited to LaTeX2e
commands (whether with optional arguments or robust) and environments.  The
variant commands also display the internal macros used by such commands, if
any.  The @code{\\showcs} variant helps with macros with exotic names.")
    (license license:lppl)))

(define-public texlive-showcharinbox
  (package
    (name "texlive-showcharinbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/showcharinbox/"
                                     "source/latex/showcharinbox/"
                                     "tex/latex/showcharinbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1y91l00r6a04bjvqxqf0s4k3bf093q2wccd6s7dcz78wbp92ycj9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/showcharinbox")
    (synopsis "Show characters inside a box")
    (description
     "The package typesets a character inside a box, showing where reference point
is, and displaying width, height, and depth information of the character.")
    (license license:lppl1.3+)))

(define-public texlive-showdim
  (package
    (name "texlive-showdim")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/showdim/" "tex/latex/showdim/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hr2hfrvgqyfqaj9jgwiikcpf1pnslg8v0zw5qbj1ii6r7l8vrrd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/showdim")
    (synopsis "Variants on printing dimensions")
    (description
     "This LaTeX package provides a number of commands for printing the value of
a TeX dimension.  For example, @code{\\tenthpt@{\\baselineskip@}} yields the
current value of @code{\\baselineskip} rounded to the nearest tenth of
a point.")
    (license license:lppl)))

(define-public texlive-showlabels
  (package
    (name "texlive-showlabels")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/showlabels/"
                                     "source/latex/showlabels/"
                                     "tex/latex/showlabels/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c88yijjfw1xnlcchmsk9965fn464fj5xzi0s9ri13nj8cq7dmsw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/showlabels")
    (synopsis "Show label commands in the margin")
    (description
     "This package helps you keep track of all the labels you define, by putting
the name of new labels into the margin whenever the @code{\\label} command is
used.  The package allows you to do the same thing for other commands.  The
only one for which this is obviously useful is the @code{\\cite} command, but
it's easy to do it for others, such as the @code{\\ref} or @code{\\begin}
commands.")
    (license license:lppl1.3c)))

(define-public texlive-sidenotes
  (package
    (name "texlive-sidenotes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sidenotes/"
                                     "source/latex/sidenotes/"
                                     "tex/latex/sidenotes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0amrcapvyz9fbh7mqck7pg85nmkr6wgqmyvjj3syjnkshlcpvrr8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sidenotes")
    (synopsis "Typeset notes containing rich content, in the margin")
    (description
     "The package allows typesetting of texts with notes, figures, citations,
captions and tables in the margin.  This is common (for example) in science
text books.")
    (license license:lppl1.3+)))

(define-public texlive-sidenotesplus
  (package
    (name "texlive-sidenotesplus")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sidenotesplus/"
                                     "source/latex/sidenotesplus/"
                                     "tex/latex/sidenotesplus/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "051vjn3jmzrlcmbx6vg3zdsqkdwf6j6ykjkla669fs2s8x2zk59z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sidenotesplus")
    (synopsis
     "Place referenced notes, alerts, figures and tables into the document margin")
    (description
     "Sidenotesplus is a comprehensive package for placing labeled or referenced
notes, temporary alerts, bibliography references, figures and tables into the
margin.  Marginals can be either floated or at fixed positions relative to the
text.  Twoside symmetry is preserved.  For BibLaTeX users, macros for side
references are provided.  Three margin styles are provided.  Two-page
symmetric layouts either as (i) Ragged outer with note reverences in the
margin separator or (ii) justified with last line ragged outer.  And (iii)
a classic look, justified with last line ragged right and note reference to
the left of the note, but two-page symmetry is lost.  The command
@code{\\sidenote} mimics the @code{\\footnote} command and provides
labelled (numbers, alphabetic, roman) references.  However, un-numbered and
custom symbols can also be specified.  Temporary sidealerts are rendered only
if the package option alerton is specified.  Alerts are useful as to do
reminders during document development.  Furthermore, captions for figures and
tables can also be placed into margin.  Also, full width environments for
figures, tables and text are provided.  The text environment can be partially
widened, suitable if that extra space for an equation is required.")
    (license license:lppl1.3c)))

(define-public texlive-silence
  (package
    (name "texlive-silence")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/silence/" "source/latex/silence/"
                                     "tex/latex/silence/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pavby09may2z85r94hb4881knlssx7alvnrp523j6k4s2wqsxyq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/silence")
    (synopsis "Selective filtering of error messages and warnings")
    (description
     "The package allows the user to filter out unwanted warnings and error
messages issued by LaTeX, packages and classes, so they won't pop out when
there's nothing one can do about them.  Filtering goes from the very
broad (``avoid all messages by such and such'') to the fine-grained (``avoid
messages that begin with...'').  Messages may be saved to an external file for
later reference.")
    (license license:lppl)))

(define-public texlive-sillypage
  (package
    (name "texlive-sillypage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sillypage/"
                                     "source/latex/sillypage/"
                                     "tex/latex/sillypage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04jnp1hl3k0hs8rgzn1q3q41rmd95wlzv7f1dd9s4affzfk6an1z"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sillypage")
    (synopsis "John Cleese's silly walk as page numbering style")
    (description
     "This simple LaTeX package provides John Cleese's iconic silly walk routine as
a page numbering style.  Other counters, as well as integers, can be typeset
in this silly style, too.")
    (license (list license:cc-by-sa4.0 license:lppl1.3c))))

(define-public texlive-simplecd
  (package
    (name "texlive-simplecd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/simplecd/"
                                     "source/latex/simplecd/"
                                     "tex/latex/simplecd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z01p6xzr17745pn344p0s4z8l76sn3vhlliy7mnqlrv29fg6x61"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/simplecd")
    (synopsis "Simple CD, DVD covers for printing")
    (description
     "The package provides printable cut-outs for various CD, DVD and other disc
holders.  The name of the package comes from its implementation and ease of
use; it was designed just for text content, but since the text is placed in
a @code{\\parbox} in a @code{tabular} environment cell, a rather wide range of
things may be placed.")
    (license license:lppl1.2+)))

(define-public texlive-simplecv
  (package
    (name "texlive-simplecv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/simplecv/"
                                     "source/latex/simplecv/"
                                     "tex/latex/simplecv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03clih4gy6isd2p0xg75w19d4l8zx1d9c2i46idfh8wzcqzr35mj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/simplecv")
    (synopsis "Simple class for writing curricula vitae")
    (description
     "This package provides a derivative of the CV class available to LyX users
(renamed to avoid the existing @code{cv} package).")
    (license license:lppl)))

(define-public texlive-simpleinvoice
  (package
    (name "texlive-simpleinvoice")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/simpleinvoice/"
                                     "tex/latex/simpleinvoice/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02rni033d2ighbc3s165blqpsxzxqz4sfvlnc7h4820l5583nvfr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/simpleinvoice")
    (synopsis "Easy typesetting of invoices")
    (description
     "This package lets you easily typeset professional-looking invoices.  The user
specifies the content of the invoice by different @code{\\setPROPERTY}
commands, and an invoice is generated automatically with the
@code{\\makeinvoice} command.")
    (license license:gpl3)))

(define-public texlive-simplivre
  (package
    (name "texlive-simplivre")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/simplivre/"
                                     "tex/latex/simplivre/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1r7dw35ad8vbvx0rjpilwgh0r0479wkdfm2y9506a61lq3yka066"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-minimalist))
    (home-page "https://ctan.org/pkg/simplivre")
    (synopsis "Write your books in a simple and clear way")
    (description
     "This package provides a LaTeX class for typesetting books with a simple and
clear design.  Currently, it has native support for Chinese (simplified and
traditional), English, French, German, Italian, Japanese, Portuguese (European
and Brazilian), Russian and Spanish typesetting.  It compiles with either
XeLaTeX or LuaLaTeX.")
    (license license:lppl1.3c)))

(define-public texlive-sitem
  (package
    (name "texlive-sitem")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sitem/" "source/latex/sitem/"
                                     "tex/latex/sitem/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a3j735747kip4l72rl8xkzlnmp0fsqj9vdig4m1jbvwk2qhsn8c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sitem")
    (synopsis "Save the optional argument of @code{\\item}")
    (description
     "The package modifies @code{\\item} commands to save the optional argument in
a box.")
    (license license:lppl1.3+)))

(define-public texlive-skb
  (package
    (name "texlive-skb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/skb/" "source/latex/skb/"
                                     "tex/latex/skb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "146fjbh3jihjq9chbzshfcaha2d05dzqwcg7j154af00na59n8qk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/skb")
    (synopsis "Tools for a repository of long-living documents")
    (description
     "The package provides macros that help to build a document repository for long
living documents.  It focuses on structure and re-use of text, code, figures
etc.  The basic concept is first to separate structure from content (i.e.,
text about a topic from the structure it is presented by) and then separating
the content from the actual published document, thus enabling easy re-use of
text blocks in different publications (i.e., text about a protocol in a short
article about this protocol as well as in a book about many protocols); all
without constantly copying or changing text.  As a side effect, using the
document classes provided, it hides a lot of LaTeX from someone who just wants
to write articles and books.")
    (license license:lppl1.3+)))

(define-public texlive-skdoc
  (package
    (name "texlive-skdoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/skdoc/" "source/latex/skdoc/"
                                     "tex/latex/skdoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0m0961393b2r5rmkyjnl9l13gvzxjmif63mbl45wykcvpwrp2jhl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/skdoc")
    (synopsis "Documentation and extraction for packages and document classes")
    (description
     "The class provides the functionality and implementation of packages and
document classes.  The class defines a @code{MacroCode} environment which
offers an alternative to the usual @code{docstrip} method of installing
packages.  It has the ability to generate both documentation and code in
a single run of a single file.")
    (license license:lppl1.3+)))

(define-public texlive-skeldoc
  (package
    (name "texlive-skeldoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/skeldoc/" "tex/latex/skeldoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10172ig4pivy3hl8y6cb3jxzxdb1lylwbjc75a17ygk2x1lm4xds"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/skeldoc")
    (synopsis "Placeholders for unfinished documents")
    (description
     "This package lets you produce placeholder elements for documents under
development, similar to the skeleton screens used while loading contents in
many applications and websites.  It also has a mechanism for attaching
explanatory endnotes to these placeholders, or to anything else in your
document.  The same note mechanism can also be used with ordinary content,
e.g., as a to-do mechanism.")
    (license license:expat)))

(define-public texlive-skeycommand
  (package
    (name "texlive-skeycommand")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/skeycommand/"
                                     "tex/latex/skeycommand/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1iqmqxiiiq6mqmnmw4ii30la4d7z970wr7jx0yv50lh102lx67rw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/skeycommand")
    (synopsis "Create commands using parameters and @code{keyval} in parallel")
    (description
     "The package provides tools for defining LaTeX commands and environments using
combinations of parameters and keys.  All the facilities of the @code{ltxkeys}
and @code{skeyval} packages are available to the user of @code{skeycommand}.")
    (license license:lppl1.3+)))

(define-public texlive-skeyval
  (package
    (name "texlive-skeyval")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/skeyval/" "tex/latex/skeyval/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09647p16f50wa9yz9jfypwckginvlv0897x4gb7m69pbvgnsdf4i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/skeyval")
    (synopsis
     "Key-value parsing combining features of @code{xkeyval} and @code{pgfkeys}")
    (description
     "The package integrates the features of @code{xkeyval} and of @code{pgfkeys}
by introducing a new type of handlers.  Style keys, links, changing key
callbacks and values on the fly, and other features of @code{pgfkeys} are
introduced in a new context.")
    (license license:lppl1.3+)))

(define-public texlive-skills
  (package
    (name "texlive-skills")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/skills/" "tex/latex/skills/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0hvh16a6iziand9wlq48lnaw3ha1lj5g396mpfv1m8ci3r9hydm6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/skills")
    (synopsis "Create proficiency tests")
    (description
     "This package attempts to make it easy for even a LaTeX novice to prepare
proficiency tests, especially in combination with the @code{exam} document
class.  Thus, almost all command names are very similar.  After defining
skills in the preamble or in an external file, they are declared using labels,
and can optionally be set as global skills.  A skills table is generated to
summarize the evaluated competencies and to allow for writing down the
resulting proficiency level.")
    (license license:lppl1.3+)))

(define-public texlive-skrapport
  (package
    (name "texlive-skrapport")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/skrapport/"
                                     "source/latex/skrapport/"
                                     "tex/latex/skrapport/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bln56w1dfd36qg07b98d9271dhszca7l8w7x4vxwfq1n4yxm1rd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/skrapport")
    (synopsis "Simple class for reports, etc.")
    (description
     "The class is intended for simple documents (e.g., reports handed in as
coursework and the like).  The class is small and straightforward; its design
was inspired by that of the PracTeX journal style.")
    (license license:lppl1.3+)))

(define-public texlive-slantsc
  (package
    (name "texlive-slantsc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/slantsc/" "source/latex/slantsc/"
                                     "tex/latex/slantsc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m00h2bmgj5w3zd219s1l25ihr05kj1kpwilggbgh720bcvc3idp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/slantsc")
    (synopsis "Access different-shaped small-caps fonts")
    (description
     "This package enables the use of small capitals in different font shapes,
e.g., slanted or bold slanted for all fonts that provide appropriate font
shapes.")
    (license license:lppl)))

(define-public texlive-smalltableof
  (package
    (name "texlive-smalltableof")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/smalltableof/"
                                     "tex/latex/smalltableof/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "022m2n0524mcgzjq4ba1sm76alwy78h4w83kvc68h3yzfb6i7mm6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/smalltableof")
    (synopsis "Create @code{listoffigures}, etc., in a single chapter")
    (description
     "The package allows you to create a list of figures and list of tables in
a chapter named List that contains separate sections for each list of figures,
tables, etc.")
    (license license:lppl)))

(define-public texlive-smart-eqn
  (package
    (name "texlive-smart-eqn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/smart-eqn/"
                                     "source/latex/smart-eqn/"
                                     "tex/latex/smart-eqn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1w98b1m1i43rk12392vqbw92133ijf5af0xwd85a0bjixjfrjdwb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/smart-eqn")
    (synopsis "Automatic math symbol styling for LaTeX documents")
    (description
     "In LaTeX typesetting, one usually needs to use different variants of a math
symbol to clarify the meanings.  For example, in linear algebra literature, it
is common to use boldfaced symbols to represent vectors, and normal symbols to
represent scalars.  However, applying these variants by typing
@code{\\mathbf}, @code{\\mathrm} commands manually can be daunting.  This
package aims to provide an automatic and customizable approach for math symbol
styling which eliminates the need to enter style commands repeatedly.")
    (license license:lppl1.3c)))

(define-public texlive-smartref
  (package
    (name "texlive-smartref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/smartref/" "tex/latex/smartref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11fvmy3173spkg8y8l9nfjwlfnhyqhz4mp8h32234x72ybjhkmhl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/smartref")
    (synopsis "Extend LaTeX's @code{\\ref} capability")
    (description
     "The package extends the LaTeX labelling system: whenever a label is set,
the values of counters (selected by the user) are recorded, along with the
label.  The value of these counters can be recalled with a command similar to
@code{\\pageref}.

The package also adds commands @code{\\s@var{NAME}ref} (for each counter
@var{NAME} that the user has selected); these commands display something only
if the value of the @var{NAME} counter is changed from when the label was set.
Many commands are provided to serve as a macro programming environment for
using the extended labels.")
    (license license:lppl)))

(define-public texlive-smartunits
  (package
    (name "texlive-smartunits")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/smartunits/"
                                     "tex/latex/smartunits/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "002962fis50p644izb5rj0yx8b54h7jj98ksxrfn5043hxq80za8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/smartunits")
    (synopsis "Converting between common metric and Imperial units")
    (description
     "This LaTeX package implements a @code{\\SmartUnit} macro for converting
between (some) metric and Imperial units.")
    (license license:lppl1.3+)))

(define-public texlive-snapshot
  (package
    (name "texlive-snapshot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/snapshot/"
                                     "source/latex/snapshot/"
                                     "tex/latex/snapshot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1skw799vxasx87ib0avmjh1wspj4h21r9lys8xyxmazm1xgwfjj3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/snapshot")
    (synopsis "List the external dependencies of a LaTeX document")
    (description
     "The @code{snapshot} package helps the owner of a LaTeX document obtain a list
of the external dependencies of the document, in a form that can be embedded
at the top of the document.  It provides a snapshot of the current processing
context of the document, insofar as it can be determined from inside LaTeX.
If a document contains such a dependency list, then it becomes possible to
arrange that the document be processed always with the same versions of
everything, in order to ensure the same output.  This could be useful for
someone wanting to keep a LaTeX document on hand and consistently reproduce an
identical DVI file from it, on the fly; or for someone wanting to shield
a document during the final stages of its production cycle from unexpected
side effects of routine upgrades to the TeX system.")
    (license license:lppl1.3c)))

(define-public texlive-snaptodo
  (package
    (name "texlive-snaptodo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/snaptodo/" "tex/latex/snaptodo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0iya0njq8icvf084ifs76hhbbc50h9livsp499v85r9x77hblmlf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/snaptodo")
    (synopsis "Todo that snaps to the closer side")
    (description
     "This package is an alternative to @code{todonotes}, from which it differs in
the following ways: depending on where you call @code{\\snaptodo}, the note is
put in the left or the right margin, whichever is closer.  The notes bump each
other so they never overlap; the lines never overlap either.  Aesthetic and
customizable style.")
    (license license:lppl1.3c)))

(define-public texlive-snotez
  (package
    (name "texlive-snotez")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/snotez/" "tex/latex/snotez/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "075aj3lbmqsvsj0vpq79zbdl64ghcym47k2kc6ijfad2k9ygijbm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/snotez")
    (synopsis "Typeset notes, in the margin")
    (description
     "The package provides a macro @code{\\sidenote}, that places a note in the
margin of the document, with its baseline aligned with the baseline in the
body of the document.  These sidenotes are numbered (both in the text, and on
the notes themselves).")
    (license license:lppl1.3c)))

(define-public texlive-soulpos
  (package
    (name "texlive-soulpos")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/soulpos/" "tex/latex/soulpos/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "11z7h0rawvvlghi5rgcr0hhvk203sp0yvs1k5r62czvsacby0qzk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-oberdiek texlive-soul))
    (home-page "https://ctan.org/pkg/soulpos")
    (synopsis "Fancy means of underlining")
    (description
     "The package combines the use of @code{soul} with the @code{savepos} mechanism
of current pdfTeX so that the user can create (almost) arbitrary underlining
and similar decorations, including rules, leaders and even pictures (PGF,
PSTricks, etc.).  Unlike @code{soul} underlines, which are built by repeating
small elements, here each chunk of text to be underlined is a single element.")
    (license license:expat)))

(define-public texlive-spacingtricks
  (package
    (name "texlive-spacingtricks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/spacingtricks/"
                                     "source/latex/spacingtricks/"
                                     "tex/latex/spacingtricks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1asf35qbqzcyf37qikhjx9sp1rbknkc8khj5bx3qplwbqiz6qk56"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/spacingtricks")
    (synopsis "Dealing with some spacing issues")
    (description
     "This package provides macros for dealing with some spacing issues, e.g.,
centering a single line, making a variable strut, indenting a block,
typesetting a compact list, placing two boxes side by side with vertical
adjustment.")
    (license license:lppl1.3+)))

(define-public texlive-spark-otf
  (package
    (name "texlive-spark-otf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/spark-otf/"
                                     "fonts/opentype/public/spark-otf/"
                                     "tex/latex/spark-otf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kydm3ixnnnv2r40aayr6hg7ky9lh4y1xyar26ip45d8a45plll2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/spark-otf")
    (synopsis "Support OpenType Spark fonts")
    (description
     "The package supports the fonts from @emph{After the Flood} which are
available from AtF Spark.")
    (license (list license:silofl1.1 license:lppl1.3+))))

(define-public texlive-sparklines
  (package
    (name "texlive-sparklines")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sparklines/"
                                     "tex/latex/sparklines/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0p40s93s51bf67gf8mq5v888mm9nhabwd4gr8lyhaf5hhl2g8909"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sparklines")
    (synopsis "Drawing sparklines: intense, simple, wordlike graphics")
    (description
     "Sparklines are intense, simple, wordlike graphics.  A sparkline can be added
using the @code{sparkline} environment.  Also, you can add sparkling
rectangles for the median and special sparkling dots in red or blue.  The
package requires pdfLaTeX; sparklines cannot appear in a DVI file.  The
sparklines package uses PGF.")
    (license license:lppl)))

(define-public texlive-sphack
  (package
    (name "texlive-sphack")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sphack/" "tex/latex/sphack/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pami588h0lw8f79idy088bwhfjrf2q993nrjw8cb0bpsbqqmrx6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sphack")
    (synopsis "Patch LaTeX kernel spacing macros")
    (description
     "This package changes the kernel internal
@code{\\@@bsphack}/@code{\\@@esphack} so that it is also invisible in vertical
mode.")
    (license license:knuth)))

(define-public texlive-splitindex
  (package
    (name "texlive-splitindex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/splitindex/"
                                     "doc/man/man1/splitindex.1"
                                     "doc/man/man1/splitindex.man1.pdf"
                                     "scripts/splitindex/"
                                     "source/latex/splitindex/"
                                     "tex/generic/splitindex/"
                                     "tex/latex/splitindex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "14c7x81zqvwwdd54jvjkyr34inhfppidcask6wx9w23xsy8mr8y8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "splitindex.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/splitindex")
    (synopsis "Unlimited number of indexes")
    (description
     "SplitIndex consists of a LaTeX package, @code{splitidx}, and a small program,
@code{splitindex}.  The package may be used to produce one index or several
indexes.  Without @command{splitindex}, the number of indexes is limited by
the number of TeX's output streams.  But using the program you may use even
more than 16 indexes: @command{splitidx} outputs only a single file and the
program splits that file into several raw index files and calls your favorite
index processor for each of the files.")
    (license license:lppl)))

(define-public texlive-spot
  (package
    (name "texlive-spot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/spot/" "source/latex/spot/"
                                     "tex/latex/spot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05y83rvvxnlgq77clmf3k7id72v5lnyfvxhyp30gfaxni68v44n5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/spot")
    (synopsis "Spotlight highlighting for Beamer")
    (description
     "The package allows dramatic highlighting of words and phrases by painting
shapes around them.  It is chiefly intended for use in Beamer presentations,
but it can be used in other document classes as well.")
    (license license:lppl1.3+)))

(define-public texlive-spotcolor
  (package
    (name "texlive-spotcolor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/spotcolor/"
                                     "tex/latex/spotcolor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "10nnal9cffwvwpw108fbkfhn7q4labs9xnb5nfz1sn9wk4li3j30"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/spotcolor")
    (synopsis "Spot colours for pdfLaTeX")
    (description
     "This package provides procedures for using spot colours in LaTeX documents
and the generated PDF files.  Predefined templates for PANTONE and HKS colour
spaces are included but new ones can easily be defined.")
    (license license:lppl)))

(define-public texlive-spreadtab
  (package
    (name "texlive-spreadtab")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/spreadtab/"
                                     "tex/latex/spreadtab/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0iz10jx2pxpwqbc9xm0s6yib2v6xb5h4wy6ygxclzams7xa4xb79"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/spreadtab")
    (synopsis "Spreadsheet features for LaTeX tabular environments")
    (description
     "The package allows the user to construct tables in a manner similar to
a spreadsheet.  The cells of a table have row and column indices and these can
be used in formulas to generate values in other cells.")
    (license license:lppl1.3c)))

(define-public texlive-spverbatim
  (package
    (name "texlive-spverbatim")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/spverbatim/"
                                     "source/latex/spverbatim/"
                                     "tex/latex/spverbatim/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nxnq5naphz9kj4a6d3yv8x9xamqi4lnhrmd9jbw4saknwc77n7p"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/spverbatim")
    (synopsis "Allow line breaks within @code{\\verb} and verbatim output")
    (description
     "LaTeX's @code{\\verb} macro treats its argument as an unbreakable unit of
text.  This can lead to poor typesetting, especially when the argument is
long.  The @code{spverbatim} package provides an @code{\\spverb} macro that is
analogous to @code{\\verb} and an @code{spverbatim} environment that is
analogous to verbatim with the difference being that @code{\\spverb} and
spverbatim allow LaTeX to break lines at space characters.")
    (license license:lppl)))

(define-public texlive-srbook-mem
  (package
    (name "texlive-srbook-mem")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/srbook-mem/"
                                     "tex/latex/srbook-mem/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1v6wwxr5hkda98wqccvfm3clch6w27lwkh3z01lgn652v6q110yj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/serbian-book")
    (synopsis "Support for use of @code{memoir} in Serbian")
    (description
     "The package provides a number of commands for adjusting @code{memoir} output
to Serbian style.")
    (license license:gpl3+)))

(define-public texlive-srcltx
  (package
    (name "texlive-srcltx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/srcltx/" "source/latex/srcltx/"
                                     "tex/latex/srcltx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yj6clsb89n0aiz8pn7il1vf2pfg369psys3b73dncf92dhlawff"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/srcltx")
    (synopsis "Jump between DVI and TeX files")
    (description
     "This package provides a @code{\\special} insertion into generated @file{.dvi}
files allowing one to jump from the @file{.dvi} file to the @file{.tex} source
and back again (given a @file{.dvi} viewer that supports this).")
    (license license:public-domain)))

(define-public texlive-sseq
  (package
    (name "texlive-sseq")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sseq/" "source/latex/sseq/"
                                     "tex/latex/sseq/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02qfqnihvyffs7j4avjn9v7z0z0p07ki10yjbxrimlj0drqcmhqv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sseq")
    (synopsis "Typesetting spectral sequence charts")
    (description
     "The package provides commands to draw spectral sequence diagrams, providing
facilities for clipping and arranging multiple symbols so that they do not
overlap.  The package is built using PGF, and shares that systems large
demands for TeX system memory.  Its geometric commands are based on a turtle
graphics model, and control structures such as loops and conditionals are
available.")
    (license license:lppl)))

(define-public texlive-sslides
  (package
    (name "texlive-sslides")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sslides/" "tex/latex/sslides/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rplfdzzp15h3xsszzr7hcbb40kqd6bbqv8850ip8df4yd19mb8r"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sslides")
    (synopsis "Slides with headers and footers")
    (description
     "The class provides a variant of the LaTeX standard slides class, in which the
user may add headers and footers to the slide.")
    (license license:lppl1.3+)))

(define-public texlive-stack
  (package
    (name "texlive-stack")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "source/latex/stack/" "tex/latex/stack/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0annz6qz921m1f7l2scqsg9kh10xxihizwf0gg10drm6yvxmy7ha"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/stack")
    (synopsis "Tools to define and use stacks")
    (description
     "The package provides a small set of commands to implement stacks
independently of TeX's own stack.  As an example of how the stacks might be
used, the documentation offers a small @code{relinput} package that implements
the backbone of the @code{import} package.")
    (license license:lppl)))

(define-public texlive-stdclsdv
  (package
    (name "texlive-stdclsdv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/stdclsdv/"
                                     "source/latex/stdclsdv/"
                                     "tex/latex/stdclsdv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hk74qclq68f4lhm4yz548zw4nmy4hldr64ijvlsw5s6l3azhzqq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/stdclsdv")
    (synopsis "Provide sectioning information for package writers")
    (description
     "The @code{stdclsdv} package is designed for package writers who need to know
what sectioning divisions are provided by the document's class.  It also
provides a version of @code{\\CheckCommand} that sets a flag rather than
printing a warning.")
    (license license:lppl)))

(define-public texlive-stdpage
  (package
    (name "texlive-stdpage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/stdpage/" "source/latex/stdpage/"
                                     "tex/latex/stdpage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "064l0mj06wnacz7hcgf9c4nqc6f7l2fyg6gvq797vbdffgw721wd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/stdpage")
    (synopsis "Standard pages with n lines of at most m characters each")
    (description
     "For translations, proofreading, journal contributions etc., standard pages
are used.  Those standard pages consist of a fixed number of lines and
characters per line.  This package produces pages with n lines of at most
m characters each.")
    (license license:lppl1.2+)))

(define-public texlive-stealcaps
  (package
    (name "texlive-stealcaps")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/stealcaps/"
                                     "source/latex/stealcaps/"
                                     "tex/latex/stealcaps/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05lskyv9k4mgkzw08cknbcgbx6d64my7qjc2jljhqgmjsxd4yh07"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/stealcaps")
    (synopsis "``Steal'' small capitals")
    (description
     "This little package is mainly meant to be used when there is a (TrueType or
OpenType) font that does not provide real small capitals.  As a workaround,
this package helps to borrow, or steal, the small capitals from another font.
This might also be useful in the rare case that someone does not like the
present small capitals, and wants to change them, or likes those from another
font better.  To achieve the borrowing, one only needs to load the package and
specify the name of the target font via the from option.")
    (license license:lppl1.3c)))

(define-public texlive-stex
  (package
    (name "texlive-stex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/stex/" "source/latex/stex/"
                                     "tex/latex/stex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p5icw5c8c6k82ycy91d4rvypk4yd958jglcxb6vhqi6hnjagpp5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/stex")
    (synopsis "Infrastructure for semantic preloading of LaTeX documents")
    (description
     "The sTeX package collection is a version of (La)TeX that allows marking
up (La)TeX documents semantically without leaving the document format,
essentially turning it into a document format for mathematical knowledge
management (MKM).")
    (license license:lppl)))

(define-public texlive-storecmd
  (package
    (name "texlive-storecmd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/storecmd/" "tex/latex/storecmd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ds88g5zb97vjlijnk2vq487ixs3pklq7f9fn66j17cdcnsz619f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/storecmd")
    (synopsis "Store the name of a defined command in a container")
    (description
     "The package provides macros for command definition that save the name of the
command being defined in a file or a macro container.  The list could be
useful for spelling exceptions in text editors that do not support TeX
syntax.")
    (license license:lppl1.3+)))

(define-public texlive-stringstrings
  (package
    (name "texlive-stringstrings")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/stringstrings/"
                                     "source/latex/stringstrings/"
                                     "tex/latex/stringstrings/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ayqzw5z2kj8q87zh0x9m8wk6swnz87s4ils21z557izqb668w4y"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/stringstrings")
    (synopsis "String manipulation for cosmetic and programming application")
    (description
     "The package provides a large and sundry set of macros for the manipulation of
strings.  The macros are developed not merely for cosmetic application (such
as changing the case of letters and string substitution), but also for
programming applications such as character look-ahead, argument parsing,
conditional tests on various string conditions, etc.  The macros were designed
all to be expandable (note that things such as @code{\\uppercase} and
@code{\\lowercase} are not expandable), so that the macros may be strung
together sequentially and nested (after a fashion) to achieve rather complex
manipulations.")
    (license license:lppl1.3+)))

(define-public texlive-sttools
  (package
    (name "texlive-sttools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/sttools/" "source/latex/sttools/"
                                     "tex/latex/sttools/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dvx30fzzkf632c3qnz7bg2ljlnawz7440qga8shcdb70i951lgm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/sttools")
    (synopsis "Various macros")
    (description
     "This package provides a collection of tools and macros, providing:
miscellaneous float control, page styles for floats, multipage tabulars, even
columns at end of twocolumn region, switching between one- and two-column
anywhere, simulating the effect of ``midfloats'', a package to manipulate
numerical lists and arrays.")
    (license license:lppl1.3+)))

(define-public texlive-stubs
  (package
    (name "texlive-stubs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/stubs/" "tex/latex/stubs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bd4ccv4lgrh0z471aqh63pdydg93ba8wkqr2a9q513y8l93i00f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/stubs")
    (synopsis "Create tear-off stubs at the bottom of a page")
    (description
     "The @code{\\stubs} command creates as many repetitions as possible of its
argument, at the bottom of the page; these stubs may be used (for example) for
contact information.")
    (license license:gpl3+)))

(define-public texlive-studenthandouts
  (package
    (name "texlive-studenthandouts")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/studenthandouts/"
                                     "tex/latex/studenthandouts/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n6h1dl6lyipaxngrlxqf8if2mv0fihvsz0kvgcn1nv002sjw9wi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/studenthandouts")
    (synopsis "Management and styling of student handout projects")
    (description
     "This package can be used to generate a single master document that contains
a set of individual student handouts.  The package has two main functions.
First, it provides a simple framework for organizing handout source code, and
supplies a set of import management tools for selectively importing a subset
of the handouts into the master document.  Selective import is convenient when
compilation of all of the handouts is unnecessary, for example when working on
a new handout.  As a secondary feature, the package defines a basic visual
style for handouts.  This style can be easily changed.")
    (license license:lppl1.3+)))

(define-public texlive-styledcmd
  (package
    (name "texlive-styledcmd")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/styledcmd/"
                                     "source/latex/styledcmd/"
                                     "tex/latex/styledcmd/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18dmxdmf1sg1y91y19n0qwqvk1053cb5m0r7maf80hsnjfi4vkfk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/styledcmd")
    (synopsis "Handling multiple versions of user-defined macros")
    (description
     "This package allows creating and maintaining different versions of the same
command, in order to choose the best option for every document.  This includes
expandable and protected commands.")
    (license license:gpl3+)))

(define-public texlive-subdepth
  (package
    (name "texlive-subdepth")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/subdepth/"
                                     "source/latex/subdepth/"
                                     "tex/latex/subdepth/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1h79qghibgnfz2savf158c6qkliizif95azma905rpwhz06zw1f9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/subdepth")
    (synopsis "Unify maths subscript height")
    (description
     "This package is based on code to equalise the height of subscripts in maths.
The default behaviour is to place subscripts slightly lower when there is
a superscript as well, but this can look odd in some situations.")
    (license license:lppl)))

(define-public texlive-subdocs
  (package
    (name "texlive-subdocs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/subdocs/" "tex/latex/subdocs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1j30b926n15i3dbdw4xgd241a9g7q084lbalaq7sf4pkjqjj9zh8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/subdocs")
    (synopsis "Multifile documents")
    (description
     "This is an experimental package aiming to provide a different approach for
multidocument works (mainly, books with a document per chapter).  Unlike the
@code{\\include} mechanism, every subdocument is a complete normal LaTeX
document and may be typeset separately.  What the package does is sharing the
@file{.aux} files.")
    (license license:expat)))

(define-public texlive-subeqn
  (package
    (name "texlive-subeqn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/subeqn/" "source/latex/subeqn/"
                                     "tex/latex/subeqn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0x58m2lsjc8d3m673g59cxw3a81cj5699cd8vvps1fly0fsl5azb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/subeqn")
    (synopsis "Package for subequation numbering")
    (description
     "Sometimes it is necessary to be able to refer to subexpressions of an
equation.  In order to do that these subexpressions should be numbered.  In
standard LaTeX there is no provision for this.  The @code{subeqn} package
solves this.  Note that this package is not compatible with the package
@code{subeqnarray}, but it can be used together with the LaTeX class options
@code{leqno} and @code{fleqn}.")
    (license license:lppl)))

(define-public texlive-subeqnarray
  (package
    (name "texlive-subeqnarray")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/subeqnarray/"
                                     "source/latex/subeqnarray/"
                                     "tex/latex/subeqnarray/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19jv7sl6p1kshv13wk813lndb9fjr4bf2rf4s1ffd0l253mmxch6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/subeqnarray")
    (synopsis "Equation array with sub numbering")
    (description
     "This package defines the @code{subeqnarray} and @code{subeqnarray*}
environments, which behave like the corresponding @code{eqnarray} and
@code{eqnarray*} environments, except that the individual lines are numbered
like @samp{1a}, @samp{1b}, etc.  To refer to these numbers an extra label
command @code{\\slabel} is provided.  Users are urged to consider the
alignment capabilities of the @code{amsmath} bundle, which produce better
results than @code{eqnarray}-related macros.")
    (license license:lppl)))

(define-public texlive-subfigmat
  (package
    (name "texlive-subfigmat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/subfigmat/"
                                     "tex/latex/subfigmat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1656zcs1zay6pz1sqlhnspbphg7zkq7ziyxb8kkn943f2a8azmka"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/subfigmat")
    (synopsis "Automates layout when using the @code{subfigure} package")
    (description
     "This package defines an @code{array}/@code{matrix}-type environment that is
used with the @code{subfigure} package to automate the placement of
sub-figures (or tables or text).  The sub-figures are placed left-to-right,
top-to-bottom.")
    (license license:lppl)))

(define-public texlive-subfloat
  (package
    (name "texlive-subfloat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/subfloat/"
                                     "source/latex/subfloat/"
                                     "tex/latex/subfloat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "119p6vf8ai1sfhma3aplkyldiypjnfc6qj08xnij69szk6yq6gdv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/subfloat")
    (synopsis "Sub-numbering for figures and tables")
    (description
     "This package enables sub-numbering of floats (figures and tables) similar to
the @code{subequations} environment of the @code{amsmath} package.  The
@code{subfloat} package is not to be confused with the @code{subfig} package
which generates sub-figures within one normal figure, and manages their
placement; @code{subfloat} only affects captions and numbering.")
    (license license:lppl)))

(define-public texlive-suppose
  (package
    (name "texlive-suppose")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/suppose/" "tex/latex/suppose/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jll93kng5kkbl1f5yvclaclvxl5kcbsv76vbzmv2p0v271miybn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/suppose")
    (synopsis "Abbreviate the word @emph{Suppose}")
    (description
     "This package provides commands for abbreviating the word ``Suppose'' in six
fonts and with other variations.  The author recommends only using these
commands when the immediately succeeding strings are mathematical in nature.
He does not recommend using them in formal work.")
    (license license:lppl1.3c)))

(define-public texlive-svgcolor
  (package
    (name "texlive-svgcolor")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/svgcolor/" "tex/latex/svgcolor/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fhgxms95j65mn3q9bj2xckp7gsjza2swwqkvlhzszk5kc2lq0l4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/svgcolor")
    (synopsis "Define SVG named colours")
    (description
     "The package defines the W3C @acronym{SVG, Scalable Vector Graphics} colour
names for use with both the @code{color} and PSTricks packages.")
    (license license:lppl)))

(define-public texlive-svn
  (package
    (name "texlive-svn")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/svn/" "source/latex/svn/"
                                     "tex/latex/svn/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1q4l4vhvkzkv5bsbp11vfmqxf407l4y4s8840qva7nc7cwvc3n7b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/svn")
    (synopsis "Typeset Subversion keywords")
    (description
     "The @code{svn} package lets you typeset (in LaTeX) the value of Subversion
keywords.  It is approximately an equivalent to the @code{rcs} package, but
for Subversion rather than CVS.")
    (license license:lppl1.3+)))

(define-public texlive-svn-multi
  (package
    (name "texlive-svn-multi")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/svn-multi/"
                                     "doc/support/svn-multi/"
                                     "scripts/svn-multi/"
                                     "source/latex/svn-multi/"
                                     "tex/latex/svn-multi/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sfvp00c7bcql1hdmsmvc28jhngc553g8ldrjglvjp8gvcfpjww5"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ydoc")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "svn-multi.pl")))
    (native-inputs (list texlive-ydoc))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/svn-multi")
    (synopsis "Subversion keywords in multi-file LaTeX documents")
    (description
     "This package lets you typeset keywords of the version control system
Subversion inside your LaTeX files anywhere you like.  Unlike the otherwise
similar package @code{svn}, the use of multiple files for one LaTeX document
is well supported.  The package interacts with an external Perl script, to
retrieve information necessary for the required output.")
    (license license:lppl)))

(define-public texlive-svninfo
  (package
    (name "texlive-svninfo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/svninfo/" "source/latex/svninfo/"
                                     "tex/latex/svninfo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y0lxpp1lqznvsxvckhcnvw3l712l9prfb9gi56csypngaqph5rb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/svninfo")
    (synopsis "Typeset Subversion keywords")
    (description
     "This is a package for incorporating the values of Subversion keywords into
typeset documents.")
    (license license:lppl1.0+)))

(define-public texlive-swfigure
  (package
    (name "texlive-swfigure")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/swfigure/"
                                     "source/latex/swfigure/"
                                     "tex/latex/swfigure/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1w2s9wil773dypa7xllbvawbdk41qdfzwy19pya17z8qp8csjqvh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/swfigure")
    (synopsis "Insert large images that do not fit into a single page")
    (description
     "This package defines five different display modes in order to place in
a document large figures that do not fit into a single page.  A single user
macro is defined to handle all five display modes.")
    (license license:lppl1.3c)))

(define-public texlive-swungdash
  (package
    (name "texlive-swungdash")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/swungdash/"
                                     "tex/latex/swungdash/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b8qq8yh6rp6gmglgbi4afdd48hbhd2gncxcjarwddy1x127jc62"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/swungdash")
    (synopsis "Typeset a swung dash in LaTeX")
    (description
     "The swung dash (U+2053) is a useful character traditionally used in
typsetting dictionaries, but not supported by most typefaces.  This package
provides one simple command to typeset a swung dash in XeLaTeX and LuaLaTeX,
by applying transformations to the given font's glyph for a tilde.")
    (license license:lppl1.3c)))

(define-public texlive-syntax
  (package
    (name "texlive-syntax")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/syntax/" "tex/latex/syntax/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n064jqsgcz3g6nkqmd05zpaf8hivm48mdms39a69cmw5958am9j"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/syntax2")
    (synopsis "Creation of syntax diagrams")
    (description
     "This package creates syntax diagrams using special environments and commands
to represent the diagram structure.")
    (license license:gpl3+)))

(define-public texlive-syntrace
  (package
    (name "texlive-syntrace")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/syntrace/"
                                     "source/latex/syntrace/"
                                     "tex/latex/syntrace/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qdl3vriidpdl3cpa05r2h2dv3i8bmqf5l47313mghyz1pilkrga"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/syntrace")
    (synopsis "Labels for tracing in a syntax tree")
    (description
     "This package adds support for traces in trees created using either the
@code{synttree} or the @code{qtree} package.  The package provides two
commands @code{(\\traceLabel} and @code{\\traceReference)} to set and use
a trace.")
    (license license:lppl)))

(define-public texlive-synttree
  (package
    (name "texlive-synttree")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/synttree/"
                                     "source/latex/synttree/"
                                     "tex/latex/synttree/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a2ifj2922477vn7gljis6gv9p51q1c0kpl3y7vyb016pmg9ny04"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/synttree")
    (synopsis "Typeset syntactic trees")
    (description
     "This package provides a package to typeset syntactic trees such as those used
in Chomsky's generative grammar, based on a description of the structure of
the tree.")
    (license license:lppl)))

(define-public texlive-tabbing
  (package
    (name "texlive-tabbing")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tabbing/" "source/latex/tabbing/"
                                     "tex/latex/tabbing/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1dpkirz4318031ikq3y1134y19cyq6lgzhj610w12zywfmdy5jcj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tabbing")
    (synopsis "Tabbing with accented letters")
    (description
     "By default, some of the tabbing environment's commands clash with default
accent commands; LaTeX provides the odd commands @code{\\a'}, etc., to deal
with the clash.  The package offers a variant of the @code{tabbing}
environment which does not create this difficulty, so that users need not
learn two sets of accent commands.")
    (license license:lppl1.0+)))

(define-public texlive-tabfigures
  (package
    (name "texlive-tabfigures")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tabfigures/"
                                     "source/latex/tabfigures/"
                                     "tex/latex/tabfigures/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18z0w4q5s1pz1r39b6ca8d5l7gp0x9dg9l4b351wsr1jjcci60c0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tabfigures")
    (synopsis "Maintain vertical alignment of figures")
    (description
     "Knuth designed his original fonts with tabular figures (figures whose width
is uniform); this makes some layout problems rather simple.  In more recent
times, fonts (such as Minion Pro), which offer proportionally spaced figures,
are increasingly being used.  The package provides mechanisms whereby such
proportional figures may still be aligned in tabular style (for example, in
the table of contents).")
    (license license:lppl1.3+)))

(define-public texlive-tableaux
  (package
    (name "texlive-tableaux")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tableaux/" "tex/latex/tableaux/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "021qins7h014pjg297iih071n45mqabx8sf0vr78ln9k984h7v8l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tableaux")
    (synopsis "Construct tables of signs and variations")
    (description
     "The package uses PSTricks; the user may define the width of the table, the
number of lines and the height of each line.  Placement of labels within the
boxes may be absolute, or as a percentage of the width; various other controls
are available.")
    (license license:lppl)))

(define-public texlive-tablefootnote
  (package
    (name "texlive-tablefootnote")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tablefootnote/"
                                     "source/latex/tablefootnote/"
                                     "tex/latex/tablefootnote/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1179jcgjnsh6plk4kfcyyczjx0xcn2cjdc413kfz4pxmx7592jdn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tablefootnote")
    (synopsis "Permit footnotes in tables")
    (description
     "The package provides the command @code{\\tablefootnote} to be used in
a @code{table} or @code{sidewaystable} environment, where @code{\\footnote}
will not work (and when using @code{\\footnotemark} and @code{\\footnotetext},
and adjusting the counter as necessary, is too much work).")
    (license license:lppl1.3+)))

(define-public texlive-tableof
  (package
    (name "texlive-tableof")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tableof/" "source/latex/tableof/"
                                     "tex/latex/tableof/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05dj51js7nvks16k7wmdjmxf771bnmfjfrv3ilpkyaj6ahadkav9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tableof")
    (synopsis "Tagging tables of contents")
    (description
     "The package provides the commands to flag chapters or sections (or anything
else destined to become a TOC line).  The command
@code{\\nexttocwithtags@{req1,req2,...@}@{excl1,excl2,...@}} specifies which
tags are to be required and which ones are to be excluded by the next
@code{\\tableofcontents} (or equivalent) command.  In a document that uses
a class where @code{\\tableofcontents} may only be used once, the command
@code{\\tableoftaggedcontents@{req1,req2,...@}@{excl1,excl2,...@}} may be used
to provide several tables.")
    (license license:lppl1.3+)))

(define-public texlive-tablists
  (package
    (name "texlive-tablists")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tablists/"
                                     "source/latex/tablists/"
                                     "tex/latex/tablists/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bwwqzdfsqnm338qwnc0lnyskk58k6s4lr0v2gfizskamzygmi1b"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-etoolbox
                  texlive-fontinst
                  texlive-helvetic
                  texlive-hypdoc
                  texlive-makecell
                  texlive-paralist
                  texlive-psnfss))))
    (home-page "https://ctan.org/pkg/tablists")
    (synopsis "Tabulated lists of short items")
    (description
     "This package offers environments and commands for one-level and two-level
lists of short items (e.g., exercises in textbooks).  The environments support
optional arguments of item numbering similar to the @code{enumerate} or
@code{paralist} packages.")
    (license license:lppl)))

(define-public texlive-tabls
  (package
    (name "texlive-tabls")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tabls/" "tex/latex/tabls/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rc8h2704ca5v7l3lxdm0mmnqc52bci216n6kylwl3770mgwivqw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tabls")
    (synopsis "Better vertical spacing in tables and arrays")
    (description
     "This package modifies LaTeX's @code{array} and @code{tabular} environments to
keep text from touching other text or hlines above or below.  Several new
parameters are defined and some standard macros are re-defined.  The package
slows down compilation of tables, since each entry is boxed twice.")
    ;; These macros may be freely used, transmitted, reproduced, or modified
    ;; provided that this notice is left intact.
    (license (license:fsf-free "file://tex/latex/tabls/tabls.sty"))))

(define-public texlive-tablvar
  (package
    (name "texlive-tablvar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tablvar/" "source/latex/tablvar/"
                                     "tex/latex/tablvar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0f937zz04b179y19amzwgpwm4406mmfdgclfxbfpnb9iwhqs15zm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tablvar")
    (synopsis
     "Typesetting pretty tables of signs and variations according to French usage")
    (description
     "This is a complete and easy-to-use package for typesetting pretty tables of
signs and variations according to French usage.  The syntax is similar to that
of the @code{array} environment and uses intuitive position commands.  Arrows
are drawn automatically (using PSTricks by default or TikZ as an option).
Macros are provided for drawing twin bars, single bars crossing the zeros,
areas where the function is not defined, or placing special values.  Several
features of the variation tables can be customized.")
    (license license:lppl1.3+)))

(define-public texlive-tabstackengine
  (package
    (name "texlive-tabstackengine")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tabstackengine/"
                                     "tex/latex/tabstackengine/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qj9w9rjsakrijy953ab2sa5k92npvvm4zz1y2z4k4a78g981q0n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tabstackengine")
    (synopsis "\"Tabbing\" front-end to stackengine")
    (description
     "The package provides a front end to the @code{stackengine} package,
to allow tabbed stacking.  In most cases, an existing @code{stackengine}
command may be prepended with the word @samp{tabbed}, @samp{align} or
@samp{tabular} to create a new tabbed version of a stacking macro.  In
addition, hooks in the package's parser that tabbed strings of data may be
parsed, extracted, and reconstituted (not requiring use of any stacking
constructions).")
    (license license:lppl1.3+)))

(define-public texlive-tabularborder
  (package
    (name "texlive-tabularborder")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tabularborder/"
                                     "source/latex/tabularborder/"
                                     "tex/latex/tabularborder/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qjjr19f5cxpvvbrna6rg506w8j72dqqddxd412z6r4pcmnbiqd4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tabularborder")
    (synopsis "Remove excess space at left and right of tabular")
    (description
     "The tabular environment is changed so that the outer @code{\\tabcolseps} are
compensated and a @code{\\hline} has the same length as the text.")
    (license license:lppl1.2+)))

(define-public texlive-tabularcalc
  (package
    (name "texlive-tabularcalc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tabularcalc/"
                                     "tex/latex/tabularcalc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xcwn9cqs32z8kfb37k1i1hyxaqjvrbhnriy5fa9spymlrb4pi3i"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tabularcalc")
    (synopsis "Calculate formulas in a tabular environment")
    (description
     "Given a list of numbers and one (or more) formulas, the package offers an
easy syntax to build a table of values, i.e., a tabular in which the first row
contains the list of numbers, and the other rows contain the calculated values
of the formulas for each number of the list.  The table may be built either
horizontally or vertically and is fully customizable.")
    (license license:lppl)))

(define-public texlive-tabularew
  (package
    (name "texlive-tabularew")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tabularew/"
                                     "source/latex/tabularew/"
                                     "tex/latex/tabularew/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02xral8h2qbwm8mr4y701mrigk72x42kgjl9zki72qnx95fcy579"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tabularew")
    (synopsis "Variation on the @code{tabular} environment")
    (description
     "The package offers a modification of the @code{tabular} environment, which
deals with the problem of column heads that are significantly wider than the
body of the column.")
    (license license:lppl)))

(define-public texlive-tabularray
  (package
    (name "texlive-tabularray")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tabularray/"
                                     "tex/latex/tabularray/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wvwrqhf30jddhaax0gv67ia7j7r2lkv4rlwh10lvbwwi8ka59g7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tabularray")
    (synopsis "Typeset tabulars and arrays with LaTeX3")
    (description
     "LaTeX tables are implemented using TeX commands such as @code{\\halign},
@code{\\noalign}, @code{\\span}, and @code{\\omit}.  In order to implement new
features, many macro packages have modified the inner table commands inside
LaTeX.  This makes package code complicated, difficult to maintain, and often
conflicts with each other.  At present, the LaTeX3 programming layer is
basically mature.  This @code{tabularray} package will discard the old
@code{\\halign} commands and directly use LaTeX3 functions to parse the table,
and then typeset the entire table.  Under the premise of being compatible with
the basic syntax of LaTeX2 tables, this macro package will completely separate
the content and style of the table, and the style of the table can be
completely set in @code{keyval} way.")
    (license license:lppl1.3c)))

(define-public texlive-tagging
  (package
    (name "texlive-tagging")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tagging/" "tex/latex/tagging/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1w1rjdfaamk1ifjv0k39hnc70aj9h5iw3l7l9cnbf8yrkkha84f4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tagging")
    (synopsis "Document configuration with tags")
    (description
     "The package allows the user to generate multiple documents from a single
source, by marking pieces of the document with tags and specifying which
marked pieces to include or exclude.")
    (license license:lppl1.3+)))

(define-public texlive-tagpair
  (package
    (name "texlive-tagpair")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tagpair/" "tex/latex/tagpair/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pw5dip8p38djkksa7c11mzqvhglppy6n0zyv54zqrsd1fwjqwll"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tagpair")
    (synopsis
     "Word-by-word glosses, translations, and bibliographic attributions")
    (description
     "This package provides environments and commands for pairing lines, bottom lines,
and tagged lines, intended to be used in particular for word-by-word glosses,
translations, and bibliographic attributions, respectively.")
    (license license:lppl1.3+)))

(define-public texlive-tagpdf
  (package
    (name "texlive-tagpdf")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tagpdf/" "source/latex/tagpdf/"
                                     "tex/latex/tagpdf/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "198fagrxswp2dl3f4dww68gfvj1pv7xsb9mdcsmxsgksbgbqxp7d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tagpdf")
    (synopsis
     "Tools for experimenting with tagging using pdfLaTeX and LuaLaTeX")
    (description
     "The package offers tools to experiment with tagging and accessibility using
pdfLaTeX and LuaTeX.  It isn't meant for production but allows the user to try
out how difficult it is to tag some structures; to try out how much tagging is
really needed; to test what else is needed so that a PDF works e.g., with
a screen reader.  Its goal is to get a feeling for what has to be done, which
kernel changes are needed, how packages should be adapted.")
    (license license:lppl1.3c)))

(define-public texlive-talk
  (package
    (name "texlive-talk")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/talk/" "source/latex/talk/"
                                     "tex/latex/talk/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ws65g8m640dqclbzbl4ip2g3n0j1kpvp447f9sl71j4hxc3lvzx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/talk")
    (synopsis "LaTeX class for presentations")
    (description
     "The @code{talk} document class allows you to create slides for screen
presentations or printing on transparencies.  It also allows you to print
personal notes for your talk.  You can create overlays and display structure
information (current section / subsection, table of contents) on your slides.
The main feature that distinguishes talk from other presentation classes like
beamer or prosper is that it allows the user to define an arbitrary number of
slide styles and switch between these styles from slide to slide.  This way
the slide layout can be adapted to the slide content.  For example, the title
or contents page of a talk can be given a slightly different layout than the
other slides.  The talk class makes no restrictions on the slide design
whatsoever.  The entire look and feel of the presentation can be defined by
the user.")
    (license license:lppl)))

(define-public texlive-tamefloats
  (package
    (name "texlive-tamefloats")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tamefloats/"
                                     "tex/latex/tamefloats/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qsmyw732ilgdwhwhh4dnd1yhk2x3hn95sn9v6aq58mdlhax2cv0"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tamefloats")
    (synopsis "Experimentally use @code{\\holdinginserts} with LaTeX floats")
    (description
     "LaTeX's figures, tables, and @code{\\marginpars} are dangerous for footnotes (and
probably also @code{\\enlargethispage}).  Here is a proposal (a patch package) to help,
by using @code{\\holdinginserts} in a simple way.  It replaces the original problem with
a new one --- it is an experiment to find out whether the new problem is less bad
(or it is just a contribution to the discussion, maybe just a summary of
previous work).")
    (license license:lppl1.3+)))

(define-public texlive-tasks
  (package
    (name "texlive-tasks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tasks/" "tex/latex/tasks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sfgnwzpyfyvilyz7j12d6wql54rlcami682b32rf6xphxjs0z3b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tasks")
    (synopsis "Horizontally columned lists")
    (description
     "The reason for the creation of the @code{tasks} environment was an unwritten
agreement in German maths textbooks (especially (junior) high school
textbooks) to organize exercises in columns counting horizontally rather than
vertically.  This is what the @code{tasks} package helps to achieve.")
    (license license:lppl1.3c)))

(define-public texlive-tcldoc
  (package
    (name "texlive-tcldoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tcldoc/" "source/latex/tcldoc/"
                                     "tex/latex/tcldoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "09z9gdhidwsmn8h1a77smyyis8w03w8qw94biqcfqqzgsra2ling"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tclldoc")
    (synopsis "Doc/docstrip for Tcl")
    (description
     "The @code{tclldoc} package and class simplify the application of the
doc/docstrip style of literate programming with Tcl.  The @code{tclldoc}
package is a bit like the @code{doc} package is for LaTeX, whereas the
@code{tclldoc} class more parallels the @code{ltxdoc} class.")
    (license license:lppl)))

(define-public texlive-tdclock
  (package
    (name "texlive-tdclock")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tdclock/" "tex/latex/tdclock/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0az6h5avri7z7mvp222zwkd7n5nsnx8np73ym2rppp9d2j8fq9wb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tdclock")
    (synopsis "Ticking digital clock package for PDF output")
    (description
     "This package provides a ticking digital clock package to be used in pdfLaTeX
documents, for example in presentations.")
    (license license:gpl2)))

(define-public texlive-technics
  (package
    (name "texlive-technics")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/technics/" "tex/latex/technics/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nhh5zkm3w3n6bxxk7ysnwkff1bxkhzbc91aplz4d03j5yvy76l6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/technics")
    (synopsis "Format technical documents")
    (description
     "The package provides a very simple LaTeX document template, in the hope that
this use of LaTeX will become attractive to typical word processor
users. (Presentation is as if it were a class; users are expected to start
from a template document.)")
    (license license:lppl)))

(define-public texlive-ted
  (package
    (name "texlive-ted")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ted/" "source/latex/ted/"
                                     "tex/latex/ted/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0vkp71bpmhs3ys29cx4sxcvqqx63pqym6n87j3sr5hy7rw20ya0x"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-etoolbox
                  texlive-hypdoc
                  texlive-lm
                  texlive-microtype
                  texlive-minitoc))))
    (home-page "https://ctan.org/pkg/ted")
    (synopsis "Primitive token list editor")
    (description
     "Just like @code{sed} is a stream editor, @code{ted} is a token list editor.
The @code{ted} package provides two user macros: @code{\\Substitute} and
@code{\\ShowTokens}.  The first is maybe the most useful: it performs
substitutions in token lists (even inside braces).  The second displays each
token of the list (one per line) with its catcode (in the list, not just the
current one), and can be useful for debugging or for TeX learners.  Ted is
designed to work well even if strange tokens (that is, unusual
@samp{@{charcode, catcode@}} pairs or tokens with a confusing meaning) occur
in the list.")
    (license license:lppl)))

(define-public texlive-templatetools
  (package
    (name "texlive-templatetools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/templatetools/"
                                     "source/latex/templatetools/"
                                     "tex/latex/templatetools/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1phjqzldc1r7c637a6wyyb7na395bm869i5nyymv1z1f15jj8lsg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/templatetools")
    (synopsis "Commands useful in LaTeX templates")
    (description
     "The package provides a collection of tools, which are helpful for the
creation of a LaTeX template if conditional paths for code execution are
required.  All the commands work both in the preamble and in the document.")
    (license license:lppl1.3+)))

(define-public texlive-termcal
  (package
    (name "texlive-termcal")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/termcal/" "source/latex/termcal/"
                                     "tex/latex/termcal/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ikqi79g3vlcl7aqm4fdszz9172mgv8sd0b6gpx20pr74r6431p7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/termcal")
    (synopsis "Print a class calendar")
    (description
     "This package is intended to print a term calendar for use in planning a class.
It has a flexible mechanism for specifying which days of the week are to be
included and for inserting text either regularly on the same day each week, or
on selected days, or for a series of consecutive days.  It also has a flexible
mechanism for specifying class and non-class days.  Text may be inserted into
consecutive days so that it automatically flows around non-class days.")
    (license license:lppl1.0+)))

(define-public texlive-termlist
  (package
    (name "texlive-termlist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/termlist/"
                                     "source/latex/termlist/"
                                     "tex/latex/termlist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qj5b8n8b4g7asc010cpk265fx2zaxlb7l52q5l77pmqzg8p3k56"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/termlist")
    (synopsis "Label any kind of term with a continuous counter")
    (description
     "The @code{termlist} package provides environments to indent and label any
kind of terms with a continuous number.  Candidate terms may appear inside an
@code{equation} or @code{eqnarray} environment.")
    (license license:lppl)))

(define-public texlive-termsim
  (package
    (name "texlive-termsim")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/termsim/" "source/latex/termsim/"
                                     "tex/latex/termsim/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yz4kjvc4ip58vnwcvyiyg65sr9szy6z772cammdakx2ga344v78"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ctex")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ctex))
    (home-page "https://ctan.org/pkg/termsim")
    (synopsis "Simulate Win10, Ubuntu, and Mac terminals")
    (description
     "This package provides environments @code{terminal} and @code{terminal*}, and
macros @code{\\termfile} and @code{\\termfile*} to simulate Win10, Ubuntu and
Mac terminals.")
    (license license:lppl1.3c)))

(define-public texlive-testhyphens
  (package
    (name "texlive-testhyphens")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/testhyphens/"
                                     "source/latex/testhyphens/"
                                     "tex/latex/testhyphens/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1sw0anyv3la86hamkrnxjxach2j6hqr2lxakihz7ma3d2l545xwh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/testhyphens")
    (synopsis "Testing hyphenation patterns")
    (description
     "The package may be used for testing hyphenation patterns or for controlling
that specific words are hyphenated as expected.  This package implements some
old TUGboat code to adapt it to LaTeX with some enhancements.  It differs form
@code{\\showhyphens}, because it typesets its output on the document's output
file.  It also works with XeLaTeX, where @code{\\showhyphens} requires
a workaround.")
    (license license:lppl1.3+)))

(define-public texlive-testidx
  (package
    (name "texlive-testidx")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bib/testidx/" "doc/latex/testidx/"
                                     "source/latex/testidx/" "tex/latex/testidx/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18wj5gv0zn014i29da74p2ac0qlzvbs12ys4vplqc9ryn8nkf1fs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/testidx")
    (synopsis "Dummy text for testing index styles and indexing applications")
    (description
     "This is a LaTeX package that provides a command to produce dummy text
interspersed with @code{\\index} commands to test an index style or indexing
application.  The dummy text is mostly in English, but includes extended Latin
characters provided either through LaTeX accent commands or directly with
UTF-8 characters, depending on the setup, to allow for testing extended Latin
alphabets.  The supplementary package @file{testidx-glossaries.sty} uses the
indexing interface provided by the @code{glossaries} package.")
    (license license:lppl1.3+)))

(define-public texlive-tex-label
  (package
    (name "texlive-tex-label")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tex-label/"
                                     "source/latex/tex-label/"
                                     "tex/latex/tex-label/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xvyyvzyxiynsf4a64b6m40m7qnn2q2xdp81fsksz53s7d3h0wp2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tex-label")
    (synopsis "Place a classification on each page of a document")
    (description
     "This package enables the user to place a classification label on each page,
at the bottom to the right of the page number.")
    (license license:lppl1.3+)))

(define-public texlive-tex-locale
  (package
    (name "texlive-tex-locale")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/tex-locale/"
                                     "source/latex/tex-locale/"
                                     "tex/generic/tex-locale/"
                                     "tex/latex/tex-locale/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h7sl172flri87cbpygabkhk2qlrng3cwkyk71hz8289qx4g0wpr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tex-locale")
    (synopsis "Localisation support for TeX and LaTeX documents")
    (description
     "This package uses both @code{tracklang} and @code{texosquery} to look up the
locale information from the operating system and provide commands that can
access locale-dependent information, such as the currency symbol and decimal
separator.")
    (license license:lppl1.3+)))

(define-public texlive-texlogos
  (package
    (name "texlive-texlogos")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/latex/texlogos/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rp4l8da3dn6djdjajavxqr5mmi3fsyadcqrpmd9cfggdvb9i8qz"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/texlogos")
    (synopsis "Ready-to-use LaTeX logos")
    (description
     "TeXlogos defines an assortment of frequently used logos not contained in base
LaTeX itself.  The Metafont, MetapostAMS, BibTeX and SliTeX logos are defined,
as long as you have the appropriate CM/Logo/AMS fonts.  Currency symbols Euro,
Cent, Yen, Won and Naira are defined so as not to need TS1-encoded fonts.
Also defined are the C++ logo, with the @samp{+} signs properly positioned,
and the logo of the Vienna University Business Administration Center (BWZ).")
    (license license:lppl)))

(define-public texlive-texmate
  (package
    (name "texlive-texmate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/texmate/" "source/latex/texmate/"
                                     "tex/latex/texmate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c584zbmz0k1kwd41cgz11zjzw29b0128j1xqz5a8wbsw894csq4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/texmate")
    (synopsis "Comprehensive chess annotation in LaTeX")
    (description
     "TeXmate formats chess games from very simple ASCII input.  The clean
@samp{1.@: e4 e5; 2.@: Nf3 Nc6; 3.@: Bb5 a6} will produce the same results as
the sloppier @samp{1 e4 e5; Nf3 Nc6 3..@: Bb5 a6}.  The resulting format is
fully customizable.  There are 4 levels of commentary: 1 is the main game, 2-3
are commentaries.  Each has its fonts, punctuation marks, etc., and these are
also customizable.  The package includes a tool for the creation of diagrams.
The package works in conjunction with @code{skak} to produce diagrams of the
current position automatically.  For chess fonts, the package uses the
@code{chessfss} system.")
    (license license:lppl)))

(define-public texlive-texments
  (package
    (name "texlive-texments")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/texments/"
                                     "source/latex/texments/"
                                     "tex/latex/texments/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06k1nfxdnl811sw4n9blp863a903ryh7b4m79rjj367kzs2zkbca"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/texments")
    (synopsis "Using the Pygments highlighter in LaTeX")
    (description
     "This package provides a package which allows using the Pygments highlighter
inside LaTeX documents.  Pygments supports syntax colouring of over 50 types
of files, and ships with multiple colour schemes.")
    (license license:lppl)))

(define-public texlive-texpower
  (package
    (name "texlive-texpower")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/texpower/"
                                     "source/latex/texpower/"
                                     "tex/latex/texpower/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jndkkngnldksg37hx1hpcawhyzy9phirqsbk03l2hwqv20r5hz4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-tpslifonts))
    (home-page "https://ctan.org/pkg/texpower")
    (synopsis "Create dynamic online presentations with LaTeX")
    (description
     "TeXPower is a bundle of packages intended to provide an all-inclusive
environment for designing pdf screen presentations to be viewed in full-screen
mode, especially for projecting online with a video beamer.  For some of its
core functions, it uses code derived from @code{ppower4} packages.  It is,
however, not a complete environment in itself: it relies on an existing class
for preparing slides (such as @code{foiltex} or @code{seminar}) or another
package such as @code{pdfslide}.")
    (license license:gpl3+)))

(define-public texlive-texshade
  (package
    (name "texlive-texshade")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/texshade/"
                                     "source/latex/texshade/"
                                     "tex/latex/texshade/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "159dv5bf126s6fcw9sr218nf0hap88386n4l6n08r9wwwd2zb4hl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/texshade")
    (synopsis "Package for setting nucleotide and peptide alignments")
    (description
     "TeXshade is alignment shading software completely written in TeX/LaTeX; it
can process multiple sequence alignments in the @file{.msf} and the
@file{.aln} file formats.  In addition to common shading algorithms, it
provides special shading modes showing functional aspects, e.g., charge or
hydropathy, and a wide range of commands for handling shading colours, text
styles, labels, legends; it even allows the user to define completely new
shading modes.")
    (license license:gpl2)))

(define-public texlive-texsurgery
  (package
    (name "texlive-texsurgery")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/texsurgery/"
                                     "tex/latex/texsurgery/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "042jafcsvsjijmmmi8vz417178rbb02vk7vwd16b4laxxpzd5b2a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/texsurgery")
    (synopsis "LaTeX companion to the @code{texsurgery} Python project")
    (description
     "This LaTeX library is a companion to the @code{texsurgery} Python project.
It will make sure that @samp{pdflatex document.tex} will work, with reasonable
defaults, for a document that is intended to work with @code{texsurgery}, and
also has other uses, always in tandem with the @code{texsurgery} Pypi
package.")
    (license license:bsd-3)))

(define-public texlive-textcsc
  (package
    (name "texlive-textcsc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/textcsc/" "tex/latex/textcsc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0771jrgrwklw3sqfw6rf0p0hbhs0gg7hd3z2gsv4i5pd73dfr5d8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/textcsc")
    (synopsis "Simple commands for caps-to-small-caps text")
    (description
     "This package provides a simple command (@code{\\textcsc} and
@code{\\cscshape}) for caps-to-small-caps text, to allow for small caps
acronyms to be presented as uppercase in text (useful for things like copying
and pasting from a PDF).")
    (license (list license:lppl1.3+ license:cc-by-sa3.0))))

(define-public texlive-textfit
  (package
    (name "texlive-textfit")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/textfit/" "source/latex/textfit/"
                                     "tex/latex/textfit/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18rhvd8xh83xi7f7mvnqblmi45ws4pcr0vbs689s2ycdxfzfhfzr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/textfit")
    (synopsis "Fit text to a desired size")
    (description
     "This package fits text to a given width or height by scaling the font.")
    (license license:lppl1.3+)))

(define-public texlive-textmerg
  (package
    (name "texlive-textmerg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/textmerg/"
                                     "source/generic/textmerg/"
                                     "tex/generic/textmerg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fr34cr1r2f5g72acx33jx74lxgf37c2f2gyjw8frfljmw3fdqc2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (home-page "https://ctan.org/pkg/textmerg")
    (synopsis "Merge text in TeX and LaTeX")
    (description
     "This package repetitively produce documents from a fixed part and a variable
part.  Such an operation is commonly used as ``mail merge'' to produce mail
shots.")
    (license license:public-domain)))

(define-public texlive-textualicomma
  (package
    (name "texlive-textualicomma")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/textualicomma/"
                                     "source/latex/textualicomma/"
                                     "tex/latex/textualicomma/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "15d2jkfmmy1n0ni7516dik071v8jr3m0wyphv2ixr63cplbmr3sk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/textualicomma")
    (synopsis
     "Use the textual comma character as decimal separator in math mode")
    (description
     "The package is based on the @code{icomma} package, and intended as a solution
for situations where the text comma character discerns from the math comma
character, e.g., when fonts without math support are involved.  Escaping to
text mode every time a comma is used in math mode may slow down the
compilation process.")
    (license license:lppl1.3c)))

(define-public texlive-texvc
  (package
    (name "texlive-texvc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/texvc/" "source/latex/texvc/"
                                     "tex/latex/texvc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ryr67kls8xqykv73zm583hiavc4z52b78jkg9wqz4zv9nykifjh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/texvc")
    (synopsis "Use MediaWiki LaTeX commands")
    (description
     "This package provides all MediaWiki commands to copy and past formulae from
MediaWiki to LaTeX documents.")
    (license license:lppl1.3+)))

(define-public texlive-theoremref
  (package
    (name "texlive-theoremref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/theoremref/"
                                     "tex/latex/theoremref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1f2897nw1qsfp3lydx1v0ph9vyvwc0ms2azln69wr8ijh3lgyack"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/theoremref")
    (synopsis "References with automatic theorem names")
    (description
     "The @code{theoremref} package provides variants of the @code{\\label} and
@code{\\ref} commands for @code{theorem}-like environments, capable of
automatically typesetting references including the theorem name (apart from
the theorem number).  The scheme is particularly valuable if the author
decides to change a lemma to a proposition or a theorem (or whatever).")
    (license (list license:lppl license:gpl2))))

(define-public texlive-thinsp
  (package
    (name "texlive-thinsp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/thinsp/" "tex/latex/thinsp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1brnqvzj9z74dalymnk3yrmagqrlrbq8zq0whcxg3bi33gx4b76f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/thinsp")
    (synopsis "Stretchable @code{\\thinspace} for LaTeX")
    (description
     "The package redefines @code{\\thinspace} to have a stretch component.")
    (license license:gpl3+)))

(define-public texlive-thmtools
  (package
    (name "texlive-thmtools")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/thmtools/"
                                     "source/latex/thmtools/"
                                     "tex/latex/thmtools/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03m8rm145144ymj18qhmgayklzpq6r150k9kqa6q9ywyx5ls4akx"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:phases
           #~(modify-phases %standard-phases
               ;; The installation process requires "VERSION.tex" from
               ;; "doc/".  Extend TEXINPUTS to include this location.
               (add-before 'build 'extend-texinputs
                 (lambda _
                   (setenv "TEXINPUTS"
                           (string-append (getcwd) "/doc/latex/thmtools:")))))))
    (home-page "https://ctan.org/pkg/thmtools")
    (synopsis "Extensions to theorem environments")
    (description
     "The bundle provides several packages for commonly-needed support for
typesetting theorems.  The packages should work with kernel theorems (theorems
out of the box with LaTeX, and the @code{theorem} and @code{amsthm} packages.
The features of the bundle include: a key-value interface to
@code{\\newtheorem}; a @code{\\listoftheorems} command; @code{hyperref} and
@code{autoref} compatibility; a mechanism for restating entire theorems in
a single macro call.")
    (license license:lppl1.3c)))

(define-public texlive-threadcol
  (package
    (name "texlive-threadcol")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/threadcol/"
                                     "source/latex/threadcol/"
                                     "tex/latex/threadcol/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0mkwcxhiajak2xhq52x3bn134sgylqk6bi3fswg4nvvz66511xc9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/threadcol")
    (synopsis "Organize document columns into PDF \"article thread\"")
    (description
     "The package combines a document's columns into a PDF ``article thread''.
PDF readers that support this mechanism can be instructed to scroll
automatically from column to column, which facilitates on-screen reading of
two-column documents.  Even for single-column documents, threadcol supports
the creation of multiple article threads, which help organize discontiguous
but logically related regions of text into a form that the user can scroll
through as if its contents were contiguous.")
    (license license:lppl1.3+)))

(define-public texlive-thumb
  (package
    (name "texlive-thumb")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/thumb/" "source/latex/thumb/"
                                     "tex/latex/thumb/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "02va4kzc032vqlr8hv893s5280bzqmziqirg2y94rb1sjhkl98zg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/thumb")
    (synopsis "Thumb marks in documents")
    (description
     "This package places thumb marks in books, manuals and reference maunals.")
    (license license:gpl3+)))

(define-public texlive-thumbs
  (package
    (name "texlive-thumbs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/thumbs/" "source/latex/thumbs/"
                                     "tex/latex/thumbs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0p7p9kg81b0zld25xfipjlv5dv9sc8mjq80kv15mkc4v2y41cdl2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/thumbs")
    (synopsis "Create thumb indexes")
    (description
     "The package puts running, customizable thumb marks in the outer margin,
moving downward as the chapter number (or whatever shall be marked by the
thumb marks) increases.  Additionally an overview page/table of thumb marks
can be added automatically, which gives the names of the thumbed objects, the
page where the object/thumb mark first appears, and the thumb mark itself at
its correct position.  The thumb marks are useful for large documents (such as
reference guides, anthologies, etc.), where a quick and easy way to find (for
example) a chapter is needed.")
    (license license:lppl1.3+)))

(define-public texlive-thumby
  (package
    (name "texlive-thumby")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/thumby/" "tex/latex/thumby/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "138ddfn5ha4lbmf66snwvvrvjx0anfgcb9gpv2slbybm0lb9gb6k"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/thumby")
    (synopsis "Create thumb indexes for printed books")
    (description
     "The package can generate thumb indexes for your document.  It features
printing thumb indexes on one- or two-sided pages, along with background- and
foreground-color selection and full LaTeX styling of the chapter numbers in
the thumb indexes.  The height of each thumb index is automatically chosen
based on the number of chapters in your document, while the width is chosen by
the user.  The package is designed to work with the @code{memoir} class, and
also requires PerlTeX and TikZ.")
    (license license:gpl3)))

(define-public texlive-ticket
  (package
    (name "texlive-ticket")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ticket/" "tex/latex/ticket/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1hn6hn8m5zf8srj67g2nwjl8jnlzbnix18db0adidf83mzwbpjws"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ticket")
    (synopsis "Make labels, visiting-cards, pins with LaTeX")
    (description
     "This package provides an easy to handle interface to produce visiting cards,
labels for your files, stickers, pins and other stuff for your office,
conferences etc.  All you need is a definition of your ticket included in
a ticket definition file and the two commands @code{\\ticketdefault} and
@code{\\ticket}.")
    (license license:lppl1.3+)))

(define-public texlive-tipauni
  (package
    (name "texlive-tipauni")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tipauni/" "source/latex/tipauni/"
                                     "tex/latex/tipauni/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1wwanhv28azbmx7wsx4xwxr1mbpzxz34kxin8dyl3ds816w0m6ar"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tipauni")
    (synopsis "Producing Unicode characters with TIPA commands")
    (description
     "Package TIPA uses the T3 encoding for producing IPA characters.  The package
is widely used in the field of linguistics, but because of the old encoding,
the output documents are less productive than Unicode-based documents.  This
package redefines most of the TIPA-commands for outputting Unicode characters.
Users can now use their beloved TIPA shortcuts with the benefits of Unicode,
i.e., searchability, copy-pasting, changing the font and many more.

As this package needs the @code{fontspec} package for loading an IPA font, it
needs to be compiled with XeLaTeX or LuaLaTeX.  This package can also be
viewed as an ASCII-based input method for producing IPA characters in Unicode.
It needs the New Computer Modern font for printing IPA characters.")
    (license (list license:gpl3+ license:fdl1.3+))))

(define-public texlive-titlecaps
  (package
    (name "texlive-titlecaps")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/titlecaps/"
                                     "tex/latex/titlecaps/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0v921cy02dm72q60976vijpcbp5zpwljgr7y8ry5n4gqzzinnfbj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/titlecaps")
    (synopsis "Setting rich-text input into titling caps")
    (description
     "The package is intended for setting rich text into titling capitals (in which
the first character of words are capitalized).  It automatically accounts for
diacritical marks (like umlauts), national symbols (like @samp{ae}),
punctuation, and font changing commands that alter the appearance or size of
the text.  It allows a list of predesignated words to be protected as
lower-cased, and also allows for titling exceptions of various sorts.")
    (license license:lppl1.3+)))

(define-public texlive-titlefoot
  (package
    (name "texlive-titlefoot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "tex/latex/titlefoot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0c0nhhxhb3hmvg3a64lr5npbqsmrmprqqj9pic91j007k4s1in4y"))))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/titlefoot")
    (synopsis "Add special material to footer of title page")
    (description
     "This package provides the capability of adding keywords (with
a @code{\\keywords} command), a running title (@code{\\runningtitle}), AMS
subject classifications (@code{\\amssubj}), and an author's footnote as
footnotes to the title or first page of a document.  It works with any class
for which the @code{\\thanks} macro works (e.g., @code{article}).")
    (license license:lppl)))

(define-public texlive-titlepic
  (package
    (name "texlive-titlepic")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/titlepic/" "tex/latex/titlepic/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mqmcqyh7c109m158n38mv0jhxlppdb92ki2g38g9y9gaq6jbr49"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/titlepic")
    (synopsis "Add picture to title page of a document")
    (description
     "The package allows you to place a picture on the title page (cover page) of
a LaTeX document.  The package currently only works with the document classes
@code{article}, @code{report} and @code{book}.")
    (license license:public-domain)))

(define-public texlive-titleref
  (package
    (name "texlive-titleref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/titleref/" "tex/latex/titleref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16s0kqln0mzs9mqnsw8rv5rpqizpd3r3lgmw3wl1yrrbq11n9grh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/titleref")
    (synopsis "@code{\\titleref} command to cross-reference section titles")
    (description
     "This package defines a command @code{\\titleref} that allows you to
cross-reference section (and chapter, etc) titles and captions just like
@code{\\ref} and @code{\\pageref}.  The package does not interwork with
@code{hyperref}; if you need @code{hypertext} capabilities, use @code{nameref}
instead.")
    (license license:public-domain)))

(define-public texlive-to-be-determined
  (package
    (name "texlive-to-be-determined")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/to-be-determined/"
                                     "source/latex/to-be-determined/"
                                     "tex/latex/to-be-determined/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jvyvcrnz8vv17rjd3mxb25d2ljrlkmmcl8qk3bnr19gpb4a1vcb"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-soul texlive-xcolor))
    (home-page "https://ctan.org/pkg/to-be-determined")
    (synopsis "Highlight text passages that need further work")
    (description
     "This package provides a single command @code{\\tbd} which highlights the
pieces of text that need to be rewritten later.  You can hide them all with
a single package option hide, or just make them disappear entirely with the
option off.")
    (license license:expat)))

(define-public texlive-tocdata
  (package
    (name "texlive-tocdata")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tocdata/" "source/latex/tocdata/"
                                     "tex/latex/tocdata/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "152p77qi16vfz41707azwixs7x8r2wsp8zzk72k6pjdmdrlcvyjr"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tocdata")
    (synopsis "Adds names to chapters, sections, figures in the TOC and LOF")
    (description
     "The @code{tocdata} package may be used to add a small amount of data to an
entry in the table of contents or list of figures, between the section or
caption name and the page number.  The typical use would be to add the name of
an author or artist of a chapter or section, such as in an anthology or
a collection of papers.  Additionally, user-level macros are provided which
add the author's name to a chapter or section, along with an optional prefix
and/or suffix, and add to a figure the artist's name, prefix, and suffix, plus
optional additional text.  Author and artist names are also added to the
index.  Additional user-level macros control formatting.  @code{tocdata} works
with the TOC/LOF formatting of the default LaTeX classes, @code{memoir},
@code{koma-script}, and with @code{titletoc}, @code{tocloft}, @code{tocbasic},
and @code{tocstyle}.")
    (license license:lppl1.3+)))

(define-public texlive-todo
  (package
    (name "texlive-todo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/todo/" "source/latex/todo/"
                                     "tex/latex/todo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0fdj17gg0c77qa7lq9xhh9dc85navhzdgfm2lfis480n4yw7wbfq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/todo")
    (synopsis "Make a to-do list for a document")
    (description
     "The package allows you to insert ``to do'' marks in your document, to make
lists of such items, and to cross-reference to them.")
    (license license:lppl1.0+)))

(define-public texlive-tokcycle
  (package
    (name "texlive-tokcycle")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/tokcycle/"
                                     "tex/generic/tokcycle/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jwpj78wc50zg2wp1mdylhc025cvz1zd548ivfixdw3lmd2wdc8s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tokcycle")
    (synopsis "Build tools to process tokens from an input stream")
    (description
     "The @code{tokcycle} package helps one to build tools to process tokens from
an input stream.  If a macro to process an arbitrary single token can be
built, then @code{tokcycle} can provide a wrapper for cycling through an input
stream (including macros, spaces, and groups) on a token-by-token basis, using
the provided macro on each successive character.  @code{tokcycle}
characterizes each successive token in the input stream as a @samp{Character},
a @samp{Group}, a @samp{Macro}, or a @samp{Space}.  Each of these token
categories are processed with a unique directive, to bring about the desired
effect of the token cycle.  If condition flags are provided to identify
active, implicit, and catcode-6 tokens as they are digested.  The package
provides a number of options for handling groups.")
    (license license:lppl1.3c)))

(define-public texlive-tokenizer
  (package
    (name "texlive-tokenizer")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tokenizer/"
                                     "tex/latex/tokenizer/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0gvqn1rc3aq7kzmg6vibwgcpvpzsqkdfbp5im43405zl3d7rzhb9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tokenizer")
    (synopsis "Tokenizer for LaTeX")
    (description
     "This package provides a tokenizer for LaTeX.
@code{\\GetTokens@{Target1@}@{Target2@}@{Source@}} splits source into two
tokens at the first encounter of a comma.  The first token is saved in a newly
created command with the name passed as @samp{<Target1>} and the second token
likewise.  A package option @code{trim} causes leading and trailing space to
be removed from each token; with this option, the @code{\\TrimSpaces} command
is defined, which removes leading and trailing spaces from its argument.")
    (license license:lppl)))

(define-public texlive-toolbox
  (package
    (name "texlive-toolbox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/toolbox/" "source/latex/toolbox/"
                                     "tex/latex/toolbox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08l1hn7ag065lmjlnap1kpa6xqppk24k81y0vm1ka45idwxi08ih"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/toolbox")
    (synopsis "Tool macros")
    (description
     "This package provides some macros convenient for writing indexes,
glossaries, or other macros.  It contains macros which support: implicit
macros; fancy optional arguments; loops over tokenlists and itemlists;
searching and splitting; controlled expansion; redefinition of macros; and
concatenated macro names; macros for text replacement.")
    (license license:lppl)))

(define-public texlive-topfloat
  (package
    (name "texlive-topfloat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/topfloat/" "tex/latex/topfloat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04m5avwr7v713k6ygbs23bvpk761c2m7cvmq677zwfq6983abrrf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/topfloat")
    (synopsis "Move floats to the top of the page")
    (description "This package moves floats to the top of the page.")
    (license license:gpl3+)))

(define-public texlive-topiclongtable
  (package
    (name "texlive-topiclongtable")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/topiclongtable/"
                                     "tex/latex/topiclongtable/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ib9d3an7glqgc329f5krjjqf5cdwrpdzfv2b9sl6hpfyw0z7r7f"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/topiclongtable")
    (synopsis "Extend longtable with cells that merge hierarchically")
    (description
     "This LaTeX package extends @code{longtable} implementing cells that: merge
with the one above if it has the same content, do not merge with the one above
unless the ones on the left are merged, are well behaved with respect to
@code{longtable} chunking on page breaks, and automatically draw the correct
separation lines.  The typical use case is a table spanning multiple pages
that contains a list of hierarchically organized topics.")
    (license license:expat)))

(define-public texlive-totalcount
  (package
    (name "texlive-totalcount")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/totalcount/"
                                     "source/latex/totalcount/"
                                     "tex/latex/totalcount/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1c24h0snldg1lpijsm7h65dr7bs32dk6nsvlgmcc92kmxc13y9lj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/totalcount")
    (synopsis "Commands for typesetting total values of counters")
    (description
     "This LaTeX package offers commands for typesetting total values of counters.")
    (license license:lppl1.3+)))

(define-public texlive-tramlines
  (package
    (name "texlive-tramlines")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tramlines/"
                                     "tex/latex/tramlines/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0q843pxar0l69h74ywiw9jr9f1rvwj64y4257cz4wn8y4dimyrv9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tramlines")
    (synopsis
     "Creae tramlines (lines above and below a title used by lawyers in the UK)")
    (description
     "This package automatically creates tramlines (lines above and below a title
used by lawyers in the UK and the Commonwealth).")
    (license (list license:lppl1.3c license:cc-by-sa3.0))))

(define-public texlive-trfsigns
  (package
    (name "texlive-trfsigns")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/trfsigns/"
                                     "source/latex/trfsigns/"
                                     "tex/latex/trfsigns/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0j2zlydfxbdmx5ligdw2gqkqbb5mcajmag05c4b99ijr2q58ccyh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/trfsigns")
    (synopsis "Typeset transform signs")
    (description
     "This package provides a package for typesetting various transformation signs
for Laplace transforms, Fourier transforms and others.")
    (license license:gpl3+)))

(define-public texlive-trivfloat
  (package
    (name "texlive-trivfloat")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/trivfloat/"
                                     "source/latex/trivfloat/"
                                     "tex/latex/trivfloat/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0kf431k8fvg69a2v5xp37q274bs0834ychc3cybwsjhisq0nzsmn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/trivfloat")
    (synopsis "Quick float definitions in LaTeX")
    (description
     "The @code{trivfloat} package provides a quick method for defining new float
types in LaTeX.  A single command sets up a new float in the same style as the
LaTeX kernel @code{figure} and @code{table} float types.  The package works
with @code{memoir} as well as the standard classes.")
    (license license:lppl)))

(define-public texlive-trsym
  (package
    (name "texlive-trsym")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/trsym/"
                                     "fonts/source/public/trsym/"
                                     "fonts/tfm/public/trsym/"
                                     "source/latex/trsym/" "tex/latex/trsym/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1njz8i5p98f9msnn9x1806jaifwm2h3ffjyn2wx7cyca9f628gx6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (native-inputs (list texlive-metafont))
    (home-page "https://ctan.org/pkg/trsym")
    (synopsis "Symbols for transformations")
    (description
     "The bundle provides Metafont source for a small font used for, e.g., Laplace
transformations, together with a LaTeX @file{.fd} file and a package providing
commands for the symbols use in mathematics.")
    (license license:lppl1.2+)))

(define-public texlive-truncate
  (package
    (name "texlive-truncate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/truncate/" "tex/latex/truncate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zxcn84lrl07cjiw4gzg2fnkriwfv8ziww5grbvfhffwqpaf8mgj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/truncate")
    (synopsis "Truncate text to a specified width")
    (description
     "The package will by default break at word boundaries, but package options are
offered to permit breaks within words.")
    (license license:public-domain)))

(define-public texlive-tucv
  (package
    (name "texlive-tucv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/tucv/" "source/latex/tucv/"
                                     "tex/latex/tucv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "127cqbyprmm5mh3nl0y3088105qv40qghq70prrd50269h89cyrl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/tucv")
    (synopsis "Support for typesetting a CV or resumee")
    (description
     "The package provides commands for typesetting a CV or resume.  It provides
commands for general-purpose headings, entries, and item/description pairs, as
well as more specific commands for formatting sections, with explicit
inclusion of school, degree, employer, job, conference, and publications
entries.  It tends to produce a somewhat long and quite detailed document but
may also be suitable to support a shorter resume.")
    (license license:cc-by-sa3.0)))

(define-public texlive-turnthepage
  (package
    (name "texlive-turnthepage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/turnthepage/"
                                     "tex/latex/turnthepage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cm62cykmf7h6piazaa44fkhbkxds1ik6idpvg4f296y7jz6mjjh"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/turnthepage")
    (synopsis "Provide ``turn page'' instructions")
    (description
     "The package prints a turn instruction at the bottom of odd-numbered
pages (except the last).  This is a common convention for examination papers
and the like.")
    (license license:lppl)))

(define-public texlive-twoinone
  (package
    (name "texlive-twoinone")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/twoinone/" "tex/latex/twoinone/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0asph7md8s5x2y8f18cczca906fc5wkh29ydabs43v3mn17lrkpw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/twoinone")
    (synopsis "Print two pages on a single page")
    (description
     "The package is for printing two pages on a single (landscape) A4 page.
Page numbers appear on the included pages, and not on the landscape container
page.")
    (license license:public-domain)))

(define-public texlive-twoup
  (package
    (name "texlive-twoup")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/twoup/" "source/latex/twoup/"
                                     "tex/latex/twoup/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0s33w3mvpkw2jy2vxfbbagasxc37vi09dlkn9kbi0917mz8k5i70"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/twoupltx")
    (synopsis "Print two virtual pages on each physical page")
    (description
     "Some tools massage PostScript into booklet and two-up printing --- that is,
printing two logical pages side by side on one side of one sheet of paper.
However, some LaTeX preliminaries are necessary to use those tools.  The
@code{twoup} package provides such preliminaries and gives advice on how to
use the PostScript tools.")
    (license license:lppl)))

(define-public texlive-txgreeks
  (package
    (name "texlive-txgreeks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/txgreeks/"
                                     "source/latex/txgreeks/"
                                     "tex/latex/txgreeks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1n5bn8jd3czcns0rhslndmqh4sgka8ym12bpps1xhz5z64lsfbjj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/txgreeks")
    (synopsis "Shape selection for TX fonts Greek letters")
    (description
     "The package allows LaTeX users who use the TX fonts to select the
shapes (italic or upright) for the Greek lowercase and uppercase letters.
Once the shapes for lowercase and uppercase have been selected via a package
option, the @samp{\\other} prefix (e.g., @code{\\otheralpha}) allows using the
alternate glyph (as in the @code{fourier} package).  The @code{txgreeks}
package does not constrain the text font that may be used in the document.")
    (license license:lppl1.3+)))

(define-public texlive-typed-checklist
  (package
    (name "texlive-typed-checklist")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/typed-checklist/"
                                     "source/latex/typed-checklist/"
                                     "tex/latex/typed-checklist/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1g0qcw8b461qsmic1xr00zzqcv84xqwdrdq9zs4klxyb3y5d0389"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/typed-checklist")
    (synopsis
     "Typesetting tasks, goals, milestones, artifacts, and more in LaTeX")
    (description
     "The main goal of this package is to provide means for typesetting checklists
in a way that stipulates users to explicitly distinguish checklists for goals,
for tasks, for artifacts, and for milestones --- i.e., the type of checklist
entries.  The intention behind this is that a user of the package is coerced
to think about what kind of entries he/she adds to the checklist.  This shall
yield a clearer result and, in the long run, help with training to distinguish
entries of different types.")
    (license license:lppl1.2+)))

(define-public texlive-typeface
  (package
    (name "texlive-typeface")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/typeface/"
                                     "source/latex/typeface/"
                                     "tex/latex/typeface/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xyqvqvk06ca4rcgw917abprz5qi8kqsrm5z89ws1n72vyzfjhgm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/typeface")
    (synopsis "Select a balanced set of fonts")
    (description
     "The package provides the means of establishing a consistent set of fonts for
use in a LaTeX document.  It allows mixing and matching the Type 1 font sets
available on the archive.  Font-set definition takes the form of a set of
options that are read when the package is loaded: for each typographic
category (main body font, sans-serif font, monospace font, mathematics fonts,
text figures, and so on), a font or a transformation is given in those
options.  The approach enables the user to remember their own
configurations (as a single command) and to borrow configurations that other
users have developed.")
    (license license:lppl1.3+)))

(define-public texlive-typoaid
  (package
    (name "texlive-typoaid")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/typoaid/" "tex/latex/typoaid/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qf84xagz2lcfygfs2k7pgml85d6nf7k5psf274a1hq1djn19rdf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/typoaid")
    (synopsis "Macros for font diagnostics")
    (description
     "This package provides macros for measuring alphabet lengths (i.e., the length
occupied by the characters @samp{abcd...xyz}), em-widths and ex-heights, which
may help in making typesetting decisions.")
    (license license:lppl1.3c)))

(define-public texlive-typogrid
  (package
    (name "texlive-typogrid")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/typogrid/"
                                     "source/latex/typogrid/"
                                     "tex/latex/typogrid/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08hq2zcr2xd73qfh0f05d33sn1zvwnizrsr8r82mb3vsnbyczn0b"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/typogrid")
    (synopsis "Print a typographic grid")
    (description
     "This package draws a grid on every page of the document; the grid divides the
page into columns, and may be used for fixing measurements of layout.")
    (license license:lppl)))

(define-public texlive-uassign
  (package
    (name "texlive-uassign")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uassign/" "tex/latex/uassign/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qfj5z9ljd5x169jcr8dv09ajib9cc1m2hwq0ymz95qc17s7rk5l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uassign")
    (synopsis
     "Environments and options for typesetting university assignments")
    (description
     "The purpose of this package is to provide simple question and solution style
environments for typesetting university assignments.")
    (license license:lppl)))

(define-public texlive-uebungsblatt
  (package
    (name "texlive-uebungsblatt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uebungsblatt/"
                                     "tex/latex/uebungsblatt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "00vgn9qv9xl0afj37r2nlvw51vb3qfdd8an5az8f7mqkydi33ppa"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uebungsblatt")
    (synopsis "LaTeX class for writing exercise sheets")
    (description
     "This package implements a LaTeX class for writing exercise sheets for
a lecture.  Its features are:

@itemize

@item quick typesetting of exercise sheets or their revisions,

@item simple user friendly commands,

@item elegant page formatting,

@item automatic numbering of exercises and sub-exercises,

@item the number of the exercise sheet is extracted automatically from the
file name,

@item static information about the lectures and the authors needs to provided
at one point only.

@end itemize")
    (license license:lppl)))

(define-public texlive-umoline
  (package
    (name "texlive-umoline")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/umoline/" "source/latex/umoline/"
                                     "tex/latex/umoline/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z1yaqvaxx9a0s6dzjx7g88f97zjq262c6f1jqkdvckmjy3zqd9w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/umoline")
    (synopsis "Underline text allowing line breaking")
    (description
     "This package provides commands @code{\\Underline}, @code{\\Midline} and
@code{\\Overline} for underlining, striking out, and overlining their text
arguments.")
    (license license:lppl)))

(define-public texlive-underlin
  (package
    (name "texlive-underlin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/underlin/"
                                     "source/latex/underlin/"
                                     "tex/latex/underlin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0537jv5m1xbib1db64skxs46qfjj7x00l89xn0rjr9w2mxksii5g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/underlin")
    (synopsis "Underlined running heads")
    (description
     "This package defines two pagestyles that provide underlined page heads in
LaTeX.")
    (license license:lppl)))

(define-public texlive-underoverlap
  (package
    (name "texlive-underoverlap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/underoverlap/"
                                     "tex/latex/underoverlap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ah8y9ninlkizjqi74qh4kxa23334pa58bnhl1g5n12vh80c4177"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/underoverlap")
    (synopsis "Position decorations over and under expressions")
    (description
     "The package overcomes TeX's inherent limitations in commands that place
decorations (such as braces) at arbitrary positions over and under expressions,
overlapping as necessary.")
    (license license:lppl1.3+)))

(define-public texlive-uni-titlepage
  (package
    (name "texlive-uni-titlepage")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uni-titlepage/"
                                     "source/latex/uni-titlepage/"
                                     "tex/latex/uni-titlepage/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1khnplr3ac51bkp57mj199f12yhz9zi5wrjfircbswlp2hn4lla5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uni-titlepage")
    (synopsis
     "Universal titlepages with configuration options and predefined styles")
    (description
     "Creation of title pages is something most authors should not have to do.  But
reality is not perfect, so a lot of authors have to do it.  This package not
only provides several pages for the title instead of only one --- at least
five are typical for a thesis! ---, it also provides a bunch of predefined
titlepage styles with several standard elements, and optionally additional
elements.")
    (license license:lppl1.3c)))

(define-public texlive-unicodefonttable
  (package
    (name "texlive-unicodefonttable")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/unicodefonttable/"
                                     "source/latex/unicodefonttable/"
                                     "tex/latex/unicodefonttable/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jfdyxqndq8bv0d8cpbrlaghby58xpfjfx3svfhyrh369aaq8ls5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/unicodefonttable")
    (synopsis "Unicode font table generator")
    (description
     "This package produces font tables for Unicode fonts as well as for 8-bit fonts.
The table layout can be adjusted in various ways including restricting the
range of output to show only a portion of a specific font.  To quickly produce
a one-off table there is a stand-alone version @file{unicodefont.tex} that
asks you a few questions and then generates the table --- somewhat similar to
@file{nfssfont.tex} for 8-bit fonts.")
    (license license:lppl1.3c)))

(define-public texlive-unisc
  (package
    (name "texlive-unisc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/unisc/" "source/latex/unisc/"
                                     "tex/latex/unisc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0rrpaga6hny2v8qv5kx860zn8b9j8ypy3bmq4a5nadscg08g7v17"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/unisc")
    (synopsis "Unicode small caps with Lua/XeLaTeX")
    (description
     "LaTeX produces small caps with @code{\\textsc@{text@}} or @code{@{\\scshape
text@}}.  Neither of these commands produce small caps in Unicode.  If the
output text is copied and pasted somewhere it shows the same characters as
used in the input.  This package aims to internally convert all the characters
provided to the commands mentioned above.  It assumes that the file using this
package is compiled with Lua/XeLaTeX and a good Unicode font which has the
small caps characters, e.g., Charis SIL.")
    (license (list license:gpl3+ license:fdl1.3+))))

(define-public texlive-unitconv
  (package
    (name "texlive-unitconv")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/unitconv/"
                                     "tex/lualatex/unitconv/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0z10w79cddldw1rm9xzsr610ydn9hczx7dfda9n8g6wlpwhal0ps"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/unitconv")
    (synopsis "Convert a length into one with another unit")
    (description
     "This package defines two macros to convert a value with unit into one with
another unit.  Supported are all TeX related units, and also @samp{km} and
@samp{m}.  The output can be in scientific notation for large values.  The
package only works with LuaLaTeX.")
    (license license:lppl1.3+)))

(define-public texlive-unravel
  (package
    (name "texlive-unravel")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/unravel/" "source/latex/unravel/"
                                     "tex/latex/unravel/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "12q9y2g7rq37wf3ihqqrnj4phxfi68mv2fnia921421a1nqfnij2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/unravel")
    (synopsis "Watching TeX digest tokens")
    (description
     "The aim of this LaTeX package is to help debug complicated macros.  This is
done by letting the user step through the execution of some TeX code, going
through the details of nested expansions, performing assignments, as well as
some simple typesetting commands.  To use this package, one should normally
run TeX in a terminal.")
    (license license:lppl1.3c)))

(define-public texlive-upmethodology
  (package
    (name "texlive-upmethodology")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "bibtex/bst/upmethodology/"
                                     "doc/latex/upmethodology/"
                                     "tex/latex/upmethodology/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1118xx6bjxj6lzqqf124r1ir0x627z0gyimdvnnscyag5n5jyqfd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/upmethodology")
    (synopsis "Writing specifications such as for UP-based methodologies")
    (description
     "The bundle allows the user to create Unified Process methodology (UP or RUP)
based documents.  The style provides document versioning, document history,
document authors, document validators, specification description, task
management, and several helping macros.")
    (license license:lgpl3)))

(define-public texlive-uri
  (package
    (name "texlive-uri")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uri/" "source/latex/uri/"
                                     "tex/latex/uri/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1vljxmd8fp5jfh8z223z2hh9rl40kiscvsp9y49k0677a1qk8yhq"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uri")
    (synopsis "Hyperlinks for a wide range of URIs")
    (description
     "The package provides automatic hyperlinks for URIs of type arXiv, ASIN,
DOI, HDL, NBN, OCLC, OID, PubMed, TINY, TINY with preview, and WebCite.  It
provides commands @code{\\citeurl}, @code{\\mailto}, @code{\\ukoeln}, and
@code{\\uref}.")
    (license license:lppl1.3c)))

(define-public texlive-ushort
  (package
    (name "texlive-ushort")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ushort/" "source/latex/ushort/"
                                     "tex/latex/ushort/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16pkrlb1v67ydjis2w3gz20i9rkmjnaidh47sxwpn62gpjgy01gw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ushort")
    (synopsis "Shorter (and longer) underlines and underbars")
    (description
     "Some engineers need underlined or twice underlined variables for which the
usual @code{\\underline} is too long.  This package provides a generic command
for creating underlines of various sizes and types.")
    (license license:lppl)))

(define-public texlive-uspace
  (package
    (name "texlive-uspace")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uspace/" "tex/latex/uspace/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0998pxjsjrbziy0pib2gbg6695nl9klz9f9i3qsczrby6zhihrgd"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uspace")
    (synopsis "Giving meaning to various Unicode space characters")
    (description
     "This LaTeX package gives meaning to various Unicode space characters.")
    (license license:expat)))

(define-public texlive-utf8add
  (package
    (name "texlive-utf8add")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/utf8add/" "tex/latex/utf8add/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0chqx3l9c4khw20gdj3pr25hky3xgmwi39y2jy6im6y1nyhwxm4s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/utf8add")
    (synopsis "Additional support for UTF-8 encoded LaTeX input")
    (description
     "This bundle contains the LaTeX packages @file{utf8add.sty} and
@file{utf8hax.sty}.  The @code{utf8add} package provides additional support
for the use of UTF-8 encoded input.  This is intended for making LaTeX input
more readable.  The @code{utf8hax} package is using UTF-8 characters for
easier access to math in LaTeX, however making the LaTeX input less readable.")
    (license license:gpl3+)))

(define-public texlive-uwmslide
  (package
    (name "texlive-uwmslide")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/uwmslide/" "tex/latex/uwmslide/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mwm4j9gsq8kmqx1wrh9ri7w9hlhqa5721a77rlpyxz18kzwv366"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/uwmslide")
    (synopsis "Slides with a simple PowerPoint-like appearance")
    (description
     "This package provides a slide format which produces slides with a simple
PowerPoint-like appearance.  Several useful features include:

@itemize

@item use of standard titlepage to produce title slide;

@item several slide environments including plain (page with a title), double
slide (two column page with slide title), item slide (item list with title),
left item slide, and right item slide;

@item Logos are placed in the upper left corner of each slide if the logo file
@file{logo.eps} is present.

@end itemize

The output is pre-configured in landscape mode and uses Times Roman by
default.")
    (license license:artistic2.0)))

(define-public texlive-variablelm
  (package
    (name "texlive-variablelm")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/fonts/variablelm/"
                                     "tex/latex/variablelm/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jlcvsz8ah8s33vqbnw13mgap3k8lh4p6ap1bwf6czwyq7m5r47h"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/variablelm")
    (synopsis "Font definitions for the variable Latin Modern fonts")
    (description
     "This package provides a mechanism for scaling a typeface.  It is directed at
the Latin Modern fonts and provides the font definitions and the corresponding
style file.  This mechanism is useful in mixed text compositions, for example
Japanese-Latin.")
    (license license:gfl1.0)))

(define-public texlive-varindex
  (package
    (name "texlive-varindex")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/varindex/"
                                     "source/latex/varindex/"
                                     "tex/latex/varindex/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "079blfmdil8dhw8qxbwp6n2kgxqc92yn8fjlk8zahkkvims89xaj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/varindex")
    (synopsis "Luxury frontend to the @code{\\index} command")
    (description
     "This package provides a convenient front-end for the @code{\\index} command.
For example, with it you can generate multiple index entries in almost any
form by a single command.")
    (license license:lppl)))

(define-public texlive-varsfromjobname
  (package
    (name "texlive-varsfromjobname")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/varsfromjobname/"
                                     "tex/latex/varsfromjobname/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1b6k85hxz2frz33cqdbkhqa204s43r6sd44i2qjihicgwlnv2q60"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/varsfromjobname")
    (synopsis "Extract variables from the name of the LaTeX file")
    (description
     "The package allows the user to extract information from the job name,
provided that the name has been structured appropriately: the package expects
the file name to consist of a set of words separated by hyphens.")
    (license license:lppl)))

(define-public texlive-vcell
  (package
    (name "texlive-vcell")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/vcell/" "tex/latex/vcell/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y4gxf5waxs7n9xb9qbraa9isk11pvxm5737z0j069kg6bkra5rl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/vcell")
    (synopsis "Vertical alignment of content inside table cells")
    (description
     "This package offers low-level macros to build rows with vertically-aligned
cells (top, middle or bottom) and calculate the height of a row.  These cells
can have variable or fixed height and can be paragraph-cells or inline-cells.
Different vertical alignments can be used in the same row.")
    (license license:lppl1.3c)))

(define-public texlive-vdmlisting
  (package
    (name "texlive-vdmlisting")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/vdmlisting/"
                                     "tex/latex/vdmlisting/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0yhgql2gflygjhx5mz87qqyiny7j0wpiqs2yvpmzm57linna3vzn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/vdmlisting")
    (synopsis "Typesetting VDM in ASCII syntax")
    (description
     "The package is an extension for the @code{listings} package that provides
a source code printer for LaTeX.  This package defines new language
definitions and listing environments for the three language dialects of the
Vienna Development Method: VDM-SL, VDM-PP and VDM-RT.  If one wants to typeset
VDM with a mathematical syntax instead of the ASCII syntax used here, one
should use the @code{vdm} package instead.")
    (license license:lppl1.3+)))

(define-public texlive-verbasef
  (package
    (name "texlive-verbasef")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/verbasef/" "tex/latex/verbasef/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0qs4142zgygcp7yl69mz1i92plnkkp61qb1icjzpw8g7myxyhn9a"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/verbasef")
    (synopsis "VERBatim Automatic Splitting of External Files")
    (description
     "The package allows you to input (subsections of a) file, print them in
verbatim mode, while automatically breaking up the input lines into pieces of
a given length, which are output as figures.  These figures are posted using
the @samp{[H]} specification, which forces LaTeX to place the figure at the
spot of invocation, rather than floating the figures to the top of the next
page.")
    (license license:gpl3+)))

(define-public texlive-verbatimcopy
  (package
    (name "texlive-verbatimcopy")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/verbatimcopy/"
                                     "tex/latex/verbatimcopy/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nmni0l73rjsapixl27i2hxp17psa73pycwkvvql4n1x9zl7yw9w"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/verbatimcopy")
    (synopsis "Make copies of text documents from within LaTeX")
    (description
     "This package provides @code{\\VerbatimCopy@{in@}@{out@}} that will enable
LaTeX to take a verbatim copy of one text file, and save it under another
name.  The package provides a means to specify the output directory to be
used, but does no checking and may therefore overwrite an important file if
used injudiciously.")
    (license license:lppl)))

(define-public texlive-verbdef
  (package
    (name "texlive-verbdef")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/verbdef/" "tex/latex/verbdef/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1l6sm2mk7c197qicxlagl1hrfcaqswpq7b5a22i7m7gq1wpa8yvg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/verbdef")
    (synopsis "Define commands which expand to verbatim text")
    (description
     "The package defines a single command @code{\\verbdef} (which has a starred
form, like @code{\\verb}).  @code{\\verbdef} will define a robust command
whose body expands to verbatim text.  By using commands defined by
@code{\\verbdef}, one can put verbatim text into the arguments of commands;
since the defined command is robust, it doesn't matter if the argument is
moving.")
    (license license:lppl)))

(define-public texlive-verbments
  (package
    (name "texlive-verbments")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/verbments/"
                                     "tex/latex/verbments/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0lsxr6mibc8v8wfabdph5mnf8zf77yk6s0qnz5p85g9z2fdvpgvf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/verbments")
    (synopsis "Syntax highlighting of source code in LaTeX documents")
    (description
     "The package provides an environment for syntax highlighting source code in
LaTeX documents.  The highlighted source code output is formatted via Pygments
library of the Python language.")
    (license license:lppl1.2+)))

(define-public texlive-verifiche
  (package
    (name "texlive-verifiche")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/verifiche/"
                                     "source/latex/verifiche/"
                                     "tex/latex/verifiche/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1pppqsr4sp9j59c4hp6dx2fvpjnl7q0x9md09sfgdsk57nxjklii"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/verifiche")
    (synopsis "Typeset (Italian) high school tests")
    (description
     "The purpose of this package is to manage the exercises for a test, their
points, levels of difficulty, and solutions.  Some typical formats of
exercises are already implemented: plain exercise, ``complete the text'',
``true or false'', closed questions, open questions, and ``find the error''.")
    (license license:lppl1.3+)))

(define-public texlive-version
  (package
    (name "texlive-version")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/version/" "tex/latex/version/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1m4w450kgv92r41cqsxxn697h59bdsmms6icvhbfg5wq819k917v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/version")
    (synopsis "Conditionally include text")
    (description
     "This package defines macros @code{\\includeversion@{@var{NAME}@}} and
@code{\\excludeversion@{@var{NAME}@}}, each of which defines an environment
@var{NAME} whose text is to be included or excluded from compilation.

Although the command syntax is very similar to that of @code{comment},
@file{comment.sty} is to be preferred to @file{version.sty} for documents
where significant chunks of text may be excluded.")
    ;; These macros may be freely used, transmitted, reproduced, or modified
    ;; provided that the copyright notice and this permission is retained.
    (license (license:fsf-free "file://tex/latex/version/version.sty"))))

(define-public texlive-versions
  (package
    (name "texlive-versions")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/versions/" "tex/latex/versions/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zq8vp85hsy8c6yjhpjslr8063q95w5rnyv23kkks44bkcgrac8l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/versions")
    (synopsis "Optionally omit pieces of text")
    (description
     "Stephan Bellantoni's @code{version} has provided preamble commands for
selecting environments to be included/excluded.  This package does the same,
but corrects, improves, and extends it in both implementation and function.")
    (license license:lppl1.3+)))

(define-public texlive-versonotes
  (package
    (name "texlive-versonotes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/versonotes/"
                                     "source/latex/versonotes/"
                                     "tex/latex/versonotes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0xa80kbcqq8xdpz8q01z71qc0v5qyvdzg9n0dkwpp5nd8x1dki00"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/versonotes")
    (synopsis "Display brief notes on verso pages")
    (description
     "This package allows you to place notes on the verso pages of an otherwise
single-sided document.")
    (license license:lppl1.3+)))

(define-public texlive-vertbars
  (package
    (name "texlive-vertbars")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/vertbars/" "tex/latex/vertbars/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kqj1f1x9apssr678y0d85x5wlc338i3dmdn3ln3mb5bgm6hbwj5"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/vertbars")
    (synopsis "Mark vertical rules in margin of text")
    (description
     "This package is an extension to @code{lineno}, replacing that package's line
numbers with bars to the left or right of the text.")
    (license license:lppl1.3c)))

(define-public texlive-vgrid
  (package
    (name "texlive-vgrid")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/vgrid/" "source/latex/vgrid/"
                                     "tex/latex/vgrid/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1czaf1rz4x7wsinnk6mg78674azg5hnyi53rwh64bv2lzs3l0ah1"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/vgrid")
    (synopsis "Overlay a grid on the printed page")
    (description
     "The package overlays a grid (whose spacing is @code{\\baselineskip}, which
offers guidelines for considering the ``rhythm'' of the document on the page.")
    (license license:lppl1.3+)))

(define-public texlive-vhistory
  (package
    (name "texlive-vhistory")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/vhistory/" "tex/latex/vhistory/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0s7p56x77yqhrmmf46y3ip703xr49dc0cs4h32qf42ahh6psw8pn"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/vhistory")
    (synopsis "Support for creating a change log")
    (description
     "Vhistory simplifies the creation of a history of versions of a document.
You can easily extract information like the current version of a list of
authors from that history.  It helps you to get consistent documents.  The
package @code{sets}, which is used by @code{vhistory}, allows you to use sets
containing text.  You can use the usual operations to create the union of sets
or the intersection of sets etc.")
    (license license:lppl1.2+)))

(define-public texlive-vmargin
  (package
    (name "texlive-vmargin")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/vmargin/" "source/latex/vmargin/"
                                     "tex/latex/vmargin/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0548wbh05b6ga8fxvarmsai8kzadcgix5zkh5l4a4ym4lsdgb47l"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/vmargin")
    (synopsis "Set various page dimensions")
    (description
     "This package provides a macro to set various margins as well as dimensions
for header/footer and page dimensions.  Most common paper sizes, paper
orientation, disabling of headers and footers, and two sided printing are
supported.

The user interface might not be very fancy, but it's fast, small, and gets the
job done.  If you are looking for something more elaborate try the
@code{geometry} package.")
    (license license:lppl)))

(define-public texlive-volumes
  (package
    (name "texlive-volumes")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/volumes/" "source/latex/volumes/"
                                     "tex/latex/volumes/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06q6p31m11p3iavksrs7hrbgbsmxhfsq0qh3h96jch0xf46dyy4c"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/volumes")
    (synopsis "Typeset only parts of a document, with complete indexes etc")
    (description
     "This package helps you if you want to produce separate printed volumes from
one LaTeX document, as well as one comprehensive, all-inclusive version.  It
suppresses the part of the table of contents that are not typeset, while
counters, definitions, index entries etc., are kept consistent throughout the
input file.")
    (license license:lppl)))

(define-public texlive-vpe
  (package
    (name "texlive-vpe")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/vpe/" "scripts/vpe/"
                                     "tex/latex/vpe/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1mic6ljwfx50rassr1rr8ymqvbiblbpvrcdqkvwbahxxirjdj1xl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments
     (list #:link-scripts #~(list "vpe.pl")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/vpe")
    (synopsis "Source specials for PDF output")
    (description
     "VPE is a system to make the equivalent of source special marks in a PDF
file.  Clicking on a mark will activate an editor, pointing at the source line
that produced the text that was marked.  The system comprises a Perl
file (@file{vpe.pl}) and a LaTeX package (@file{vpe.sty}).")
    (license license:lppl)))

(define-public texlive-vruler
  (package
    (name "texlive-vruler")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/vruler/" "tex/latex/vruler/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06yvgz6bl6xjkvf7a4nwdsrpdql97bg812vh7s524f7y3whka1lp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/vruler")
    (synopsis "Numbering text")
    (description
     "The package offers facilities for adding a columns of numbering to the
general text so that the text can be properly referenced.  The vertical ruler
can be scaled and moved freely.")
    (license license:lppl1.0+)))

(define-public texlive-vtable
  (package
    (name "texlive-vtable")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/vtable/" "tex/latex/vtable/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1kvkaksls3nvjzqpf45l13jmm8mdpz8iccxhx5pqsfhwy19b9yp2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/vtable")
    (synopsis "Vertical alignment of table cells")
    (description
     "The package allows vertical alignment of table cell by providing: @samp{Z},
@samp{L}, @samp{C}, @samp{R}, samp{J} and @samp{I} column types,
@code{\\nextRow} and @code{\\lb} commands, @code{\\setMultiColRow},
@code{\\setMultiColumn}, @code{\\setMultiRow} and @code{\\tableFormatedCell}
commands for @code{tabular} and similar environment.")
    (license license:expat)))

(define-public texlive-vwcol
  (package
    (name "texlive-vwcol")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/vwcol/" "source/latex/vwcol/"
                                     "tex/latex/vwcol/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06lj8yvijjdlffl4qbgcxkygy6s43w6h8bgvs7k3vnn7znb7ga00"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/vwcol")
    (synopsis "Variable-width multiple text columns")
    (description
     "The package provides a crude environment (@code{vwcol}) for typesetting
multicolumn paragraph text of various column widths on a single page.")
    (license license:lppl1.3+)))

(define-public texlive-wallcalendar
  (package
    (name "texlive-wallcalendar")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/lualatex/wallcalendar/"
                                     "tex/lualatex/wallcalendar/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "18f6jxwn1lzg98bw8y3yaxfm7wv8s4spp6nkhrqsssc0n7x2x8ig"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/wallcalendar")
    (synopsis "Wall calendar class with custom layouts")
    (description
     "This package provides a wall calendar class with custom layouts and support
for internationalization.  There is also support for loading event marks from
a CSV file.")
    (license license:lppl)))

(define-public texlive-warning
  (package
    (name "texlive-warning")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/warning/" "tex/latex/warning/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "19jx6msglrniwprzgrk9via012zr7fc99dkn5yy8ma040ws1p595"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/warning")
    (synopsis "Global warnings at the end of the logfile")
    (description
     "This package provides a command that generates a list of warnings that are
printed out at the very end of the logfile.  This is useful for warnings such
as ``Rerun for this or that reason'' or ``This is a draft''.")
    (license license:lppl)))

(define-public texlive-warpcol
  (package
    (name "texlive-warpcol")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/warpcol/" "source/latex/warpcol/"
                                     "tex/latex/warpcol/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0f03v03vsfavkx3wchh2nli10hihapjlgw822rgxi8z6bm5jphss"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/warpcol")
    (synopsis "Relative alignment of rows in numeric columns in tabulars")
    (description
     "This package defines a tabular column type for formatting numerical columns
in LaTeX.  The column type enables numerical items to be right justified
relative to each other, while centred beneath the column label.  In addition,
macros are provided to enable variations on this column type to be defined.")
    (license license:lppl)))

(define-public texlive-webquiz
  (package
    (name "texlive-webquiz")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/webquiz/"
                                     "doc/man/man1/webquiz.1"
                                     "doc/man/man1/webquiz.man1.pdf"
                                     "scripts/webquiz/" "tex/latex/webquiz/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1z2qwm3jaj2wh8f6vx7mih21y32d0604jirdgd3bywq7yv57y125"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "webquiz.py")))
    (inputs (list python))
    (home-page "https://ctan.org/pkg/webquiz")
    (synopsis "Write interactive web based quizzes")
    (description
     "WebQuiz makes it possible to use LaTeX to write interactive web based
quizzes.  The quizzes are first written in LaTeX and then converted into HTML
files using @command{webquiz}, which is written in Python.  The conversion
from LaTeX to HTML is done behind the scenes using TeX4ht.")
    (license license:gpl3+)))

(define-public texlive-widetable
  (package
    (name "texlive-widetable")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/widetable/"
                                     "source/latex/widetable/"
                                     "tex/latex/widetable/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1fb1545agxpkd4xjh6hs70flqpwna13rh5kzc202w64jxsfgwwzs"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/widetable")
    (synopsis "Environment for typesetting tables of specified width")
    (description
     "The package defines a new environment that, unlike tabularX, typesets a table
of specified width by working on the inter-column glue; the tabular cells will
all be stretched (or shrunk) according to need.")
    (license license:lppl1.3+)))

(define-public texlive-widows-and-orphans
  (package
    (name "texlive-widows-and-orphans")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/widows-and-orphans/"
                                     "source/latex/widows-and-orphans/"
                                     "tex/latex/widows-and-orphans/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rxnsbpxash0cwka23nd2744cbjvgv9fajz5v52v9ccn7fxbmaxg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/widows-and-orphans")
    (synopsis "Identify (typographic) widows and orphans")
    (description
     "This package identifies all widows and orphans in a document to help a user
to get rid of them.  The act of resolving still needs to be done manually: by
rewriting text, running some paragraph long or short or or explicitly breaking
in some strategic place.  It will also identify and warn about words broken
across columns or pages and display formulas separated from their introductory
paragraph.")
    (license license:lppl1.3c)))

(define-public texlive-williams
  (package
    (name "texlive-williams")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/williams/" "tex/latex/williams/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1rk7x20a23mq3r920hr96m65x48040q8m0ps6in91qlf77fz0lpw"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/williams")
    (synopsis "Miscellaneous macros by Peter Williams")
    (description
     "The bundle provides two packages: @code{antree}, which provides macros for
annotated node trees, and @code{toklist}, which is an implementation of
Knuth's token list macros, to be found on pp.378--379 of the @emph{TeXbook}.")
    (license license:lppl)))

(define-public texlive-withargs
  (package
    (name "texlive-withargs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/withargs/" "tex/latex/withargs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "06zyvaldbwf80hijp3526qyyrfrbj6zc03fw5pan38gxhin270hg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/withargs")
    (synopsis "In-place argument substitution")
    (description
     "The @code{\\withargs} command provides a clean way to populate
a template (containing @samp{#1}, @samp{#2}, etc.) using LaTeX argument
substitution.  It also allows you to carefully control argument expansion
using a LaTeX3-style argument specification.")
    (license license:lppl1.3+)))

(define-public texlive-wordcount
  (package
    (name "texlive-wordcount")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/wordcount/" "scripts/wordcount/"
                                     "tex/latex/wordcount/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1x4qx3skvlndinligp0k2j8dpgpkim6374vc4fxfjrsd2bhw2fnm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "wordcount.sh")))
    (home-page "https://ctan.org/pkg/wordcount")
    (synopsis "Estimate the number of words in a LaTeX document")
    (description
     "The package provides a relatively easy way of estimating the number of words
in a LaTeX document.  It requires something like Unix @samp{grep -c} that can
search a file for a particular string and report the number of matching lines.
An accompanying shell script @file{wordcount.sh} contains more information in
its comments.")
    (license license:lppl)))

(define-public texlive-wordlike
  (package
    (name "texlive-wordlike")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/wordlike/"
                                     "source/latex/wordlike/"
                                     "tex/latex/wordlike/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04m9syfp78grgxfa0d3vq990381sdrayg1id34gp13c8cl6kxdv8"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/wordlike")
    (synopsis "Simulating word processor layout")
    (description
     "The package simulates typical word processor layout: narrow page margins,
Times, Helvetica and Courier fonts, @code{\\LARGE} or @code{\\Large} headings,
and @code{\\sloppy} typesetting.

The package aims at making life easier for users who are discontent with
LaTeX's standard layout settings because they need a layout that resembles the
usual ``wordlike'' output.")
    (license license:lppl)))

(define-public texlive-worksheet
  (package
    (name "texlive-worksheet")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/worksheet/"
                                     "tex/latex/worksheet/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0bciww1nnjgh7z7w3b5fwh0dr2hbsqw6ymdsx9xxm2ycrxx0lbxk"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/worksheet")
    (synopsis "Easy creation of worksheets")
    (description
     "This package provides macros and an environment for easy worksheet creation:

@itemize

@item use the @code{exercise} environment for formatting exercises in a simple,
efficient design;

@item typeset customized and automatically numbered worksheet titles in the
same way as standard LaTeX titles (using @code{\\maketitle});

@item provide course and author information with
a @code{scrlayer}-@code{scrpage} based automated header; @end itemize

This package conforms to different Babel languages. (Currently English,
French, and German are supported.)")
    (license license:lppl1.3c)))

(define-public texlive-wrapfig2
  (package
    (name "texlive-wrapfig2")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/wrapfig2/"
                                     "source/latex/wrapfig2/"
                                     "tex/latex/wrapfig2/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "155dap0plyrxflhq7qc5906f0sbnkvfrbs8qlwnqd5dsl01wlcqi"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/wrapfig2")
    (synopsis "Wrap text around figures")
    (description
     "This package wrap text around figures.  It is a fork of @code{wrapfig}
package.  It is backwards compatible with the original environments.")
    (license license:lppl1.3c)))

(define-public texlive-wrapstuff
  (package
    (name "texlive-wrapstuff")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/wrapstuff/"
                                     "source/latex/wrapstuff/"
                                     "tex/latex/wrapstuff/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1a5dlivmmpanlk376c3f9hx71cmb2cx0dg8ijhl7bccqic0zx234"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-ctex")))
    (build-system texlive-build-system)
    (native-inputs (list texlive-ctex))
    (home-page "https://ctan.org/pkg/wrapstuff")
    (synopsis "Wrapping text around stuff")
    (description
     "This package provides another implementation of text wrapping.")
    (license license:lppl1.3c)))

(define-public texlive-writeongrid
  (package
    (name "texlive-writeongrid")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/writeongrid/"
                                     "tex/latex/writeongrid/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1zfjnxzbmj1rmzn3nq925ailyj4fy1z3ixv0x0vivjllw27k2zja"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/writeongrid")
    (synopsis "Write on grid lines")
    (description
     "This package provides an environment to create grids (type 5x5 or Seyes or
Ruled) and commands to write texts right on the lines.")
    (license license:lppl1.3c)))

(define-public texlive-wtref
  (package
    (name "texlive-wtref")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/wtref/" "tex/latex/wtref/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "031cfrsvs8m1ci6z1jv4kxiam7mb339l9y4yavwg0qzms7achy4s"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/wtref")
    (synopsis "Extend LaTeX's cross-reference system")
    (description
     "This package extends the cross-reference system of LaTeX2e and introduces
concepts of namespace and scope.  It also allows users to customize reference
formats.")
    (license license:expat)))

(define-public texlive-xargs
  (package
    (name "texlive-xargs")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xargs/" "source/latex/xargs/"
                                     "tex/latex/xargs/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1gbdnc1k819fncvnhzihx9q6qdxsrkpfjy47dh70bdwqf5klhqbh"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments (list #:tex-format "latex"))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-etoolbox
                  texlive-hypdoc
                  texlive-lm
                  texlive-microtype
                  texlive-minitoc
                  texlive-mparhack
                  texlive-xkeyval))))
    (home-page "https://ctan.org/pkg/xargs")
    (synopsis "Define commands with many optional arguments")
    (description
     "The package provides extended versions of @code{\\newcommand} and related
LaTeX commands, which allow easy and robust definition of macros with many
optional arguments, using a clear and simple @code{xkeyval}-style syntax.")
    (license license:lppl)))

(define-public texlive-xassoccnt
  (package
    (name "texlive-xassoccnt")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xassoccnt/"
                                     "tex/latex/xassoccnt/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0b38fjfi9ydm0snkdwmgzm2qrmh32dzl3k8ypj06fwaan7n3341n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xassoccnt")
    (synopsis "Associated counters stepping simultaneously")
    (description
     "This package provides a way of associating counters to an existing driver
counter so that incrementing the driver counter will increase its associated
counters as well.  This package can be regarded as a supplement to the
@code{totcount} package, but it can be used without it, too.

@code{xassoccnt} is a successor and a complete rewrite of the @code{assoccnt}
package.  However, some features of @code{assoccnt} are not (yet) contained in
@code{xassoccnt} so that the older package cannot yet be regarded as
obsolete.")
    (license license:lppl1.3+)))

(define-public texlive-xbmks
  (package
    (name "texlive-xbmks")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xbmks/" "source/latex/xbmks/"
                                     "tex/latex/xbmks/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0sgbd4083kiinhy7wq1fh6apx1ln1pyfkvl6k0822na9cxd2z560"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xbmks")
    (synopsis "Create a cross-document bookmark tree")
    (description
     "The package defines the concept of a document bundle, which is a collection
of documents that are to be built separately, but have a common bookmark
tree.")
    (license license:lppl1.2+)))

(define-public texlive-xcntperchap
  (package
    (name "texlive-xcntperchap")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xcntperchap/"
                                     "tex/latex/xcntperchap/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cbkvf8dw1pi6qr397pf985s4zyvdmc5g87y9jvg9na69v8r4pkj"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xcntperchap")
    (synopsis
     "Track the number of subsections etc., that occur in a specified tracklevel")
    (description
     "This package is the successor of @code{cntperchap} and allows providing more
tracklevels than just only one.")
    (license license:lppl1.3+)))

(define-public texlive-xcolor-material
  (package
    (name "texlive-xcolor-material")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xcolor-material/"
                                     "source/latex/xcolor-material/"
                                     "tex/latex/xcolor-material/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ks2mp2r9dgpp1397ci5qza93cwwc3b02rax1rqs1vpd4bxrklnp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xcolor-material")
    (synopsis "Defines the 256 colors from Google Material Color Palette")
    (description
     "The package is built on top of the great @code{xcolor} package.  It provides
a definition of the Google Material Color Palette for its use in document
writing with LaTeX and friends.")
    (license license:lppl1.3+)))

(define-public texlive-xcolor-solarized
  (package
    (name "texlive-xcolor-solarized")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xcolor-solarized/"
                                     "source/latex/xcolor-solarized/"
                                     "tex/latex/xcolor-solarized/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1jcq23p50syr16hz1hskkwf55whb68sdyyh45y8q3zvh7q7y1qr7"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xcolor-solarized")
    (synopsis
     "Defines the 16 colors from Ethan Schoonover's Solarized palette")
    (description
     "Built on top of the @code{xcolor} package, this package defines the sixteen
colors of Ethan Schoonover's popular color palette, Solarized, for use in
documents typeset with LaTeX and friends.")
    (license license:lppl1.3+)))

(define-public texlive-xcookybooky
  (package
    (name "texlive-xcookybooky")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xcookybooky/"
                                     "source/latex/xcookybooky/"
                                     "tex/latex/xcookybooky/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h0a4y1aax9zkm3mnxjhi8q9s3ql8jg50s88npazac5c2b2f8qxv"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xcookybooky")
    (synopsis "Typeset (potentially long) recipes")
    (description
     "The package enables the user to typeset recipes, which could be greater than
one page.  Above the recipe text two (optional) pictures can be displayed.
Other features are recipe name, energy content, portions, preparation and
baking time, baking temperatures, recipe source and of course preparation
steps and required ingredients.  At the bottom you may insert an optional
hint.  The package depends on the Emerald fonts.")
    (license license:lppl1.3+)))

(define-public texlive-xcpdftips
  (package
    (name "texlive-xcpdftips")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xcpdftips/"
                                     "source/latex/xcpdftips/"
                                     "tex/latex/xcpdftips/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16in0hkr8ij36xxclq6z0rxmkldn0pba49sj3vnfamrgq80r70xg"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xcpdftips")
    (synopsis "@code{natbib} citations with PDF tooltips")
    (description
     "This LaTeX package uses @code{pdfcomment} and @code{bibentry} to surround
@code{natbib} citations with PDF tooltips.")
    (license license:gpl3+)))

(define-public texlive-xdoc
  (package
    (name "texlive-xdoc")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xdoc/" "makeindex/xdoc/"
                                     "source/latex/xdoc/" "tex/latex/xdoc/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0jyvl0xaknycr47rypcvdcriz4kx0kgnvy643p1rgmnjddvarv1n"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xdoc")
    (synopsis "Extending the LaTeX doc system")
    (description
     "Xdoc is a project to rewrite the implementation of the LaTeX @code{doc}
package (in a broader sense) to make its features more general and flexible.
For example, where @code{doc} only provides commands for documenting macros
and environments, @code{xdoc} also provides commands for similarly documenting
package options and switches.  This is furthermore done in such a way that it
is very easy to add more such commands for documenting things, such as e.g.,
templates, and program components for other languages (functions, classes,
procedures, etc.).")
    (license license:lppl)))

(define-public texlive-xellipsis
  (package
    (name "texlive-xellipsis")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xellipsis/"
                                     "source/latex/xellipsis/"
                                     "tex/latex/xellipsis/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1p1xzaprrglliid7zsl4s22zzqd7wrryhn69mdpac267jh8cpxds"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xellipsis")
    (synopsis
     "Extremely configurable ellipses with formats for various style manuals")
    (description
     "The @code{xellipsis} package provides a system for configuring (almomst)
every possible aspect of ellipses, including preceding and proceeding
characters; the character itself; distances before and after each of these;
and number of characters.  It comes with both a compatibility option for
standard LaTeX @code{\\ldots} as well as preset package options for the
@emph{Chicago Manual of Style} (Turabian); the Bluebook; and MLA guidelines.")
    (license license:lppl1.3+)))

(define-public texlive-xfakebold
  (package
    (name "texlive-xfakebold")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xfakebold/"
                                     "tex/latex/xfakebold/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01xccsppabncidpwr24ikcyhfbhaphir2pacj1saw4d2kx6la0lz"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-iftex))
    (home-page "https://ctan.org/pkg/xfakebold")
    (synopsis "Fake a regular font for bold characters")
    (description
     "This package uses PDF's text rendering to modify the linewidth of an outline
font to get bold characters.  It works only for vectorfonts where the glyphs
are defined by their outline.")
    (license license:lppl1.3c)))

(define-public texlive-xhfill
  (package
    (name "texlive-xhfill")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xhfill/" "tex/latex/xhfill/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0a69ri107qpzzhclja1jn01nb33wlzs5g6x8c8k0iz9qzwbrm3by"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xhfill")
    (synopsis "Extending @code{\\hrulefill}")
    (description
     "The package provides extended macros for the default @code{\\hrulefill} command.  It
allows modification of the width and the colour of the line.")
    (license license:lppl)))

(define-public texlive-xint
  (package
    (name "texlive-xint")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/generic/xint/" "source/generic/xint/"
                                     "tex/generic/xint/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dk1rgip7svqzlsvdr67hk9yw3ifak2ka67hpym0hlslmy1igvd2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xint")
    (synopsis "Expandable operations on long numbers")
    (description
     "The @code{xint} bundle modules are:

@itemize

@item @code{xinttools} utilities of independent interest such as expandable
and non-expandable loops,

@item @code{xintcore} expandable macros implementing addition, subtraction,
multiplication, division, and powers for arbitrarily long integers,

@item @code{xint} extension of @code{xintcore}, @code{xintfrac} extends the
scope of @code{xint} to decimal numbers, to numbers using scientific notation
and also to (exact) fractions,

@item @code{xintexpr} expandable parsers of numeric expressions using the
standard infix notations, parentheses, built-in functions, user definable
functions and variables (and more ...), which do either exact
evaluations (also with fractions) or floating point evaluations under a user
chosen precision.

@item @code{xintkernel} supports macros for all the bundle constituents,

@code{xintbinhex} converts to and from hexadecimal and binary bases,

@code{xintgcd} provides @code{gcd()} and @code{lcm()} functions to
@code{xintexpr},

@code{xintseries}, which evaluates numerically partial sums of series and
power series with fractional coefficients,

@item and @code{xintcfrac}, dedicated to the computation and display of
continued fractions).

@end itemize

All computations are compatible with expansion-only context.")
    (license license:lppl1.3c)))

(define-public texlive-xkcdcolors
  (package
    (name "texlive-xkcdcolors")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xkcdcolors/"
                                     "tex/latex/xkcdcolors/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "03smf9r9w3xhjg68magcygyq5mwbcxpq135brkjhrxnzgdjzv4wl"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xkcdcolors")
    (synopsis "XKCD names of colors")
    (description
     "In the year 2010, Randall Munroe on posted a really funny and nice article on
XKCD.  He made a very curious experiment: showing colors to a lot of people
and asking to name each one.  Afterward, he processed the data and sorted the
names for each color by popularity --- that means, how many people gave the
same name to the same color.  This package makes the collected color names
usable with LaTeX.")
    (license (list license:lppl1.3c license:cc0))))

(define-public texlive-xltabular
  (package
    (name "texlive-xltabular")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xltabular/"
                                     "tex/latex/xltabular/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "08wpgf2w0pcl2nqm2mgplxvy9q0zbszd5lm4rqzkz3vyi6zlravm"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xltabular")
    (synopsis "@code{longtable} support with possible X-column specifier")
    (description
     "This package loads package @code{ltablex}, but keeps the current
@code{tabularx} environment as is.  The new environment @code{xltabular} is
a combination of @code{longtable} and @code{tabularx}: Header/footer
definitions, X-column specifier, and with possible pagebreaks.")
    (license license:lppl1.3+)))

(define-public texlive-xnewcommand
  (package
    (name "texlive-xnewcommand")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xnewcommand/"
                                     "tex/latex/xnewcommand/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nicb4v9mxkavsgns37ap9bhi5wc1aqlk82dcsvpysxps1rmmyk4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xnewcommand")
    (synopsis
     "Define @code{\\global} and @code{\\protected} commands with @code{\\newcommand}")
    (description
     "The package provides the means of defining @code{\\global} and (e-TeX)
@code{\\protected} commands, within the framework of LaTeX's standard
@code{\\newcommand}.")
    (license license:lppl)))

(define-public texlive-xoptarg
  (package
    (name "texlive-xoptarg")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xoptarg/" "tex/latex/xoptarg/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "13fifaq7c64rpqaaqj9zlq280ckmzdlqrs4p1gzs1h269p9z8mbf"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xoptarg")
    (synopsis "Expandable macros that take an optional argument")
    (description
     "Commands that take an optional argument are not ordinarily expandable; this
package allows such commands to be expandable provided that they have at least
one mandatory argument.")
    (license license:lppl)))

(define-public texlive-xpunctuate
  (package
    (name "texlive-xpunctuate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xpunctuate/"
                                     "source/latex/xpunctuate/"
                                     "tex/latex/xpunctuate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dx0fjz1ngld8g6f73d5g4ylmpgmmb8s0si1i6rp0im69yf5pr3v"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xpunctuate")
    (synopsis "Process trailing punctuation which may be redundant")
    (description
     "The package provides commands that enable the user (or package writer) to
insert punctuation after the macro.  The package provides the commands
@code{\\xperiod}, @code{\\xcomma} and @code{\\xperiodcomma}, which follow
a similar procedure to that of @code{\\xspace}, and insert punctuation if and
only if it is necessary.")
    (license license:lppl1.2+)))

(define-public texlive-xpeek
  (package
    (name "texlive-xpeek")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xpeek/" "source/latex/xpeek/"
                                     "tex/latex/xpeek/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "01khzfgkvsfs8vs64wym07k5hnaa0rmcgpgajp1q06g5f9shcsjc"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-native-inputs "texlive-updmap.cfg")))
    (build-system texlive-build-system)
    (arguments
     (list #:tex-format "latex"
           #:phases
           #~(modify-phases %standard-phases
               ;; Building documentation, automatic when generating
               ;; runfiles, fails.  Skip building it.
               (add-after 'unpack 'skip-documentation
                 (lambda _
                   (substitute* "source/latex/xpeek/xpeek.dtx"
                     (("\\\\DocInput\\{\\\\jobname\\.dtx\\}") "")))))))
    (native-inputs
     (list (texlive-updmap.cfg
            (list texlive-alphalph
                  texlive-booktabs
                  texlive-csquotes
                  texlive-enumitem
                  texlive-fancyvrb
                  texlive-foreign
                  texlive-hologo
                  texlive-hypdoc
                  texlive-qstest
                  texlive-underscore
                  texlive-xpunctuate))))
    (home-page "https://ctan.org/pkg/xpeek")
    (synopsis "Define commands that peek ahead in the input stream")
    (description
     "The package provides tools to help define commands that, like
@code{\\xspace} and the LaTeX command @code{\\textit}, peek at what
follows them in the command stream and choose appropriate behaviour.")
    (license license:lppl1.3+)))

(define-public texlive-xprintlen
  (package
    (name "texlive-xprintlen")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xprintlen/"
                                     "tex/latex/xprintlen/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0skz6y06wslzf0yb0g101g24kw6bkm9kl825swpqahyzdgwapxw4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xprintlen")
    (synopsis "Print TeX lengths in a variety of units")
    (description
     "The package defines a command, @code{\\printlen}, to print TeX lengths in
a variety of units.  It can handle all units supported by TeX.")
    (license license:lppl1.3+)))

(define-public texlive-xsavebox
  (package
    (name "texlive-xsavebox")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xsavebox/"
                                     "source/latex/xsavebox/"
                                     "tex/latex/xsavebox/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1k055jv83yk17f7l8bvg8mvm7cw7afry7sykli4fbz8w0yjq3yci"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xsavebox")
    (synopsis "Saveboxes for repeating content without code replication")
    (description
     "The package defines commands for saving content that can be repeatedly placed
into the document without replicating DVI/PDF code in the output file,
allowing for smaller file size of the final PDF and improved content caching
for faster display in certain PDF viewers.  The method makes use of Form
XObjects defined in the PDF specification.  The user commands are modelled
after the standard LaTeX commands @code{\\savebox}, @code{\\sbox},
@code{\\usebox} and the @code{lrbox} environment.")
    (license license:lppl)))

(define-public texlive-xsim
  (package
    (name "texlive-xsim")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xsim/" "tex/latex/xsim/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dalnjkisyk4ixxqpim5hvjzi9sn71gjiygj08ix0ifpbix9hqn2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xsim")
    (synopsis "@acronym{XSIM, eXercise Sheets IMproved}")
    (description
     "This package helps in creating exercises and the corresponding solutions.  It
is the official successor of the @code{exsheets} package and fixes/improves
various long-standing issues.")
    (license license:lppl1.3c)))

(define-public texlive-xtab
  (package
    (name "texlive-xtab")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xtab/" "source/latex/xtab/"
                                     "tex/latex/xtab/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0d9rc8dwirxlzvyfrwf884achshimcrz99c2d57gad2097c6qkd6"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xtab")
    (synopsis "Break tables across pages")
    (description
     "Xtab is an extended and somewhat improved version of @code{supertabular}; its
@code{xtabular} environment provides tables that break across pages.")
    (license license:lppl)))

(define-public texlive-xurl
  (package
    (name "texlive-xurl")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xurl/" "tex/latex/xurl/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0g03b27vg4qmprjy7jlpvpvq0223xsjfd6ynhsfwglqva3yq70ri"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xurl")
    (synopsis "Allow URL breaks at any alphanumerical character")
    (description
     "This package loads @code{url} by default and defines possible URL breaks for
all alphanumerical characters, as well as @samp{=}, @samp{/}, @samp{.},
@samp{:}, @samp{*}, @samp{-}, @samp{~}, and @samp{\"}.  All arguments which
are valid for @code{url} can be used and will be passed on to this package.")
    (license license:lppl1.3+)))

(define-public texlive-xwatermark
  (package
    (name "texlive-xwatermark")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xwatermark/"
                                     "tex/latex/xwatermark/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1xisq0xg5jl7id4ajl0ywjz8d8s8bzl4qy8sxg0rya3p013p5990"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xwatermark")
    (synopsis "Graphics and text watermarks on selected pages")
    (description
     "The package extends @code{draftmark} and the @code{watermark} packages.  It
is currently unmaintained and does not work with modern LaTeX releases.")
    (license license:lppl1.3+)))

(define-public texlive-xytree
  (package
    (name "texlive-xytree")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/xytree/" "tex/latex/xytree/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0l0is0a46zp21qswwdb5rbjh4ap61lm5d581j5q9baiycmxk4ban"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/xytree")
    (synopsis "Tree macros using XY-Pic")
    (description
     "The package provides means to draw linguistic syntactic trees with ease and
to support hopefully sufficient functionalities, that the linguist may need.")
    (license license:lppl)))

(define-public texlive-yafoot
  (package
    (name "texlive-yafoot")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/yafoot/" "source/latex/yafoot/"
                                     "tex/latex/yafoot/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "04p8qlk7nbrapr2gggkqm2iqgq36ywh7a7iqawmmqhsqnmz501cp"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/yafoot")
    (synopsis "Bundle of miscellaneous footnote packages")
    (description
     "This package contains three packages: @code{pfnote} to number footnotes per page,
@code{fnpos} to control the position of footnotes, and @code{dblfnote} to make
footnotes double-columned.")
    (license license:lppl)))

(define-public texlive-yagusylo
  (package
    (name "texlive-yagusylo")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/yagusylo/"
                                     "source/latex/yagusylo/"
                                     "tex/latex/yagusylo/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0y2fgfj21m15n44xc6i996rgyf4wpg7wjk0db6cyc5wb7q012270"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/yagusylo")
    (synopsis "Symbol loader")
    (description
     "The package allows the user to access a symbol without loading the package
that usually provides it; this has the advantage of avoiding the name clashes
that so commonly trouble those who load symbol-packages.")
    (license license:lppl)))

(define-public texlive-yaletter
  (package
    (name "texlive-yaletter")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/yaletter/"
                                     "source/latex/yaletter/"
                                     "tex/latex/yaletter/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1ak35xs7b7v5314nic8mb158828rnq1bv53v412ad2zmsha7wrg9"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/yaletter")
    (synopsis
     "Extremely flexible macros for letters, envelopes, and label sheets")
    (description
     "The @code{yaletter} class provides extremely configurable macros for
typesetting letters in any conceivable style.  It provides facilities for
maintaining easily-accessible databases of letterheads and addresses for
repeat use.  It further provides easy macros for envelopes and for label
sheets.  Finally, it provides some nice defaults for a few of the more common
styles and sizes.")
    (license license:lppl1.3+)))

(define-public texlive-ycbook
  (package
    (name "texlive-ycbook")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ycbook/" "tex/latex/ycbook/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ikjh157df0l2yq8whpsizs32i92xg8am65migbjq6pfm57bph70"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ycbook")
    (synopsis "Versatile book class")
    (description
     "This class is intended to be an interpretation of the @code{mwbk} class which
is a part of the @code{mwcls} package.  The @code{mwcls} classes are simple,
yet powerful and customizable classes that allow the end-user to customize the
layout of headers, headings etc.  They also have the benefit of being more
economic in space than the most common LaTeX classes, while keeping a clear
appearance and a smooth flow.")
    (license license:lppl1.3c)))

(define-public texlive-yplan
  (package
    (name "texlive-yplan")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/yplan/" "scripts/yplan/"
                                     "tex/latex/yplan/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0cwd7yzmsp3jxb9190cqy05mbp40kw5qx1fjc7f8rbf5m2dfcbb7"))))
    (outputs '("out" "doc"))
    (properties '((updater-extra-inputs "perl")))
    (build-system texlive-build-system)
    (arguments (list #:link-scripts #~(list "yplan")))
    (inputs (list perl))
    (home-page "https://ctan.org/pkg/yplan")
    (synopsis "Daily planner type calendar")
    (description
     "This package prints two six-monthly vertical-type daily planner (i.e.,
months along the top, days downwards), with each 6-month period fitting onto
a single A4 (or US letter) sheet.  The package offers support for English,
French, German, Spanish and Portuguese.  The previous scheme of annual updates
has now been abandoned, in favour of a Perl script @command{yplan} that
generates a year's planner automatically.")
    (license license:lppl)))

(define-public texlive-zebra-goodies
  (package
    (name "texlive-zebra-goodies")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/zebra-goodies/"
                                     "source/latex/zebra-goodies/"
                                     "tex/latex/zebra-goodies/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0ggrcldhcxgbh7jbn13kkss5qxxs0qg7664vs6jrm66bvivb346g"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/zebra-goodies")
    (synopsis "Collection of handy macros for paper writing")
    (description
     "This package offers a collection of macros to help in the process of writing
a paper.  You may add comments, todo notes, etc.,during revision, in
a colourful way.  The package also summarizes the inserted notes at the end of
the document.  There are some predefined note commands as well as a way of
defining new ones to suit the user's needs.  You may safely remove this
package once the paper is finished.")
    (license license:lppl1.3c)))

(define-public texlive-zed-csp
  (package
    (name "texlive-zed-csp")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/zed-csp/" "tex/latex/zed-csp/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "16xv24vf6d3znfa2a6qhbz7hgq3s5n8fg8i8h07i9rf008apja0d"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/zed-csp")
    (synopsis "Typesetting Z and CSP format specifications")
    (description
     "The package supports real-time CSP and incorporates the functionality of
Spivey's original Z package, written for LaTeX 2.09.")
    ;; "You may copy and distribute this file freely."
    (license (license:non-copyleft "file://tex/latex/zed-csp/zed-csp.sty"))))

(define-public texlive-zennote
  (package
    (name "texlive-zennote")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/zennote/" "tex/latex/zennote/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0iviklm37rdzn7fbq8i6kn5hfj3kqh32pz5pamr1bg52whvn0ly2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/zennote")
    (synopsis "Streamline your note-taking process")
    (description
     "This package aims to provide you with an easy interface to speed up the
process when organizing and producing elegant notes.  All the tables, figures,
equations, and listings are labelled according to the notenumber with the
@code{\\titlebox} command.  The @code{noteframe} environment helps you
generate fancy colored boxes to emphasize the important
information (e.g. theorems, equations, proofs, etc.) in your document.  You
can customize the style and color to denote different categories, too.")
    (license license:cc-by4.0)))

(define-public texlive-ziffer
  (package
    (name "texlive-ziffer")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/ziffer/" "tex/latex/ziffer/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "073w0rpkf7g1pjy4i30x20g7k0wksqpwi2288ly2fz4b2d66aafc"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/ziffer")
    (synopsis "Conversion of punctuation in maths mode")
    (description
     "The package modifies the behaviour of characters in maths mode so that:

@itemize

@item @samp{.} is used as a one-thousand separator (as is common in Germany);

@item @samp{,} is used as a decimal separator (as is common in Germany);

@item @samp{--} is represented with spacing as appropriate to such constructs
as @samp{1.000,--}.

@end itemize

These conversions may be switched on and off.")
    (license license:lppl)))

(define-public texlive-zref-check
  (package
    (name "texlive-zref-check")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/zref-check/"
                                     "source/latex/zref-check/"
                                     "tex/latex/zref-check/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0dx7jsyrlcd6a323lgcknkffx9lrvcmcvww4v6154inda33l5vw4"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/zref-check")
    (synopsis "Flexible cross-references with contextual checks based on @code{zref}")
    (description
     "This package provides an user interface for making LaTeX cross-references
flexibly, while allowing to have them checked for consistency with the
document structure as typeset.  Statements such as @samp{above}, @samp{on the
next page}, @samp{previously}, can be given to @code{\\zcheck} in free-form,
and a set of checks can be specified to be run against a given label, which
will result in a warning at compilation time if any of these checks fail.
@code{\\zctarget} and the @code{zcregion} environment are also defined as
a means to easily set label targets to arbitrary places in the text which can
be referred to by @code{\\zcheck}.")
    (license license:lppl1.3c)))

(define-public texlive-zref-clever
  (package
    (name "texlive-zref-clever")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/zref-clever/"
                                     "source/latex/zref-clever/"
                                     "tex/latex/zref-clever/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0h50xvkfy68672wd9nh52zq4cyx1965rv0dihg4jp5vd19dw1na2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/zref-clever")
    (synopsis "Clever LaTeX cross-references based on @code{zref}")
    (description
     "This package provides a user interface for making LaTeX cross-references
which automates some of their typical features, thus easing their input in the
document and improving the consistency of typeset results.  A reference made
with @code{\\zcref} includes a name according to its type, and lists of
multiple labels can be automatically sorted and compressed into ranges when
due.  The reference format is highly and easily customizable, both globally
and locally.")
    (license license:lppl1.3c)))

(define-public texlive-zref-vario
  (package
    (name "texlive-zref-vario")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/zref-vario/"
                                     "source/latex/zref-vario/"
                                     "tex/latex/zref-vario/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0nq0g0ql31fkck13wsmjvk1dm6rwj94g3b9hr0y6g9qpzrqdzfw2"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (propagated-inputs (list texlive-tools texlive-zref-clever))
    (home-page "https://ctan.org/pkg/zref-vario")
    (synopsis
     "Extended cross-references with @code{varioref} and @code{zref-clever}")
    (description
     "This package offers a compatibility layer for @code{varioref} to be used
alongside @code{zref-clever}.  It provides @samp{\\z...}  counterparts to
@code{varioref}'s main reference commands, each of which essentially does
some (scoped) setup for @code{varioref}, then calls the original one.")
    (license license:lppl1.3c)))

(define-public texlive-zwgetfdate
  (package
    (name "texlive-zwgetfdate")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/zwgetfdate/"
                                     "tex/latex/zwgetfdate/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1qkipas5qrrxvjvm08fws45vfqg87qz3x4ghpgcmipd91ydcaxc3"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/zwgetfdate")
    (synopsis "Get package or file date")
    (description
     "The package can fetch the date declaration of packages and files used by
a document, and then provide the information in macros.  The facilities
provide a means of obtaining the date of a package being documented.")
    (license license:lppl1.3+)))

(define-public texlive-zwpagelayout
  (package
    (name "texlive-zwpagelayout")
    (version "2024.2")
    (source (origin
              (method svn-multi-fetch)
              (uri (svn-multi-reference
                    (url (texlive-packages-repository version))
                    (revision 70951)
                    (locations (list "doc/latex/zwpagelayout/"
                                     "tex/latex/zwpagelayout/"))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "0wvdx8jgvxpxln61xbh4lyd95r6g1dnjmhy1vjsqqdhqwwgch40x"))))
    (outputs '("out" "doc"))
    (build-system texlive-build-system)
    (home-page "https://ctan.org/pkg/zwpagelayout")
    (synopsis "Page layout and crop-marks")
    (description
     "This package was developed as a typographers toolbox offering important
basic features for everyday work.  It allows setting the paper size and the
page layout; it can print crop marks; and it can reflect pages both
horizontally and vertically.")
    (license license:lppl)))

;;;
;;; Avoid adding new packages to the end of this file. To reduce the chances
;;; of a merge conflict, place them above by existing packages with similar
;;; functionality or similar names.
;;;
